package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AcbameVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Btnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Acbgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Toegrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 入汇账户备案取消
*/
@Transaction(vo= AcbameVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Acbame extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Acbame.class);

        //备案账户取消
        private transient IControl cslacb = new ControlImpl("cslacb", "备案账户取消", this);
        //查询
        private transient IControl quepty = new ControlImpl("quepty", "查询", this);
        //下一步
        private transient IControl nxt = new ControlImpl("nxt", "下一步", this);
		@BDGetter
		private Acbgrp acbgrp;

		@BDGetter
		private Toegrp toegrp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Btnmod btnmod;


		public Acbame()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new java.math.BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:acbame.@0000.script
        */
        @Rule(target="quepty",order=100)
        public boolean ruleQueptyN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getAcbgrp().getRec().getInwardacct()) && MdaUtils.isEmpty(this.getAcbgrp().getPty().getCid()) && MdaUtils.isEmpty(this.getAcbgrp().getRec().getSocialcrdtcd()))
			{
			  ctx.setFieldError(this,"quepty",MdaUtils.getI18NString("acbame","CT000026"));
			  return true;
			}
			String sql = "select distinct pty.inr ptyinr,acb.inwardacct inwardacct, pty.cid cid, pty.nam  nam,acb.socialcrdtcd socialcrdtcd from pty left join acb on pty.cifno = acb.socialcrdtcd where (acb.isuse <> 'N' or acb.isuse is null) ";
			if(!MdaUtils.isEmpty(this.getAcbgrp().getRec().getInwardacct()))
			{
			  sql = sql+" and acb.inwardacct = '" + this.getAcbgrp().getRec().getInwardacct() + "'";
			}
			if(!MdaUtils.isEmpty(this.getAcbgrp().getPty().getCid()))
			{
			  sql = sql+" and pty.cid = '" + this.getAcbgrp().getPty().getCid() + "'";
			}
			if(!MdaUtils.isEmpty(this.getAcbgrp().getRec().getSocialcrdtcd()))
			{
			  sql = sql+" and acb.socialcrdtcd = '" + this.getAcbgrp().getRec().getSocialcrdtcd() + "'";
			}
			log.info("{}","query:"+sql );
			ctx.getDaoSession().dbExecuteSQL(sql);

			Argument<String> ptyinr = new Argument<String>("ptyinr");
			Argument<String> inwardacct = new Argument<String>("inwardacct");
			Argument<String> cid = new Argument<String>("cid");
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> socialcrdtcd = new Argument<String>("socialcrdtcd");

			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(ptyinr,inwardacct,cid,nam,socialcrdtcd);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getAcbgrp().getPty().setInr(ptyinr.value);
			    this.getAcbgrp().getRec().setInwardacct(inwardacct.value);
			    this.getAcbgrp().getPty().setCid(cid.value);
			    this.getAcbgrp().getPty().setNam(nam.value);
			    this.getAcbgrp().getRec().setSocialcrdtcd(socialcrdtcd.value);

			  }
			  else if(errorCode == NO_MORE_ROW)
			  {

			    log.info("{}","no more row!!");
			    break;
			  }
			  else
			  {
			    log.error("{}","errorCode:"+errorCode);
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			
			
			
			


			return true;
        }

        /**
        *   source:acbame.@0001.script
        */
        @Rule(target="nxt",order=100)
        public boolean ruleNxtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getAcbgrp().getPty().getInr()))
			{
			  ctx.setFieldError(this,"nxt",MdaUtils.getI18NString("acbame","CT000031"));
			  return true;
			}
			else
			{
			  
			  this.loadAcb();
			}

			return true;
        }

        /**
        *   source:acbame.@0003.script
        */
        @Rule(target="cslacb",order=100)
        public boolean ruleCslacbN100(){
            IContext ctx = MdaEnv.getContext();
            

			int index = -1;
			int count = 0;
			int length = this.getAcbgrp().getAcblst().fullSize();
			for(int i=0;i<length;i++)
			{
			  if(!"X".equals(this.getAcbgrp().getAcblst().getElement(i).getAcbflg()))
			    continue;
			  index=i;
			  ++count;
			}

			//int index = Platform.getSelectedRowIndex($acbgrp\\acblst);
			// int length = $acbgrp\\acblst.fullSize();
			if( index < 0   ||   index > length )
			{
			  ctx.setMessage("",MdaUtils.getI18NString("acbame","CT000033"));
			  return true;
			}

			if(MdaUtils.prompt(MdaUtils.getI18NString("acbame","CT000034"),MdaUtils.getI18NString("acbame","CT000035")))
			  return true;

			ctx.getDaoSession().dbBegin();
			//Platform.clear($acbgrp\\rec);
			ctx.getDaoSession().dbRead(this.getAcbgrp().getRec(),new Argument<String>("inr",this.getAcbgrp().getAcblst().getElement(index).getInr()));
			this.getAcbgrp().getRec().setIsuse("N");
			ctx.getDaoSession().dbUpdate(this.getAcbgrp().getRec());
			ctx.getDaoSession().dbCommit();
			


			return true;
        }




        /**
        *   source:acbame.@0002.script
        */
        public void loadAcb()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","社会信用证代码：" + this.getAcbgrp().getRec().getSocialcrdtcd());
			MdaUtils.clear(this.getAcbgrp().getAcblst());
			ctx.getDaoSession().dbReadset(this.getAcbgrp().getAcblst(),new Argument<String>("socialcrdtcd",this.getAcbgrp().getRec().getSocialcrdtcd()));
		}










}