package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AcbopnVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Btnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Acbp;
import com.ceb.gjjs.mda.manager.module.Swmmod;
import com.ceb.gjjs.mda.manager.module.Acbgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 收汇账号备案申请
*/
@Transaction(vo= AcbopnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Acbopn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Acbopn.class);

		@BDGetter
		private Acbgrp acbgrp;

		@BDGetter
		private Acbp acbp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Swmmod swmmod;

		@BDGetter
		private Btnmod btnmod;


		public Acbopn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAcbp().setAcbgrpHolder(()->this.getAcbgrp());
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:acbopn.@0001.script
        */
        @Rule(target="acbp.exit",order=100)
        public boolean ruleAcbpExitN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:acbopn.@0002.script
        */
        @Rule(target="acbp.save",order=100)
        public boolean ruleAcbpSaveN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getAcbgrp().getRec().getBchcod()))
			{
			  ctx.setFieldError(this,"acbgrp.rec.bchcod",MdaUtils.getI18NString("acbopn","CT000012"));
			  return false;
			}
			if(!ctx.checkAll(this.getAcbgrp()))
			{
			  return false;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("acbopn","CT000013"),MdaUtils.getI18NString("acbopn","CT000014")))
			{
			  return false;
			}
			if(!MdaUtils.isEmpty(this.getAcbgrp().getRec().getReason()))
			{
			  this.getAcbgrp().getRec().setReason(NULLSTR);
			  
			}
			String cifno = this.getAcbgrp().getRec().getSocialcrdtcd();
			if(!ctx.absGet(Sysmod.class).judgeSWFunctions("open_account",cifno,""))
			{
			  log.info("{}","该客户尚未签约或未签约该功能，请退回该笔业务!");
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000015"),MdaUtils.getI18NString("acbopn","CT000016"));
			  return false;
			}
			//国结系统查询该账号
			String inact = this.getAcbgrp().getRec().getInwardacct();
			String cid = this.getAcbgrp().getRec().getCusid();

			Object resMsg = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","getstlact","getstlact",new Object[]{inact,cid,cifno});
			String inr = "";
			String cur ="";
			String dyckflg = "";
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Map map =  (Map)MdaUtils.invoke(resMsg,"getContent");
			  String errorCode = (String)map.get("errorCode");
			  String  errorMsg= (String)map.get("errorMsg");
			  log.info("{}","errorCode "+errorCode);
			  if(!MdaUtils.isEmpty(errorCode) && "000000".equals(errorCode))
			  {
			    inr = (String)map.get("inr");
			    cur = (String)map.get("cur");
			    dyckflg = (String)map.get("DYCKFLG");
			  }
			  else
			  {
			    //errorMsg = "国结系统接口调用异常:"+errorMsg;
			    ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000017"),errorMsg);
			    return false;
			  }

			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000107"),MdaUtils.getI18NString("acbopn","CT000108"));
			  return false;
			}
			if(MdaUtils.isEmpty(inr))
			{
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000109"),MdaUtils.getI18NString("acbopn","CT000452"));
			  return false;
			}
			//新增信息
			String result="01";//01:成功；02:失败
			String reason="";
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			//根据操作类型执行具体操作:A添加 D 删除
			String optyp = this.getAcbgrp().getRec().getOpttype();
			resMsg = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","updstlact","updstlact",new Object[]{inact,cid,cifno,optyp});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Map map =  (Map)MdaUtils.invoke(resMsg,"getContent");
			  String errorCode = (String)map.get("errorCode");
			  String  errorMsg= (String)map.get("errorMsg");
			  if(!MdaUtils.isEmpty(errorCode) && "000000".equals(errorCode))
			  {
			    inr = (String)map.get("inr");
			    log.info("{}","汇入账号国结备案成功!");
			  }
			  else
			  {
			    // errorMsg = "国结系统接口调用异常:"+errorMsg;
			    ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000453"),errorMsg);
			    ctx.getDaoSession().dbRollback();
			    return false;
			  }
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000454"),MdaUtils.getI18NString("acbopn","CT000455"));
			  ctx.getDaoSession().dbRollback();
			  return false;
			}

			//if("A".equals(optyp))
			//{
			//E结算账号备案
			MdaUtils.clear(this.getAcbgrp().getAct());
			ctx.getDaoSession().dbRead(this.getAcbgrp().getAct(),new Argument<String>("act",inact));

			ctx.getDaoSession().dbRead(this.getAcbgrp().getSwinfo(),new Argument<String>("cifno",this.getAcbgrp().getRec().getSocialcrdtcd()));

			MdaUtils.clear(this.getAcbgrp().getPtys());
			ctx.getDaoSession().dbRead(this.getAcbgrp().getPtys(),new Argument<String>("cid",this.getAcbgrp().getRec().getBchcod()));
			this.getAcbgrp().getAct().setBelbchinr(this.getAcbgrp().getPtys().getInr());
			this.getAcbgrp().getAct().setBelbchnam(this.getAcbgrp().getPtys().getNam());

			this.getAcbgrp().getAct().setCur(cur);
			this.getAcbgrp().getAct().setDelflg(optyp);
			this.getAcbgrp().getAct().setActflg("D");     //D:单一窗口备案账号标志
			this.getAcbgrp().getAct().setNam("单一窗口汇入账号");
			this.getAcbgrp().getAct().setAct(inact);
			this.getAcbgrp().getAct().setPtyinr(this.getAcbgrp().getSwinfo().getCidptyinr());
			this.getAcbgrp().getAct().setCredat(MdaUtils.today());
			if(MdaUtils.isEmpty(this.getAcbgrp().getAct().getInr()))
			{
			  this.getAcbgrp().getAct().setInr(Platform.sdbCounter("act"));
			  ctx.getDaoSession().dbInsert(this.getAcbgrp().getAct());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getAcbgrp().getAct());
			}
			// }
			this.getAcbgrp().getRec().setResult("01");
			/*if(Platform.isEmpty($acbgrp\\rec\\inr))
			  {
			  $acbgrp\\rec\\inr.setValue(Platform.sdbCounter("acb"));
			  Platform.dbInsert($acbgrp\\rec);
			  }*/
			ctx.getDaoSession().dbUpdate(this.getAcbgrp().getRec());
			//转历史
			if(!MdaUtils.isEmpty(this.getAcbgrp().getRec().getBchcod()))
			{
			  String bchcod =this.getAcbgrp().getRec().getBchcod();
			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}
			String tst="";
			if("A".equals(optyp))
			  tst="汇入账号备案成功!";
			else
			  tst="汇入账号删除成功!";

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"经办,"+tst;

			this.getTrnmod().goHistory(this.getAcbgrp().getRec().getInr(),"acb",ctx.getTransName(),this.getAcbp().getAcbopn(),txt);
			log.info("{}","after history :"+ctx.getErrorCode());
			//根据处理结果返回单一窗口
			//发送业务报文给单一窗口
			Map map = new HashMap();
			map.put("code","SFS115");
			this.getSysmod().setSwHeaderMap("SFS115","",map,this.getAcbgrp().getRec().getMsgref());
			map.put("Result",this.getAcbgrp().getRec().getResult());
			this.getSwmmod().storeSWM("SFS115",this.getAcbgrp().getRec().getInr(),"acb",map);
			log.info("{}","after storeSWM :"+ctx.getErrorCode());
			//根据处理结果返回单一窗口
			/* Map rst = $sysmod.retSW("SFS115",map,null);
			  //判断处理结果，给出提示
			  String code = (String) rst.get("code");
			  if(Platform.isEmpty(code))
			  {
			  Platform.message(#CT000456,#CT000457);
			  Platform.dbRollback();
			  return false;
			  }
			  else
			  {
			  if(!"000000".equals(code))
			  {
			  String des = (String) rst.get("des");
			  Platform.message(#CT000458,des);
			  Platform.dbRollback();
			  return false;
			  }
			  }
			  */
			ctx.getDaoSession().dbCommit();
			int err = ctx.getErrorCode();
			log.info("{}","commit errorcode "+err);
			if(err == NO_ERROR)
			{
			  if("A".equals(optyp))
			    ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000459"),MdaUtils.getI18NString("acbopn","CT000460"));
			  else
			    ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000461"),MdaUtils.getI18NString("acbopn","CT000469"));
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000474"),MdaUtils.getI18NString("acbopn","CT000475"));
			  return false;
			}
			

			return true;
        }

        /**
        *   source:acbopn.@0003.script
        */
        @Rule(target="acbp.tohistory",order=100)
        public boolean ruleAcbpTohistoryN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*if(Platform.isEmpty($acbgrp\\rec\\bchcod.getValue()))
			  {
			  Platform.error($acbgrp\\rec\\bchcod,#CT000097);
			  return false;
			  }*/
			if(MdaUtils.prompt(MdaUtils.getI18NString("acbopn","CT000098"),MdaUtils.getI18NString("acbopn","CT000099")))
			{
			  return false;
			}
			if(MdaUtils.isEmpty(this.getAcbgrp().getRec().getReason()))
			{
			  ctx.setFieldError(this,"acbgrp.rec.reason",MdaUtils.getI18NString("acbopn","CT000100"));
			  return false;
			}
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			this.getAcbgrp().getRec().setResult("02");
			if(MdaUtils.isEmpty(this.getAcbgrp().getRec().getInr()))
			{
			  this.getAcbgrp().getRec().setInr(Platform.sdbCounter("acb"));
			  ctx.getDaoSession().dbInsert(this.getAcbgrp().getRec());
			}
			ctx.getDaoSession().dbUpdate(this.getAcbgrp().getRec());
			if(!MdaUtils.isEmpty(this.getAcbgrp().getRec().getBchcod()))
			{
			  String bchcod =this.getAcbgrp().getRec().getBchcod();
			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"退回,退回原因："+this.getAcbgrp().getRec().getReason();

			this.getTrnmod().goHistory(this.getAcbgrp().getRec().getInr(),"acb",ctx.getTransName(),this.getAcbp().getAcbopn(),txt);
			//根据处理结果返回单一窗口
			//发送业务报文给单一窗口
			Map map = new HashMap();
			map.put("code","SFS115");
			this.getSysmod().setSwHeaderMap("SFS115","",map,this.getAcbgrp().getRec().getMsgref());
			map.put("Result",this.getAcbgrp().getRec().getResult());
			map.put("Reason",this.getAcbgrp().getRec().getReason());
			this.getSwmmod().storeSWM("SFS115",this.getAcbgrp().getRec().getInr(),"acb",map);
			/*Map rst = $sysmod.retSW("SFS115",map,null);
			  //判断处理结果，给出提示
			  String code = (String) rst.get("code");
			  if(Platform.isEmpty(code))
			  {
			  Platform.message(#CT000101,#CT000102);
			
			  Platform.dbRollback();
			  return false;
			  }
			  else
			  {
			  if(!"000000".equals(code))
			  {
			  String des = (String) rst.get("des");
			  Platform.message(#CT000103,des);
			  Platform.dbRollback();
			  return false;
			  }
			  }*/
			ctx.getDaoSession().dbCommit();
			int err = ctx.getErrorCode();
			log.info("{}","commit errorcode "+err);
			if(err != NO_ERROR)
			{
			  //  Platform.dbRollback();
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000104"),MdaUtils.getI18NString("acbopn","CT000105"));
			  return false;
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acbopn","CT000106"),MdaUtils.getI18NString("acbopn","CT000467"));
			}
			

			return true;
        }



        /**
        *   source:acbopn.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			IModule mdl = (IModule)ctx.restoreData("com.brilliance.acbopn.ref");
			if(!MdaUtils.isEmpty(mdl))
			  this.getAcbgrp().getRec().copyValue(mdl);

			Date today = MdaUtils.today();
			this.getAcbgrp().getRec().setCredat(today);

			ctx.getDaoSession().dbRead(this.getAcbgrp().getPty(),new Argument<String>("cifno",EQ,this.getAcbgrp().getRec().getSocialcrdtcd()));
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodFlg(this.getAcbgrp().getPty().getInr(),this.getAcbgrp().getRec().getBchcod());
			MdaUtils.setValues(this.getAcbgrp().getRec(),"bchcod",bchcod);
			String objinr = this.getAcbgrp().getRec().getInr();
			String objtyp = "acb";
			MdaUtils.clear(this.getTrnmod().getBnktrn());
			ctx.getDaoSession().dbRead(this.getTrnmod().getBnktrn(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp",objtyp));
			
			
			
			
			
			
			
			

			return true;
        }










}