package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AcbselVO;

import com.ceb.gjjs.mda.bo.Acblst;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Acbp;
import com.ceb.gjjs.mda.manager.module.Acbgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Acbmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 汇入备案账号信息查询
*/
@Transaction(vo= AcbselVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Acbsel extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Acbsel.class);

        //查询
        private transient IControl serachs = new ControlImpl("serachs", "查询", this);
        //开始日期
        private Date stadat;
        //结束日期
        private Date stodat;
        //导出
        private IStream download = new StreamImpl();
        //归属机构
        private String ptynam;
		@BDGetter
		private Acbgrp acbgrp;

		@BDGetter
		private Acbp acbp;

		@BDGetter
		private Acbmod acbmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private ModuleList<Acblst> acblst;


		public Acbsel()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAcbp().setAcbgrpHolder(()->this.getAcbgrp());
           this.getAcbmod().setAcbgrpHolder(()->this.getAcbgrp());
        }

        /**
        *   source:acbsel.@0000.script
        */
        @Rule(target="download",order=100)
        public boolean ruleDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream is=this.getDownload();
			is.setType("xls");

			List<Object[]>list=new ArrayList<Object[]>();
			String []tit=new String[5];
			//tit[0] = "备案业务编号";
			tit[0] = "客户名称";
			tit[1] = "统一社会信用代码";
			tit[2] = "备案账号";
			tit[3] = "备案时间";
			tit[4] = "业务归属机构";

			list.add(tit);
			int len=this.getAcblst().fullSize();
			log.debug("{}","数据条数：  "+len);
			for(int i=0;i<len;i++)
			{
			  String []lins=new String[5];
			  //lins[0]=$acblst[i]\\ownref.getValue();
			  lins[0]=this.getAcblst().getElement(i).getNam();
			  lins[1]=this.getAcblst().getElement(i).getSocialcrdtcd();
			  lins[2]=this.getAcblst().getElement(i).getInwardacct();

			  if(!MdaUtils.isEmpty(this.getAcblst().getElement(i).getCredat()))
			    lins[3]=MdaUtils.format(this.getAcblst().getElement(i).getCredat(),"yyyy/MM/dd HH:mm:ss");
			  else
			    lins[3]="";

			  lins[4]=this.getAcblst().getElement(i).getPnam();
			  list.add(lins);
			}

			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH_mm_ss");
			String fileName = "汇入绑定账号信息-"+today+".xls";
			try
			{
			  is.setName(new String(fileName.getBytes("GBK"),"GBK"));
			}
			catch(Exception e)
			{
			}

			MdaUtils.unloadExcel(list,is,false);


			return true;
        }

        /**
        *   source:acbsel.@0004.script
        */
        @Rule(target="serachs",order=100)
        public boolean ruleSerachsN100(){
            IContext ctx = MdaEnv.getContext();
            
			doFresh();

			return true;
        }



        /**
        *   source:acbsel.@0003.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.setStadat(MdaUtils.add(MdaUtils.today(),-15));
			this.setStodat(MdaUtils.today());
			
			

			List<CodetableItem> bchcod=this.getSysmod().getBranchList(this.getSysmod().getPty().getCid());
			MdaUtils.setValues(this,"ptynam",bchcod);
			if(!MdaUtils.isEmpty(bchcod))
			  this.setPtynam(bchcod.get(0).getValue());

			doFresh();

			return true;
        }


        /**
        *   source:acbsel.@0001.script
        */
        public void doFresh()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Date sta=this.getStadat();
			Date sto=this.getStodat();
			if(MdaUtils.isEmpty(sta) || MdaUtils.isEmpty(sto))
			{
			  if(MdaUtils.isEmpty(sta))
			    ctx.setFieldError(this,"stadat",MdaUtils.getI18NString("acbsel","CT000023"));
			  else
			    ctx.setFieldError(this,"stodat",MdaUtils.getI18NString("acbsel","CT000024"));
			  return ;
			}

			MdaUtils.clear(this.getAcblst());
			String ptynam=this.getPtynam();
			String sql="";
			Argument<String> inr =new Argument<String>("inr");
			Argument<String> inwardacct =new Argument<String>("inwardacct");
			//Argument<String> ownref =new Argument<String>("ownref");
			Argument<String> minr =new Argument<String>("minr");
			Argument<String> socialcrdtcd =new Argument<String>("socialcrdtcd");
			Argument<Date> credat =new Argument<Date>("credat");
			Argument<String> pinr=new Argument<String>("pinr");
			Argument<String> nam =new Argument<String>("nam");
			Argument<String> pnam =new Argument<String>("pnam");

			sql="SELECT a.inr,a.ptyinr minr,a.act inwardacct,m.cifno socialcrdtcd,credat,a.belbchinr pinr,m.nam,a.belbchnam pnam FROM act a,pty m WHERE a.actflg='D' AND a.delflg='A' and a.ptyinr=m.inr  ";

			sql=sql+" AND credat>=? AND credat<=?";
			String ptyinr=this.getSysmod().getPty().getInr();
			String lvl=this.getSysmod().getPty().getLvl();
			String  cid=this.getSysmod().getPty().getCid();
			if(!MdaUtils.isEmpty(this.getPtynam())&&!"ptynam".equals(ptyinr))   //获取机构主键和机构等级
			{
			  ptyinr=ptynam;
			  lvl=this.getSysmod().getBchmod().getBranchLvlByInr(ptyinr);
			  cid=this.getSysmod().getCidByInr(ptyinr);
			}
			log.debug("{}","ptyinr    lvl   cid="+ptyinr+ "   "+lvl+"   "+cid);

			if("0".equals(lvl))
			{
			  sql=sql+" AND EXISTS (SELECT inr FROM pty p WHERE p.inr=a.belbchinr)";
			}
			else if("1".equals(lvl))
			{
			  sql=sql+ " AND EXISTS (SELECT inr FROM pty p WHERE p.inr=a.belbchinr and (a.belbchinr='"+ptyinr+"' or pntinr='"+cid+"'))";
			}
			else
			{
			  sql=sql+" AND a.belbchinr='"+ptyinr+"'";
			}

			sql=sql+" ORDER  BY credat DESC";
			log.debug("{}","[acbsel->search]查询的sql="+sql);
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getStadat(),GT),MdaUtils.sqlDate(this.getStodat(),LT));
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,minr,inwardacct,socialcrdtcd,pinr,credat,nam,pnam);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    // Argument<String> nam =new Argument<String>($this.getNamByCid(cusid.value));
			    //Argument<String> pnam =new Argument<String>($this.getNamByCid(bchcod.value));
			    this.getAcblst().add(inr,minr,inwardacct,socialcrdtcd,pinr,credat,nam,pnam);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:acbsel.@0002.script
        */
        public String getNamByCid(String cid)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(cid))
			{
			  return null;
			}
			Argument<String> nam=new Argument<String>("nam");
			ctx.getDaoSession().dbExecuteSQL("SELECT nam FROM pty WHERE cid='"+cid+"'");
			ctx.getDaoSession().dbFetchFields(nam);
			ctx.getDaoSession().dbCloseCursor();
			int e=ctx.getErrorCode();
			if(e==NO_ERROR)
			{
			  if(!MdaUtils.isEmpty(nam.value))
			  {

			    return nam.value;
			  }
			  else
			  {

			    return null;
			  }
			}
			else
			{
			  return null;
			}
		}











}