package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;

import com.brilliance.eibs.core.service.ResultMsg;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;

import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AcdopnVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Btnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Swmmod;
import com.ceb.gjjs.mda.manager.module.Acdp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Acdgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 在线预约开户
*/
@Transaction(vo= AcdopnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Acdopn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Acdopn.class);

        //国民经济行业分类
        private String industry;
		@BDGetter
		private Acdgrp acdgrp;

		@BDGetter
		private Acdp acdp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Btnmod btnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Swmmod swmmod;


		public Acdopn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAcdp().setAcdgrpHolder(()->this.getAcdgrp());
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new BigDecimal("0.00")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>("0"));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>("0"));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>("0"));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>("0"));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:acdopn.@0001.script
        */
        @Rule(target="acdp.save",order=100)
        public boolean ruleAcdpSaveN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getAcdgrp().getRec().getBchcod()))
			{
			  ctx.setFieldError(this,"acdgrp.rec.bchcod",MdaUtils.getI18NString("acdopn","CT000003"));
			  return false;
			}
			if(!ctx.checkAll(this.getAcdgrp()))
			{
			  return false;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("acdopn","CT000004"),MdaUtils.getI18NString("acdopn","CT000005")))
			{
			  return false;
			}
			if(!MdaUtils.isEmpty(this.getAcdgrp().getRec().getReason()))
			{
			  this.getAcdgrp().getRec().setReason(NULLSTR);
			  
			}
			String cifno = this.getAcdgrp().getRec().getSocialcrdtcd();
			if(!ctx.absGet(Sysmod.class).judgeSWFunctions("open_account",cifno,""))
			{
			  log.info("{}","该客户尚未签约或未签约该功能，请退回该笔业务!");
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000006"),MdaUtils.getI18NString("acdopn","CT000007"));
			  return false;
			}
			String transID = this.getAcdgrp().getRec().getTransid();
			if(!MdaUtils.isEmpty(transID))
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000008"),MdaUtils.getI18NString("acdopn","CT000015"));
			  return false;
			}
			//为确保影像已提交，把影像单独提取出来再起事务。
			String cibBranchID = this.getSysmod().getPty().getCid().substring(0,2);
			String cibOrgID = this.getSysmod().getPty().getCid().substring(2);
			ctx.getDaoSession().dbRead(ctx.absGet(Trnmod.class).getItfmod().getImgmod().getImg(),new Argument("trninr",this.getTrnmod().getBnktrn().getInr()));
			Boolean result=ctx.absGet(Trnmod.class).getItfmod().getImgmod().uploadImagesDyck(ctx.absGet(Trnmod.class).getItfmod().getImgmod().getImg().getOwnref(),ctx.absGet(Trnmod.class).getItfmod().getImgmod().getImg().getImgref(),ctx.absGet(Trnmod.class).getItfmod().getImgmod().getImg().getGuid(),cibBranchID,cibOrgID);
			log.info("{}","upload result=" +result);
			if(!result)
			{
			  log.debug("{}","#######");
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000016"),MdaUtils.getI18NString("acdopn","CT000044"));
			  return false;
			}
			String bk =getBk(this.getAcdgrp().getRec().getOpenoutletibk());//新增
			String accounttype=getAccounttype(this.getAcdgrp().getRec().getAccounttype());//新增
			String registercurrency="";
			if(!MdaUtils.isEmpty(this.getAcdgrp().getRec().getRegistercurrency()))
			  registercurrency=getRegistercurrency(this.getAcdgrp().getRec().getRegistercurrency());//新增
			String guid = this.getTrnmod().getItfmod().getImgmod().getImg().getGuid();
			String industry=getCode(this.getAcdgrp().getRec().getIndustry());

			String registerfund="";
			if(!MdaUtils.isEmpty(this.getAcdgrp().getRec().getRegisterfund()))
			{
			  BigDecimal rf=new BigDecimal(this.getAcdgrp().getRec().getRegisterfund());
			  BigDecimal rf1 = new BigDecimal("10000");
			  BigDecimal rf2=rf.multiply(rf1);
			  //String registerfund=rf2.toString();
			  registerfund=rf2.toString();
			}
			//组织报文发给预约开户系统，等待返回
			Map yymap = new HashMap();
			String seq =MdaUtils.format(ctx.getDaoSession().dbCounter("WindowsLSH"),"0000000000");
			String transid = "270"+seq;

			yymap.put("TransID",transid);
			yymap.put("EntName",this.getAcdgrp().getRec().getEntname());
			//yymap.put("AccountType",$acdgrp\\rec\\accounttype.getValue());
			yymap.put("AccountType",accounttype);
			yymap.put("EntTel",this.getAcdgrp().getRec().getEnttel());
			yymap.put("OpenOutletIbk",this.getAcdgrp().getRec().getOpenoutletibk());
			yymap.put("LegalRepresentative",this.getAcdgrp().getRec().getLegalrepresentative());
			yymap.put("FinancialAdmin",this.getAcdgrp().getRec().getFinancialadmin());
			yymap.put("Transactor",this.getAcdgrp().getRec().getTransactor());
			yymap.put("TransVerifier1",this.getAcdgrp().getRec().getTransverifier1());
			yymap.put("TransVerifier2",this.getAcdgrp().getRec().getTransverifier2());
			yymap.put("ProductType",this.getAcdgrp().getRec().getProducttype());
			yymap.put("SocialCrdtcd",this.getAcdgrp().getRec().getSocialcrdtcd());
			yymap.put("LegalName",this.getAcdgrp().getRec().getLegalname());
			// yymap.put("RegisterFund",$acdgrp\\rec\\registerfund.getValue());
			yymap.put("RegisterFund",registerfund);
			//yymap.put("RegisterCurrency",$acdgrp\\rec\\registercurrency.getValue());
			yymap.put("RegisterCurrency",registercurrency);
			yymap.put("OpenDate",MdaUtils.format(this.getAcdgrp().getRec().getOpendate(),"yyyyMMdd"));
			//yymap.put("Industry",$acdgrp\\rec\\industry.getValue());
			yymap.put("Industry",industry);
			yymap.put("EntType",this.getAcdgrp().getRec().getEnttype());
			yymap.put("RegAddr",this.getAcdgrp().getRec().getRegaddr());
			yymap.put("BusiScope",this.getAcdgrp().getRec().getBusiscope());
			yymap.put("startTime",MdaUtils.format(MdaUtils.today(),"yyyy-MM-dd HH:mm:ss"));
			yymap.put("guid",guid);
			yymap.put("ContactAddress",this.getAcdgrp().getRec().getContactaddress());//新增
			yymap.put("AppointmentDate",MdaUtils.format(this.getAcdgrp().getRec().getAppointmentdate(),"yyyyMMdd"));//新增
			yymap.put("openaccRegion",bk);//新增

			//Object resMsg = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","w414","w414",new Object[]{yymap});
			//测试用 这里如果没有传入code 或者exeTaskResult，后台会报异常，但是前端 respCode仍然是AAAAAA
			Object resMsg = new ResultMsg();
			Map retMap=new HashMap();
			retMap.put("code","000000");
			//retMap.put("exeTaskResult","1");
			retMap.put("promptInfo","exeTaskResult is null,please check!");
			ResultMsg retMsg= (ResultMsg) resMsg;
			retMsg.setContent(retMap);
			resMsg=retMsg;

			Map yyrst = null;
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  yyrst =  (Map)MdaUtils.invoke(resMsg,"getContent");
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000051"),MdaUtils.getI18NString("acdopn","CT000052"));
			  return false;
			}
			//判断处理结果，给出提示
			String yycode = (String) yyrst.get("code");
			if(MdaUtils.isEmpty(yycode))
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000149"),MdaUtils.getI18NString("acdopn","CT000150"));
			  return false;
			}
			else
			{
			  if("999999".equals(yycode))
			  {
			    String yydes = (String) yyrst.get("des");
			    ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000151"),yydes);
			    return false;
			  }
			}
			String exeTaskResult = (String)yyrst.get("exeTaskResult");
			String promptInfo = (String)yyrst.get("promptInfo");
			String accountSerialNo = (String)yyrst.get("accountSerialNo");
			String openaccBizId = (String)yyrst.get("openaccBizId");
			//0:受理失败  1：受理成功
			if(MdaUtils.isEmpty(exeTaskResult)||!"1".equals(exeTaskResult))
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000152"),promptInfo);
			  return false;
			}

			//新增信息
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			//处理业务逻辑
			if(MdaUtils.isEmpty(this.getAcdgrp().getRec().getInr()))
			{
			  this.getAcdgrp().getRec().setInr(Platform.sdbCounter("acd"));
			}

			//光大状态：0-预受理；1-审核未通过；2-审核通过；3审核已修改；4-审核已打印；5-网点审核
			//6-流程处理中；7-开户成功；8-开户撤销
			//9-预开户撤销
			
			//单一窗口状态：01：资料审核中；w 02：待前往银行办理；03：待修改资料；04：开户成功；05：开户失败 ；06：银行处理中
			this.getAcdgrp().getRec().setTransid(transid);
			this.getAcdgrp().getRec().setStatus("01");
			this.getAcdgrp().getRec().setAcdno(openaccBizId);
			//$acdgrp\\rec\\senddat.setValue(Platform.format(Platform.today(),"yyyyMMddHHMMDD"));
			
			log.info("{}","============================="+this.getAcdgrp().getRec().getSocialcrdtcd());
			ctx.getDaoSession().dbUpdate(this.getAcdgrp().getRec());
			//发送回执给单一窗口
			Map swmap = new HashMap();
			swmap.put("code","SFS104");
			this.getSysmod().setSwHeaderMap("SFS104","",swmap,this.getAcdp().getAcdgrp().getRec().getMsgref());
			swmap.put("Status",this.getAcdgrp().getRec().getStatus());
			swmap.put("ApplyID",this.getAcdgrp().getRec().getAcdno());
			swmap.put("TransId",this.getAcdgrp().getRec().getTransid());
			swmap.put("Reason",this.getAcdgrp().getRec().getReason());
			// swmap.put("SendTime",Platform.today());
			swmap.put("SendTime", MdaUtils.format(MdaUtils.today(),"yyyyMMddHHmmss"));
			this.getSwmmod().storeSWM("SFS104",this.getAcdgrp().getRec().getInr(),"acd",swmap);

			//转历史
			if(!MdaUtils.isEmpty(this.getAcdgrp().getRec().getBchcod()))
			{
			  String bchcod =this.getAcdgrp().getRec().getBchcod();
			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}
			String objinr = this.getAcdp().getAcdgrp().getRec().getInr();
			String objtyp = "acd";

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"经办,";

		//	ctx.absGet(Trnmod.class).goHistory(objinr,objtyp,ctx.getTransName(),this.getMainp(),txt);

			//提交入库
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode() != NO_ERROR)
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000153"),MdaUtils.getI18NString("acdopn","CT000091"));
			  return false;
			}
			ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000092"),MdaUtils.getI18NString("acdopn","CT000095"));

			


			return true;
        }

        /**
        *   source:acdopn.@0002.script
        */
        @Rule(target="acdp.exit",order=100)
        public boolean ruleAcdpExitN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:acdopn.@0003.script
        */
        @Rule(target="acdp.imgviw",order=100)
        public boolean ruleAcdpImgviwN100(){
            IContext ctx = MdaEnv.getContext();
            
			// String trninr = (String)Platform.restoreData("com.brilliance.inr.ref");
			//com.brilliance.inr.ref
			ctx.absGet(Trnmod.class).getItfmod().getImgmod().imgScans(this.getTrnmod().getBnktrn().getInr());


			return true;
        }

        /**
        *   source:acdopn.@0004.script
        */
        @Rule(target="btnmod.history",order=100)
        public boolean ruleBtnmodHistoryN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*if(Platform.isEmpty($acdgrp\\rec\\bchcod.getValue()))
			  {
			  Platform.error($acdgrp\\rec\\bchcod,#CT000073);
			  return false;
			  }*/

			if(MdaUtils.prompt(MdaUtils.getI18NString("acdopn","CT000074"),MdaUtils.getI18NString("acdopn","CT000075")))
			{
			  return false;
			}
			if(MdaUtils.isEmpty(this.getAcdgrp().getRec().getReason()))
			{
			  ctx.setFieldError(this,"acdgrp.rec.reason",MdaUtils.getI18NString("acdopn","CT000076"));
			  return false;
			}
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			//05：开户失败 ；
			this.getAcdgrp().getRec().setStatus("05");//直接返回开户失败
			String seq =MdaUtils.format(ctx.getDaoSession().dbCounter("WindowsLSH"),"0000000000");
			String transid = "270"+seq;
			this.getAcdgrp().getRec().setTransid(transid);
			if(MdaUtils.isEmpty(this.getAcdgrp().getRec().getInr()))
			{
			  this.getAcdgrp().getRec().setInr(Platform.sdbCounter("acd"));
			  ctx.getDaoSession().dbInsert(this.getAcdgrp().getRec());
			}
			ctx.getDaoSession().dbUpdate(this.getAcdgrp().getRec());
			if(!MdaUtils.isEmpty(this.getAcdgrp().getRec().getBchcod()))
			{

			  String bchcod =this.getAcdgrp().getRec().getBchcod();

			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"退回,退回原因："+this.getAcdgrp().getRec().getReason();

		//	this.getTrnmod().goHistory(this.getAcdgrp().getRec().getInr(),"acd",ctx.getTransName(),this.getMainp(),txt);
			//根据处理结果返回单一窗口
			Map map = new HashMap();
			map.put("code","SFS104");
			this.getSysmod().setSwHeaderMap("SFS104","",map,this.getAcdgrp().getRec().getMsgref());
			map.put("Status",this.getAcdgrp().getRec().getStatus());
			map.put("ApplyID",this.getAcdgrp().getRec().getOwnref());//失败业务返回业务参号。
			map.put("TransId",this.getAcdgrp().getRec().getTransid());
			map.put("Reason",this.getAcdgrp().getRec().getReason());
			map.put("SendTime",MdaUtils.format(MdaUtils.today(),"yyyyMMddHHmmss"));
			this.getSwmmod().storeSWM("SFS104",this.getAcdgrp().getRec().getInr(),"acd",map);
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000077"),MdaUtils.getI18NString("acdopn","CT000078"));
			  return false;
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("acdopn","CT000079"),MdaUtils.getI18NString("acdopn","CT000096"));
			}
			

			return true;
        }



        /**
        *   source:acdopn.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			IModule acd = (IModule)ctx.restoreData("com.brilliance.acdopn.ref");
			if(!MdaUtils.isEmpty(acd))
			  this.getAcdgrp().getRec().copyValue(acd);

			//测试用
			ctx.getDaoSession().dbRead(this.getAcdgrp().getRec(),new Argument<String>("inr",EQ,"00000686"));
			//ctx.getDaoSession().dbReadByInr(this.getAcdgrp().getRec(),"00000686");



			ctx.getDaoSession().dbRead(this.getAcdgrp().getPty(),new Argument<String>("cifno",EQ,this.getAcdgrp().getRec().getSocialcrdtcd()));
			this.getAcdgrp().getRec().setNcid(this.getAcdgrp().getPty().getCid());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodFlg(this.getAcdgrp().getPty().getInr(),this.getAcdgrp().getRec().getBchcod());
			MdaUtils.setValues(this.getAcdgrp().getRec(),"bchcod",bchcod);

			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			

			// $acdgrp\\rec\\producttype.setValue("网银企业服务#单位结算卡#对公短信通#回单服务#支付密码#银企对账协议");
			String objinr = this.getAcdp().getAcdgrp().getRec().getInr();
			String objtyp = "acd";
			MdaUtils.clear(this.getTrnmod().getBnktrn());
			ctx.getDaoSession().dbRead(this.getTrnmod().getBnktrn(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp",objtyp));

			return true;
        }


        /**
        *   source:acdopn.@0005.script
        */
        public String getCode(String industry)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String code = "" ;
			if(MdaUtils.isEmpty(industry))
			  return code;
			else
			{
			  if("-01-02-03-04-05-".indexOf(industry.substring(0,2)) > 0)
			  {
			    code = "A" ; // 农、林、牧、渔业
			  }
			  else
			  {
			    if("-06-07-08-09-10-11-".indexOf(industry.substring(0,2)) > 0)
			    {
			      code = "B" ; // 采矿业
			    }
			    else
			    {
			      if(("-13-14-15-16-17-18-19-".indexOf(industry.substring(0,2))>0) || ("-2-3".indexOf(industry.substring(0,1))>0) ||("-40-41-42-43-".indexOf(industry.substring(0,2))> 0))
			      {
			        code = "C" ; // 制造业
			      }
			      else
			      {
			        if("-44-45-46-".indexOf(industry.substring(0,2)) > 0)
			        {
			          code = "D" ; // 电力、燃气及水的生产和供应业
			        }
			        else
			        {
			          if("-47-48-49-50-".indexOf(industry.substring(0,2)) > 0)
			          {
			            code = "E" ; // 建筑业
			          }
			          else
			          {
			            if("-5-".indexOf(industry.substring(0,1)) > 0 && "-0-".indexOf(industry.substring(1,2)) < 0 )
			            {
			              code = "F" ; // 交通运输、仓储和邮政业
			            }
			            else
			            {
			              if("-60-61-62-".indexOf(industry.substring(0,2)) > 0 )
			              {
			                code = "G" ; // 信息传输、计算机服务和软件业
			              }
			              else
			              {
			                if("-63-65-".indexOf(industry.substring(0,2)) > 0 )
			                {
			                  code = "H" ; // 批发和零售业
			                }
			                else
			                {
			                  if("-66-67-".indexOf(industry.substring(0,2)) > 0 )
			                  {
			                    code = "I" ; // 住宿和餐饮业
			                  }
			                  else
			                  {
			                    if("-68-69-70-71-".indexOf(industry.substring(0,2)) > 0 )
			                    {
			                      code = "J" ; // 金融业
			                    }
			                    else
			                    {
			                      if("-72-".indexOf(industry.substring(0,2)) > 0 )
			                      {
			                        code = "K" ; // 房地产业
			                      }
			                      else
			                      {
			                        if("-73-74-".indexOf(industry.substring(0,2)) > 0 )
			                        {
			                          code = "L" ; // 租赁和商务服务业
			                        }
			                        else
			                        {
			                          if("-75-76-77-78-".indexOf(industry.substring(0,2)) > 0 )
			                          {
			                            code = "M" ; // 科学研究、技术服务和地质勘查业
			                          }
			                          else
			                          {
			                            if("-79-80-81-".indexOf(industry.substring(0,2)) > 0 )
			                            {
			                              code = "N" ; // 水利、环境和公共设施管理业
			                            }
			                            else
			                            {
			                              if("-82-83-".indexOf(industry.substring(0,2)) > 0 )
			                              {
			                                code = "O" ; // 居民服务和其他服务业
			                              }
			                              else
			                              {
			                                if("-84-".indexOf(industry.substring(0,2)) > 0 )
			                                {
			                                  code = "P" ; // 教育
			                                }
			                                else
			                                {
			                                  if("-85-86-87-".indexOf(industry.substring(0,2)) > 0 )
			                                  {
			                                    code = "Q" ; // 卫生、社会保障和社会福利业
			                                  }
			                                  else
			                                  {
			                                    if("-88-89-90-91-92-".indexOf(industry.substring(0,2)) > 0 )
			                                    {
			                                      code = "R" ; // 文化、体育和娱乐业
			                                    }
			                                    else
			                                    {
			                                      if("-93-94-95-96-97-".indexOf(industry.substring(0,2)) > 0 )
			                                      {
			                                        code = "S" ; // 公共管理和社会组织
			                                      }
			                                      else
			                                      {
			                                        if("-98-".indexOf(industry.substring(0,2)) > 0 )
			                                        {
			                                          code = "T" ; // 国际组织
			                                        }
			                                      }
			                                    }
			                                  }
			                                }
			                              }
			                            }
			                          }
			                        }
			                      }
			                    }
			                  }
			                }
			              }
			            }
			          }
			        }
			      }
			    }
			  }
			  return code;
			}
		}
        /**
        *   source:acdopn.@0006.script
        */
        public String getBk(String bk)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String rtnBk="";
			String sql="select pntinr from pty where lvl='2' and cid LIKE '%"+ bk +"%' ";
			Argument<String> pntinr = new Argument<String>("pntinr");

			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getDaoSession().dbFetchFields(pntinr);
			ctx.getDaoSession().dbCloseCursor();
			String pntBk = pntinr.value.substring(2,6);

			switch (Integer.parseInt(pntBk))
			{
			  case 3550 :
			  rtnBk = "01";
			  break;

			  case 3650 :
			  rtnBk = "06" ;
			  break;

			  case 3948 :
			  rtnBk = "09" ;
			  break;

			  case 7545 :
			  rtnBk = "21" ;
			  break;

			  case 3860 :
			  rtnBk = "12" ;
			  break;

			  case 3909 :
			  rtnBk = "04" ;
			  break;

			  case 3703 :
			  rtnBk = "18" ;
			  break;

			  case 7825 :
			  rtnBk = "16" ;
			  break;

			  case 3830 :
			  rtnBk = "14" ;
			  break;

			  case 7675 :
			  rtnBk = "23" ;
			  break;

			  case 7654 :
			  rtnBk = "20" ;
			  break;

			  case 3800 :
			  rtnBk = "10" ;
			  break;

			  case 3991 :
			  rtnBk = "32" ;
			  break;

			  case 7880 :
			  rtnBk = "26" ;
			  break;

			  case 7689 :
			  rtnBk = "29" ;
			  break;

			  case 7715 :
			  rtnBk = "22" ;
			  break;

			  case 3810 :
			  rtnBk = "05" ;
			  break;

			  case 3570 :
			  rtnBk = "07" ;
			  break;

			  case 3780 :
			  rtnBk = "24" ;
			  break;

			  case 7865 :
			  rtnBk = "25" ;
			  break;

			  case 7668 :
			  rtnBk = "30" ;
			  break;

			  case 3760 :
			  rtnBk = "17" ;
			  break;

			  case 3590 :
			  rtnBk = "08" ;
			  break;

			  case 3600 :
			  rtnBk = "03" ;
			  break;

			  case 7520 :
			  rtnBk = "28" ;
			  break;

			  case 3640 :
			  rtnBk = "19" ;
			  break;

			  case 5001 :
			  rtnBk = "33" ;
			  break;

			  case 3960 :
			  rtnBk = "13" ;
			  break;

			  case 3750 :
			  rtnBk = "15" ;
			  break;

			  case 7896 :
			  rtnBk = "27" ;
			  break;

			  case 5171 :
			  rtnBk = "36" ;
			  break;

			  case 7540 :
			  rtnBk = "31" ;
			  break;

			  case 5011 :
			  rtnBk = "34" ;
			  break;

			  case 5081 :
			  rtnBk = "35" ;
			  break;

			  case 5181 :
			  rtnBk = "37" ;
			  break;

			  case 5451 :
			  rtnBk = "39" ;
			  break;

			  case 3920 :
			  rtnBk = "11" ;
			  break;

			  case 5581 :
			  rtnBk = "41" ;
			  break;

			  case 5681 :
			  rtnBk = "43" ;
			  break;

			  default:
			  rtnBk = "" ;
			  break;

			}
			return rtnBk;
		}
        /**
        *   source:acdopn.@0007.script
        */
        public String getAccounttype(String accounttype)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String at="0";
			switch (Integer.parseInt(accounttype))
			{
			  case 01 :
			  at ="0";
			  break;

			  case 02 :
			  at ="1";
			  break;

			  case 03 :
			  at ="3";
			  break;

			  case 04 :
			  at ="2" ;
			  break;

			  default:
			  at = "0" ;
			  break;

			}
			return at;
		}
        /**
        *   source:acdopn.@0008.script
        */
        public String getRegistercurrency(String registercurrency)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String  rc="";
			switch (Integer.parseInt(registercurrency))
			{
			  case 110 :
			  rc ="13";
			  break;

			  case 116 :
			  rc ="27";
			  break;

			  case 121 :
			  rc ="81";
			  break;

			  case 129 :
			  rc ="82" ;
			  break;

			  case 132 :
			  rc ="32" ;
			  break;

			  case 133 :
			  rc ="88" ;
			  break;

			  case 136 :
			  rc ="84" ;
			  break;

			  case 142 :
			  rc ="01" ;
			  break;

			  case 143 :
			  rc ="02" ;
			  break;

			  case 300 :
			  rc ="38" ;
			  break;

			  case 302 :
			  rc ="22" ;
			  break;

			  case 303 :
			  rc ="12" ;
			  break;

			  case 326 :
			  rc ="23" ;
			  break;

			  case 330 :
			  rc ="21" ;
			  break;

			  case 331 :
			  rc ="15" ;
			  break;

			  case 501 :
			  rc ="28" ;
			  break;

			  case 502 :
			  rc ="14" ;
			  break;

			  case 601 :
			  rc ="29" ;
			  break;

			  case 609 :
			  rc ="87" ;
			  break;

			  default:
			  rc = "" ;
			  break;

			}

			return rc;

		}









}