package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AptcfmVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Aptp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Apdgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口代付协议补充修订(银行端)
*/
@Transaction(vo= AptcfmVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Aptcfm extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Aptcfm.class);

		@BDGetter
		private Apdgrp apdgrp;

		@BDGetter
		private Aptp aptp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Aptcfm()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAptp().setApdgrpHolder(()->this.getApdgrp());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("IF"));
           this.getMtabut().setRecHolder(()->this.getApdgrp().getRec());
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.cur");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setCur(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getCur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.amt");}
 				public void setValue(BigDecimal arg){Aptcfm.this.getApdgrp().getRec().setAmt(arg);}
 				public BigDecimal getValue(){return Aptcfm.this.getApdgrp().getRec().getAmt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.ownref");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.ownref");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.inr");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setInr(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.ptyinr");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Aptcfm.this.getFieldPath("apdgrp.rec.stlref");}
 				public void setValue(String arg){Aptcfm.this.getApdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Aptcfm.this.getApdgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:aptcfm.@0001.script
        */
        @Rule(target="mtabut.bnkcfm",order=100)
        public boolean ruleMtabutBnkcfmN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","在matbut模块bnkcfm按钮order[200].......");
			if(!(ctx.checkAll(this.getApdgrp().getIxd())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("aptcfm","CT000000"),MdaUtils.getI18NString("aptcfm","CT000001"));
			  return false;
			}
			ctx.getDaoSession().dbUpdate(this.getApdgrp().getIxd());
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.debug("{}","filename is "+filename);
			//获得当前显示步骤条所对应的面板
			IPanel[] panels=this.getAptp().getStpmod().getAllPanelsName();
			ctx.saveDisplay(filename);
			//保存trn
			ctx.absGet(Trnmod.class).setTrnForSecondConfirm();


			return true;
        }

        /**
        *   source:aptcfm.@0002.script
        */
        @Rule(target="aptp.pdfixd",order=100)
        public boolean ruleAptpPdfixdN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getAptp().getPdfviw().callPDFComponent("","aptopn1","进口代付申请",1);

			return true;
        }

        /**
        *   source:aptcfm.@0003.script
        */
        @Rule(target="aptp.pdfbxd",order=100)
        public boolean ruleAptpPdfbxdN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getAptp().getPdfviw().callPDFComponent("","bxdopn","保证金协议",1);

			return true;
        }



        /**
        *   source:aptcfm.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			IDatafield objinr=(IDatafield)ctx.restoreData("com.brilliance.aptcfm.inr");
			if(!MdaUtils.isEmpty(objinr))
			{
			  ctx.getDaoSession().dbRead(this.getApdgrp().getRec(),new Argument<String>("inr",objinr));
			  ctx.getDaoSession().dbRead(this.getApdgrp().getIxd(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp","apd"));
			  //定义步骤条
			  this.getAptp().getStpmod().storePanel(this.getAptp().getAptcfmstep01(),this.getAptp().getAptcfmstep02(),this.getAptp().getAptcfmstep03());
			  String steps=null;
			  String flags=this.getApdgrp().getRec().getFlags();
			  //签订了保证金协议
			  if("0001".equals(flags))
			  {
			    ctx.getDaoSession().dbRead(this.getApdgrp().getBxd(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp","apd"));
			    steps = "0:进口代付协议;1:保证金协议;2:合同展示";
			    

			  }
			  else if("0000".equals(flags))
			  {
			    steps = "0:进口代付协议;1:合同展示";
			    
			  }
			  
			  this.getAptp().getStpmod().setPages(steps);
			  this.getAptp().getStpmod().calcSteps();
			  this.getAptp().getStpmod().setStepBtnSta();
			  //隐藏出口押汇协议界面上是否签订保证金勾选项
			  
			}

			return true;
        }









}