package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.AutqryVO;

import com.ceb.gjjs.mda.manager.module.Authp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Authgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 主管授权信息反馈
*/
@Transaction(vo= AutqryVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Autqry extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Autqry.class);

		@BDGetter
		private Authgrp authgrp;

		@BDGetter
		private Authp authp;

		@BDGetter
		private Sysmod sysmod;


		public Autqry()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAuthp().setAuthgrpHolder(()->this.getAuthgrp());
        }

        /**
        *   source:autqry.@0000.script
        */
        @Rule(target="authp.query",order=100)
        public boolean ruleAuthpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			String sql="SELECT inr,frm,dattim,sub,sta from auth where usrinr='"+this.getSysmod().getUsr().getInr().trim()+"'";
			ArrayList paras = new ArrayList();
			if(!MdaUtils.isEmpty(this.getAuthp().getStartdate()))
			{
			  sql+=" and dattim>=?";
			  paras.add(MdaUtils.sqlDate(this.getAuthp().getStartdate(),GT));//GT对应timestamp,GE对应date，没有时分秒
			}
			if(!MdaUtils.isEmpty(this.getAuthp().getEnddate()))
			{
			  sql+=" and dattim<=?";
			  paras.add(MdaUtils.sqlDate(this.getAuthp().getEnddate(),LT));
			}
			if(!MdaUtils.isEmpty(this.getAuthp().getStat()))
			{
			  sql+=" and sta=?";
			  paras.add(this.getAuthp().getStat());
			}
			sql+=" order by inr desc";
			log.info("{}","paras.size:"+paras.size());
			switch(paras.size())
			{
			  case 0:
			  ctx.getDaoSession().dbExecuteSQL(sql);
			  break;
			  case 1:
			  ctx.getDaoSession().dbExecuteSQL(sql,paras.get(0));
			  break;
			  case 2:
			  ctx.getDaoSession().dbExecuteSQL(sql,paras.get(0),paras.get(1));
			  break;
			  case 3:
			  ctx.getDaoSession().dbExecuteSQL(sql,paras.get(0),paras.get(1),paras.get(2));
			  break;
			}
			MdaUtils.clear(this.getAuthgrp().getAuthlst());
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> frm = new Argument<String>("frm");
			Argument<Date> dattim = new Argument<Date>("dattim");
			Argument<String> sub = new Argument<String>("sub");
			Argument<String> sta = new Argument<String>("sta");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,frm,dattim,sub,sta);
			  int errorCode=ctx.getErrorCode();
			  if(errorCode==NO_ERROR)
			    this.getAuthgrp().getAuthlst().add(inr,frm,dattim,sub,sta);
			  else if(errorCode==NO_MORE_ROW)
			  {
			    log.debug("{}","no more row!");
			    break;
			  }
			  else
			  {
			    log.debug("{}","errorCode:"+errorCode);
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			

			return true;
        }

        /**
        *   source:autqry.@0002.script
        */
        @Rule(target="authp.sel",order=100)
        public boolean ruleAuthpSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			goSelectedItem();

			return true;
        }

        /**
        *   source:autqry.@0004.script
        */
        @Rule(target="authgrp.authlst",order=100)
        public boolean ruleAuthgrpAuthlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			goSelectedItem();

			return true;
        }



        /**
        *   source:autqry.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			Date startDate = MdaUtils.add(MdaUtils.today(),-30);
			ctx.getDaoSession().dbReadset(this.getAuthgrp().getAuthlst(),new Argument<String>("usrinr",this.getSysmod().getUsr().getInr()),new Argument<Date>("dattim",GT,startDate),new Argument<String>("inr",DESC));
			//GT,GE,LT,LE
			log.info("{}","autqry Init authlst size = "+this.getAuthgrp().getAuthlst().fullSize());
			

			return true;
        }

        /**
        *   source:autqry.@0005.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getAuthp().getStat()))
			  this.getAuthp().setStat("W");

			return true;
        }


        /**
        *   source:autqry.@0003.script
        */
        public void goSelectedItem()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int index = 0;
			if(index<0   ||  index>=this.getAuthgrp().getAuthlst().fullSize())
			{
			  ctx.setMessage(MdaUtils.getI18NString("autqry","CT000009"),MdaUtils.getI18NString("autqry","CT000010"));
			  return;
			}
			//读取display文件
			String fileName="";
			/*
			  if("dbmaut".equals($authgrp\\authlst[index]\\frm.getValue().trim()))
			  {
			  fileName="/data/grant/dbmaut/dsp/"+$authgrp\\authlst[index]\\inr.getValue()+".zul";
			  //$authp\\display.setValue("/dsp"+filename);
			  }
			  else if("dbmopr0".equals($authgrp\\authlst[index]\\frm.getValue().trim()))
			  {
			  fileName="/data/grant/dbmopr0/dsp/"+$authgrp\\authlst[index]\\inr.getValue()+".zul";
			  //$authp\\display.setValue("/dsp"+filename);
			  }
			  else
			  {
			  Platform.message(#CT000011,#CT000012);
			  return;
			  }
			  */
			fileName = "/data/grant/"+this.getAuthgrp().getAuthlst().getElement(index).getFrm().trim()+"/dsp/"+this.getAuthgrp().getAuthlst().getElement(index).getInr()+".zul";
			fileName="file:"+MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),fileName);
			log.debug("{}","autqry Selected fileName = "+fileName);
			
		}




}