package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BdtdfrVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Ditp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ditmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Didgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 买方信用证杂项处理申请(商行自主开立)
*/
@Transaction(vo= BdtdfrVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bdtdfr extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bdtdfr.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Didgrp didgrp;

		@BDGetter
		private Ditmod ditmod;

		@BDGetter
		private Ditp ditp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Bdtdfr()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getDitp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getDitp().setDidgrpHolder(()->this.getDidgrp());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("DC"));
           this.getMtabut().setRecHolder(()->this.getDidgrp().getRec());
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("didgrp.rec.isscur");}
 				public void setValue(String arg){Bdtdfr.this.getDidgrp().getRec().setIsscur(arg);}
 				public String getValue(){return Bdtdfr.this.getDidgrp().getRec().getIsscur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("didgrp.rec.issamt");}
 				public void setValue(BigDecimal arg){Bdtdfr.this.getDidgrp().getRec().setIssamt(arg);}
 				public BigDecimal getValue(){return Bdtdfr.this.getDidgrp().getRec().getIssamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("didgrp.rec.ownref");}
 				public void setValue(String arg){Bdtdfr.this.getDidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Bdtdfr.this.getDidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("afdgrp.rec.bchcod");}
 				public void setValue(String arg){Bdtdfr.this.getAfdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Bdtdfr.this.getAfdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("afdgrp.rec.inr");}
 				public void setValue(String arg){Bdtdfr.this.getAfdgrp().getRec().setInr(arg);}
 				public String getValue(){return Bdtdfr.this.getAfdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("didgrp.rec.ptyinr");}
 				public void setValue(String arg){Bdtdfr.this.getDidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Bdtdfr.this.getDidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdfr.this.getFieldPath("didgrp.rec.stlref");}
 				public void setValue(String arg){Bdtdfr.this.getDidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Bdtdfr.this.getDidgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:bdtdfr.@0003.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.dbBegin();
			if(!(ctx.checkAll(this.getDidgrp()) && ctx.checkAll(this.getAfdgrp())))
			  return false;
			this.getAfdgrp().getRec().setInr(Platform.sdbCounter("afd"));
			this.getAfdgrp().getRec().setObjtyp("did");
			this.getAfdgrp().getRec().setObjinr(this.getDidgrp().getRec().getInr());
			this.getAfdgrp().getRec().setApytyp("0");
			this.getAfdgrp().getRec().setOprtyp("0");
			this.getAfdgrp().getRec().setOwnusr(this.getSysmod().getUsr().getInr());
			ctx.getDaoSession().dbInsert(this.getAfdgrp().getRec());
			this.dealPDFData();
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:bdtdfr.@0005.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in  images 50 ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }

        /**
        *   source:bdtdfr.@0006.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            

			IStream stream=this.getMtabut().getApldoc();
			ctx.absGet(Sysmod.class).generatorPdf("","bdtdfr",stream,false );

			return true;
        }



        /**
        *   source:bdtdfr.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getAfdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			
			
			
			
			
			
			
			
			
			
			
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return true;
			IModule did = (IModule)ctx.restoreData("com.brilliance.bdtdfr.ref");
			if(!MdaUtils.isEmpty(did))
			  this.getDidgrp().getRec().copyValue(did);
			if(!MdaUtils.isEmpty(bchcod))
			  this.getAfdgrp().getRec().setBchcod((bchcod.get(0)).getValue());
			this.getAfdgrp().getRec().setCredat(MdaUtils.today());
			ctx.getDaoSession().dbRead(this.getDidgrp().getApl().getPts(),new Argument<String>("objinr",this.getDidgrp().getRec().getInr()),new Argument<String>("objtyp","did"),new Argument<String>("rol","apl"));
			ctx.getDaoSession().dbRead(this.getDidgrp().getBen().getPts(),new Argument<String>("objinr",this.getDidgrp().getRec().getInr()),new Argument<String>("objtyp","did"),new Argument<String>("rol","ben"));

			return true;
        }

        /**
        *   source:bdtdfr.@0001.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","bchcod="+this.getAfdgrp().getRec().getBchcod());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getAfdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  //$didgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			{
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			    this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			  else
			  {
			    if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getDbchcod()))
			      this.getAfdgrp().getRec().setBchcod(this.getDidgrp().getRec().getDbchcod());
			    else
			    {
			      this.getAfdgrp().getRec().setBchcod(this.getDidgrp().getRec().getBchcod());
			    }
			    
			  }
			  log.info("{}","bchcod="+this.getDidgrp().getRec().getBchcod()+",dbchcod="+this.getDidgrp().getRec().getDbchcod());
			}


			return true;
        }


        /**
        *   source:bdtdfr.@0007.script
        */
        public void dealPDFData()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			this.getDitp().setCredat(NULLSTR);
			String credat = MdaUtils.format(this.getAfdgrp().getRec().getCredat(),"yyyy年MM月dd日");
			this.getDitp().setCredat(credat);
		}









}