package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BdtdsnVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Bdtp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Didgrp;
import com.ceb.gjjs.mda.manager.module.Bddgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 国内信用证承兑付款拒付（商行）
*/
@Transaction(vo= BdtdsnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bdtdsn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bdtdsn.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Bddgrp bddgrp;

		@BDGetter
		private Didgrp didgrp;

		@BDGetter
		private Bdtp bdtp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Bdtdsn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBdtp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBdtp().setBddgrpHolder(()->this.getBddgrp());
           this.getBdtp().setDidgrpHolder(()->this.getDidgrp());
           this.getMtabut().setRecHolder(()->this.getBddgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("DB"));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.advcur");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setAdvcur(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getAdvcur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.advamt");}
 				public void setValue(BigDecimal arg){Bdtdsn.this.getBddgrp().getRec().setAdvamt(arg);}
 				public BigDecimal getValue(){return Bdtdsn.this.getBddgrp().getRec().getAdvamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.ownref");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.bchcod");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.inr");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setInr(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.ptyinr");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bdtdsn.this.getFieldPath("bddgrp.rec.stlref");}
 				public void setValue(String arg){Bdtdsn.this.getBddgrp().getRec().setStlref(arg);}
 				public String getValue(){return Bdtdsn.this.getBddgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:bdtdsn.@0003.script
        */
        @Rule(target="afdgrp.rec.oprtyp",order=100)
        public boolean ruleAfdgrpRecOprtypN100(){
            IContext ctx = MdaEnv.getContext();
            
			changeOprTyp();

			return true;
        }

        /**
        *   source:bdtdsn.@0005.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(!(ctx.checkAll(this.getBddgrp()) && ctx.checkAll(this.getAfdgrp())))
			  return false;
			log.info("{}","sav200开始================" );
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  log.info("{}","B  SPT  ...........");
			  ctx.getDaoSession().dbUpdate(this.getBddgrp().getRec());
			  String objinr = this.getBddgrp().getRec().getInr();
			  //申请人
			  this.getMtabut().UpdatePtsForBack(this.getBddgrp().getApl().getPts(),objinr);
			  //受益人
			  this.getMtabut().UpdatePtsForBack(this.getBddgrp().getBen().getPts(),objinr);
			}
			else
			{
			  log.info("{}","fei B");
			  this.getAfdgrp().getRec().setInr(Platform.sdbCounter("afd"));
			  this.getBddgrp().getRec().setInr(Platform.sdbCounter("bdd"));
			  String objinr = this.getBddgrp().getRec().getInr();
			  String objtyp = "bdd";
			  //申请人
			  this.getBddgrp().getApl().savpts(objinr,objtyp);
			  //受益人
			  this.getBddgrp().getBen().savpts(objinr,objtyp);
			  this.getAfdgrp().getRec().setObjtyp("bdd");
			  this.getAfdgrp().getRec().setObjinr(this.getBddgrp().getRec().getInr());
			  this.getBddgrp().getRec().setPnttyp("did");
			  this.getBddgrp().getRec().setPntinr(this.getDidgrp().getRec().getInr());
			  this.getBddgrp().getRec().setPntstlref(this.getDidgrp().getRec().getStlref());
			  log.info("{}","stlref   "+this.getDidgrp().getRec().getStlref());
			  this.getBddgrp().getRec().setConno(this.getDidgrp().getRec().getConno());
			  this.getBddgrp().getRec().setAdvdat(this.getAfdgrp().getRec().getCredat());
			  this.getAfdgrp().getRec().setApytyp("0");
			  this.getAfdgrp().getRec().setOwnusr(this.getSysmod().getUsr().getInr());
			  ctx.getDaoSession().dbInsert(this.getAfdgrp().getRec());
			  this.getMtabut().getRef();
			  ctx.getDaoSession().dbInsert(this.getBddgrp().getRec());
			  log.info("{}", "sav200入库结束================" );
			}
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);
			log.info("{}", "sav200结束================" );

			return true;
        }

        /**
        *   source:bdtdsn.@0006.script
        */
        @Rule(target="bdtp.accdoc",order=100)
        public boolean ruleBdtpAccdocN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*Platform.clear($bdtp\\bchcod);
			  List<CodetableItem> bchcod = $sysmod.getAndSetBchcodvals();
			  String bch= $afdgrp\\rec\\bchcod.getValue();
			  String key ="" ;
			  String nam ="" ;
			  for(CodetableItem ct : bchcod)
			  {
			  key = ct.getValue() ;
			  if( !Platform.isEmpty(bch)&& bch.equals(key))
			  {
			  nam = ct.getLabel() ;
			  break;
			  }
			  }
			  $bdtp\\bchcod = nam ;
			  */
			this.getBdtp().setAdvamt(NULLSTR);
			if(MdaUtils.isEmpty(this.getBddgrp().getRec().getAdvamt())   ||   MdaUtils.isEmpty(this.getBddgrp().getRec().getAdvcur()))
			  return true;
			String amt = this.getSysmod().covCnAmt(this.getBddgrp().getRec().getAdvamt(),this.getBddgrp().getRec().getAdvcur());
			this.getBdtp().setAdvamt(amt);

			this.getBdtp().setCredat(NULLSTR);
			String credat = MdaUtils.format(this.getAfdgrp().getRec().getCredat(),"yyyy年MM月dd日");
			this.getBdtp().setCredat(credat);

			this.getBdtp().setAccdat(NULLSTR);
			String accdat = MdaUtils.format(this.getBddgrp().getRec().getAccdat(),"yyyy年MM月dd日");
			this.getBdtp().setAccdat(accdat);

			IStream stream=this.getBdtp().getAccdoc();
			ctx.absGet(Sysmod.class).generatorPdf("","bdtdsn1",stream,false);

			return true;
        }

        /**
        *   source:bdtdsn.@0007.script
        */
        @Rule(target="bdtp.rejdoc",order=100)
        public boolean ruleBdtpRejdocN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*Platform.clear($bdtp\\bchcod);
			  List<CodetableItem> bchcod = $sysmod.getAndSetBchcodvals();
			  String bch= $afdgrp\\rec\\bchcod.getValue();
			  String key ="" ;
			  String nam ="" ;
			  for(CodetableItem ct : bchcod)
			  {
			  key = ct.getValue() ;
			  if( !Platform.isEmpty(bch)&& bch.equals(key))
			  {
			  nam = ct.getLabel() ;
			  break;
			  }
			  }
			  $bdtp\\bchcod = nam ;
			  */
			this.getBdtp().setAdvamt(NULLSTR);
			if(MdaUtils.isEmpty(this.getBddgrp().getRec().getAdvamt())   ||   MdaUtils.isEmpty(this.getBddgrp().getRec().getAdvcur()))
			  return true;
			String amt = this.getSysmod().covCnAmt(this.getBddgrp().getRec().getAdvamt(),this.getBddgrp().getRec().getAdvcur());
			this.getBdtp().setAdvamt(amt);

			this.getBdtp().setCredat(NULLSTR);
			String credat = MdaUtils.format(this.getAfdgrp().getRec().getCredat(),"yyyy年MM月dd日");
			this.getBdtp().setCredat(credat);

			IStream stream=this.getBdtp().getRejdoc();
			ctx.absGet(Sysmod.class).generatorPdf("","bdtdsn2",stream,false);

			return true;
        }

        /**
        *   source:bdtdsn.@0009.script
        */
        @Rule(target="bdtp.getref",order=100)
        public boolean ruleBdtpGetrefN100(){
            IContext ctx = MdaEnv.getContext();
            
			searchbdd();
			

			return true;
        }

        /**
        *   source:bdtdsn.@0011.script
        */
        @Rule(target="bdtp.select",order=100)
        public boolean ruleBdtpSelectN100(){
            IContext ctx = MdaEnv.getContext();
            
			//选中list一条记录，然后将参号传给chain到的页面，并将信息回填。
			int index = 0;
			log.info("{}","current line selected is ="+index );
			int length = this.getBdtp().getBddlst().fullSize();
			log.info("{}","size of bddlst is ="+length);
			if( index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("bdtdsn","CT000003"),MdaUtils.getI18NString("bdtdsn","CT000004"));
			  return true;
			}
			this.getBddgrp().getRec().setStlref(this.getBdtp().getBddlst().getElement(index).getStlref());
			
			if(!MdaUtils.isEmpty(this.getBddgrp().getRec().getStlref()))
			{
			  ctx.getDaoSession().dbRead(this.getBddgrp().getRec(),new Argument<String>("stlref",this.getBddgrp().getRec().getStlref()),new Argument<String>("pntinr",this.getDidgrp().getRec().getInr()));
			  int err=ctx.getErrorCode();
			  if(err == NO_ERROR)
			  {
			    
			    
			    
			    
			    
			    this.getAfdgrp().getRec().setOwnref(this.getBddgrp().getRec().getStlref());
			    ctx.getDaoSession().dbRead(this.getBddgrp().getApl().getPts(),new Argument<String>("objinr",this.getBddgrp().getRec().getInr()),new Argument<String>("objtyp","bdd"),new Argument<String>("rol","apl"));
			    int err1=ctx.getErrorCode();
			    ctx.getDaoSession().dbRead(this.getBddgrp().getBen().getPts(),new Argument<String>("objinr",this.getBddgrp().getRec().getInr()),new Argument<String>("objtyp","bdd"),new Argument<String>("rol","ben"));
			    int err2=ctx.getErrorCode();
			    if(err1 == NO_ERROR)
			    {
			      
			      
			    }
			    if(err2 == NO_ERROR)
			    {
			      
			      
			    }
			  }
			}
			

			return true;
        }

        /**
        *   source:bdtdsn.@0012.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream stream=this.getBdtp().getAccdoc();
			if("BMTACC".equals(this.getAfdgrp().getRec().getOprtyp()))
			  ctx.absGet(Sysmod.class).generatorPdf("","bdtdsn1",stream,false);
			else if("BMTDCR".equals(this.getAfdgrp().getRec().getOprtyp()))
			  ctx.absGet(Sysmod.class).generatorPdf("","bdtdsn2",stream,false);

			return true;
        }

        /**
        *   source:bdtdsn.@0013.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in  images 50 ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }



        /**
        *   source:bdtdsn.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getAfdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			if(!(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T")))
			{
			  IModule did = (IModule)ctx.restoreData("com.brilliance.bdtdsn.ref");
			  if(!MdaUtils.isEmpty(did))
			    this.getDidgrp().getRec().copyValue(did);
			}
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			{
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			  {
			    this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			    this.getBddgrp().getRec().setBchcod(this.getAfdgrp().getRec().getBchcod());
			  }
			  else
			  {
			    this.getAfdgrp().getRec().setBchcod(this.getDidgrp().getRec().getBchcod());
			    this.getBddgrp().getRec().setBchcod(this.getAfdgrp().getRec().getBchcod());
			  }
			}
			String stlref = this.getDidgrp().getRec().getOwnref();
			if(MdaUtils.isEmpty(stlref))
			  return true;
			List<CodetableItem> oprtyp =null;
			if("Z".equals(this.getDidgrp().getRec().getCretyp()))
			{
			  oprtyp = MdaUtils.getCodetable("apltyp7");
			}
			else
			{
			  oprtyp = MdaUtils.getCodetable("apltyp0");
			  MdaUtils.setValues(this.getAfdgrp().getRec(),"oprval",MdaUtils.getCodetable("refres"));
			}
			MdaUtils.setValues(this.getAfdgrp().getRec(),"oprtyp",oprtyp);
			changeOprTyp();
			
			
			
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			  return true;
			this.getAfdgrp().getRec().setCredat(MdaUtils.today());
			this.getBddgrp().getRec().setRelcur("CNY");
			this.getBddgrp().getRec().setAdvcur("CNY");

			return true;
        }

        /**
        *   source:bdtdsn.@0002.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","bchcod="+this.getAfdgrp().getRec().getBchcod());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getAfdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  //$didgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			{
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			  {
			    this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			    this.getBddgrp().getRec().setBchcod(this.getAfdgrp().getRec().getBchcod());
			  }
			  else
			  {
			    if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getDbchcod()))
			    {
			      this.getAfdgrp().getRec().setBchcod(this.getDidgrp().getRec().getDbchcod());
			      this.getBddgrp().getRec().setBchcod(this.getAfdgrp().getRec().getBchcod());
			    }
			    else
			    {
			      this.getAfdgrp().getRec().setBchcod(this.getDidgrp().getRec().getBchcod());
			      this.getBddgrp().getRec().setBchcod(this.getAfdgrp().getRec().getBchcod());
			    }
			    
			  }
			}


			return true;
        }


        /**
        *   source:bdtdsn.@0000.script
        */
        public void changeOprTyp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String val = this.getAfdgrp().getRec().getOprtyp();
			if("BMTACC".equals(val))
			{
			  
			  
			  this.getAfdgrp().getRec().setOprval(NULLSTR);
			  
			  
			  
			  
			  
			  this.getBddgrp().getRec().setRejpaytxt(NULLSTR);
			  this.getBddgrp().getRec().setNote(NULLSTR);
			  
			  
			}
			else if("BMTDCR".equals(val))
			{
			  
			  
			  this.getAfdgrp().getRec().setOprval(NULLSTR);
			  
			  
			  
			  this.getBddgrp().getRec().setAccdat(null);
			  
			  
			  
			  
			}
			else
			{
			  
			  
			  this.getAfdgrp().getRec().setOprval(NULLSTR);
			  
			  
			  
			  this.getBddgrp().getRec().setAccdat(null);
			  
			  
			  this.getBddgrp().getRec().setRejpaytxt(NULLSTR);
			  this.getBddgrp().getRec().setNote(NULLSTR);
			  
			  
			}
			
			
			
			
			
			
			
		}
        /**
        *   source:bdtdsn.@0010.script
        */
        public void searchbdd()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getBdtp().getBddlst());
			String queryClause ="select stlref,advamt,rcvdat from bdd where pnttyp='did' and pntinr='"+this.getDidgrp().getRec().getInr()+"'";
			ctx.getDaoSession().dbExecuteSQL(queryClause);
			int tmp = ctx.getErrorCode();
			log.info("{}",MdaUtils.getI18NString("bdtdsn","CT000002") + queryClause);
			Argument<String> stlref = new Argument<String>("stlref");
			Argument<BigDecimal> advamt = new Argument<BigDecimal>("advamt");
			Argument<Date> rcvdat = new Argument<Date>("rcvdat");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(stlref,advamt,rcvdat);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getBdtp().getBddlst().add(stlref,advamt,rcvdat);
			  }
			  else
			  {
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			if(this.getBdtp().getBddlst().fullSize() == 0)
			{
			  return;
			}
			
		}









}