package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.Bdtsnd0VO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Selmod;
import com.ceb.gjjs.mda.manager.module.Selp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Didgrp;
import com.ceb.gjjs.mda.manager.module.Bddgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 国内信用证承兑/付款/拒付
*/
@Transaction(vo= Bdtsnd0VO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bdtsnd0 extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bdtsnd0.class);

		@BDGetter
		private Bddgrp bddgrp;

		@BDGetter
		private Didgrp didgrp;

		@BDGetter
		private Selmod selmod;

		@BDGetter
		private Selp selp;

		@BDGetter
		private Sysmod sysmod;


		public Bdtsnd0()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:bdtsnd0.@0001.script
        */
        @Rule(target="selp.sure",order=100)
        public boolean ruleSelpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			if("1".equals(seltyp))
			{
			  //到单通知
			  this.getSelp().sureBtn1("bddgrp","bdtsnd");
			}
			else if("2".equals(seltyp))
			{
			  //不符点通知
			  this.getSelp().sureBtn("bddgrp","bdtsnd");
			}
			else if("3".equals(seltyp))
			{
			  //国内证
			  if(!"1".equals(this.getSysmod().getPty().getPtytyp()))
			    return true;
			  else
			    this.getSelp().sureBtn3("didgrp","bdtdsn");
			}
			ctx.storeData("com.brilliance.bdtsnd.seltyp",seltyp);

			return true;
        }

        /**
        *   source:bdtsnd0.@0002.script
        */
        @Rule(target="selp.query",order=100)
        public boolean ruleSelpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			String queryClause = null;
			if("1".equals(seltyp))
			{
			  //进口信用证项下的到单通知
			  
			  
			  
			  //queryClause = "SELECT b.inr trsinr,b.stlref ref,b.advcur cur,b.advamt amt,b.rcvdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM bdd b,pts s,adr a,pta p WHERE b.docflg = 'docadv' AND s.rol = 'ben' AND s.objtyp = 'bdd' AND s.objinr = b.inr AND pta.inr = s.ptainr AND a.inr = pta.objinr";
			  queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			    +"FROM bdd rec,pts s  WHERE (rec.docflg = 'docadv' OR rec.docflg = 'accept' OR rec.docflg = 'hodrej') "
			    +"AND s.objtyp = 'bdd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  this.getSelp().queryBtn1(queryClause);
			}
			else if("2".equals(seltyp))
			{
			  //进口信用证项下的电提不符点通知
			  
			  
			  
			  //queryClause = "SELECT b.inr trsinr,b.stlref ref,b.totcur cur,b.totamt amt,b.disdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM bdd b,pts s,adr a,pta p WHERE b.docflg = 'disadv' AND s.rol = 'ben' AND s.objtyp = 'bdd' AND s.objinr = b.inr AND pta.inr = s.ptainr AND a.inr = pta.objinr";
			  queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.disdat dat,substr(s.adrblk,0,35) bennam "
			    +"FROM bdd rec,pts s  WHERE rec.DOCFLG ='disadv' "
			    +"AND s.objtyp = 'bdd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  this.getSelp().queryBtn(queryClause);
			}
			else if("3".equals(seltyp))
			{
			  //自主开立国内证
			  
			  
			  
			  if(!"1".equals(this.getSysmod().getPty().getPtytyp()))
			    return true;
			  else
			  {
			    queryClause ="SELECT rec.inr trsinr,rec.ownref ref,rec.isscur cur,rec.issamt amt,rec.credat dat,substr(s.adrblk,0,35) bennam "
			      +"FROM did rec,pts s WHERE rec.cretyp='Z' "
			      +"AND s.objtyp = 'did' AND s.rol = 'ben' AND s.objinr=rec.inr "
			      +" AND rec.etyinr='"+this.getSysmod().getEty().getInr()+"'"
			      +" AND  rec.clsdat is  null  AND rec.ownref IS NOT NULL";
			    this.getSelp().queryBtn3(queryClause);
			  }
			}
			
			
			

			return true;
        }

        /**
        *   source:bdtsnd0.@0003.script
        */
        @Rule(target="selp.tmplst",order=100)
        public boolean ruleSelpTmplstN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			//不符点通知
			this.getSelp().sureBtn("bddgrp","bdtsnd");
			ctx.storeData("com.brilliance.bdtsnd.seltyp",seltyp);


			return true;
        }

        /**
        *   source:bdtsnd0.@0004.script
        */
        @Rule(target="selp.tmplst1",order=100)
        public boolean ruleSelpTmplst1N100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			//到单通知
			this.getSelp().sureBtn1("bddgrp","bdtsnd");
			ctx.storeData("com.brilliance.bdtsnd.seltyp",seltyp);

			return true;
        }

        /**
        *   source:bdtsnd0.@0005.script
        */
        @Rule(target="selp.tmplst2",order=100)
        public boolean ruleSelpTmplst2N100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();

			//国内证
			if(!"1".equals(this.getSysmod().getPty().getPtytyp()))
			  return true;
			else
			  this.getSelp().sureBtn3("didgrp","bdtdsn");
			ctx.storeData("com.brilliance.bdtsnd.seltyp",seltyp);

			return true;
        }



        /**
        *   source:bdtsnd0.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.setValues($selp\\seltyp,Platform.getCodetable("selbdtsnd"));
			List<CodetableItem> seltyp = new ArrayList<CodetableItem>();
			if("1".equals(ctx.absGet(Sysmod.class).getPty().getPtytyp()))
			{
			  seltyp.add(new CodetableItem("委托开立买方证下到单通知","1"));
			  seltyp.add(new CodetableItem("委托开立买方证下电提不符点通知","2"));
			  seltyp.add(new CodetableItem("自主开立国内证","3"));
			}
			else
			{
			  seltyp.add(new CodetableItem("买方证下到单通知","1"));
			  seltyp.add(new CodetableItem("买方证下电提不符点通知","2"));
			}
			MdaUtils.setValues(this.getSelp(),"seltyp",seltyp);
			this.getSelp().setSeltyp("1");

			
			
			
			//将查询语句输入selp层的Argument类型控件queryClause字段
			//String queryClause = "SELECT b.inr trsinr,b.stlref ref,b.advcur cur,b.advamt amt,b.rcvdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM bdd b,pts s,adr a,pta p WHERE b.docflg = 'docadv' AND s.rol = 'ben' AND s.objtyp = 'bdd' AND s.objinr = b.inr AND p.inr = s.ptainr AND a.inr = p.objinr";
			String queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			  +"FROM bdd rec,pts s  WHERE (rec.docflg = 'docadv' OR rec.docflg = 'accept' OR rec.docflg = 'hodrej') "
			  +"AND s.objtyp = 'bdd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			  +ctx.absGet(Sysmod.class).getSelection();
			//WHERE (b.docflg = 'docadv'  or b.docflg='accept'  or b.docflg = 'hodrej')"
			this.getSelp().queryBtn1(queryClause);

			return true;
        }








}