package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BetdftVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ledgrp;
import com.ceb.gjjs.mda.manager.module.Betp;
import com.ceb.gjjs.mda.manager.module.Betmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bedgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 出口议付汇票制作
*/
@Transaction(vo= BetdftVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Betdft extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Betdft.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Ledgrp ledgrp;

		@BDGetter
		private Bedgrp bedgrp;

		@BDGetter
		private Betmod betmod;

		@BDGetter
		private Betp betp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Rmkmod rmkmod;


		public Betdft()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBetmod().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBetmod().setBedgrpHolder(()->this.getBedgrp());
           this.getBetmod().setLedgrpHolder(()->this.getLedgrp());
           this.getBetp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBetp().setLedgrpHolder(()->this.getLedgrp());
           this.getBetp().setBedgrpHolder(()->this.getBedgrp());
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.ddamt");}
 				public void setValue(BigDecimal arg){Betdft.this.getBedgrp().getRec().setDdamt(arg);}
 				public BigDecimal getValue(){return Betdft.this.getBedgrp().getRec().getDdamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.bchcod");}
 				public void setValue(String arg){Betdft.this.getBedgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Betdft.this.getBedgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.ddcur");}
 				public void setValue(String arg){Betdft.this.getBedgrp().getRec().setDdcur(arg);}
 				public String getValue(){return Betdft.this.getBedgrp().getRec().getDdcur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.inr");}
 				public void setValue(String arg){Betdft.this.getBedgrp().getRec().setInr(arg);}
 				public String getValue(){return Betdft.this.getBedgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.ownref");}
 				public void setValue(String arg){Betdft.this.getBedgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Betdft.this.getBedgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("bedgrp.rec.ptyinr");}
 				public void setValue(String arg){Betdft.this.getBedgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Betdft.this.getBedgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Betdft.this.getFieldPath("ledgrp.rec.stlref");}
 				public void setValue(String arg){Betdft.this.getLedgrp().getRec().setStlref(arg);}
 				public String getValue(){return Betdft.this.getLedgrp().getRec().getStlref();}}
			 );
           this.getMtabut().setRecHolder(()->this.getBedgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:betdft.@0005.script
        */
        @Rule(target="betp.add",order=100)
        public boolean ruleBetpAddN100(){
            IContext ctx = MdaEnv.getContext();
            

			ctx.getDaoSession().dbReadset(this.getBetp().getClslst(),new Argument<String>("typ","betdft"),new Argument<String>("flg","8"),new Argument<Object>("status",NE,"0"));
			
			this.getBetp().setTempvar(NULLSTR);
			
			

			return true;
        }

        /**
        *   source:betdft.@0006.script
        */
        @Rule(target="betp.clslst",order=100)
        public boolean ruleBetpClslstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index=0;
			if(index<0)
			  return false;
			this.getBetp().setTempvar(NULLSTR);
			this.getBetp().setTempvar(this.getBetp().getClslst().getElement(index).getClstxt());
			

			return true;
        }

        /**
        *   source:betdft.@0007.script
        */
        @Rule(target="betp.ok",order=100)
        public boolean ruleBetpOkN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBetp().getTempvar()))
			{
			  this.getBedgrp().getDocdft().setCls(NULLSTR);
			  this.getBedgrp().getDocdft().setCls(this.getBetp().getTempvar());
			  
			}
			

			return true;
        }



        /**
        *   source:betdft.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbRead(this.getBedgrp().getCls(),new Argument<String>("typ","betdft"),new Argument<String>("flg","8"),new Argument<String>("status","0"));
			this.getBedgrp().getDocdft().setCls(this.getBedgrp().getCls().getClstxt());
			//Platform.setModified($bedgrp\\docdft\\cls);
			/* if(Platform.isEmpty($sysmod\\spt\\ordinr))
			  $\\trnmod.ordNew();
			  $bedgrp\\docdft\\cty.setValue("CHINA");
			  $bedgrp\\rec\\ddcur.setValue("USD");
			  $bedgrp\\docdft\\orderof.setValue("OURSELVES");
			  $bedgrp\\rec\\tenor.setValue("At Sight");
			  $bedgrp\\docdft\\issinf.setValue("L/C No." + CR + "Issuing Date" + CR + "Issuing Bank");
			  */

			return true;
        }












}