package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BetdocVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ledgrp;
import com.ceb.gjjs.mda.manager.module.Betp;
import com.ceb.gjjs.mda.manager.module.Betmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bedgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 出口议付面函制作
*/
@Transaction(vo= BetdocVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Betdoc extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Betdoc.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Ledgrp ledgrp;

		@BDGetter
		private Bedgrp bedgrp;

		@BDGetter
		private Betmod betmod;

		@BDGetter
		private Betp betp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Rmkmod rmkmod;


		public Betdoc()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBetmod().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBetmod().setBedgrpHolder(()->this.getBedgrp());
           this.getBetmod().setLedgrpHolder(()->this.getLedgrp());
           this.getBetp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBetp().setBedgrpHolder(()->this.getBedgrp());
           this.getBetp().setLedgrpHolder(()->this.getLedgrp());
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.doccur");}
 				public void setValue(String arg){Betdoc.this.getBedgrp().getRec().setDoccur(arg);}
 				public String getValue(){return Betdoc.this.getBedgrp().getRec().getDoccur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.docamt");}
 				public void setValue(BigDecimal arg){Betdoc.this.getBedgrp().getRec().setDocamt(arg);}
 				public BigDecimal getValue(){return Betdoc.this.getBedgrp().getRec().getDocamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.ownref");}
 				public void setValue(String arg){Betdoc.this.getBedgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Betdoc.this.getBedgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.bchcod");}
 				public void setValue(String arg){Betdoc.this.getBedgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Betdoc.this.getBedgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.inr");}
 				public void setValue(String arg){Betdoc.this.getBedgrp().getRec().setInr(arg);}
 				public String getValue(){return Betdoc.this.getBedgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("bedgrp.rec.ptyinr");}
 				public void setValue(String arg){Betdoc.this.getBedgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Betdoc.this.getBedgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Betdoc.this.getFieldPath("ledgrp.rec.stlref");}
 				public void setValue(String arg){Betdoc.this.getLedgrp().getRec().setStlref(arg);}
 				public String getValue(){return Betdoc.this.getLedgrp().getRec().getStlref();}}
			 );
           this.getMtabut().setRecHolder(()->this.getBedgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:betdoc.@0001.script
        */
        @Rule(target="mtabut.dft",order=100)
        public boolean ruleMtabutDftN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream stream =this.getMtabut().getDft();
			this.getSysmod().getPdfmod().generatorFreePdf(stream,this.getBetp().getLogo());

			return true;
        }

        /**
        *   source:betdoc.@0006.script
        */
        @Rule(target="bedgrp.docdft.sdutyp",order=100)
        public boolean ruleBedgrpDocdftSdutypN100(){
            IContext ctx = MdaEnv.getContext();
            

			this.getBedgrp().getDocdft().setCls(NULLSTR);
			MdaUtils.clear(this.getBedgrp().getCls());
			String sdutyp= this.getBedgrp().getDocdft().getSdutyp();
			log.debug("{}","sdutyp="+sdutyp);
			ctx.getDaoSession().dbRead(this.getBedgrp().getCls(),new Argument<String>("typ",sdutyp),new Argument<String>("flg","8"),new Argument<String>("status","0"));
			if(MdaUtils.isEmpty(this.getBedgrp().getCls().getInr()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("betdoc","CT000010"),MdaUtils.getI18NString("betdoc","CT000011"));
			  return false;
			}
			this.getBedgrp().getDocdft().setCls(this.getBedgrp().getCls().getClstxt());
			

			return true;
        }

        /**
        *   source:betdoc.@0007.script
        */
        @Rule(target="betp.add",order=100)
        public boolean ruleBetpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getBetp().setTempvar(NULLSTR);
			String sdutyp= this.getBedgrp().getDocdft().getSdutyp();
			ctx.getDaoSession().dbReadset(this.getBetp().getClslst(),new Argument<String>("typ",sdutyp),new Argument<String>("flg","8"),new Argument<Object>("status",NE,"0"));
			
			
			

			return true;
        }

        /**
        *   source:betdoc.@0008.script
        */
        @Rule(target="betp.clslst",order=100)
        public boolean ruleBetpClslstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index=0;
			if(index<0)
			  return false;
			this.getBetp().setTempvar(NULLSTR);
			this.getBetp().setTempvar(this.getBetp().getClslst().getElement(index).getClstxt());
			

			return true;
        }

        /**
        *   source:betdoc.@0009.script
        */
        @Rule(target="betp.ok",order=100)
        public boolean ruleBetpOkN100(){
            IContext ctx = MdaEnv.getContext();
            

			this.getBedgrp().getDocdft().setCls(NULLSTR);
			this.getBedgrp().getDocdft().setCls(this.getBetp().getTempvar());
			
			

			return true;
        }


        /**
        *   source:betdoc.@0004.script
        */
        @Check(target="bedgrp.docdft.sdutyp",order=100)
        public boolean checkBedgrpDocdftSdutypN100(){
            IContext ctx = MdaEnv.getContext();
            

			String sdutyp= this.getBedgrp().getDocdft().getSdutyp();
			ctx.getDaoSession().dbRead(this.getBedgrp().getCls(),new Argument<String>("typ",sdutyp),new Argument<String>("flg","8"),new Argument<String>("status","0"));
			this.getBedgrp().getDocdft().setCls(this.getBedgrp().getCls().getClstxt());
			

			return true;
        }


        /**
        *   source:betdoc.@0005.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getBedgrp().getDocdft().setSdutyp("betdoc1");
			ctx.getDaoSession().dbRead(this.getBedgrp().getCls(),new Argument<String>("typ","betdoc1"),new Argument<String>("flg","8"),new Argument<String>("status","0"));
			this.getBedgrp().getDocdft().setCls(this.getBedgrp().getCls().getClstxt());

			return true;
        }












}