package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.Bettpl1VO;

import com.ceb.gjjs.mda.manager.module.Tplgrp;
import com.ceb.gjjs.mda.manager.module.Tplmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Tplp;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 代客制单(客户选择)
*/
@Transaction(vo= Bettpl1VO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bettpl1 extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bettpl1.class);

		@BDGetter
		private Tplgrp tplgrp;

		@BDGetter
		private Tplmod tplmod;

		@BDGetter
		private Tplp tplp;

		@BDGetter
		private Sysmod sysmod;


		public Bettpl1()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getTplmod().setTplgrpHolder(()->this.getTplgrp());
           this.getTplp().setTplgrpHolder(()->this.getTplgrp());
        }

        /**
        *   source:bettpl1.@0002.script
        */
        @Rule(target="tplp.search",order=100)
        public boolean ruleTplpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			searchPty();
			this.getTplp().setPtynam(this.getTplgrp().getPty().getNam());
			
			loadled();

			return true;
        }

        /**
        *   source:bettpl1.@0003.script
        */
        @Rule(target="tplp.cancel",order=100)
        public boolean ruleTplpCancelN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getTplgrp().getPty());
			MdaUtils.clear(this.getTplgrp().getLedlst());
			

			return true;
        }

        /**
        *   source:bettpl1.@0004.script
        */
        @Rule(target="tplp.sure",order=100)
        public boolean ruleTplpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getTplgrp().getLedlst().fullSize();
			if(index < 0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("bettpl1","CT000004"),MdaUtils.getI18NString("bettpl1","CT000005"));
			  return true;
			}
			this.getTplgrp().getLedtmp().copyValue(this.getTplgrp().getLedlst().getElement(index));
			ctx.storeData("com.brilliance.bettpl1.ledtmp",this.getTplgrp().getLedtmp());
			ctx.storeData("com.brilliance.bettpl1.pty",this.getTplgrp().getPty());
			

			return true;
        }

        /**
        *   source:bettpl1.@0005.script
        */
        @Rule(target="tplp.ptyncid",order=100)
        public boolean ruleTplpPtyncidN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  Platform.clear($tplgrp\\pty);
			  Platform.dbRead($tplgrp\\pty,new Argument<String>("ncid",$tplp\\ptyncid));
			  $tplp\\ptynam.setValue($tplgrp\\pty\\nam.getValue());
			  log.debug("Search Ptynam = "+$tplp\\ptynam);
			  Platform.setModified($tplp\\ptynam);
			  loadled();
			  */

			return true;
        }



        /**
        *   source:bettpl1.@0006.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			String ptytyp = this.getSysmod().getPty().getPtytyp();
			if("2".equals(ptytyp)  ||  "3".equals(ptytyp))
			{
			  ctx.getDaoSession().dbRead(this.getTplgrp().getPty(),new Argument<String>("inr",this.getSysmod().getPty().getInr()));
			  this.getTplp().setPtyncid(this.getTplgrp().getPty().getNcid());
			  this.getTplp().setPtynam(this.getTplgrp().getPty().getNam());
			  
			  
			  
			  
			  
			  loadled();
			}

			return true;
        }


        /**
        *   source:bettpl1.@0000.script
        */
        public void loadled()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getTplgrp().getLedlst());
			String sql = "SELECT rec.inr trsinr,rec.stlref ref,rec.lcccur cur,rec.lccamt amt,rec.advdat dat,s.adrblk aplnam";
			sql += " FROM led rec,pts s";
			sql += " WHERE s.rol = 'apl' AND s.objinr = rec.inr AND s.objtyp = 'led'";
			sql += " AND rec.ptyinr = '"+this.getTplgrp().getPty().getInr()+"'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> trsinr = new Argument<String>("trsinr");
			Argument<String> ref = new Argument<String>("ref");
			Argument<String> cur = new Argument<String>("cur");
			Argument<BigDecimal> amt = new Argument<BigDecimal>("amt");
			Argument<Date> dat = new Argument<Date>("dat");
			Argument<String> aplnam = new Argument<String>("aplnam");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(trsinr,ref,cur,amt,dat,aplnam);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			    this.getTplgrp().getLedlst().add(trsinr,ref,cur,amt,dat,aplnam);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:bettpl1.@0007.script
        */
        public void searchPty()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String extKey = this.getTplp().getPtyncid();
			MdaUtils.clear(this.getTplgrp().getPty());
			String sql = "SELECT inr FROM pty WHERE cid = '"+extKey+"' AND status = '0'";
			//判断当前机构是光大还是商行
			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			  sql += " AND (ptytyp = '1' OR ptytyp = '2')";
			else if("1".equals(this.getSysmod().getPty().getPtytyp())&&!extKey.equals(this.getSysmod().getPty().getNcid()))
			  sql += " AND ptytyp = '3' AND inr IN(SELECT preptyinr FROM ptr WHERE ptrtyp = '2' AND nxtptyinr = '"+this.getSysmod().getPty().getInr()+"')";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbFetchFields(inr);
			log.debug("{}","searchPty pty is NOT Found! "+MdaUtils.isEmpty(inr.value));
			if(MdaUtils.isEmpty(inr.value))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bettpl1","CT000020"),MdaUtils.getI18NString("bettpl1","CT000021"));
			  ctx.getDaoSession().dbCloseCursor();
			  return;
			}
			else
			  ctx.getDaoSession().dbRead(this.getTplgrp().getPty(),new Argument<String>("inr",String.valueOf(inr.value)));
			log.debug("{}","Search Pty inr = "+this.getTplgrp().getPty().getInr());
			ctx.getDaoSession().dbCloseCursor();
		}





}