package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BhgsadVO;

import com.ceb.gjjs.mda.manager.module.Gsdgrp;
import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bhtp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 保函文本新增交易
*/
@Transaction(vo= BhgsadVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bhgsad extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bhgsad.class);

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Gsdgrp gsdgrp;

		@BDGetter
		private Bhtp bhtp;

		@BDGetter
		private Trnmod trnmod;


		public Bhgsad()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBhtp().setGsdgrpHolder(()->this.getGsdgrp());
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new java.math.BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:bhgsad.@0000.script
        */
        @Rule(target="bhtp.sav",order=100)
        public boolean ruleBhtpSavN100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbBegin();
			String inr = Platform.sdbCounter("gsd");
			this.getGsdgrp().getGsd().setInr(inr);

			//补充：清空用户输入的文本编号或者页面上不显示文本编号也可以
			//Platform.clear($gsdgrp\\gsd\\wbinr);
			
			//
			if(MdaUtils.isEmpty(this.getGsdgrp().getGsd().getWbinr()))
			{
			  log.info("{}","自动生成文本编号");
			  if("Q".equals(this.getGsdgrp().getGsd().getBhtyp()))
			  {
			    this.getGsdgrp().getGsd().setWbinr("TB"+inr);
			  }
			  else if("N".equals(this.getGsdgrp().getGsd().getBhtyp()))
			  {
			    this.getGsdgrp().getGsd().setWbinr("LY"+inr);
			  }
			  else if("A".equals(this.getGsdgrp().getGsd().getBhtyp()))
			  {
			    this.getGsdgrp().getGsd().setWbinr("YFK"+inr);
			  }
			  else if("1".equals(this.getGsdgrp().getGsd().getBhtyp()))
			  {
			    this.getGsdgrp().getGsd().setWbinr("NMG"+inr);
			  }
			  else if("D".equals(this.getGsdgrp().getGsd().getBhtyp()))
			  {
			    this.getGsdgrp().getGsd().setWbinr("ZL"+inr);
			  }
			}

			//补充：文本状态既然是固定的，页面应该不显示吧？
			this.getGsdgrp().getGsd().setWbsta("1");
			log.info("{}","上传的文件："+this.getGsdgrp().getGsd().getDocx());
			if(MdaUtils.isEmpty(this.getGsdgrp().getGsd().getDocx()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsad","CT000000"),MdaUtils.getI18NString("bhgsad","CT000001"));
			  return true;
			}
			Date today = MdaUtils.today();
			log.info("{}","today==="+today);
			this.getGsdgrp().getGsd().setWbdat(today);
			//$gsdgrp\\gsd\\wbdat.setValue(Platform.format(today,"yyyy-MM-dd hh:mm:ss"));
			
			log.info("{}","归属机构1："+this.getSysmod().getPty().getCid());
			this.getGsdgrp().getGsd().setBchcod(this.getSysmod().getPty().getCid());
			ctx.getDaoSession().dbInsert(this.getGsdgrp().getGsd());
			log.info("{}","Insert gsd inr = "+this.getGsdgrp().getGsd().getInr());
			ctx.getDaoSession().dbCommit();

			//补充:  页面信息没有填全时也会提示操作成功，但是数据库没有数据，tomcat日志报错，
			//     页面填全时就会保存成功，是不是应该设置为必输项
			
			if(ctx.getErrorCode()!=NO_ERROR)
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsad","CT000008"),MdaUtils.getI18NString("bhgsad","CT000009"));
			  return true;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsad","CT000014"),MdaUtils.getI18NString("bhgsad","CT000015"));
			

			return true;
        }

        /**
        *   source:bhgsad.@0001.script
        */
        @Rule(target="bhtp.can",order=100)
        public boolean ruleBhtpCanN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bhgsad.@0004.script
        */
        @Rule(target="bhtp.docxdo",order=100)
        public boolean ruleBhtpDocxdoN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","docxdo============================================");
			Object[] obj = (Object[])MdaUtils.getEventData();
			//IStream stream = $bhtp\\docxdo.getValue();
			IStream stream = this.getBhtp().getDocxdo();
			upLoad(stream,obj);

			return true;
        }




        /**
        *   source:bhgsad.@0002.script
        */
        public void upLoad(IStream stream,Object[] obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","进入方法");
			String docxNam = obj[1].toString();
			int index = docxNam.indexOf(".");
			log.info("{}","源文件名========"+docxNam);
			String postfix = docxNam.substring(index + 1);
			log.info("{}","后缀名========"+postfix);
			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			String filnam = this.getGsdgrp().getGsd().getWbinr() + time + "." + postfix;
			if(postfix.equals("docx"))
			{
			  String filPath = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/data/szdzbh/bilmdl/"+filnam);
			  //String filWhlNam = filPath+"\\\\"+ docxNam;
			  if(MdaUtils.fileExists(filPath))
			    MdaUtils.fileDelete(filPath);
			  MdaUtils.streamSave(stream,filPath);
			  log.info("{}","filWhlNam========"+filPath);
			  //上传文件名称
			  this.getGsdgrp().getGsd().setDocx(filPath);
			  //源文件名称
			  this.getGsdgrp().getGsd().setOdocx(docxNam);
			  this.getGsdgrp().getGsd().setFilenam(filnam);
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsad","CT000002"),MdaUtils.getI18NString("bhgsad","CT000003"));
			  return;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsad","CT000004"),MdaUtils.getI18NString("bhgsad","CT000005"));
		}






}