package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BhgsrkVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Gsdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bhtp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 保函文本入库
*/
@Transaction(vo= BhgsrkVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bhgsrk extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bhgsrk.class);

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Gsdgrp gsdgrp;

		@BDGetter
		private Bhtp bhtp;


		public Bhgsrk()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new java.math.BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
           this.getBhtp().setGsdgrpHolder(()->this.getGsdgrp());
        }

        /**
        *   source:bhgsrk.@0000.script
        */
        @Rule(target="bhtp.add",order=100)
        public boolean ruleBhtpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bhgsrk.@0001.script
        */
        @Rule(target="bhtp.mod",order=100)
        public boolean ruleBhtpModN100(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0){
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000000"),MdaUtils.getI18NString("bhgsrk","CT000001"));
			return true;
			}
			//如果没有分行经办权限，不允许修改
			String wbsta = this.getBhtp().getGsdlst().getElement(i).getWbsta();
			if(!"1".equals(wbsta))
			{
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000140"),MdaUtils.getI18NString("bhgsrk","CT000141"));
			return true;
			}
			String inr = this.getBhtp().getGsdlst().getElement(i).getInr();
			log.debug("{}","选中记录inr="+inr);
			ctx.storeData("bhgsinr",inr);
			

			return true;
        }

        /**
        *   source:bhgsrk.@0002.script
        */
        @Rule(target="bhtp.del",order=100)
        public boolean ruleBhtpDelN100(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0){
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000002"),MdaUtils.getI18NString("bhgsrk","CT000003"));
			return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("bhgsrk","CT000004"),MdaUtils.getI18NString("bhgsrk","CT000005")))
			{
			return true;
			}
			String inr = this.getBhtp().getGsdlst().getElement(i).getInr();
			log.info("{}","选中记录inr="+inr);
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbDelete(this.getBhtp().getGsdgrp().getGsd(),new Argument("inr",inr));
			ctx.getDaoSession().dbDelete(this.getBhtp().getGsdgrp().getWblog(),new Argument("gsdinr",inr));
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			ctx.getDaoSession().dbRollback();
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000124"),MdaUtils.getI18NString("bhgsrk","CT000125"));
			return false;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000186"),MdaUtils.getI18NString("bhgsrk","CT000187"));
			

			return true;
        }

        /**
        *   source:bhgsrk.@0004.script
        */
        @Rule(target="bhtp.sub",order=50)
        public boolean ruleBhtpSubN50(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000016"),MdaUtils.getI18NString("bhgsrk","CT000017"));
			  return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("bhgsrk","CT000020"),MdaUtils.getI18NString("bhgsrk","CT000021")))
			{
			  return false;
			}
			log.info("{}","业务处理开始，ORDER编号:50");
			log.info("{}","客户名称["+ctx.absGet(Sysmod.class).getPty().getNam()+"],客户号["+ctx.absGet(Sysmod.class).getPty().getNcid()+"]");
			log.info("{}","操作员ID["+ctx.absGet(Sysmod.class).getUsr().getOid()+"],操作员登陆名["+ctx.absGet(Sysmod.class).getUsr().getLgnnam()+"]");

			if("1".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())&&(!"1".equals(this.getSysmod().getPty().getLvl())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000028"),MdaUtils.getI18NString("bhgsrk","CT000029"));
			  return false;
			}
			else if("2".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())&&(!"1".equals(this.getSysmod().getPty().getLvl())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000030"),MdaUtils.getI18NString("bhgsrk","CT000031"));
			  return false;
			}
			else if("3".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())&&(!"0".equals(this.getSysmod().getPty().getLvl())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000184"),MdaUtils.getI18NString("bhgsrk","CT000185"));
			  return false;
			}
			else if("4".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())&&(!"0".equals(this.getSysmod().getPty().getLvl())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000224"),MdaUtils.getI18NString("bhgsrk","CT000225"));
			  return false;
			}
			else if("0".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())||("5".equals(this.getBhtp().getGsdlst().getElement(i).getWbsta())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000226"),MdaUtils.getI18NString("bhgsrk","CT000227"));
			  return false;
			}
			else if(this.getSysmod().getUsr().getInr().equals(this.getBhtp().getGsdlst().getElement(i).getUsrinr1())||(this.getSysmod().getUsr().getInr().equals(this.getBhtp().getGsdlst().getElement(i).getUsrinr2())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000228"),MdaUtils.getI18NString("bhgsrk","CT000229"));
			  return false;
			}
			else
			{

			}

			/*
			  //检查是否有经办权限
			  if(!Platform.isEmpty($\\trnmod\\trninr))
			  {
			  if(!$\\sysmod.checkRight(Platform.getTransName()))
			  {
			  log.warn("当前用户没有复核单一窗口业务权限，退出！");
			  return false;
			  }
			  }
			  else
			  {
			  if(!$\\sysmod.checkSubmitRight(Platform.getTransName()))
			  {
			  log.warn("当前用户没有经办权限，退出！");
			  return false;
			  }
			  }*/
			String wbsta = this.getBhtp().getGsdlst().getElement(i).getWbsta();
			//提交记录日志 wblog表
			ctx.getDaoSession().dbBegin();

			this.getGsdgrp().getWblog().setInr(Platform.sdbCounter("wblog"));
			this.getGsdgrp().getWblog().setOusr(ctx.absGet(Sysmod.class).getUsr().getLgnnam());
			this.getGsdgrp().getWblog().setOpty(ctx.absGet(Sysmod.class).getUsr().getPtynam());
			Date today = MdaUtils.today();
			this.getGsdgrp().getWblog().setOtime(MdaUtils.format(today,"yyyy-MM-dd HH:mm:ss"));
			this.getGsdgrp().getWblog().setOact("提交");
			this.getGsdgrp().getWblog().setWbinr(this.getBhtp().getGsdlst().getElement(i).getWbinr());
			this.getGsdgrp().getWblog().setWbsta(wbsta);
			ctx.getDaoSession().dbInsert(this.getGsdgrp().getWblog());

			//更新保函文本状态
			String sql = "";
			if("0".equals(wbsta))
			{
			  sql = "update gsd set wbsta='1' where inr =?";
			  ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());
			}
			else if("1".equals(wbsta))
			{
			  sql = "update gsd set wbsta='2',usrinr1 = '" + this.getSysmod().getUsr().getInr() +"' where inr =?";
			  ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());
			}
			else if("2".equals(wbsta))
			{
			  sql = "update gsd set wbsta='3' where inr =?";
			  ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());
			}
			else if("3".equals(wbsta))
			{
			  sql = "update gsd set wbsta='4',usrinr2 = '" + this.getSysmod().getUsr().getInr() +"' where inr =?";
			  ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());
			}
			else if("4".equals(wbsta))
			{
			  sql = "update gsd set wbsta='5' where inr =?";
			  ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());
			}
			else if("5".equals(wbsta))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000230"),MdaUtils.getI18NString("bhgsrk","CT000231"));
			  return true;
			}
			ctx.getErrorCode();
			ctx.getDaoSession().dbCloseCursor();
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000232"),MdaUtils.getI18NString("bhgsrk","CT000233"));
			  return false;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000196"),MdaUtils.getI18NString("bhgsrk","CT000197"));
			


			return true;
        }

        /**
        *   source:bhgsrk.@0005.script
        */
        @Rule(target="bhtp.sel",order=100)
        public boolean ruleBhtpSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			String querysta = this.getBhtp().getGsdgrp().getGsd().getWbsta();
			String querytyp = this.getBhtp().getGsdgrp().getGsd().getBhtyp();
			Date querybdat = this.getBhtp().getBegdat();
			Date queryedat = this.getBhtp().getEnddat();

			if(MdaUtils.isEmpty(querysta)&&MdaUtils.isEmpty(querytyp)&&MdaUtils.isEmpty(querybdat)&&MdaUtils.isEmpty(queryedat))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000172"),MdaUtils.getI18NString("bhgsrk","CT000173"));
			  return true;
			}

			if((!MdaUtils.isEmpty(querybdat)&&MdaUtils.isEmpty(queryedat))||(MdaUtils.isEmpty(querybdat)&&!MdaUtils.isEmpty(queryedat)))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000174"),MdaUtils.getI18NString("bhgsrk","CT000175"));
			  return true;
			}
			if(!MdaUtils.isEmpty(querysta)&&MdaUtils.isEmpty(querytyp)&&MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("wbsta",querysta));
			}
			else if(MdaUtils.isEmpty(querysta)&&!MdaUtils.isEmpty(querytyp)&&MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("bhtyp",querytyp));
			}
			else if(MdaUtils.isEmpty(querysta)&&MdaUtils.isEmpty(querytyp)&&!MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<Date>("wbdat",GE,querybdat),new Argument<Date>("wbdat",LE,queryedat));
			}
			else if(!MdaUtils.isEmpty(querysta)&&!MdaUtils.isEmpty(querytyp)&&MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("wbsta",querysta),new Argument<String>("bhtyp",querytyp));
			}
			else if(!MdaUtils.isEmpty(querysta)&&MdaUtils.isEmpty(querytyp)&&!MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("wbsta",querysta),new Argument<Date>("wbdat",GE,querybdat),new Argument<Date>("wbdat",LE,queryedat));
			}
			else if(MdaUtils.isEmpty(querysta)&&!MdaUtils.isEmpty(querytyp)&&!MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("bhtyp",querytyp),new Argument<Date>("wbdat",GE,querybdat),new Argument<Date>("wbdat",LE,queryedat));
			}
			else if(!MdaUtils.isEmpty(querysta)&&!MdaUtils.isEmpty(querytyp)&&!MdaUtils.isEmpty(querybdat))
			{
			  ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("wbsta",querysta),new Argument<String>("bhtyp",querytyp),new Argument<Date>("wbdat",GE,querybdat),new Argument<Date>("wbdat",LE,queryedat));
			}

			

			return true;
        }

        /**
        *   source:bhgsrk.@0006.script
        */
        @Rule(target="bhtp.sellog",order=100)
        public boolean ruleBhtpSellogN100(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0){
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000036"),MdaUtils.getI18NString("bhgsrk","CT000037"));
			return true;
			}
			String inr = this.getBhtp().getGsdlst().getElement(i).getWbinr();
			log.info("{}","选中记录inr="+inr);
			ctx.storeData("bhgsinr",inr);
			

			return true;
        }

        /**
        *   source:bhgsrk.@0007.script
        */
        @Rule(target="bhtp.back",order=100)
        public boolean ruleBhtpBackN100(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0){
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000110"),MdaUtils.getI18NString("bhgsrk","CT000111"));
			return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("bhgsrk","CT000112"),MdaUtils.getI18NString("bhgsrk","CT000113")))
			{
			return false;
			}
			log.info("{}","业务处理开始，ORDER编号:50");
			log.info("{}","客户名称["+ctx.absGet(Sysmod.class).getPty().getNam()+"],客户号["+ctx.absGet(Sysmod.class).getPty().getNcid()+"]");
			log.info("{}","操作员ID["+ctx.absGet(Sysmod.class).getUsr().getOid()+"],操作员登陆名["+ctx.absGet(Sysmod.class).getUsr().getLgnnam()+"]");

			//检查是否有经办权限
			if(!MdaUtils.isEmpty(ctx.absGet(Trnmod.class).getTrninr()))
			{
			if(!ctx.absGet(Sysmod.class).checkRight(ctx.getTransName()))
			{
			  log.warn("{}","当前用户没有复核单一窗口业务权限，退出！");
			  return false;
			}
			}
			else
			{
			if(!ctx.absGet(Sysmod.class).checkSubmitRight(ctx.getTransName()))
			{
			  log.warn("{}","当前用户没有经办权限，退出！");
			  return false;
			}
			}
			String wbsta = this.getBhtp().getGsdlst().getElement(i).getWbsta();
			if("0".equals(wbsta))
			{
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000114"),MdaUtils.getI18NString("bhgsrk","CT000115"));
			return true;
			}

			//退回记录日志 wblog表
			ctx.getDaoSession().dbBegin();

			this.getGsdgrp().getWblog().setInr(Platform.sdbCounter("wblog"));
			this.getGsdgrp().getWblog().setOusr(ctx.absGet(Sysmod.class).getUsr().getLgnnam());
			this.getGsdgrp().getWblog().setOpty(ctx.absGet(Sysmod.class).getUsr().getPtynam());
			Date today = MdaUtils.today();

			this.getGsdgrp().getWblog().setOtime(MdaUtils.format(today,"yyyy-MM-dd HH:mm:ss"));
			this.getGsdgrp().getWblog().setOact("退回");
			this.getGsdgrp().getWblog().setWbinr(this.getBhtp().getGsdlst().getElement(i).getWbinr());
			this.getGsdgrp().getWblog().setWbsta(wbsta);
			ctx.getDaoSession().dbInsert(this.getGsdgrp().getWblog());
			//更新保函文本状态,目前做成不论在什么状态，都退回至分行经办
			String sql = "update gsd set wbsta='1' where inr =?";
			ctx.getDaoSession().dbExecuteSQL(sql,this.getBhtp().getGsdlst().getElement(i).getInr());

			ctx.getDaoSession().dbCloseCursor();
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			ctx.getDaoSession().dbRollback();
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000116"),MdaUtils.getI18NString("bhgsrk","CT000117"));
			return false;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000118"),MdaUtils.getI18NString("bhgsrk","CT000119"));
			

			return true;
        }

        /**
        *   source:bhgsrk.@0012.script
        */
        @Rule(target="bhtp.download",order=100)
        public boolean ruleBhtpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			int i = 0;
			if(i<0){
			  ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000188"),MdaUtils.getI18NString("bhgsrk","CT000189"));
			return true;
			}
			String fileName = this.getBhtp().getGsdlst().getElement(i).getDocx();

			//标准保函格式文本
			String wbinr = this.getBhtp().getGsdlst().getElement(i).getWbinr();
			//Platform.dbRead($gitp\\gsdgrp\\gsd,new Argument<String>("wbinr",wbinr));
			log.info("{}","标准格式文本filnam:"+this.getBhtp().getGsdlst().getElement(i).getFilenam());

			if(MdaUtils.isEmpty(wbinr))
			{
			ctx.setMessage(MdaUtils.getI18NString("bhgsrk","CT000190"),MdaUtils.getI18NString("bhgsrk","CT000191"));
			return true;
			}

			//source  docx原目标路径
			//target  转换后html路径
			String source = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),("/data/szdzbh/bilmdl/" + this.getBhtp().getGsdlst().getElement(i).getFilenam()));
			String target = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),("/data/pdf/bilhtml/" + wbinr + ".html"));
			log.info("{}","stawebtext source:"+source);
			log.info("{}","stawebtext target:"+target);
			MdaUtils.invoke("com.brilliance.utils.WordCompareUtil","docx2html",source,target);

			String htmlsrc = "/bank/pdf/bilhtml/"+ wbinr + ".html";
			MdaUtils.invoke("client:","bhcompare",htmlsrc);

			/*
			if(!Platform.fileExists(fileName))
			{
			log.error("未找到序列化文件");
			return;
			}
			
			IStream is = $bhtp\\docx.getValue();
			Platform.streamLoad(is,fileName);
			Platform.loadData($bhtp,is);
			Map<String,String> df = new HashMap<String,String>();
			df.put($bhtp\\gsdlst[i]\\wbnam.getValue(),$bhtp\\gsdlst[i]\\wbdes.getValue());
			
			Platform.invoke("com.brilliance.etrade.document.PDFDocumentGenerator","generateApplyDocument",fileName,df,"",is);
			*/

			return true;
        }



        /**
        *   source:bhgsrk.@0003.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbReadset(this.getBhtp().getGsdlst(),new Argument<String>("inr",DESC));
			log.debug("{}","读取到记录数"+this.getBhtp().getGsdlst().size());
			

			return true;
        }








}