package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BhgsupVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Gsdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bhtp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 保函文本修改交易
*/
@Transaction(vo= BhgsupVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bhgsup extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bhgsup.class);

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Gsdgrp gsdgrp;

		@BDGetter
		private Bhtp bhtp;


		public Bhgsup()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new java.math.BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
           this.getBhtp().setGsdgrpHolder(()->this.getGsdgrp());
        }

        /**
        *   source:bhgsup.@0001.script
        */
        @Rule(target="bhtp.sav",order=100)
        public boolean ruleBhtpSavN100(){
            IContext ctx = MdaEnv.getContext();
            
			//补充：如果文本编号是自动生成，此处应该设置文本编号不能修改？如果保函类别修改了，编号怎么处理
			
			ctx.getDaoSession().dbBegin();
			log.info("{}","Update gsd inr = "+this.getGsdgrp().getGsd().getInr());
			if(MdaUtils.isEmpty(this.getGsdgrp().getGsd().getDocx()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsup","CT000002"),MdaUtils.getI18NString("bhgsup","CT000003"));
			  return true;
			}
			ctx.getDaoSession().dbUpdate(this.getGsdgrp().getGsd());
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("bhgsup","CT000004"),MdaUtils.getI18NString("bhgsup","CT000005"));
			

			return true;
        }

        /**
        *   source:bhgsup.@0002.script
        */
        @Rule(target="bhtp.can",order=100)
        public boolean ruleBhtpCanN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bhgsup.@0003.script
        */
        @Rule(target="bhtp.docxdo",order=100)
        public boolean ruleBhtpDocxdoN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","docxdo============================================");
			Object[] obj = (Object[])MdaUtils.getEventData();
			IStream stream = this.getBhtp().getDocxdo();
			upLoad(stream,obj);

			return true;
        }



        /**
        *   source:bhgsup.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            //
			String inr=(String)ctx.restoreData("bhgsinr");
			log.debug("{}","bhgsinr = "+inr);
			ctx.getDaoSession().dbRead(this.getGsdgrp().getGsd(),new Argument<String>("inr",EQ,inr));
			

			return true;
        }


        /**
        *   source:bhgsup.@0004.script
        */
        public void upLoad(IStream stream,Object[] obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","进入方法");
			String docxNam = obj[1].toString();
			int index = docxNam.indexOf(".");
			log.info("{}","源文件名========"+docxNam);
			String postfix = docxNam.substring(index + 1);
			log.info("{}","后缀名========"+postfix);
			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			String filnam = this.getGsdgrp().getGsd().getWbinr() + time + "." + postfix;
			if(postfix.equals("docx"))
			{
			  String filPath = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/data/szdzbh/bilmdl/"+filnam);
			  //String filWhlNam = filPath+"\\\\"+ docxNam;
			  if(MdaUtils.fileExists(filPath))
			    MdaUtils.fileDelete(filPath);
			  MdaUtils.streamSave(stream,filPath);
			  log.info("{}","filWhlNam========"+filPath);
			  //上传文件名称
			  this.getGsdgrp().getGsd().setDocx(filPath);
			  //源文件名称
			  this.getGsdgrp().getGsd().setOdocx(docxNam);
			  this.getGsdgrp().getGsd().setFilenam(filnam);
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("bhgsup","CT000010"),MdaUtils.getI18NString("bhgsup","CT000011"));
			  return;
			}
			ctx.setMessage(MdaUtils.getI18NString("bhgsup","CT000012"),MdaUtils.getI18NString("bhgsup","CT000013"));
		}






}