package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BptopcVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Bptp;
import com.ceb.gjjs.mda.manager.module.Bpdgrp;
import com.ceb.gjjs.mda.manager.module.Bodgrp;
import com.ceb.gjjs.mda.manager.module.Ledgrp;
import com.ceb.gjjs.mda.manager.module.Bptmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Bedgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 出口托收寄单项下来证/托收押汇申请
*/
@Transaction(vo= BptopcVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bptopc extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bptopc.class);

		@BDGetter
		private Bodgrp bodgrp;

		@BDGetter
		private Bpdgrp bpdgrp;

		@BDGetter
		private Bptmod bptmod;

		@BDGetter
		private Bptp bptp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Bedgrp bedgrp;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Ledgrp ledgrp;


		public Bptopc()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBptmod().setBedgrpHolder(()->this.getBedgrp());
           this.getBptmod().setBodgrpHolder(()->this.getBodgrp());
           this.getBptmod().setBpdgrpHolder(()->this.getBpdgrp());
           this.getBptp().setBedgrpHolder(()->this.getBedgrp());
           this.getBptp().setBodgrpHolder(()->this.getBodgrp());
           this.getBptp().setBpdgrpHolder(()->this.getBpdgrp());
           this.getBptp().setLedgrpHolder(()->this.getLedgrp());
           this.getMtabut().setRecHolder(()->this.getBpdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("PD"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.fftamt");}
 				public void setValue(BigDecimal arg){Bptopc.this.getBpdgrp().getRec().setFftamt(arg);}
 				public BigDecimal getValue(){return Bptopc.this.getBpdgrp().getRec().getFftamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.bchcod");}
 				public void setValue(String arg){Bptopc.this.getBpdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Bptopc.this.getBpdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.fftcur");}
 				public void setValue(String arg){Bptopc.this.getBpdgrp().getRec().setFftcur(arg);}
 				public String getValue(){return Bptopc.this.getBpdgrp().getRec().getFftcur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.inr");}
 				public void setValue(String arg){Bptopc.this.getBpdgrp().getRec().setInr(arg);}
 				public String getValue(){return Bptopc.this.getBpdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.ownref");}
 				public void setValue(String arg){Bptopc.this.getBpdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Bptopc.this.getBpdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bpdgrp.rec.ptyinr");}
 				public void setValue(String arg){Bptopc.this.getBpdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Bptopc.this.getBpdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopc.this.getFieldPath("bodgrp.rec.stlref");}
 				public void setValue(String arg){Bptopc.this.getBodgrp().getRec().setStlref(arg);}
 				public String getValue(){return Bptopc.this.getBodgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:bptopc.@0001.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.checkAll($\\);
			//Platform.dbBegin();
			if(!(ctx.checkAll(this.getBodgrp()) && ctx.checkAll(this.getBpdgrp().getRec())))
			  return false;

			BigDecimal fftamt=this.getBptp().getVals(this.getBpdgrp().getRec().getFftamt());
			this.getBpdgrp().getRec().setFftamt(fftamt);
			if(!MdaUtils.isEmpty(this.getBodgrp().getRec().getOccamt()))
			{
			  BigDecimal occamt=this.getBptp().getVals(this.getBodgrp().getRec().getOccamt());
			  this.getBodgrp().getRec().setOccamt(occamt);
			}

			if(MdaUtils.isEmpty(this.getBpdgrp().getCbl().getPts().getNam()))
			{
			  String adrblk=this.getBpdgrp().getCbl().getPts().getAdrblk();
			  String adr[]=adrblk.split("\\n");
			  this.getBpdgrp().getCbl().getPts().setNam(adr[0]);
			}

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  ctx.getDaoSession().dbUpdate(this.getBpdgrp().getRec());
			  String objinr = this.getBpdgrp().getRec().getInr();
			  this.getMtabut().UpdatePtsForBack(this.getBpdgrp().getApl().getPts(),objinr);
			  this.getMtabut().UpdatePtsForBack(this.getBpdgrp().getCbl().getPts(),objinr);
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getBodgrp().getRec().getInr()))
			  {
			    this.getBodgrp().getRec().setInr(Platform.sdbCounter("bod"));
			    ctx.getDaoSession().dbInsert(this.getBodgrp().getRec());
			  }
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			    this.getBpdgrp().getRec().setIbchcod(this.getBpdgrp().getRec().getBchcod());
			  else
			    this.getBpdgrp().getRec().setDbchcod(this.getBpdgrp().getRec().getBchcod());
			  this.getBpdgrp().getRec().setInr(Platform.sdbCounter("bpd"));
			  this.getBpdgrp().getRec().setPntinr(this.getBodgrp().getRec().getInr());
			  this.getBpdgrp().getRec().setPnttyp("bod");
			  this.getBptp().setPtytyp("BOD");
			  this.getBpdgrp().getRec().setPntref(this.getBodgrp().getRec().getStlref());
			  ctx.getDaoSession().dbInsert(this.getBpdgrp().getRec());
			  String objinr = this.getBpdgrp().getRec().getInr();
			  String objtyp = "bpd";
			  this.getBpdgrp().getApl().savpts(objinr,objtyp);
			  this.getBpdgrp().getCbl().savpts(objinr,objtyp);
			  this.getBpdgrp().getDap().getPts().setInr(Platform.sdbCounter("pts"));
			  this.getBpdgrp().getDap().getPts().setObjinr(objinr);
			  this.getBpdgrp().getDap().getPts().setObjtyp( "bpd");
			  ctx.getDaoSession().dbInsert(this.getBpdgrp().getDap().getPts());
			}
			this.dealPDFData();
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:bptopc.@0002.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.dealPDFData();
			IStream stream=this.getMtabut().getApldoc();
			//if("BED".equals($bptp\\ptytyp.getValue()))
			//{
			ctx.absGet(Sysmod.class).generatorPdf("","bptopc",stream,false );
			/*}
			  else if("CPD".equals($bptp\\ptytyp.getValue()))
			  {
			  $\\sysmod.generatorPdf("","bptopc1",stream,false );
			  }*/

			return true;
        }

        /**
        *   source:bptopc.@0011.script
        */
        @Rule(target="bpdgrp.rec.llsty",order=100)
        public boolean ruleBpdgrpRecLlstyN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else if("2".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else if("3".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			}
			else if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getLlsty()))
			{
			  ctx.setFieldError(this,"bpdgrp.rec.llsty",MdaUtils.getI18NString("bptopc","CT000033"));
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else
			{
			  ctx.setFieldError(this,"bpdgrp.rec.llsty",MdaUtils.getI18NString("bptopc","CT000034"));
			  this.getBpdgrp().getRec().setLlsty(NULLSTR);
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  

			}
			
			
			
			

			return true;
        }

        /**
        *   source:bptopc.@0012.script
        */
        @Rule(target="bpdgrp.rec.jssty",order=100)
        public boolean ruleBpdgrpRecJsstyN100(){
            IContext ctx = MdaEnv.getContext();
            
			String str=this.getBpdgrp().getRec().getJssty();
			String js="^[1,2,3,4]{1}";
			Pattern pattern=Pattern.compile(js);
			Matcher matcher = pattern.matcher(str);
			if(!matcher.matches())
			{
			  ctx.setFieldError(this,"bpdgrp.rec.jssty",MdaUtils.getI18NString("bptopc","CT000037"));
			  this.getBpdgrp().getRec().setJssty(NULLSTR);
			}

			/*if(js.equals(str))
			  //if(!"1".equals($bpdgrp\\rec\\jssty.getValue())||!"2".equals($bpdgrp\\rec\\jssty.getValue())||!"3".equals($bpdgrp\\rec\\jssty.getValue())||!"4".equals($bpdgrp\\rec\\jssty.getValue()))
			  {
			  Platform.error($bpdgrp\\rec\\jssty,#CT000038);
			  Platform.clear($bpdgrp\\rec\\jssty);
			  }*/
			

			return true;
        }

        /**
        *   source:bptopc.@0013.script
        */
        @Rule(target="bptp.returns",order=100)
        public boolean ruleBptpReturnsN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bptopc.@0014.script
        */
        @Rule(target="mtabut.sav",order=210)
        public boolean ruleMtabutSavN210(){
            IContext ctx = MdaEnv.getContext();
            
			int cnt = 1;
			String labels = "出口融资申请书";
			String tempfiles = "A:bptopc";

			this.getTrnmod().getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().getApldoc().generatorAllPDF();


			return true;
        }

        /**
        *   source:bptopc.@0016.script
        */
        @Rule(target="bptp.actselect",order=100)
        public boolean ruleBptpActselectN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getBptp().popupActchs();

			return true;
        }

        /**
        *   source:bptopc.@0018.script
        */
        @Rule(target="bptp.actcancel",order=100)
        public boolean ruleBptpActcancelN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bptopc.@0019.script
        */
        @Rule(target="bptp.actsure",order=100)
        public boolean ruleBptpActsureN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index=0;
			int le=this.getBptp().getActlst().fullSize();
			if(index < 0 || index >= le )
			{
			  ctx.setMessage(MdaUtils.getI18NString("bptopc","CT000040"),MdaUtils.getI18NString("bptopc","CT000041"));
			  return true;
			}
			this.getBpdgrp().getRec().setRmbact(this.getBptp().getActlst().getElement(index).getAct());
			
			

			return true;
        }

        /**
        *   source:bptopc.@0020.script
        */
        @Rule(target="mtabut.apldocs",order=100)
        public boolean ruleMtabutApldocsN100(){
            IContext ctx = MdaEnv.getContext();
            
			//$bedgrp\\rec\\docgrd.setValue($latp\\docgrdm.encode());
			//IStream stream=$mtabut\\apldoc.getValue();
			//$\\sysmod.generatorPdf("","letats",stream,false );
			BigDecimal fftamt=this.getBptp().getVals(this.getBpdgrp().getRec().getFftamt());
			this.getBpdgrp().getRec().setFftamt(fftamt);
			
			if(!MdaUtils.isEmpty(this.getBodgrp().getRec().getOccamt()))
			{
			  BigDecimal occamt=this.getBptp().getVals(this.getBodgrp().getRec().getOccamt());
			  this.getBodgrp().getRec().setOccamt(occamt);
			  
			}

			if(MdaUtils.isEmpty(this.getBpdgrp().getCbl().getPts().getNam()))
			{
			  String adrblk=this.getBpdgrp().getCbl().getPts().getAdrblk();
			  String adr[]=adrblk.split("\\n");
			  this.getBpdgrp().getCbl().getPts().setNam(adr[0]);
			  
			}

			this.getBptp().getPdfviw().callPDFComponent("","bptopc","出口融资申请书",1);

			return true;
        }


        /**
        *   source:bptopc.@0004.script
        */
        @Check(target="bpdgrp.rec.fftamt",order=100)
        public boolean checkBpdgrpRecFftamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			BigDecimal fftamt = this.getBpdgrp().getRec().getFftamt();
			BigDecimal docamt = this.getBedgrp().getRec().getDocamt();
			BigDecimal occamt = this.getBodgrp().getRec().getOccamt();
			if(!MdaUtils.isEmpty(docamt))
			{
			  if(fftamt.compareTo(docamt)>0)
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopc","CT000015"));
			}
			if(!MdaUtils.isEmpty(occamt))
			{
			  if(fftamt.compareTo(occamt)>0)
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopc","CT000016"));
			}
			if(!MdaUtils.isEmpty(fftamt))
			{
			  BigDecimal js=MdaUtils.parseDecimal(0.00);
			  if(fftamt.compareTo(js)<0)
			  {
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopc","CT000043"));
			  }
			}
			

			return true;
        }

        /**
        *   source:bptopc.@0005.script
        */
        @Check(target="bpdgrp.rec.conref",order=100)
        public boolean checkBpdgrpRecConrefN100(){
            IContext ctx = MdaEnv.getContext();
            
			if( MdaUtils.isEmpty(this.getBpdgrp().getRec().getConref()))
			  ctx.setFieldError(this,"bpdgrp.rec.conref",MdaUtils.getI18NString("bptopc","CT000018"));

			return true;
        }

        /**
        *   source:bptopc.@0006.script
        */
        @Check(target="bpdgrp.rec.matdat",order=100)
        public boolean checkBpdgrpRecMatdatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBpdgrp().getRec().getMatdat()) && !MdaUtils.isEmpty(this.getBpdgrp().getRec().getFftvaldat()))
			{
			  if(MdaUtils.diff(this.getBpdgrp().getRec().getMatdat(),this.getBpdgrp().getRec().getFftvaldat())==0)
			  {
			    ctx.setFieldError(this,"bpdgrp.rec.matdat",MdaUtils.getI18NString("bptopc","CT000021"));
			  }
			}

			return true;
        }

        /**
        *   source:bptopc.@0009.script
        */
        @Check(target="bpdgrp.rec.isagr",order=100)
        public boolean checkBpdgrpRecIsagrN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!TRUE.equals(this.getBpdgrp().getRec().getIsagr()))
			{
			  ctx.setFieldError(this,"bpdgrp.rec.isagr",MdaUtils.getI18NString("bptopc","CT000030"));
			  return true;
			}

			return true;
        }

        /**
        *   source:bptopc.@0017.script
        */
        @Check(target="bpdgrp.rec.rmbact",order=100)
        public boolean checkBpdgrpRecRmbactN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBptp().getBpdgrp().getRec().getRmbact()))
			{
			  /*String lengt=$bpdgrp\\rec\\rmbact.getValue();
			    if(lengt.length()>17||lengt.length()<17)
			    {
			    Platform.error($bpdgrp\\rec\\rmbact,#CT000039);
			    return;
			    }
			    */
			  Pattern pattern=Pattern.compile("[0-9]*");
			  String rmbact=this.getBpdgrp().getRec().getRmbact();
			  if(!pattern.matcher(rmbact).matches())
			  {
			    ctx.setFieldError(this,"bpdgrp.rec.rmbact",MdaUtils.getI18NString("bptopc","CT000049"));
			  }
			}

			return true;
        }

        /**
        *   source:bptopc.@0021.script
        */
        @Check(target="bpdgrp.rec.fftvaldat",order=200)
        public boolean checkBpdgrpRecFftvaldatN200(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  if(!Platform.isEmpty($bpdgrp\\rec\\fftvaldat) && !Platform.isEmpty($bpdgrp\\rec\\credat))
			  {
			  if(Platform.diff($bpdgrp\\rec\\fftvaldat.getValue(),$bpdgrp\\rec\\credat.getValue())!=0)
			  {
			  if(Platform.diff($bpdgrp\\rec\\fftvaldat.getValue(),$bpdgrp\\rec\\credat.getValue())<0)
			  {
			  Platform.error($bpdgrp\\rec\\fftvaldat,#CT000045);
			  return false;
			  }
			  }
			  }
			  */

			return true;
        }

        /**
        *   source:bptopc.@0022.script
        */
        @Check(target="bpdgrp.rec.days",order=100)
        public boolean checkBpdgrpRecDaysN100(){
            IContext ctx = MdaEnv.getContext();
            
			int days=this.getBpdgrp().getRec().getDays();
			if( days>999 || days<1 )
			{
			  ctx.setFieldError(this,"bpdgrp.rec.days",MdaUtils.getI18NString("bptopc","CT000047"));
			}

			return true;
        }


        /**
        *   source:bptopc.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  if(!($\\sysmod.sptIsLoaded("B")  ||  $\\sysmod.sptIsLoaded("P")  ||  $\\sysmod.sptIsLoaded("T")))
			  {
			  if(Platform.prompt(#CT000028,#CT000029))
			  {
			  Platform.returnToCaller();
			  return false;
			  }
			  }
			  if(Platform.isEmpty($sysmod\\spt\\ordinr))
			  {
			  $trnmod.ordNew();
			  }
			  List<CodetableItem> bchcod =$sysmod.getAndSetBchcodvals();
			  $bpdgrp\\aplnam.setValue($sysmod\\pty\\nam.getValue());
			  Platform.setValues($bpdgrp\\rec\\bchcod,bchcod);
			  if(!Platform.isEmpty(bchcod)&&!$\\sysmod.sptIsLoaded("B")&&!$\\sysmod.sptIsLoaded("P"))
			  $bpdgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			  Platform.setValues($bpdgrp\\rec\\paytyp,Platform.getCodetable("acctyp"));
			  // $bptp\\rmblabel.setValue("人民币账号：");
			  // $bptp\\reblabel.setValue("原币账号：");
			  if(Platform.isEmpty($bpdgrp\\rec\\paytyp))
			  $bpdgrp\\rec\\paytyp.setValue("1");
			  // $bptp.onChangePayTyp();
			  String flg =null;
			  Platform.invisible($bptp\\contquery);
			  if(Platform.isEmpty($bpdgrp\\flg))
			  {
			  IModule  bod=(IModule)Platform.restoreData("com.brilliance.bptopc.ref");
			  if(!Platform.isEmpty(bod))
			  {
			  $bodgrp\\rec.copyValue(bod);
			  $bpdgrp\\flg.setValue("S");// select
			  log.debug("is select");
			  }
			  else
			  {
			  $bpdgrp\\flg.setValue("N");// new
			  log.debug("is new");
			  }
			  $bptp\\ptytyp.setValue("BOD");
			  }
			  else
			  log.debug("is return "+$bpdgrp\\flg.getValue());
			  flg = $bpdgrp\\flg.getValue();
			  if("S".equals(flg))
			  {
			  Platform.disable($bpdgrp\\rec\\credat);
			  Platform.disable($bodgrp\\rec\\stlref);
			  Platform.disable($bodgrp\\rec\\doctypcod);
			  Platform.dbRead($bpdgrp\\cbl\\pts,new Argument<String>("objtyp","bod"),new Argument<String>("rol","clb"),new Argument<String>("objinr",$bodgrp\\rec\\inr.getValue()));
			  Platform.dbRead($bodgrp\\drr\\pts,new Argument<String>("objtyp","bod"),new Argument<String>("rol","drr"),new Argument<String>("objinr",$bodgrp\\rec\\inr.getValue()));
			  Platform.disable($bpdgrp\\cbl\\pts\\extkey);
			  Platform.disable($bpdgrp\\cbl\\pts\\adrblk);
			  Platform.disable($bptp\\cblp);
			  Platform.disable($bptp\\cblp\\sel);
			  Platform.disable($bodgrp\\rec\\setcur);
			  Platform.disable($bodgrp\\rec\\setamt);
			  Platform.disable($bodgrp\\rec\\occcur);
			  Platform.disable($bodgrp\\rec\\occamt);
			  $bpdgrp\\rec\\fftcur.setValue($bodgrp\\rec\\occcur.getValue());
			  Platform.disable($bpdgrp\\rec\\fftcur);
			  // Platform.disable($bodgrp\\rec\\invno);
			  Platform.setNotRequired($bodgrp\\rec\\stlref);
			  Platform.setNotRequired($bodgrp\\rec\\doctypcod);
			  Platform.setNotRequired($bpdgrp\\cbl\\pts\\extkey);
			  Platform.setNotRequired($bpdgrp\\cbl\\pts\\adrblk);
			  Platform.setNotRequired($bodgrp\\rec\\setcur);
			  Platform.setNotRequired($bodgrp\\rec\\setamt);
			  //Platform.setNotRequired($bodgrp\\rec\\invno);
			  //Platform.disable($bpdgrp\\rec\\fftcur);
			  }
			  $bptp\\rgtclu\\clstyp.setValue("bptopn");
			  Platform.disable($bpdgrp\\rec\\xdrat);
			  Platform.disable($bpdgrp\\rec\\gbrat);
			  Platform.disable($bpdgrp\\rec\\jdrat);
			  Platform.disable($bpdgrp\\rec\\qtnote);
			
			  if($\\sysmod.sptIsLoaded("B")  ||  $\\sysmod.sptIsLoaded("P")  ||  $\\sysmod.sptIsLoaded("T"))
			  {
			  if($\\sysmod.sptIsLoaded("B"))
			  {
			  $trnmod\\apldoc.loadApldocByOrdinr($sysmod\\spt\\ordinr.getValue());
			  }
			  if(Platform.isEmpty($bptp\\ptytyp))
			  {
			  $bptp\\ptytyp.setValue($bpdgrp\\rec\\ptytyp.getValue());
			  Platform.setModified($bptp\\ptytyp);
			  }
			
			  List<CodetableItem> yhfkfs= $bptp.getYhfkfsCodeTable($bptp\\ptytyp.getValue());
			  Platform.setValues($bpdgrp\\rec\\fkfs,yhfkfs);
			  Platform.setModified($bpdgrp\\rec\\fkfs);
			  return false;
			  }
			
			  Platform.setRequired($bpdgrp\\rec\\days);
			  $bpdgrp\\rec\\credat.setValue(Platform.today());
			  //$bpdgrp\\rec\\fftcur.setValue("USD");
			  $bpdgrp\\apl\\pty\\ncid.setValue($sysmod\\pty\\ncid.getValue());
			  $bpdgrp\\apl\\pty\\nam.setValue($sysmod\\pty\\nam.getValue());
			  $bpdgrp\\apl\\pts\\extkey.setValue($sysmod\\pty\\ncid.getValue());
			  if(Platform.isEmpty($bodgrp\\rec\\setcur))
			  $bodgrp\\rec\\setcur.setValue("USD");
			  if(Platform.isEmpty($bpdgrp\\rec\\rgtclu))
			  {
			  //Platform.dbRead($bptp\\rgtclu\\cls,new Argument<String>("flg","3"),new Argument<String>("typ","bptopn"),new Argument<String>("status","0"));
			  Platform.dbRead($bptp\\rgtclu\\cls,new Argument<String>("inr",$bptp\\rgtclu.readDefaultClsInr("bptopn")));
			  $bpdgrp\\rec\\rgtclu.setValue($bptp\\rgtclu\\cls\\clstxt.getValue());
			  }
			
			  List<CodetableItem> yhfkfs= $bptp.getYhfkfsCodeTable($bptp\\ptytyp.getValue());
			  Platform.setValues($bpdgrp\\rec\\fkfs,yhfkfs);
			  Platform.setModified($bpdgrp\\rec\\fkfs);
			  */

			return true;
        }

        /**
        *   source:bptopc.@0023.script
        */
        @Init(order=50)
        public boolean	init50(){
            IContext ctx = MdaEnv.getContext();
            
			if(!(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T")))
			{
			  if(MdaUtils.prompt(MdaUtils.getI18NString("bptopc","CT000056"),MdaUtils.getI18NString("bptopc","CT000057")))
			  {
			    
			    return false;
			  }
			}
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			{
			  this.getTrnmod().ordNew();
			}
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			this.getBpdgrp().setAplnam(this.getSysmod().getPty().getNam());
			MdaUtils.setValues(this.getBpdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getBpdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			MdaUtils.setValues(this.getBpdgrp().getRec(),"paytyp",MdaUtils.getCodetable("acctyp"));
			// $bptp\\rmblabel.setValue("人民币账号：");
			// $bptp\\reblabel.setValue("原币账号：");
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getPaytyp()))
			  this.getBpdgrp().getRec().setPaytyp("1");
			// $bptp.onChangePayTyp();
			String flg =null;
			
			if(MdaUtils.isEmpty(this.getBpdgrp().getFlg()))
			{
			  IModule  bod=(IModule)ctx.restoreData("com.brilliance.bptopc.ref");
			  if(!MdaUtils.isEmpty(bod))
			  {
			    this.getBodgrp().getRec().copyValue(bod);
			    this.getBpdgrp().setFlg("S");// select
			    log.debug("{}","is select");
			  }
			  else
			  {
			    this.getBpdgrp().setFlg("N");// new
			    log.debug("{}","is new");
			  }
			  this.getBptp().setPtytyp("BOD");
			}
			else
			  log.debug("{}","is return "+this.getBpdgrp().getFlg());
			flg = this.getBpdgrp().getFlg();
			if("S".equals(flg))
			{
			  
			  
			  
			  ctx.getDaoSession().dbRead(this.getBpdgrp().getCbl().getPts(),new Argument<String>("objtyp","bod"),new Argument<String>("rol","clb"),new Argument<String>("objinr",this.getBodgrp().getRec().getInr()));
			  ctx.getDaoSession().dbRead(this.getBodgrp().getDrr().getPts(),new Argument<String>("objtyp","bod"),new Argument<String>("rol","drr"),new Argument<String>("objinr",this.getBodgrp().getRec().getInr()));
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getBpdgrp().getRec().setFftcur(this.getBodgrp().getRec().getOcccur());
			  
			  // Platform.disable($bodgrp\\rec\\invno);
			  
			  
			  
			  
			  
			  
			  //Platform.setNotRequired($bodgrp\\rec\\invno);
			  //Platform.disable($bpdgrp\\rec\\fftcur);
			}
			this.getBptp().getRgtclu().setClstyp("bptopn");
			
			
			
			

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			{
			  if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			  {
			    this.getTrnmod().getApldoc().loadApldocByOrdinr(this.getSysmod().getSpt().getOrdinr());
			  }
			  if(MdaUtils.isEmpty(this.getBptp().getPtytyp()))
			  {
			    this.getBptp().setPtytyp(this.getBpdgrp().getRec().getPtytyp());
			    
			  }

			  List<CodetableItem> yhfkfs= this.getBptp().getYhfkfsCodeTable(this.getBptp().getPtytyp());
			  MdaUtils.setValues(this.getBpdgrp().getRec(),"fkfs",yhfkfs);
			  
			  return false;
			}

			
			this.getBpdgrp().getRec().setCredat(MdaUtils.today());
			//$bpdgrp\\rec\\fftcur.setValue("USD");
			this.getBpdgrp().getApl().getPty().setNcid(this.getSysmod().getPty().getNcid());
			this.getBpdgrp().getApl().getPty().setNam(this.getSysmod().getPty().getNam());
			this.getBpdgrp().getApl().getPts().setExtkey(this.getSysmod().getPty().getNcid());
			if(MdaUtils.isEmpty(this.getBodgrp().getRec().getSetcur()))
			  this.getBodgrp().getRec().setSetcur("USD");
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getRgtclu()))
			{
			  //Platform.dbRead($bptp\\rgtclu\\cls,new Argument<String>("flg","3"),new Argument<String>("typ","bptopn"),new Argument<String>("status","0"));
			  ctx.getDaoSession().dbRead(this.getBptp().getRgtclu().getCls(),new Argument<String>("inr",this.getBptp().getRgtclu().readDefaultClsInr("bptopn")));
			  this.getBpdgrp().getRec().setRgtclu(this.getBptp().getRgtclu().getCls().getClstxt());
			}

			List<CodetableItem> yhfkfs= this.getBptp().getYhfkfsCodeTable(this.getBptp().getPtytyp());
			MdaUtils.setValues(this.getBpdgrp().getRec(),"fkfs",yhfkfs);
			


			return true;
        }


        /**
        *   source:bptopc.@0007.script
        */
        public void dealPDFData()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

			this.getBptp().setCredat(MdaUtils.format(MdaUtils.today(),"yyyy年MM月dd日"));
			this.getBptp().setRmbact(NULLSTR);
			this.getBptp().setRmaact(NULLSTR);
			if (!MdaUtils.isEmpty(this.getBpdgrp().getRec().getPaytyp()))
			{
			  if("1".equals(this.getBpdgrp().getRec().getPaytyp()))
			    this.getBptp().setRmbact(this.getBpdgrp().getRec().getRmbact());
			  else if("2".equals(this.getBpdgrp().getRec().getPaytyp()))
			    this.getBptp().setRmaact(this.getBpdgrp().getRec().getRmbact());
			}

		}











}