package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BptoplVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Bptp;
import com.ceb.gjjs.mda.manager.module.Bpdgrp;
import com.ceb.gjjs.mda.manager.module.Bodgrp;
import com.ceb.gjjs.mda.manager.module.Ledgrp;
import com.ceb.gjjs.mda.manager.module.Bptmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Radgrp;
import com.ceb.gjjs.mda.manager.module.Bedgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 出口信用证寄单项下来证/托收押汇申请
*/
@Transaction(vo= BptoplVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Bptopl extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Bptopl.class);

		@BDGetter
		private Bedgrp bedgrp;

		@BDGetter
		private Bodgrp bodgrp;

		@BDGetter
		private Bpdgrp bpdgrp;

		@BDGetter
		private Bptmod bptmod;

		@BDGetter
		private Bptp bptp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Ledgrp ledgrp;

		@BDGetter
		private Radgrp radgrp;


		public Bptopl()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBptmod().setBedgrpHolder(()->this.getBedgrp());
           this.getBptmod().setBodgrpHolder(()->this.getBodgrp());
           this.getBptmod().setBpdgrpHolder(()->this.getBpdgrp());
           this.getBptp().setBedgrpHolder(()->this.getBedgrp());
           this.getBptp().setBodgrpHolder(()->this.getBodgrp());
           this.getBptp().setBpdgrpHolder(()->this.getBpdgrp());
           this.getBptp().setLedgrpHolder(()->this.getLedgrp());
           this.getMtabut().setRecHolder(()->this.getBpdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("PD"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.fftamt");}
 				public void setValue(BigDecimal arg){Bptopl.this.getBpdgrp().getRec().setFftamt(arg);}
 				public BigDecimal getValue(){return Bptopl.this.getBpdgrp().getRec().getFftamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.bchcod");}
 				public void setValue(String arg){Bptopl.this.getBpdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Bptopl.this.getBpdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.fftcur");}
 				public void setValue(String arg){Bptopl.this.getBpdgrp().getRec().setFftcur(arg);}
 				public String getValue(){return Bptopl.this.getBpdgrp().getRec().getFftcur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.inr");}
 				public void setValue(String arg){Bptopl.this.getBpdgrp().getRec().setInr(arg);}
 				public String getValue(){return Bptopl.this.getBpdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.ownref");}
 				public void setValue(String arg){Bptopl.this.getBpdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Bptopl.this.getBpdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bpdgrp.rec.ptyinr");}
 				public void setValue(String arg){Bptopl.this.getBpdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Bptopl.this.getBpdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Bptopl.this.getFieldPath("bedgrp.rec.stlref");}
 				public void setValue(String arg){Bptopl.this.getBedgrp().getRec().setStlref(arg);}
 				public String getValue(){return Bptopl.this.getBedgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:bptopl.@0002.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(!(ctx.checkAll(this.getBedgrp()) && ctx.checkAll(this.getBpdgrp().getRec())))
			  return false;
			String scr=ctx.absGet(Sysmod.class).getSpt().getScr();

			BigDecimal fftamt=this.getBptp().getVals(this.getBpdgrp().getRec().getFftamt());
			this.getBpdgrp().getRec().setFftamt(fftamt);
			if(!MdaUtils.isEmpty(this.getBedgrp().getRec().getDocamt()))
			{
			  BigDecimal docamt=this.getBptp().getVals(this.getBedgrp().getRec().getDocamt());
			  this.getBedgrp().getRec().setDocamt(docamt);
			}

			if("BED".equals(this.getBptp().getPtytyp()))
			{
			  if(MdaUtils.isEmpty(this.getBpdgrp().getIsb().getPts().getNam()))
			  {
			    String adrblk=this.getBpdgrp().getIsb().getPts().getAdrblk();
			    String adr[]=adrblk.split("\\n");
			    this.getBpdgrp().getIsb().getPts().setNam(adr[0]);
			  }
			}

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")||(ctx.absGet(Sysmod.class).sptIsLoaded("T")&&"S".equals(scr)))
			{

			  ctx.getDaoSession().dbUpdate(this.getBpdgrp().getRec());
			  String objinr = this.getBpdgrp().getRec().getInr();
			  log.info("{}","objinr=="+objinr );
			  this.getMtabut().UpdatePtsForBack(this.getBpdgrp().getIsb().getPts(),objinr);
			  this.getMtabut().UpdatePtsForBack(this.getBpdgrp().getApl().getPts(),objinr);
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getBedgrp().getRec().getInr())  && !MdaUtils.isEmpty(this.getBpdgrp().getRec().getPnttyp()) && !"cpd".equals(this.getBpdgrp().getRec().getPnttyp()))
			  {
			    this.getBedgrp().getRec().setInr(Platform.sdbCounter("bed"));
			    ctx.getDaoSession().dbInsert(this.getBedgrp().getRec());
			  }
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			    this.getBpdgrp().getRec().setIbchcod(this.getBpdgrp().getRec().getBchcod());
			  else
			    this.getBpdgrp().getRec().setDbchcod(this.getBpdgrp().getRec().getBchcod());
			  this.getBpdgrp().getRec().setInr(Platform.sdbCounter("bpd"));
			  if(!MdaUtils.isEmpty(this.getBpdgrp().getRec().getPnttyp()) && "cpd".equals(this.getBpdgrp().getRec().getPnttyp()))
			  {
			    this.getBpdgrp().getRec().setPntref(this.getBpdgrp().getIsb().getPts().getRef());
			    this.getBptp().setPtytyp("CPD");
			  }
			  else
			  {
			    this.getBptp().setPtytyp("BED");
			    this.getBpdgrp().getRec().setPntinr(this.getBedgrp().getRec().getInr());
			    this.getBpdgrp().getRec().setPnttyp("bed");
			    this.getBpdgrp().getRec().setPntref(this.getBedgrp().getRec().getStlref());
			  }
			  log.info("{}","bpd inr=="+this.getBpdgrp().getRec().getInr() );
			  ctx.getDaoSession().dbInsert(this.getBpdgrp().getRec());
			  String objinr=this.getBpdgrp().getRec().getInr();
			  String objtyp = "bpd";
			  this.getBpdgrp().getDap().getPts().setInr(Platform.sdbCounter("pts"));
			  this.getBpdgrp().getDap().getPts().setObjinr(objinr);
			  this.getBpdgrp().getDap().getPts().setObjtyp(objtyp);
			  ctx.getDaoSession().dbInsert(this.getBpdgrp().getDap().getPts());
			  this.getBpdgrp().getApl().savpts(objinr,objtyp);
			  this.getBpdgrp().getIsb().savpts(objinr,objtyp);
			}
			this.dealPDFData();
			this.dealpdf();

			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:bptopl.@0003.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.dealPDFData();
			IStream stream=this.getMtabut().getApldoc();
			if("BED".equals(this.getBptp().getPtytyp()))
			{
			  ctx.absGet(Sysmod.class).generatorPdf("","bptopl",stream,false );
			}
			else if("CPD".equals(this.getBptp().getPtytyp()))
			{
			  ctx.absGet(Sysmod.class).generatorPdf("","bptopl1",stream,false );
			}

			return true;
        }

        /**
        *   source:bptopl.@0013.script
        */
        @Rule(target="bpdgrp.rec.llsty",order=100)
        public boolean ruleBpdgrpRecLlstyN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else if("2".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else if("3".equals(this.getBpdgrp().getRec().getLlsty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			}
			else if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getLlsty()))
			{
			  ctx.setFieldError(this,"bpdgrp.rec.llsty",MdaUtils.getI18NString("bptopl","CT000022"));
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  
			}
			else
			{
			  ctx.setFieldError(this,"bpdgrp.rec.llsty",MdaUtils.getI18NString("bptopl","CT000026"));
			  this.getBpdgrp().getRec().setLlsty(NULLSTR);
			  this.getBpdgrp().getRec().setXdrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setGbrat(new BigDecimal(0));
			  
			  
			  this.getBpdgrp().getRec().setJdrat(new BigDecimal(0));
			  
			  

			}
			
			
			
			

			return true;
        }

        /**
        *   source:bptopl.@0014.script
        */
        @Rule(target="bpdgrp.rec.jssty",order=100)
        public boolean ruleBpdgrpRecJsstyN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("2".equals(this.getBpdgrp().getRec().getJssty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setQtnote(NULLSTR);
			}
			else if("3".equals(this.getBpdgrp().getRec().getJssty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setRatday(NULLSTR);
			}
			else
			{
			  
			  this.getBpdgrp().getRec().setQtnote(NULLSTR);

			  
			  this.getBpdgrp().getRec().setRatday(NULLSTR);
			}
			
			/*
			  String str=$bpdgrp\\rec\\jssty.getValue();
			  String js="^[1,2,3,4]{1}";
			  Pattern pattern=Pattern.compile(js);
			  Matcher matcher = pattern.matcher(str);
			  if(!matcher.matches())
			  {
			  Platform.error($bpdgrp\\rec\\jssty,#CT000024);
			  Platform.clear($bpdgrp\\rec\\jssty);
			  }
			  */

			/*if(js.equals(str))
			  //if(!"1".equals($bpdgrp\\rec\\jssty.getValue())||!"2".equals($bpdgrp\\rec\\jssty.getValue())||!"3".equals($bpdgrp\\rec\\jssty.getValue())||!"4".equals($bpdgrp\\rec\\jssty.getValue()))
			  {
			  Platform.error($bpdgrp\\rec\\jssty,#CT000030);
			  Platform.clear($bpdgrp\\rec\\jssty);
			  }*/
			

			return true;
        }

        /**
        *   source:bptopl.@0016.script
        */
        @Rule(target="bptp.returns",order=100)
        public boolean ruleBptpReturnsN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bptopl.@0018.script
        */
        @Rule(target="mtabut.sav",order=210)
        public boolean ruleMtabutSavN210(){
            IContext ctx = MdaEnv.getContext();
            
			int cnt = 1;
			String labels = "出口融资申请书";
			String tempfiles=null;
			if("BED".equals(this.getBptp().getPtytyp()))
			{
			  tempfiles = "A:bptopl";
			}
			else if("CPD".equals(this.getBptp().getPtytyp()))
			{
			  tempfiles = "A:bptopl1";
			}
			this.getTrnmod().getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().getApldoc().generatorAllPDF();


			return true;
        }

        /**
        *   source:bptopl.@0020.script
        */
        @Rule(target="bptp.actselect",order=100)
        public boolean ruleBptpActselectN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getBptp().popupActchs();

			return true;
        }

        /**
        *   source:bptopl.@0023.script
        */
        @Rule(target="bptp.actcancel",order=100)
        public boolean ruleBptpActcancelN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:bptopl.@0024.script
        */
        @Rule(target="bptp.actsure",order=100)
        public boolean ruleBptpActsureN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index=0;
			int len=this.getBptp().getActlst().fullSize();
			if(index<0 || index>=len)
			{
			  ctx.setMessage(MdaUtils.getI18NString("bptopl","CT000036"),MdaUtils.getI18NString("bptopl","CT000037"));
			  return true;
			}
			this.getBpdgrp().getRec().setRmbact(this.getBptp().getActlst().getElement(index).getAct());
			
			

			return true;
        }

        /**
        *   source:bptopl.@0025.script
        */
        @Rule(target="mtabut.apldocs",order=100)
        public boolean ruleMtabutApldocsN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream stream=this.getMtabut().getApldoc();
			BigDecimal fftamt=this.getBptp().getVals(this.getBpdgrp().getRec().getFftamt());
			this.getBpdgrp().getRec().setFftamt(fftamt);
			
			if(!MdaUtils.isEmpty(this.getBedgrp().getRec().getDocamt()))
			{
			  BigDecimal docamt=this.getBptp().getVals(this.getBedgrp().getRec().getDocamt());
			  this.getBedgrp().getRec().setDocamt(docamt);
			  
			}
			this.dealpdf();

			if("BED".equals(this.getBptp().getPtytyp()))
			{
			  if(MdaUtils.isEmpty(this.getBpdgrp().getIsb().getPts().getNam()))
			  {
			    String adrblk=this.getBpdgrp().getIsb().getPts().getAdrblk();
			    String adr[]=adrblk.split("\\n");
			    this.getBpdgrp().getIsb().getPts().setNam(adr[0]);
			    
			  }
			  this.getBptp().getPdfviw().callPDFComponent("","bptopl","出口融资申请书",1);
			}
			else if("CPD".equals(this.getBptp().getPtytyp()))
			{
			  this.getBptp().getPdfviw().callPDFComponent("","bptopl1","出口融资申请书",1);
			}

			return true;
        }

        /**
        *   source:bptopl.@0029.script
        */
        @Rule(target="bptp.bpdgrp.querat",order=100)
        public boolean ruleBptpBpdgrpQueratN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getFftcur()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000062"));
			  return true;
			}
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getLrldat()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000063"));
			  return true;
			}
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getLrltyp()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000064"));
			}
			String year = "" + this.getBpdgrp().getRec().getLrldat().getYear();
			year = "" + (Integer.parseInt(year) + 1900);
			String month =  "" + this.getBpdgrp().getRec().getLrldat().getMonth();
			month = "" + (Integer.parseInt(month) + 1);
			String cur = this.getBpdgrp().getRec().getFftcur();

			log.info("{}","querat:  year = " + Integer.parseInt(year) + " month = " + month + " cur = " + cur);
			ctx.getDaoSession().dbRead(this.getRadgrp().getRat(),new Argument<Integer>("year",Integer.parseInt(year)),new Argument<String>("month",month),new Argument<String>("cur",cur));

			if("0".equals(this.getBpdgrp().getRec().getLrltyp())&&MdaUtils.isEmpty(this.getRadgrp().getRat().getOyrate()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000065"));
			}
			else if("1".equals(this.getBpdgrp().getRec().getLrltyp())&&MdaUtils.isEmpty(this.getRadgrp().getRat().getFyrate()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000066"));
			}

			if("0".equals(this.getBpdgrp().getRec().getLrltyp()))
			{
			  this.getBpdgrp().getRec().setLrlrat(this.getRadgrp().getRat().getOyrate());
			}
			else if("1".equals(this.getBpdgrp().getRec().getLrltyp()))
			{
			  this.getBpdgrp().getRec().setLrlrat(this.getRadgrp().getRat().getFyrate());
			}
			else
			{
			  this.getBpdgrp().getRec().setLrlrat(new BigDecimal(0));
			}
			

			return true;
        }

        /**
        *   source:bptopl.@0030.script
        */
        @Rule(target="bptp.bpdgrp.sumrat",order=100)
        public boolean ruleBptpBpdgrpSumratN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getLrldat()))
			{
			  ctx.setFieldError(this,"bpdgrp.querat",MdaUtils.getI18NString("bptopl","CT000067"));
			  this.getBpdgrp().getRec().setTrunll(new BigDecimal(0));
			  return true;
			}

			BigDecimal lrlrat = this.getBpdgrp().getRec().getLrlrat();
			BigDecimal bpsnum = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getBpsnum(),"#0.0000"));
			bpsnum = bpsnum.multiply(new BigDecimal("0.01"));
			BigDecimal rate =new BigDecimal("0.00000");
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getBpsas())||MdaUtils.isEmpty(this.getBpdgrp().getRec().getBpsnum()))
			{
			  rate = this.getBpdgrp().getRec().getLrlrat();
			}
			else
			{

			  if("0".equals(this.getBpdgrp().getRec().getBpsas()))
			  {
			    rate = lrlrat.add(bpsnum);
			  }
			  else
			  {
			    rate = lrlrat.subtract(bpsnum);
			  }
			}
			this.getBpdgrp().getRec().setTrunll(MdaUtils.parseDecimal(MdaUtils.format(rate,"#0.000000")));
			

			return true;
        }

        /**
        *   source:bptopl.@0031.script
        */
        @Rule(target="bptp.bpdgrp.rec.cnyltyp",order=100)
        public boolean ruleBptpBpdgrpRecCnyltypN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  //Platform.enable($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  
			  
			  

			  //Platform.setRequired($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  //Platform.setRequired($brtp\\bpdgrp\\rec\\bpsas);
			  //Platform.setRequired($brtp\\bpdgrp\\rec\\bpsnum);
			  

			  
			  this.getBptp().getBpdgrp().getRec().setRatcycle(NULLSTR);
			  
			}
			else if("2".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  //Platform.enable($brtp\\bpdgrp\\rec\\lrldat);
			  
			  
			  
			  
			  
			  

			  //Platform.setRequired($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsas);
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsnum);
			  
			  
			}
			else
			{
			  this.getBptp().getBpdgrp().getRec().setLrldat(null);
			  this.getBptp().getBpdgrp().getRec().setLrltyp(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setLrlrat(new BigDecimal(0));
			  this.getBptp().getBpdgrp().getRec().setBpsas(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setBpsnum(0);
			  this.getBptp().getBpdgrp().getRec().setRatcycle(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setTrunll(new BigDecimal(0));

			  
			  
			  
			  
			  
			  
			  

			  
			  
			  
			  
			  
			  
			  
			}
			
			
			
			
			
			
			
			

			Calendar cal1 =  Calendar.getInstance();
			if(!MdaUtils.isEmpty(this.getBpdgrp().getRec().getCredat()))
			{
			  cal1.setTime(this.getBpdgrp().getRec().getCredat());
			}
			int day = cal1.get(Calendar.DAY_OF_MONTH);
			cal1.set(Calendar.DATE,20);
			if(day < 20)
			{
			  cal1.add(Calendar.MONTH,-1);
			}
			Date date1 = cal1.getTime();
			this.getBpdgrp().getRec().setLrldat(date1);
			

			return true;
        }

        /**
        *   source:bptopl.@0032.script
        */
        @Rule(target="bptp.bpdgrp.rec.fcnytyp",order=100)
        public boolean ruleBptpBpdgrpRecFcnytypN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}
			else if("2".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}
			else if("3".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  
			  

			  
			  
			}
			else
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}

			
			
			
			

			return true;
        }

        /**
        *   source:bptopl.@0033.script
        */
        @Rule(target="bptp.bpdgrp.rec.trunll",order=100)
        public boolean ruleBptpBpdgrpRecTrunllN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBptp().getBpdgrp().getRec().getTrunll()))
			{
			  ctx.setFieldError(this,"bptp.bpdgrp.rec.trunll",MdaUtils.getI18NString("bptopl","CT000068"));
			}

			return true;
        }

        /**
        *   source:bptopl.@0042.script
        */
        @Rule(target="bptp.bpdgrp.rec.fftcur",order=100)
        public boolean ruleBptpBpdgrpRecFftcurN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.dealInit();

			return true;
        }


        /**
        *   source:bptopl.@0001.script
        */
        @Check(target="bpdgrp.rec.fftamt",order=100)
        public boolean checkBpdgrpRecFftamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			BigDecimal fftamt = this.getBpdgrp().getRec().getFftamt();
			BigDecimal docamt = this.getBedgrp().getRec().getDocamt();
			BigDecimal occamt = this.getBodgrp().getRec().getOccamt();
			if(!MdaUtils.isEmpty(docamt))
			{
			  if(fftamt.compareTo(docamt)>0)
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopl","CT000000"));
			}
			if(!MdaUtils.isEmpty(occamt))
			{
			  if(fftamt.compareTo(occamt)>0)
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopl","CT000004"));
			}
			if(!MdaUtils.isEmpty(fftamt))
			{
			  BigDecimal js=MdaUtils.parseDecimal(0.00);
			  if(fftamt.compareTo(js)<0)
			  {
			    this.getBpdgrp().getRec().setFftamt(new BigDecimal(0));
			    ctx.setFieldError(this,"bpdgrp.rec.fftamt",MdaUtils.getI18NString("bptopl","CT000040"));
			  }
			}
			

			return true;
        }

        /**
        *   source:bptopl.@0007.script
        */
        @Check(target="bpdgrp.rec.conref",order=100)
        public boolean checkBpdgrpRecConrefN100(){
            IContext ctx = MdaEnv.getContext();
            
			if( MdaUtils.isEmpty(this.getBpdgrp().getRec().getConref()))
			  ctx.setFieldError(this,"bpdgrp.rec.conref",MdaUtils.getI18NString("bptopl","CT000013"));

			return true;
        }

        /**
        *   source:bptopl.@0008.script
        */
        @Check(target="bpdgrp.rec.matdat",order=200)
        public boolean checkBpdgrpRecMatdatN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBpdgrp().getRec().getMatdat()) && !MdaUtils.isEmpty(this.getBpdgrp().getRec().getFftvaldat()) && MdaUtils.diff(this.getBpdgrp().getRec().getMatdat(),this.getBpdgrp().getRec().getFftvaldat())==0)
			  ctx.setFieldError(this,"bpdgrp.rec.matdat",MdaUtils.getI18NString("bptopl","CT000017"));

			return true;
        }

        /**
        *   source:bptopl.@0017.script
        */
        @Check(target="bpdgrp.rec.isagr",order=100)
        public boolean checkBpdgrpRecIsagrN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!TRUE.equals(this.getBpdgrp().getRec().getIsagr()))
			{
			  ctx.setFieldError(this,"bpdgrp.rec.isagr",MdaUtils.getI18NString("bptopl","CT000027"));
			  return true;
			}

			return true;
        }

        /**
        *   source:bptopl.@0021.script
        */
        @Check(target="bpdgrp.rec.rmbact",order=100)
        public boolean checkBpdgrpRecRmbactN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getBptp().getBpdgrp().getRec().getRmbact()))
			{
			  /*String lengt=$bpdgrp\\rec\\rmbact.getValue();
			    if(lengt.length()>17||lengt.length()<17)
			    {
			    Platform.error($bpdgrp\\rec\\rmbact,#CT000033);
			    return;
			    }
			    */
			  Pattern pattern=Pattern.compile("[0-9]*");
			  String rmbact=this.getBpdgrp().getRec().getRmbact();
			  if(!pattern.matcher(rmbact).matches())
			  {
			    ctx.setFieldError(this,"bpdgrp.rec.rmbact",MdaUtils.getI18NString("bptopl","CT000047"));
			  }
			}

			return true;
        }

        /**
        *   source:bptopl.@0026.script
        */
        @Check(target="bpdgrp.rec.days",order=100)
        public boolean checkBpdgrpRecDaysN100(){
            IContext ctx = MdaEnv.getContext();
            
			int days=this.getBpdgrp().getRec().getDays();
			if( days>999 || days<1 )
			{
			  ctx.setFieldError(this,"bpdgrp.rec.days",MdaUtils.getI18NString("bptopl","CT000045"));
			}

			return true;
        }

        /**
        *   source:bptopl.@0027.script
        */
        @Check(target="bptp.bpdgrp.rec.fftamt",order=100)
        public boolean checkBptpBpdgrpRecFftamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkIllegalAmt(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"fftamt"));

			return true;
        }

        /**
        *   source:bptopl.@0028.script
        */
        @Check(target="bptp.bpdgrp.rec.ttamt",order=100)
        public boolean checkBptpBpdgrpRecTtamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkIllegalAmt(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"ttamt"));

			return true;
        }

        /**
        *   source:bptopl.@0036.script
        */
        @Check(target="bptp.bpdgrp.rec.consrate",order=100)
        public boolean checkBptpBpdgrpRecConsrateN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"consrate"));

			return true;
        }

        /**
        *   source:bptopl.@0037.script
        */
        @Check(target="bptp.bpdgrp.rec.postedrate",order=100)
        public boolean checkBptpBpdgrpRecPostedrateN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"postedrate"));

			return true;
        }

        /**
        *   source:bptopl.@0038.script
        */
        @Check(target="bptp.bpdgrp.rec.basnum",order=100)
        public boolean checkBptpBpdgrpRecBasnumN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkInotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"basnum"));

			return true;
        }

        /**
        *   source:bptopl.@0039.script
        */
        @Check(target="bptp.bpdgrp.rec.lrlrat",order=100)
        public boolean checkBptpBpdgrpRecLrlratN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"lrlrat"));


			return true;
        }

        /**
        *   source:bptopl.@0040.script
        */
        @Check(target="bptp.bpdgrp.rec.bpsnum",order=100)
        public boolean checkBptpBpdgrpRecBpsnumN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkInotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"bpsnum"));


			return true;
        }

        /**
        *   source:bptopl.@0041.script
        */
        @Check(target="bptp.bpdgrp.rec.trunll",order=100)
        public boolean checkBptpBpdgrpRecTrunllN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"trunll"));

			return true;
        }

        /**
        *   source:bptopl.@0044.script
        */
        @Check(target="bptp.bpdgrp.rec.disrat",order=100)
        public boolean checkBptpBpdgrpRecDisratN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"disrat"));

			return true;
        }

        /**
        *   source:bptopl.@0045.script
        */
        @Check(target="bptp.bpdgrp.rec.intrat",order=100)
        public boolean checkBptpBpdgrpRecIntratN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checknotZ(MdaDriver.getDatafield(this.getBptp().getBpdgrp().getRec(),"intrat"));


			return true;
        }


        /**
        *   source:bptopl.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T")))
			{
			  if(MdaUtils.prompt(MdaUtils.getI18NString("bptopl","CT000018"),MdaUtils.getI18NString("bptopl","CT000019")))
			  {
			    
			    return true;
			  }
			}
			this.getBpdgrp().setAplnam(this.getSysmod().getPty().getNam());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getBpdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getBpdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			MdaUtils.setValues(this.getBpdgrp().getRec(),"paytyp",MdaUtils.getCodetable("acctyp"));
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getPaytyp()))
			  this.getBpdgrp().getRec().setPaytyp("1");
			//  $bptp.onChangePayTyp();
			String flg =null;
			
			if(MdaUtils.isEmpty(this.getBpdgrp().getFlg()))
			{
			  IModule bed=(IModule)ctx.restoreData("com.brilliance.bptopl.ref");
			  if(!MdaUtils.isEmpty(bed))
			  {
			    this.getBedgrp().getRec().copyValue(bed);
			    this.getBpdgrp().setFlg("S");// select
			    this.getBptp().setPtytyp("BED");
			    log.debug("{}","is select");
			  }
			  else
			  {
			    IModule cpd=(IModule)ctx.restoreData("com.brilliance.bptopl.cpd.ref");
			    if(!MdaUtils.isEmpty(cpd))
			    {
			      this.getBpdgrp().getRec().setPnttyp("cpd");
			      log.debug("{}","汇款 "+this.getBpdgrp().getRec().getPnttyp());
			      this.getBptp().setPtytyp("CPD");
			      this.getBpdgrp().setFlg("N");// new
			    }
			    else
			    {
			      this.getBpdgrp().setFlg("N");// new
			      this.getBptp().setPtytyp("BED");
			      log.debug("{}","is new");
			    }
			  }
			}
			else
			  log.debug("{}","is return "+this.getBpdgrp().getFlg());
			flg = this.getBpdgrp().getFlg();
			if("S".equals(flg))
			{
			  // Platform.disable($bpdgrp\\rec\\credat);
			  
			  
			  //Platform.disable($bedgrp\\rec\\tenor);
			  log.debug("{}","bedinr="+this.getBedgrp().getRec().getInr());
			  ctx.getDaoSession().dbRead(this.getBpdgrp().getIsb().getPts(),new Argument<String>("objtyp","bed"),new Argument<String>("rol","isb"),new Argument<String>("objinr",this.getBedgrp().getRec().getInr()));
			  ctx.getDaoSession().dbRead(this.getBedgrp().getApl().getPts(),new Argument<String>("objtyp","bed"),new Argument<String>("rol","apl"),new Argument<String>("objinr",this.getBedgrp().getRec().getInr()));
			  
			  
			  if(MdaUtils.isEmpty(this.getBpdgrp().getIsb().getPts().getRef()))
			    this.getBpdgrp().getIsb().getPts().setRef(this.getBedgrp().getRec().getPntref());
			  log.debug("{}","bkref="+this.getBpdgrp().getIsb().getPts().getRef());
			  
			  
			  //Platform.disable($bedgrp\\rec\\doccur);
			  //Platform.disable($bedgrp\\rec\\docamt);
			  //Platform.disable($bedgrp\\rec\\invno);
			
			  
			  
			  
			  

			  
			  

			  this.getBpdgrp().getRec().setFftcur(this.getBodgrp().getRec().getOcccur());
			  
			  
			  
			  

			  
			  
			  //Platform.setNotRequired($bedgrp\\rec\\tenor);
			  
			  
			  //Platform.setNotRequired($bedgrp\\rec\\doccur);
			  //Platform.setNotRequired($bedgrp\\rec\\docamt);
			  //Platform.setNotRequired($bedgrp\\rec\\invno);
			  

			}
			else if("N".equals(flg) && !MdaUtils.isEmpty(this.getBpdgrp().getRec().getPnttyp()) && "cpd".equals(this.getBpdgrp().getRec().getPnttyp()))
			{
			  
			  //Platform.disable($bedgrp\\rec\\tenor);
			  //Platform.disable($bedgrp\\rec\\doccur);
			  //Platform.disable($bedgrp\\rec\\docamt);
			  
			  //Platform.disable($bedgrp\\rec\\invno);
			  
			  //Platform.disable($bedgrp\\rec\\tenor);
			  
			  
			  
			  
			  //Platform.setNotRequired($bedgrp\\rec\\tenor);
			  
			  
			  
			  
			  //Platform.setNotRequired($bedgrp\\rec\\doccur);
			  //Platform.setNotRequired($bedgrp\\rec\\docamt);
			  //Platform.setNotRequired($bedgrp\\rec\\invno);
			  
			}
			this.getBptp().getRgtclu().setClstyp("bptopn");
			this.getBpdgrp().getRec().setFftcur(this.getBedgrp().getRec().getDoccur());
			
			
			
			
			this.dealInit();

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			{
			  if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			  {
			    this.getTrnmod().getApldoc().loadApldocByOrdinr(this.getSysmod().getSpt().getOrdinr());
			  }
			  if(MdaUtils.isEmpty(this.getBptp().getPtytyp()))
			  {
			    this.getBptp().setPtytyp(this.getBpdgrp().getRec().getPtytyp());
			    
			  }

			  List<CodetableItem> yhfkfs= this.getBptp().getYhfkfsCodeTable(this.getBptp().getPtytyp());
			  MdaUtils.setValues(this.getBpdgrp().getRec(),"fkfs",yhfkfs);
			  
			  return false;
			}

			this.getBpdgrp().getRec().setCredat(MdaUtils.today());
			//$bpdgrp\\rec\\fftcur.setValue($bedgrp\\rec\\doccur.getValue());
			this.getBpdgrp().getApl().getPty().setNcid(this.getSysmod().getPty().getNcid());
			this.getBpdgrp().getApl().getPty().setNam(this.getSysmod().getPty().getNam());
			this.getBpdgrp().getApl().getPts().setExtkey(this.getSysmod().getPty().getNcid());
			if(MdaUtils.isEmpty(this.getBpdgrp().getRec().getRgtclu()))
			{
			  //Platform.dbRead($bptp\\rgtclu\\cls,new Argument<String>("flg","3"),new Argument<String>("typ","bptopn"),new Argument<String>("status","0"));
			  ctx.getDaoSession().dbRead(this.getBptp().getRgtclu().getCls(),new Argument<String>("inr",this.getBptp().getRgtclu().readDefaultClsInr("bptopn")));
			  this.getBpdgrp().getRec().setRgtclu(this.getBptp().getRgtclu().getCls().getClstxt());
			}
			this.getBpdgrp().getRec().setPtytyp(this.getBptp().getPtytyp());
			

			log.debug("{}","start 110...........");
			List<CodetableItem> yhfkfs= this.getBptp().getYhfkfsCodeTable(this.getBptp().getPtytyp());
			MdaUtils.setValues(this.getBpdgrp().getRec(),"fkfs",yhfkfs);
			

			/*if(!Platform.isEmpty($bodgrp\\rec\\occamt))
			  {
			  Platform.disable($bedgrp\\rec\\tenor);
			  Platform.disable($bodgrp\\rec\\occcur);
			  Platform.disable($bodgrp\\rec\\occamt);
			  $bpdgrp\\rec\\fftcur.setValue($bodgrp\\rec\\occcur.getValue());
			  Platform.disable($bpdgrp\\rec\\fftcur);
			  }*/

			return true;
        }


        /**
        *   source:bptopl.@0009.script
        */
        public void dealPDFData()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String credat = MdaUtils.format(MdaUtils.today(),"yyyy年MM月dd日");
			this.getBptp().setCredat(credat);
			this.getBptp().setRmbact(NULLSTR);
			this.getBptp().setRmaact(NULLSTR);
			if (!MdaUtils.isEmpty(this.getBpdgrp().getRec().getPaytyp()))
			{
			  if("1".equals(this.getBpdgrp().getRec().getPaytyp()))
			    this.getBptp().setRmbact(this.getBpdgrp().getRec().getRmbact());
			  else if("2".equals(this.getBpdgrp().getRec().getPaytyp()))
			    this.getBptp().setRmaact(this.getBpdgrp().getRec().getRmbact());
			}
		}
        /**
        *   source:bptopl.@0034.script
        */
        public void dealpdf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

			//lrlrat  trunll  consrate  postedrate  disrat
			BigDecimal rate = new BigDecimal("#0.000000");

			rate = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getLrlrat(),"#0.000000"));
			this.getBpdgrp().getRec().setLrlrat(rate);
			

			rate = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getTrunll(),"#0.000000"));
			this.getBpdgrp().getRec().setTrunll(rate);
			

			rate = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getConsrate(),"#0.000000"));
			this.getBpdgrp().getRec().setConsrate(rate);
			

			rate = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getPostedrate(),"#0.000000"));
			this.getBpdgrp().getRec().setPostedrate(rate);
			

			rate = MdaUtils.parseDecimal(MdaUtils.format(this.getBpdgrp().getRec().getDisrat(),"#0.000000"));
			this.getBpdgrp().getRec().setDisrat(rate);
			

			if("7".equals(this.getBpdgrp().getRec().getRatcycle()))
			{
			  this.getBpdgrp().setRatcyclend("√");
			}
			else
			{
			  this.getBpdgrp().setRatcyclend(NULLSTR);
			}

			//lcref=lidgrp\\\\rec\\\\stlref 信用证号码     rmipnam=brdgrp\\\\rmi\\\\pta\\\\nam 来单银行名称    ben=brdgrp\\\\ben\\\\pts\\\\adrblk 受益人
			
			//人民币押汇方式
			this.getBptp().getBpdgrp().setTrunll(NULLSTR);
			this.getBptp().getBpdgrp().setLrldat1(null);
			this.getBptp().getBpdgrp().setLrldat2(null);
			this.getBptp().getBpdgrp().setLrltyp(NULLSTR);
			this.getBptp().getBpdgrp().setLrlrat(NULLSTR);
			this.getBptp().getBpdgrp().setBpsas(NULLSTR);
			this.getBptp().getBpdgrp().setBpsnum(NULLSTR);

			StringBuffer trunll=new StringBuffer();
			StringBuffer lrltyp=new StringBuffer();
			StringBuffer lrlrat=new StringBuffer();
			StringBuffer bpsas=new StringBuffer();
			StringBuffer bpsnum=new StringBuffer();
			String conn = ",";
			String cc = null;
			BigDecimal bd = null;

			if("1".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  bd = this.getBpdgrp().getRec().getTrunll();
			  log.debug("{}",""+bd+(bd.compareTo(new BigDecimal(0))!=0));
			  if(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)
			    trunll.append("");
			  else
			    trunll.append(bd);

			  cc = this.getBptp().getBpdgrp().getRec().getLrltyp();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  else if("0".equals(cc))
			    cc="一年期";
			  else if("1".equals(cc))
			    cc="五年期";
			  lrltyp.append(cc).append(conn);

			  cc = this.getBptp().getBpdgrp().getRec().getLrlrat().toString();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  lrlrat.append(cc).append(conn);

			  cc = this.getBptp().getBpdgrp().getRec().getBpsas();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  else if("0".equals(cc))
			    cc="加";
			  else if("1".equals(cc))
			    cc="减";
			  bpsas.append(cc).append(conn);

			  cc = ""+this.getBptp().getBpdgrp().getRec().getBpsnum().toString();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  bpsnum.append(cc).append(conn);

			  this.getBptp().getBpdgrp().setLrldat1(this.getBptp().getBpdgrp().getRec().getLrldat());
			}
			else if("2".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  bd = this.getBpdgrp().getRec().getTrunll();
			  log.debug("{}",""+bd+(bd.compareTo(new BigDecimal(0))!=0));
			  if(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)
			    trunll.append("");
			  else
			    trunll.append(conn).append(bd);

			  cc = this.getBptp().getBpdgrp().getRec().getLrltyp();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  else if("0".equals(cc))
			    cc="一年期";
			  else if("1".equals(cc))
			    cc="五年期";
			  lrltyp.append(conn).append(cc);

			  cc = this.getBptp().getBpdgrp().getRec().getLrlrat().toString();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  lrlrat.append(conn).append(cc);

			  cc = this.getBptp().getBpdgrp().getRec().getBpsas();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  else if("0".equals(cc))
			    cc="加";
			  else if("1".equals(cc))
			    cc="减";
			  bpsas.append(conn).append(cc);

			  cc = ""+this.getBptp().getBpdgrp().getRec().getBpsnum().toString();
			  if(MdaUtils.isEmpty(cc))
			    cc="";
			  bpsnum.append(conn).append(cc);

			  this.getBptp().getBpdgrp().setLrldat2(this.getBptp().getBpdgrp().getRec().getLrldat());
			}

			this.getBptp().getBpdgrp().setTrunll(trunll.toString());
			this.getBptp().getBpdgrp().setLrltyp(lrltyp.toString());
			this.getBptp().getBpdgrp().setLrlrat(lrlrat.toString());
			this.getBptp().getBpdgrp().setBpsas(bpsas.toString());
			this.getBptp().getBpdgrp().setBpsnum(bpsnum.toString());
		}
        /**
        *   source:bptopl.@0035.script
        */
        public void dealInit()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//押汇方式
			if("CNY".equals(this.getBptp().getBpdgrp().getRec().getFftcur()))
			{
			  
			  

			  this.getBptp().getBpdgrp().getRec().setFcnytyp(NULLSTR);
			  
			  

			  
			  
			}
			else if(!MdaUtils.isEmpty(this.getBptp().getBpdgrp().getRec().getFftcur()))
			{
			  
			  

			  this.getBptp().getBpdgrp().getRec().setCnyltyp(NULLSTR);
			  
			  

			  
			  
			}
			else
			{
			  this.getBptp().getBpdgrp().getRec().setFcnytyp(NULLSTR);
			  //Platform.setNotRequired($bptp\\bpdgrp\\rec\\fcnytyp);
			  

			  this.getBptp().getBpdgrp().getRec().setCnyltyp(NULLSTR);
			  //Platform.setNotRequired($bptp\\bpdgrp\\rec\\cnyltyp);
			  

			  
			  
			}
			
			

			//外币押汇方式
			if("1".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}
			else if("2".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}
			else if("3".equals(this.getBptp().getBpdgrp().getRec().getFcnytyp()))
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  
			  

			  
			  
			}
			else
			{
			  this.getBptp().getBpdgrp().getRec().setConsrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setPostedrate(new BigDecimal(0));
			  
			  

			  this.getBptp().getBpdgrp().getRec().setLihibor(NULLSTR);
			  
			  

			  this.getBptp().getBpdgrp().getRec().setBasnum(0);
			  
			  
			}

			
			
			
			

			//人民币押汇方式
			if("1".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  
			  //Platform.enable($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  
			  
			  
			  this.getBptp().getBpdgrp().getRec().setRatcycle(NULLSTR);
			  

			  
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsas);
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsnum);
			  
			  
			  
			}
			else if("2".equals(this.getBptp().getBpdgrp().getRec().getCnyltyp()))
			{
			  
			  //Platform.enable($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  
			  
			  

			  
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\lrldat);
			  
			  
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsas);
			  //Platform.setRequired($bptp\\bpdgrp\\rec\\bpsnum);
			  
			  
			}
			else
			{
			  this.getBptp().getBpdgrp().getRec().setCnyltyp(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setLrldat(null);
			  this.getBptp().getBpdgrp().getRec().setLrltyp(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setLrlrat(new BigDecimal(0));
			  this.getBptp().getBpdgrp().getRec().setBpsas(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setBpsnum(0);
			  this.getBptp().getBpdgrp().getRec().setRatcycle(NULLSTR);
			  this.getBptp().getBpdgrp().getRec().setTrunll(new BigDecimal(0));

			  
			  
			  
			  
			  
			  
			  
			  

			  //Platform.disable($bptp\\bpdgrp\\rec\\cnyltyp);
			  
			  
			  
			  
			  
			  
			  
			}
			
			
			
			
			
			
			
			
			
			//计收利息的方式
			if("2".equals(this.getBpdgrp().getRec().getJssty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setQtnote(NULLSTR);
			}
			else if("3".equals(this.getBpdgrp().getRec().getJssty()))
			{
			  
			  
			  this.getBpdgrp().getRec().setRatday(NULLSTR);
			}
			else
			{
			  
			  this.getBpdgrp().getRec().setQtnote(NULLSTR);

			  
			  this.getBpdgrp().getRec().setRatday(NULLSTR);
			}
			
			
		}












}