package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BrtfrcVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Litmod;
import com.ceb.gjjs.mda.manager.module.Litp;
import com.ceb.gjjs.mda.manager.module.Lidgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口信用证杂项处理申请
*/
@Transaction(vo= BrtfrcVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Brtfrc extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Brtfrc.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Lidgrp lidgrp;

		@BDGetter
		private Litmod litmod;

		@BDGetter
		private Litp litp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Brtfrc()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getLitmod().setLidgrpHolder(()->this.getLidgrp());
           this.getLitmod().setAfdgrpHolder(()->this.getAfdgrp());
           this.getLitp().setLidgrpHolder(()->this.getLidgrp());
           this.getLitp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getMtabut().setRecHolder(()->this.getLidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("LC"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Brtfrc.this.getFieldPath("lidgrp.rec.issamt");}
 				public void setValue(BigDecimal arg){Brtfrc.this.getLidgrp().getRec().setIssamt(arg);}
 				public BigDecimal getValue(){return Brtfrc.this.getLidgrp().getRec().getIssamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("afdgrp.rec.bchcod");}
 				public void setValue(String arg){Brtfrc.this.getAfdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Brtfrc.this.getAfdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("lidgrp.rec.isscur");}
 				public void setValue(String arg){Brtfrc.this.getLidgrp().getRec().setIsscur(arg);}
 				public String getValue(){return Brtfrc.this.getLidgrp().getRec().getIsscur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("afdgrp.rec.inr");}
 				public void setValue(String arg){Brtfrc.this.getAfdgrp().getRec().setInr(arg);}
 				public String getValue(){return Brtfrc.this.getAfdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("lidgrp.rec.ownref");}
 				public void setValue(String arg){Brtfrc.this.getLidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Brtfrc.this.getLidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("lidgrp.rec.ptyinr");}
 				public void setValue(String arg){Brtfrc.this.getLidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Brtfrc.this.getLidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Brtfrc.this.getFieldPath("lidgrp.rec.stlref");}
 				public void setValue(String arg){Brtfrc.this.getLidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Brtfrc.this.getLidgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:brtfrc.@0001.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.dbBegin();
			if(!(ctx.checkAll(this.getLidgrp()) && ctx.checkAll(this.getAfdgrp())))
			  return false;
			this.getAfdgrp().getRec().setInr(Platform.sdbCounter("afd"));
			this.getAfdgrp().getRec().setObjtyp("lid");
			this.getAfdgrp().getRec().setObjinr(this.getLidgrp().getRec().getInr());
			this.getAfdgrp().getRec().setApytyp("0");
			this.getAfdgrp().getRec().setOprtyp("0");
			this.getAfdgrp().getRec().setOwnusr(this.getSysmod().getUsr().getInr());
			ctx.getDaoSession().dbInsert(this.getAfdgrp().getRec());
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:brtfrc.@0002.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            

			IStream stream=this.getMtabut().getApldoc();
			ctx.absGet(Sysmod.class).generatorPdf("","brtfrc",stream,false );

			return true;
        }

        /**
        *   source:brtfrc.@0004.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in  images 50 ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }

        /**
        *   source:brtfrc.@0005.script
        */
        @Rule(target="litp.return",order=100)
        public boolean ruleLitpReturnN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:brtfrc.@0006.script
        */
        @Rule(target="mtabut.apldocs",order=100)
        public boolean ruleMtabutApldocsN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getLitp().getPdfviw().callPDFComponent("","brtfrc","进口证杂项处理",1);

			return true;
        }

        /**
        *   source:brtfrc.@0007.script
        */
        @Rule(target="mtabut.sav",order=210)
        public boolean ruleMtabutSavN210(){
            IContext ctx = MdaEnv.getContext();
            
			int cnt = 1;
			String labels = "进口信用证杂项申请";
			String tempfiles = "A:brtfrc";
			this.getTrnmod().getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().getApldoc().generatorAllPDF();

			return true;
        }



        /**
        *   source:brtfrc.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			/*
			  List<CodetableItem> bchcod =$sysmod.getAndSetBchcodvals();
			  Platform.setValues($afdgrp\\rec\\bchcod,bchcod);
			  if(!Platform.isEmpty(bchcod)&&!$\\sysmod.sptIsLoaded("B")&&!$\\sysmod.sptIsLoaded("P"))
			  $afdgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			  */
			
			
			
			
			
			
			
			
			
			
			
			
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			{
			  if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			  {
			    this.getTrnmod().getApldoc().loadApldocByOrdinr(this.getSysmod().getSpt().getOrdinr());
			  }
			  return true;
			}
			IModule lid = (IModule)ctx.restoreData("com.brilliance.brtfrc.ref");
			if(!MdaUtils.isEmpty(lid))
			  this.getLidgrp().getRec().copyValue(lid);
			// if(!Platform.isEmpty(bchcod))
			//   $afdgrp\\rec\\bchcod.setValue((bchcod.get(0)).getValue());
			this.getLidgrp().getDap().initDap("lid");
			this.getLidgrp().getApl().copyValues(this.getLidgrp().getDap());
			this.getAfdgrp().getRec().setCredat(MdaUtils.today());
			ctx.getDaoSession().dbRead(this.getLidgrp().getApl().getPts(),new Argument<String>("objinr",this.getLidgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","apl"));
			ctx.getDaoSession().dbRead(this.getLidgrp().getBen().getPts(),new Argument<String>("objinr",this.getLidgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","ben"));
			//$lidgrp\\apl\\pts\\nam.setValue($sysmod\\pty\\nam.getValue());
			
			return true;
        }

        /**
        *   source:brtfrc.@0003.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","bchcod="+this.getAfdgrp().getRec().getBchcod());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getAfdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  //$lidgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			{
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			    this.getAfdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			  else
			  {
			    if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getDbchcod()))
			      this.getAfdgrp().getRec().setBchcod(this.getLidgrp().getRec().getDbchcod());
			    else
			    {
			      this.getAfdgrp().getRec().setBchcod(this.getLidgrp().getRec().getBchcod());
			      //$lidgrp\\rec\\dbchcod.setValue($lidgrp\\rec\\bchcod.getValue());
			    }
			    
			  }
			  log.info("{}","bchcod="+this.getLidgrp().getRec().getBchcod()+",dbchcod="+this.getLidgrp().getRec().getDbchcod());
			}


			return true;
        }











}