package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BrtfreVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Selmod;
import com.ceb.gjjs.mda.manager.module.Selp;
import com.ceb.gjjs.mda.manager.module.Lidgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Brdgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口信用证杂项申请查询入口
*/
@Transaction(vo= BrtfreVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Brtfre extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Brtfre.class);

		@BDGetter
		private Brdgrp brdgrp;

		@BDGetter
		private Selmod selmod;

		@BDGetter
		private Selp selp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Lidgrp lidgrp;


		public Brtfre()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:brtfre.@0001.script
        */
        @Rule(target="selp.query",order=100)
        public boolean ruleSelpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			String queryClause = null;
			if("1".equals(seltyp))
			{
			  //进口信用证记录
			  
			  
			  //queryClause = "SELECT lid.inr trsinr,lid.stlref ref,lid.isscur cur,lid.issamt amt,lid.credat date,pts.nam bennam,adr.adr benadr,adr.tel bentel,adr.fax benfax FROM lid,pts,adr,pta WHERE lid.flg = '2' AND pts.rol = 'ben' AND pts.objtyp = 'lid' AND pts.objinr = lid.inr AND pta.inr = pts.ptainr AND adr.inr = pta.objinr";
			  queryClause = "SELECT rec.inr trsinr,rec.stlref ref,rec.isscur cur,rec.issamt amt,rec.opndat dat ,substr(s.adrblk,0,35) bennam FROM lid rec,pts s WHERE rec.flg in('1','2') AND s.rol = 'ben' AND s.objtyp = 'lid' "
			    +"AND s.objinr = rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  this.getSelp().queryBtn1(queryClause);
			}
			else if("2".equals(seltyp))
			{
			  //进口信用证项下到单记录
			  
			  
			  // queryClause = "SELECT brd.inr trsinr,brd.stlref ref,brd.advcur cur,brd.advamt amt,brd.rcvdat dat,pts.nam bennam,adr.adr benadr,adr.tel bentel,adr.fax benfax FROM brd,pts,adr,pta WHERE brd.docflg = 'docadv' AND pts.rol = 'ben' AND pts.objtyp = 'brd' AND pts.objinr = brd.inr AND pta.inr = pts.ptainr AND adr.inr = pta.objinr";
			  queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			    // 杂项申请不关联 docflg 字段
			    +"FROM brd rec,pts s  WHERE "
			    +" s.objtyp = 'brd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  this.getSelp().queryBtn(queryClause);
			}
			
			

			return true;
        }

        /**
        *   source:brtfre.@0002.script
        */
        @Rule(target="selp.sure",order=100)
        public boolean ruleSelpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			if("1".equals(seltyp))
			{
			  //进口信用证记录
			  this.getSelp().sureBtn1("lidgrp","brtfrc");
			}
			else if("2".equals(seltyp))
			{
			  //进口信用证到单记录
			  this.getSelp().sureBtn("brdgrp","brtfrd");
			}

			return true;
        }

        /**
        *   source:brtfre.@0003.script
        */
        @Rule(target="selp.tmplst1",order=100)
        public boolean ruleSelpTmplst1N100(){
            IContext ctx = MdaEnv.getContext();
            
			//进口信用证记录
			this.getSelp().sureBtn1("lidgrp","brtfrc");

			return true;
        }

        /**
        *   source:brtfre.@0004.script
        */
        @Rule(target="selp.tmplst",order=100)
        public boolean ruleSelpTmplstN100(){
            IContext ctx = MdaEnv.getContext();
            
			//进口信用证到单记录
			this.getSelp().sureBtn("brdgrp","brtfrd");

			return true;
        }



        /**
        *   source:brtfre.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.setValues(this.getSelp(),"seltyp",MdaUtils.getCodetable("selbrtfre"));
			this.getSelp().setSeltyp("1");
			//String queryClause = "SELECT lirec.inr trsinr,lirec.stlref ref,lirec.isscur cur,lirec.issamt amt,lirec.credat dat,pts.nam bennam,adr.adr benadr,adr.tel bentel,adr.fax benfax FROM lid,pts,adr,pta WHERE lirec.flg = '2' AND pts.rol = 'ben' AND pts.objtyp = 'lid' AND pts.objinr = lirec.inr AND pta.inr = pts.ptainr AND adr.inr = pta.objinr";
			
			
			
			String queryClause = "SELECT rec.inr trsinr,rec.stlref ref,rec.isscur cur,rec.issamt amt,rec.opndat dat ,substr(s.adrblk,0,35) bennam FROM lid rec,pts s WHERE rec.flg in('1','2') AND s.rol = 'ben' AND s.objtyp = 'lid' "
			  +"AND s.objinr = rec.inr"
			  +ctx.absGet(Sysmod.class).getSelection();
			// +" WHERE rec.stlref is not null ";
			//+"and rec.ptyinr='"+$sysmod\\pty\\inr+"'";
			this.getSelp().queryBtn1(queryClause);

			return true;
        }








}