package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.BrtsetVO;

import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Trdgrp;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Apdgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;
import com.ceb.gjjs.mda.manager.module.Brtmod;
import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Cpdgrp;
import com.ceb.gjjs.mda.manager.module.Brtp;
import com.ceb.gjjs.mda.manager.module.Lidgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Brdgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口信用证授权议付/承兑/付款通知
*/
@Transaction(vo= BrtsetVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Brtset extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Brtset.class);

		@BDGetter
		private Brdgrp brdgrp;

		@BDGetter
		private Lidgrp lidgrp;

		@BDGetter
		private Brtmod brtmod;

		@BDGetter
		private Brtp brtp;

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Cpdgrp cpdgrp;

		@BDGetter
		private Apdgrp apdgrp;

		@BDGetter
		private Trdgrp trdgrp;


		public Brtset()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getBrtmod().setBrdgrpHolder(()->this.getBrdgrp());
           this.getBrtmod().setLidgrpHolder(()->this.getLidgrp());
           this.getBrtmod().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBrtp().setBrdgrpHolder(()->this.getBrdgrp());
           this.getBrtp().setLidgrpHolder(()->this.getLidgrp());
           this.getBrtp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getBrtp().setApdgrpHolder(()->this.getApdgrp());
           this.getBrtp().setTrdgrpHolder(()->this.getTrdgrp());
           this.getBrtp().setPrefixdfHolder(new FieldConstantHolder<>("DF"));
           this.getBrtp().setPrefixtrHolder(new FieldConstantHolder<>("TR"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.advamt");}
 				public void setValue(BigDecimal arg){Brtset.this.getBrdgrp().getRec().setAdvamt(arg);}
 				public BigDecimal getValue(){return Brtset.this.getBrdgrp().getRec().getAdvamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.bchcod");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.advcur");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setAdvcur(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getAdvcur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.inr");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setInr(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.ownref");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.ptyinr");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Brtset.this.getFieldPath("brdgrp.rec.stlref");}
 				public void setValue(String arg){Brtset.this.getBrdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Brtset.this.getBrdgrp().getRec().getStlref();}}
			 );
           this.getMtabut().setRecHolder(()->this.getBrdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:brtset.@0000.script
        */
        @Rule(target="mtabut.edit",order=0)
        public boolean ruleMtabutEditN0(){
            IContext ctx = MdaEnv.getContext();
            
			if("2".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  
			  
			  
			  
			  
			  
			  
			  
			  
			}

			return true;
        }



        /**
        *   source:brtset.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			String labels = "";
			String tempfiles =  "";
			//获取需要存表的pdf或草稿名
			Map<String,String> cntLabel = ctx.absGet(Trnmod.class).getPDFInfo();
			labels = cntLabel.get("label") + labels;
			tempfiles = cntLabel.get("tempfile") + tempfiles;
			String[] strs = labels.split(",");
			int cnt = strs.length;
			log.debug("{}","labels=====" + labels);
			log.debug("{}","tempfiles====" + tempfiles);
			log.debug("{}","cnt ======"+ cnt);
			ctx.absGet(Trnmod.class).getApldoc().setPDFInfo(cnt,labels,tempfiles);

			this.getTrnmod().noticeAck(this.getBrtp().getBrtp04());

			return true;
        }

        /**
        *   source:brtset.@0002.script
        */
        @Init(order=50)
        public boolean	init50(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.absGet(Mtabut.class).getImgtp().getImgRef();

			return true;
        }















}