package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.Brtsnd0VO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Selmod;
import com.ceb.gjjs.mda.manager.module.Selp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Brdgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口信用证承兑/付款/拒付
*/
@Transaction(vo= Brtsnd0VO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Brtsnd0 extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Brtsnd0.class);

		@BDGetter
		private Brdgrp brdgrp;

		@BDGetter
		private Selmod selmod;

		@BDGetter
		private Selp selp;

		@BDGetter
		private Sysmod sysmod;


		public Brtsnd0()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:brtsnd0.@0001.script
        */
        @Rule(target="selp.sure",order=100)
        public boolean ruleSelpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			if("1".equals(seltyp))
			{
			  //到单通知
			  this.getSelp().sureBtn1("brdgrp","brtsnd");
			}
			else if("2".equals(seltyp))
			{
			  //不符点通知
			  this.getSelp().sureBtn("brdgrp","brtsnd");
			}
			ctx.storeData("com.brilliance.brtsnd.seltyp",seltyp);

			return true;
        }

        /**
        *   source:brtsnd0.@0002.script
        */
        @Rule(target="selp.query",order=100)
        public boolean ruleSelpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			String queryClause = null;
			if("1".equals(seltyp))
			{
			  //进口信用证项下的到单通知
			  
			  
			  //queryClause = "SELECT b.inr trsinr,b.stlref ref,b.advcur cur,b.advamt amt,b.rcvdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM brd b,pts s,adr a,pta p WHERE b.docflg = 'docadv' AND s.rol = 'ben' AND s.objtyp = 'brd' AND s.objinr = b.inr AND pta.inr = s.ptainr AND a.inr = pta.objinr";
			  queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			    +"FROM brd rec,pts s  WHERE (rec.docflg = 'docadv' OR rec.docflg = 'accept' OR rec.docflg = 'hodrej') "
			    +"AND s.objtyp = 'brd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  //queryClause = "SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			  //+"FROM brd rec,pts s  WHERE (rec.docflg = 'docadv' OR rec.docflg = 'accept' OR rec.docflg = 'hodrej') "
			  //+"AND s.objtyp = 'brd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			  this.getSelp().queryBtn1(queryClause);
			}
			else if("2".equals(seltyp))
			{
			  //进口信用证项下的电提不符点通知
			  
			  
			  //queryClause = "SELECT b.inr trsinr,b.stlref ref,b.totcur cur,b.totamt amt,b.disdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM brd b,pts s,adr a,pta p WHERE b.docflg = 'disadv' AND s.rol = 'ben' AND s.objtyp = 'brd' AND s.objinr = b.inr AND pta.inr = s.ptainr AND a.inr = pta.objinr";
			  queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.disdat dat,substr(s.adrblk,0,35) bennam "
			    +"FROM brd rec,pts s  WHERE rec.DOCFLG ='disadv' "
			    +"AND s.objtyp = 'brd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			    +ctx.absGet(Sysmod.class).getSelection();
			  this.getSelp().queryBtn(queryClause);
			}
			
			

			return true;
        }

        /**
        *   source:brtsnd0.@0003.script
        */
        @Rule(target="selp.tmplst1",order=100)
        public boolean ruleSelpTmplst1N100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			this.getSelp().sureBtn1("brdgrp","brtsnd");
			ctx.storeData("com.brilliance.brtsnd.seltyp",seltyp);

			return true;
        }

        /**
        *   source:brtsnd0.@0004.script
        */
        @Rule(target="selp.tmplst",order=100)
        public boolean ruleSelpTmplstN100(){
            IContext ctx = MdaEnv.getContext();
            
			String seltyp = this.getSelp().getSeltyp();
			//不符点通知
			this.getSelp().sureBtn("brdgrp","brtsnd");
			ctx.storeData("com.brilliance.brtsnd.seltyp",seltyp);

			return true;
        }



        /**
        *   source:brtsnd0.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.setValues(this.getSelp(),"seltyp",MdaUtils.getCodetable("selbrtsnd"));
			this.getSelp().setSeltyp("1");
			
			
			//将查询语句输入selp层的Argument类型控件queryClause字段
			//String queryClause = "SELECT b.inr trsinr,b.stlref ref,b.advcur cur,b.advamt amt,b.rcvdat dat,s.nam bennam,a.adr benadr,a.tel bentel,a.fax benfax FROM brd b,pts s,adr a,pta p WHERE b.docflg = 'docadv' AND s.rol = 'ben' AND s.objtyp = 'brd' AND s.objinr = b.inr AND p.inr = s.ptainr AND a.inr = p.objinr";
			String queryClause ="SELECT rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.rcvdat dat,substr(s.adrblk,0,35) bennam "
			  +"FROM brd rec,pts s  WHERE (rec.docflg = 'docadv' OR rec.docflg = 'accept' OR rec.docflg = 'hodrej') "
			  +"AND s.objtyp = 'brd' AND s.rol = 'ben' AND s.objinr=rec.inr"
			  +ctx.absGet(Sysmod.class).getSelection();
			//WHERE (b.docflg = 'docadv'  or b.docflg='accept'  or b.docflg = 'hodrej')"
			this.getSelp().queryBtn1(queryClause);

			return true;
        }







}