package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.ComaplVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Comgrp;
import com.ceb.gjjs.mda.manager.module.Comp;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Commod;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 公共自由报文申请
*/
@Transaction(vo= ComaplVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Comapl extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Comapl.class);

		@BDGetter
		private Comgrp comgrp;

		@BDGetter
		private Commod commod;

		@BDGetter
		private Comp comp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Comapl()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getCommod().setComgrpHolder(()->this.getComgrp());
           this.getComp().setComgrpHolder(()->this.getComgrp());
           this.getMtabut().setRecHolder(()->this.getComgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("COM"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.amt");}
 				public void setValue(BigDecimal arg){Comapl.this.getComgrp().getRec().setAmt(arg);}
 				public BigDecimal getValue(){return Comapl.this.getComgrp().getRec().getAmt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.bchcod");}
 				public void setValue(String arg){Comapl.this.getComgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Comapl.this.getComgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.cur");}
 				public void setValue(String arg){Comapl.this.getComgrp().getRec().setCur(arg);}
 				public String getValue(){return Comapl.this.getComgrp().getRec().getCur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.inr");}
 				public void setValue(String arg){Comapl.this.getComgrp().getRec().setInr(arg);}
 				public String getValue(){return Comapl.this.getComgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.ownref");}
 				public void setValue(String arg){Comapl.this.getComgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Comapl.this.getComgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("comgrp.rec.ptyinr");}
 				public void setValue(String arg){Comapl.this.getComgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Comapl.this.getComgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Comapl.this.getFieldPath("commod.comgrp.rec.stlref");}
 				public void setValue(String arg){Comapl.this.getCommod().getComgrp().getRec().setStlref(arg);}
 				public String getValue(){return Comapl.this.getCommod().getComgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:comapl.@0002.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            

			IStream stream=this.getMtabut().getApldoc();
			//$\\sysmod.generatorPdf("","comapl",stream,false );
			this.getComp().getPdfviw().callPDFComponent("","comapl","杂项处理申请书",1);


			return true;
        }

        /**
        *   source:comapl.@0003.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","业务处理开始，编号200");
			if(!ctx.checkAll(this.getComgrp()))
			{
			  log.warn("{}","页面校验未通过，退出！");
			  return false;
			}

			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:comapl.@0005.script
        */
        @Rule(target="mtabut.sav",order=210)
        public boolean ruleMtabutSavN210(){
            IContext ctx = MdaEnv.getContext();
            
			//企业端提交时，生成pdf预览文件放在weblogic下
			int cnt = 1;
			String labels = "申请书";
			String tempfiles;
			tempfiles = "A:comapl";
			this.getTrnmod().getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().getApldoc().generatorAllPDF();

			return true;
        }

        /**
        *   source:comapl.@0006.script
        */
        @Rule(target="mtabut.apldocs",order=100)
        public boolean ruleMtabutApldocsN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getComp().getPdfviw().callPDFComponent("","comapl","杂项处理申请书",1);

			return true;
        }


        /**
        *   source:comapl.@0008.script
        */
        @Check(target="comp.comgrp.rec.amt",order=100)
        public boolean checkCompComgrpRecAmtN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkIllegalAmt(MdaDriver.getDatafield(this.getComp().getComgrp().getRec(),"amt"));

			return true;
        }


        /**
        *   source:comapl.@0004.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getComgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getComgrp().getRec().setBchcod(bchcod.get(0).getValue());
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return true;
			else
			{
			  //$comgrp\\rec\\credat.setValue("");
			  this.getComgrp().getRec().setOpndat(MdaUtils.today());
			  
			  this.getComgrp().getDap().initDap("com");
			  this.getComgrp().getApl().copyValues(this.getComgrp().getDap());
			  this.getComgrp().getApl().getPts().setRol("apl");
			  this.getComgrp().getApl().getPts().setNam(ctx.absGet(Sysmod.class).getPty().getNam());
			}

			return true;
        }










}