package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.CptgpiVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Gpitmp;
import com.ceb.gjjs.mda.manager.module.Gpistatus;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* gpi汇款状态
*/
@Transaction(vo= CptgpiVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Cptgpi extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Cptgpi.class);

        //开始日期
        private Date begdat;
        //截止日期
        private Date enddat;
        //国业参考号
        private String stlref;
        //参号
        private String ownref;
        //查询
        private transient IControl search = new ControlImpl("search", "查询", this);
        //查看汇款状态
        private transient IControl gpistat = new ControlImpl("gpistat", "查看汇款状态", this);
        //返回上层
        private transient IControl ret = new ControlImpl("ret", "返回上层", this);
        //exmgrd
        private StreamGrid exmgrd;
        //NewField
        private transient IControl evtset = new ControlImpl("evtset", "NewField", this);
        //grid展示
        private transient IControl grid = new ControlImpl("grid", "grid展示", this);
        //入账反馈
        private transient IControl infeed = new ControlImpl("infeed", "入账反馈", this);
		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private ModuleList<Gpitmp> gpitmp;

		@BDGetter
		private Gpistatus gpistatus;

		@BDGetter
		private ModuleList<Gpistatus> gpilst;


		public Cptgpi()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:cptgpi.@0001.script
        */
        @Rule(target="search",order=100)
        public boolean ruleSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.search();

			return true;
        }

        /**
        *   source:cptgpi.@0002.script
        */
        @Rule(target="gpistat",order=100)
        public boolean ruleGpistatN100(){
            IContext ctx = MdaEnv.getContext();
            
			String stlref=null;
			if(!Platform.isFromApp())
			{
			  int index = -1;
			  int count = 0;
			  for(int i=0;i<this.getGpitmp().fullSize();i++)
			  {
			    if(!"X".equals(this.getGpitmp().getElement(i).getSelflg()))
			      continue;
			    index=i;
			    ++count;
			    if(count>1)
			    {

			      ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000028"),MdaUtils.getI18NString("cptgpi","CT000029"));
			      return true;

			    }
			  }

			  if(index<0||index>=this.getGpitmp().fullSize())
			  {
			    index=0;
			    if(index<0||index>=this.getGpitmp().fullSize())
			      return true;
			  }

			  //目前暂不支持UTER,只是用国结业务号查询
			  stlref = this.getGpitmp().getElement(index).getStlref();
			}
			else
			{
			  stlref=this.getStlref();
			  //  stlref=(String)Platform.restoreData("stlref");
			}
			log.info("{}","国结业务编号："+stlref);
			if(MdaUtils.isEmpty(stlref))
			{
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000030"),MdaUtils.getI18NString("cptgpi","CT000031"));
			  return false;
			}
			//开始接口调用逻辑
			log.info("{}","*********gpi接口开始********");
			ICallback  callback = new ICallback() {
				@Override
				public Object invoke(Object... paramVarArgs) {
					showGpiInfo(paramVarArgs);
					return null;
				}
			};
			Object resMsg = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","gpi1002","gpi1002",new Object[]{stlref,callback});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Map map =  (Map)MdaUtils.invoke(resMsg,"getContent");
			  String errCode=(String)map.get("errorCode");
			  if("000000".equals(errCode))
			  {
			    log.debug("{}","gpi成功 ... ");
			    showGpiInfo((Object[])map.get("result"));
			  }
			  else
			  {
			    log.debug("{}","gpi失败 ... ");
			    String desp = (String)map.get("errorDesp");
			    log.debug("{}","errorcod=" +desp);
			    if(MdaUtils.isEmpty(desp))
			      desp="服务方未知错误!";
			    ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000080"),desp);
			    return false;
			  }
			}
			else
			{
			  log.debug("{}","errorcod=接口调用Exception");
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000081"),MdaUtils.getI18NString("cptgpi","CT000152"));
			  return false;
			}
			log.info("{}","********调用接口结束********");

			return true;
        }

        /**
        *   source:cptgpi.@0003.script
        */
        @Rule(target="ret",order=100)
        public boolean ruleRetN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.showMainPanel();

			return true;
        }

        /**
        *   source:cptgpi.@0007.script
        */
        @Rule(target="evtset",order=200)
        public boolean ruleEvtsetN200(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000158"),MdaUtils.getI18NString("cptgpi","CT000159"));

			return true;
        }

        /**
        *   source:cptgpi.@0008.script
        */
        @Rule(target="evtset",order=100)
        public boolean ruleEvtsetN100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000160"),MdaUtils.getI18NString("cptgpi","CT000161"));

			return true;
        }

        /**
        *   source:cptgpi.@0009.script
        */
        @Rule(target="grid",order=100)
        public boolean ruleGridN100(){
            IContext ctx = MdaEnv.getContext();
            
			initExmGrd();
			

			return true;
        }

        /**
        *   source:cptgpi.@0010.script
        */
        @Rule(target="infeed",order=100)
        public boolean ruleInfeedN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = -1;
			int count = 0;
			for(int i=0;i<this.getGpitmp().fullSize();i++)
			{
			  if(!"X".equals(this.getGpitmp().getElement(i).getSelflg()))
			    continue;
			  index=i;
			  ++count;
			  if(count>1)
			  {

			    ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000182"),MdaUtils.getI18NString("cptgpi","CT000183"));
			    return true;

			  }
			}

			if(index<0||index>=this.getGpitmp().fullSize())
			{
			  index=0;
			  if(index<0||index>=this.getGpitmp().fullSize())
			    return true;
			}

			//目前暂不支持UTER,只是用国结业务号查询
			String stlref = this.getGpitmp().getElement(index).getStlref();
			if(MdaUtils.isEmpty(stlref))
			{
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000184"),MdaUtils.getI18NString("cptgpi","CT000185"));
			  return false;
			}
			//开始接口调用逻辑
			log.info("{}","*********gpi接口开始********");
			ICallback  callback = new ICallback() {
				@Override
				public Object invoke(Object... paramVarArgs) {
					showGpiInfo(paramVarArgs);
					return null;
				}
			};
			Object resMsg = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","gpi1001","gpi1001",new Object[]{stlref,callback});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Map map =  (Map)MdaUtils.invoke(resMsg,"getContent");
			  String errCode=(String)map.get("errorCode");
			  if("000000".equals(errCode))
			  {
			    log.debug("{}","gpi成功 ... ");
			    // showGpiInfo((Object[])map.get("result"));
			  }
			  else
			  {
			    log.debug("{}","gpi失败 ... ");
			    String desp = (String)map.get("errorDesp");
			    log.debug("{}","errorcod=" +desp);
			    if(MdaUtils.isEmpty(desp))
			      desp="服务方未知错误!";
			    ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000186"),desp);
			    return false;
			  }
			}
			else
			{
			  log.debug("{}","errorcod=接口调用Exception");
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000187"),MdaUtils.getI18NString("cptgpi","CT000188"));
			  return false;
			}
			log.info("{}","********调用接口结束********");

			return true;
        }



        /**
        *   source:cptgpi.@0004.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.setBegdat(MdaUtils.add(MdaUtils.today(),-7));
			this.setEnddat(MdaUtils.today());
			if(!Platform.isFromApp())
			{
			  search();
			}

			return true;
        }


        /**
        *   source:cptgpi.@0000.script
        */
        public void search()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getGpitmp());
			String ptyinr=this.getSysmod().getPty().getInr();
			log.debug("{}","ptyinr:" +ptyinr);
			String ptytyp=this.getSysmod().getPty().getPtytyp();
			String lvl=this.getSysmod().getTransLevel(this.getSysmod().getPty().getCid());
			String cid = this.getSysmod().getPty().getCid();
			// String list= "'cptsub','cptout','cptopn','cptops','cptimp'";
			String list= "'cptout','cptopn','cptops','cptimp'";//暂时不支持汇入。
			List objs = new ArrayList();

			Argument<String> inr =new Argument<String>("inr");
			Argument<String> oriinr =new Argument<String>("oriinr");
			Argument<String> ownref =new Argument<String>("ownref");
			Argument<String> inifrm =new Argument<String>("inifrm");
			Argument<Date> inidattim =new Argument<Date>("inidattim");
			Argument<String> nam =new Argument<String>("nam");
			Argument<String> stlref =new Argument<String>("stlref");
			Argument<String> reloricur=new Argument<String>("reloricur");
			Argument<BigDecimal> reloriamt =new Argument<BigDecimal>("reloriamt");
			Argument<String> modtyp =new Argument<String>("modtyp");
			//通知汇款
			String sql="SELECT spt.inr inr,ownref,smh.f21 stlref,objnam,frm inifrm,dattim inidattim, trncur reloricur,trnamt reloriamt,nam "
			  + " FROM spt  left join smh on spt.smhinr = smh.inr WHERE scr='A' AND sta='T' "
			  + " AND spt.ptyinr='"+ptyinr+"'" + " AND frm IN ("+list+") "
			  + " AND smh.f21 IS NOT NULL ";
			//历史汇款
			String hissql="SELECT inr,ownref,inifrm,inidattim,nam,reloricur,reloriamt,stlref,oriinr,modtyp FROM trn WHERE sta='A' AND modtyp='1' "
			  + " AND ptyinr= '"+ptyinr+"'"+" AND ptytyp=2  AND inifrm IN ("+list+")"
			  + " AND stlref IS NOT NULL ";
			// 关联系统参号
			if(!MdaUtils.isEmpty(this.getStlref()))
			{
			  sql+=" AND smh.f21  like ? ";
			  hissql+=" AND stlref  like ? ";
			  objs.add("%"+this.getStlref().toUpperCase()+"%");
			}
			// 业务参号
			if(!MdaUtils.isEmpty(this.getOwnref()))
			{
			  String ownref1 = this.getOwnref();
			  sql+= " AND ownref  like ? ";
			  hissql+= " AND ownref  like ? ";
			  objs.add( "%"+ownref1.toUpperCase()+"%");
			}
			if(!MdaUtils.isEmpty(this.getBegdat()))
			{
			  sql += " AND dattim >= ? " ;
			  hissql += " AND inidattim >= ? " ;
			  objs.add(MdaUtils.sqlDate(this.getBegdat(),GT));
			}
			if(!MdaUtils.isEmpty(this.getEnddat()))
			{
			  sql += " AND dattim <= ? " ;
			  hissql += " AND inidattim <= ? " ;
			  objs.add(MdaUtils.sqlDate(this.getEnddat(),LT));
			}
			// 201709 第一顺序为业务类型，第二顺序为客户名称，第三顺序为业务金额
			sql += " ORDER BY dattim DESC,frm ASC,nam ASC,trnamt ASC";
			hissql+= " ORDER BY inidattim DESC,cfmdattim DESC ";
			if( objs.size()>0 )
			{
			  ctx.getDaoSession().dbExecuteSQL(sql,objs.toArray());
			}
			else
			{
			  ctx.getDaoSession().dbExecuteSQL(sql);
			}
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,ownref,stlref,inifrm,inidattim,nam,reloricur,reloriamt);
			  if(ctx.getErrorCode()==NO_ERROR)
			    this.getGpitmp().add(inr,ownref,stlref,inifrm,inidattim,nam,reloricur,reloriamt);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			//合并历史夹子记录
			if( objs.size()>0 )
			{
			  ctx.getDaoSession().dbExecuteSQL(hissql,objs.toArray());
			}
			else
			{
			  ctx.getDaoSession().dbExecuteSQL(hissql);
			}

			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,ownref,stlref,inifrm,inidattim,nam,reloricur,reloriamt);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getGpitmp().add(inr,ownref,stlref,inifrm,inidattim,nam,reloricur,reloriamt);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:cptgpi.@0005.script
        */
        public Object showGpiInfo(Object... obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  gpi路径查询
			  obj[0]:接口查询成功为查询到的条数，查询失败会返回-1
			  obj[1]:查询成功则数据List<Map>，失败则是失败描述信息String
			  */
			log.debug("{}","in showGpiInfo...");
			MdaUtils.clear(this.getGpilst());
			MdaUtils.clear(this.getGpistatus());
			if(MdaUtils.isEmpty(obj))
			{
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000117"),MdaUtils.getI18NString("cptgpi","CT000118"));
			  return null;
			}
			//返回的错误判断标志cnt
			Integer cnta = (Integer)obj[0];
			int cnt = cnta.intValue();
			if(cnt < 0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000119"),MdaUtils.getI18NString("cptgpi","CT000120"));
			  return null;
			}
			else
			{
			  //添加最新状态
			  Map map =  (Map)obj[1];
			  if(!MdaUtils.isEmpty(map.get("Uetr")))
			    this.getGpistatus().setUetr(map.get("Uetr").toString());
			  if(!MdaUtils.isEmpty(map.get("RefNo")))
			    this.getGpistatus().setRefno(map.get("RefNo").toString());
			  if(!MdaUtils.isEmpty(map.get("GpiStatus")))
			    this.getGpistatus().setGpistatus(map.get("GpiStatus").toString());
			  if(!MdaUtils.isEmpty(map.get("GpiStatusCode")))
			    this.getGpistatus().setGpistatuscode(map.get("GpiStatusCode").toString());
			  if(!MdaUtils.isEmpty(map.get("GpiTimeStamp")))
			    this.getGpistatus().setGpitimestamp(MdaUtils.parseDate(map.get("GpiTimeStamp"),"yyyyMMddHHmmss"));
			  if(!MdaUtils.isEmpty(map.get("GpiBank")))
			    this.getGpistatus().setGpibank(map.get("GpiBank").toString());
			  if(!MdaUtils.isEmpty(map.get("GpiFwdBank")))
			    this.getGpistatus().setGpifwdbank(map.get("GpiFwdBank").toString());

			  //添加历程历史
			  List<Map> list = (List<Map>)obj[2];
			  if(cnt==0||list.size()==0)
			  {
			    log.error("{}","无历程反馈查询！");
			    ctx.setMessage(MdaUtils.getI18NString("cptgpi","CT000121"),MdaUtils.getI18NString("cptgpi","CT000132"));
			    return null;
			  }
			  log.info("{}","历程反馈查询 : "+list.size());
			  int count = 0;

			  for(Map gpi:list)
			  {
			    Argument<String> ioflag =new Argument<String>("ioflag");
			    Argument<String> msgtype =new Argument<String>("msgtype");
			    Argument<String> stid =new Argument<String>("stid");
			    Argument<String> uetr =new Argument<String>("uetr");
			    Argument<String> refno =new Argument<String>("refno");
			    Argument<String> relno =new Argument<String>("relno");
			    Argument<String> gpistatus =new Argument<String>("gpistatus");
			    Argument<String> gpistatuscode=new Argument<String>("gpistatuscode");
			    Argument<Date> gpitimestamp =new Argument<Date>("gpitimestamp");
			    Argument<String> gpibank =new Argument<String>("gpibank");
			    Argument<String> gpifwdbank =new Argument<String>("gpifwdbank");
			    Argument<Date> valuedate =new Argument<Date>("valuedate");
			    Argument<String> ccy =new Argument<String>("ccy");
			    Argument<BigDecimal> amt=new Argument<BigDecimal>("amt");
			    Argument<String> srcccy =new Argument<String>("srcccy");
			    Argument<String> tranccy =new Argument<String>("tranccy");
			    Argument<BigDecimal> rate =new Argument<BigDecimal>("rate");
			    Argument<String> feecur=new Argument<String>("feecur");
			    Argument<BigDecimal> feeamt =new Argument<BigDecimal>("feeamt");
			    /*
			      if(!Platform.isEmpty(gpi.get("IoFlag")))
			      ioflag.value=gpi.get("IoFlag").toString();
			      log.debug("ioflag="+ioflag.value);
			      //
			      if(!Platform.isEmpty(gpi.get("MsgType")))
			      msgtype.value=gpi.get("MsgType").toString();
			      log.debug("msgtype="+$gpistatus\\msgtype);
			      //
			      if(!Platform.isEmpty(gpi.get("Stid")))
			      stid.value=gpi.get("Stid").toString();
			      log.debug("lgnnam="+$gpistatus\\stid);
			      */
			    if(!MdaUtils.isEmpty(gpi.get("Uetr")))
			      uetr.value=gpi.get("Uetr").toString();
			    log.debug("{}","uetr="+this.getGpistatus().getUetr());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("RefNo")))
			      refno.value=gpi.get("RefNo").toString();
			    log.debug("{}","refno="+this.getGpistatus().getRefno());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("RelNo")))
			      relno.value=gpi.get("RelNo").toString();
			    log.debug("{}","relno="+this.getGpistatus().getRelno());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("GpiStatus")))
			      gpistatus.value=gpi.get("GpiStatus").toString();
			    log.debug("{}","gpistatus="+this.getGpistatus().getGpistatus());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("GpiStatusCode")))
			      gpistatuscode.value=gpi.get("GpiStatusCode").toString();
			    log.debug("{}","gpistatuscode="+this.getGpistatus().getGpistatuscode());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("GpiTimeStamp")))
			      gpitimestamp.value=MdaUtils.parseDate(gpi.get("GpiTimeStamp"),"yyyyMMddHHmmss");
			    log.debug("{}","gpitimestamp="+this.getGpistatus().getGpitimestamp());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("GpiBank")))
			      gpibank.value=gpi.get("GpiBank").toString();
			    log.debug("{}","gpibank="+this.getGpistatus().getGpibank());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("GpiFwdBank")))
			      gpifwdbank.value=gpi.get("GpiFwdBank").toString();
			    log.debug("{}","gpifwdbank="+this.getGpistatus().getGpifwdbank());
			    //
			    if(!MdaUtils.isEmpty(gpi.get("ValueDate")))
			      valuedate.value=MdaUtils.parseDate(gpi.get("ValueDate"),"yyyyMMdd");
			    log.debug("{}","valuedate="+this.getGpistatus().getValuedate());
			    /*
			      if(!Platform.isEmpty(gpi.get("Ccy")))
			      ccy.value=gpi.get("Ccy").toString();
			      log.debug("ccy="+$gpistatus\\ccy);
			      //
			      if(!Platform.isEmpty(gpi.get("Amt")))
			      amt.value=new BigDecimal(gpi.get("Amt").toString());
			      log.debug("amt="+$gpistatus\\amt);
			      //
			      if(!Platform.isEmpty(gpi.get("SrcCcy")))
			      srcccy.value=gpi.get("SrcCcy").toString();
			      log.debug("srcccy="+$gpistatus\\srcccy);
			      //
			      if(!Platform.isEmpty(gpi.get("TranCcy")))
			      tranccy.value=gpi.get("TranCcy").toString();
			      log.debug("tranccy="+$gpistatus\\tranccy);
			      //
			      if(!Platform.isEmpty(gpi.get("Rate")))
			      rate.value=new BigDecimal(gpi.get("Rate").toString());
			      log.debug("rate="+$gpistatus\\rate);
			      //
			      if(!Platform.isEmpty(gpi.get("FeeCur")))
			      feecur.value=gpi.get("FeeCur").toString();
			      log.debug("feecur="+$gpistatus\\feecur);
			      //
			      if(!Platform.isEmpty(gpi.get("FeeAmt")))
			      feeamt.value=new BigDecimal(gpi.get("FeeAmt").toString());
			      log.debug("feeamt="+$gpistatus\\feeamt);
			      */
			    this.getGpilst().add(ioflag,msgtype,stid,uetr,refno,relno,gpistatus,gpistatuscode,gpitimestamp,gpibank,gpifwdbank,valuedate,ccy,amt,srcccy,tranccy, rate,feecur,feeamt);
			  }
			  
			  
			  
			}
			return null;
		}
        /**
        *   source:cptgpi.@0006.script
        */
        public void initExmGrd()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//生成顶级表头
			StreamGrid grid = this.getExmgrd();
			/* List<IAttributeValue[]> subHeaders = new ArrayList<IAttributeValue[]>();
			  grid.setExtHeaders(subHeaders);
			  //生成顶级表头
			  AttributeValue rootHeader = new AttributeValue("Grid控件使用示例");
			
			  Platform.setViewType(rootHeader,VIEW_LABEL,13,1950,0);
			  subHeaders.add(new IAttributeValue[]{rootHeader});
			  //第二层表头
			  AttributeValue lblAtt = new AttributeValue("文本");
			  Platform.setViewType(lblAtt,VIEW_LABEL,2,300,0);//设置跨2列，高位为0表示默认
			  AttributeValue cobAtt = new AttributeValue("下拉框");
			  AttributeValue datAtt = new AttributeValue("日期");
			  Platform.setViewType(datAtt,VIEW_LABEL,3,450,0);//设置跨3列，高位为0表示默认
			  AttributeValue numAtt = new AttributeValue("数字");
			  Platform.setViewType(numAtt,VIEW_LABEL,4,600,0);//设置跨4列，高位为0表示默认
			  AttributeValue btnAtt = new AttributeValue("按钮");
			  Platform.setViewType(btnAtt,VIEW_LABEL,2,600,0);//设置跨4列，高位为0表示默认
			  AttributeValue chkAtt = new AttributeValue("复选框");
			  subHeaders.add(new IAttributeValue[]{lblAtt,cobAtt,datAtt,numAtt,btnAtt,chkAtt});
			  */
			//直接表头
			AttributeValue lblnp = new AttributeValue("无格式");
			AttributeValue lblwp = new AttributeValue("设置码表");
			AttributeValue cobnp = new AttributeValue("无格式");
			AttributeValue datnp1 = new AttributeValue("无格式");
			AttributeValue datnp2 = new AttributeValue("编辑框");
			AttributeValue datwp = new AttributeValue("有格式文本");
			AttributeValue numnp1 = new AttributeValue("无格式文本");
			AttributeValue numnp2 = new AttributeValue("无格式编辑框");
			AttributeValue numwp1 = new AttributeValue("有格式文本");
			AttributeValue numwp2 = new AttributeValue("有格式编辑框");
			AttributeValue btnnp = new AttributeValue("无图片");
			AttributeValue btnwp = new AttributeValue("有图片");
			AttributeValue chknp = new AttributeValue("无格式");
			grid.setHeaders(new IAttributeValue[]{lblnp,lblwp,cobnp,datnp1,datnp2,datwp,numnp1,numnp2,numwp1,numwp2,btnnp,btnwp,chknp});
			//开始设置底层内容
			List<CodetableItem> cdtlst = new ArrayList<CodetableItem>();
			//文本
			cdtlst.add(new CodetableItem(MdaUtils.getI18NString("cptgpi","CT000162"),"test1"));
			AttributeValue lblnpexm = new AttributeValue("test1");
			//设置背景色为red，红色
			AttributeValue lblwpexm = new AttributeValue("test1");
			
			//下拉框
			AttributeValue cobnpexm = new AttributeValue();  //下来框
			
			
			//日期
			Date d = MdaUtils.today();
			AttributeValue datnp1exm = new AttributeValue(d); //日期LABEL
			AttributeValue datnp2exm = new AttributeValue(d);  //日期编辑框
			
			AttributeValue datwpexm = new AttributeValue(d);		//日期格式化的文本
			
			//数字
			AttributeValue numnp1exm = new AttributeValue(1000);  // 数字文本
			AttributeValue numnp2exm = new AttributeValue(1000); //数字编辑框
			
			AttributeValue numwp1exm = new AttributeValue(1000);
			
			AttributeValue numwp2exm = new AttributeValue(1000);
			
			
			Platform.addEventRule(numwp2exm,onChange,this.getEvtset(),200);//为该数字编辑框设置onChange事件，执行控件evtset的order 为200的onChange事件
			//按钮
			AttributeValue btnnpexm = new AttributeValue("无图片按钮");
			
			IStream is = new StreamImpl();
			is.setValue("images/chaxun.png");
			AttributeValue btnwpexm = new AttributeValue(is);
			
			Platform.addEventRule(btnwpexm,onClick,this.getEvtset(),100);//为该数字编辑框设置点击事件，执行控件evtset的order 为100的onClick事件
			AttributeValue chknpexm = new AttributeValue("X");
			
			//	String[] secondHeader = new String[]{"文本"};
			grid.add(new IValue[]{lblnpexm,lblwpexm,cobnpexm,datnp1exm,datnp2exm,datwpexm,numnp1exm,numnp2exm,numwp1exm,numwp2exm,btnnpexm,btnwpexm,chknpexm});
		}
















}