package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbbagtVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Agtgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Agtp;
import com.ceb.gjjs.mda.manager.module.Agtmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 推荐代理行信息
*/
@Transaction(vo= DbbagtVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbbagt extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbbagt.class);

		@BDGetter
		private Agtgrp agtgrp;

		@BDGetter
		private Agtmod agtmod;

		@BDGetter
		private Agtp agtp;

		@BDGetter
		private Sysmod sysmod;


		public Dbbagt()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAgtmod().setAgtgrpHolder(()->this.getAgtgrp());
           this.getAgtp().setAgtgrpHolder(()->this.getAgtgrp());
        }

        /**
        *   source:dbbagt.@0001.script
        */
        @Rule(target="agtp.add",order=0)
        public boolean ruleAgtpAddN0(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getAgtgrp().getPty());
			MdaUtils.clear(this.getAgtgrp().getPta());
			MdaUtils.clear(this.getAgtgrp().getAdr());
			
			

			return true;
        }

        /**
        *   source:dbbagt.@0002.script
        */
        @Rule(target="agtp.modify",order=100)
        public boolean ruleAgtpModifyN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getAgtgrp().getPtylst().fullSize();
			if( index < 0   ||   index >= length )
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000014"),MdaUtils.getI18NString("dbbagt","CT000015"));
			  return false;
			}
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPta(),new Argument<String>("inr",this.getAgtgrp().getPtylst().getElement(index).getInr()));
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument<String>("inr",this.getAgtgrp().getPta().getPtyinr()));
			ctx.getDaoSession().dbRead(this.getAgtgrp().getAdr(),new Argument<String>("inr",this.getAgtgrp().getPta().getObjinr()));
			log.info("{}","ptainr========"+this.getAgtgrp().getPta().getInr());
			log.info("{}","ptyinr========"+this.getAgtgrp().getPty().getInr());
			log.info("{}","adrinr========"+this.getAgtgrp().getAdr().getInr());
			
			

			return true;
        }

        /**
        *   source:dbbagt.@0003.script
        */
        @Rule(target="agtp.delete",order=100)
        public boolean ruleAgtpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getAgtgrp().getPtylst().fullSize();
			if( index < 0   ||   index >= length )
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000022"),MdaUtils.getI18NString("dbbagt","CT000023"));
			  return false;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbbagt","CT000069"),MdaUtils.getI18NString("dbbagt","CT000070")))
			  return false;
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPta(),new Argument<String>("inr",this.getAgtgrp().getPtylst().getElement(index).getInr()));
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument<String>("inr",this.getAgtgrp().getPta().getPtyinr()));
			ctx.getDaoSession().dbRead(this.getAgtgrp().getAdr(),new Argument<String>("inr",this.getAgtgrp().getPta().getObjinr()));
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPtr(),new Argument<String>("preptyinr",this.getAgtgrp().getPta().getPtyinr()),new Argument<String>("ptrtyp","4"));
			ctx.getDaoSession().dbDelete(this.getAgtgrp().getPta());
			ctx.getDaoSession().dbDelete(this.getAgtgrp().getPty());
			ctx.getDaoSession().dbDelete(this.getAgtgrp().getAdr());
			ctx.getDaoSession().dbDelete(this.getAgtgrp().getPtr());
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000071"),MdaUtils.getI18NString("dbbagt","CT000072"));
			initptyLst(1000);

			return true;
        }

        /**
        *   source:dbbagt.@0004.script
        */
        @Rule(target="agtp.submit",order=100)
        public boolean ruleAgtpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getAgtgrp()))
			  return false;
			ctx.getDaoSession().dbBegin();
			//if(Platform.isEnabled($agtgrp\\pty\\ncid))
			
			if(MdaUtils.isEmpty(this.getAgtgrp().getPty().getInr()))
			{
			  //新增
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPtytmp(),new Argument("ncid",this.getAgtgrp().getPty().getNcid()));
			  int err=ctx.getErrorCode();
			  if(err==NO_ERROR)
			  {
			    ctx.setFieldError(this,"agtgrp.pty.ncid",MdaUtils.getI18NString("dbbagt","CT000047"));
			    return true;
			  }
			  //存pty
			  this.getAgtgrp().getPty().setInr(Platform.sdbCounter("pty"));
			  this.getAgtgrp().getPty().setExtkey(this.getAgtgrp().getPty().getNcid());
			  this.getAgtgrp().getPty().setPtytyp("5");
			  this.getAgtgrp().getPty().setStatus("0");
			  this.getAgtgrp().getPty().setBegdat(MdaUtils.today());
			  this.getAgtgrp().getPty().setEtyinr(this.getSysmod().getEty().getInr());
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPty());
			  //存adr
			  this.getAgtgrp().getAdr().setInr(Platform.sdbCounter("adr"));
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getAdr());
			  //存pta
			  this.getAgtgrp().getPta().setInr(Platform.sdbCounter("pta"));
			  this.getAgtgrp().getPta().setPtyinr(this.getAgtgrp().getPty().getInr());
			  this.getAgtgrp().getPta().setNam(this.getAgtgrp().getPty().getEngnam());
			  //$ptygrp\\pta\\pri.setValue("0");
			  this.getAgtgrp().getPta().setObjinr(this.getAgtgrp().getAdr().getInr());
			  this.getAgtgrp().getPta().setObjkey(this.getAgtgrp().getAdr().getExtkey());
			  this.getAgtgrp().getPta().setPtytyp("4");
			  this.getAgtgrp().getPta().setPtyextkey(this.getAgtgrp().getPty().getExtkey());
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPta());
			  //存ptr
			  this.getAgtgrp().getPtr().setInr(Platform.sdbCounter("ptr"));
			  this.getAgtgrp().getPtr().setPreptyinr(this.getAgtgrp().getPty().getInr());
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument<String>("cid",Platform.headBchcod()));
			  log.info("{}","Bchcod ="+Platform.headBchcod());
			  log.info("{}","ptr inr ="+this.getAgtgrp().getPtr().getInr());
			  this.getAgtgrp().getPtr().setNxtptyinr(this.getAgtgrp().getPty().getInr());
			  this.getAgtgrp().getPtr().setPtrtyp("4");
			  this.getAgtgrp().getPtr().setDes("");
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPtr());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getAgtgrp().getPty());
			  ctx.getDaoSession().dbUpdate(this.getAgtgrp().getAdr());
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000048"),MdaUtils.getI18NString("dbbagt","CT000081"));
			
			initptyLst(1000);

			return true;
        }

        /**
        *   source:dbbagt.@0006.script
        */
        @Rule(target="agtp.search",order=100)
        public boolean ruleAgtpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			initptyLst(2000);

			return true;
        }

        /**
        *   source:dbbagt.@0007.script
        */
        @Rule(target="agtp.addlst",order=100)
        public boolean ruleAgtpAddlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","====批量导入开始=====");
			Date today=MdaUtils.today();

			String bankPtyinr = "" ;
			ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument<String>("cid",Platform.headBchcod()));
			bankPtyinr = this.getAgtgrp().getPty().getInr();
			List<String[]> list = new ArrayList<String[]>();
			IStream is = this.getAgtp().getAddlst();
			String fileName=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/excel_imp.properties");
			int sheetIndex = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_sheetIndex"));
			int rowOffset = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_rowOffset"));
			int rowMax = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_rowMax"));
			int columnOffset = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_columnOffset"));
			int columnCount = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_columnCount"));
			int rowCountLimited = Integer.valueOf(MdaUtils.getPropertyValue(fileName,"dbbagt_rowCountLimited"));
			log.debug("{}","sheetIndex="+sheetIndex + ",rowOffset="+rowOffset +",rowMax="+rowMax +",columnOffset="+columnOffset +",columnCount="+columnCount );
			int recode = MdaUtils.loadExcel(list,is,sheetIndex,rowOffset,rowMax,columnOffset,columnCount);
			if(recode==-1)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000069"),MdaUtils.getI18NString("dbbagt","CT000070"));
			  return true;
			}
			if(recode==-2)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000260"),MdaUtils.getI18NString("dbbagt","CT000261"));
			  return true;
			}

			if(MdaUtils.isEmpty(list))
			{
			  log.debug("{}","------------------list is null----------------------------");
			}
			log.debug("{}","list.size="+list.size()+";recode="+recode);
			int cnt = 0;
			int errcnt=0;
			String errinf="";

			String ncid = null;
			String ennam = null;
			String nam = null;
			String con = null ;
			int listCount = getListSize(list);

			if( listCount >  rowCountLimited )
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000262"),MdaUtils.getI18NString("dbbagt","CT000263")+rowCountLimited+MdaUtils.getI18NString("dbbagt","CT000264"));
			  MdaUtils.clear(this.getAgtp().getAddlst());
			  return false;
			}

			ctx.getDaoSession().dbBegin();
			for(int i=1;i<list.size();i++)
			{
			  String[] ss = list.get(i);
			  if(MdaUtils.isEmpty(ss))
			  {
			    continue;
			  }
			  int sslen = ss.length;
			  // 校验这一行导入内容是否为空
			  ncid = ss[0];
			  ennam = ss[1];
			  nam =ss[2];

			  if(MdaUtils.isEmpty(ncid) || MdaUtils.isEmpty(ennam))
			  {
			    con = "第"+i+"行错误:   "+CR;
			    errinf = errinf +  con +  ncid +" 银行标识码 或 英文名称为空 " +CR ;
			    errcnt ++ ;
			    continue;
			  }
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument("ncid",ncid.trim()));
			  if(ctx.getErrorCode() == NO_ERROR)
			  {
			    con = "第"+i+"行错误:   "+CR;
			    errinf=errinf + con +   ncid +"  该银行标识码已存在！   " +CR;
			    errcnt ++ ;
			    continue;
			  }

			  MdaUtils.clear(this.getAgtgrp().getPty());
			  MdaUtils.clear(this.getAgtgrp().getPta());
			  MdaUtils.clear(this.getAgtgrp().getAdr());
			  MdaUtils.clear(this.getAgtgrp().getPtr());

			  //存pty
			  this.getAgtgrp().getPty().setInr(Platform.sdbCounter("pty"));
			  this.getAgtgrp().getPty().setNcid(ss[0].trim());
			  this.getAgtgrp().getPty().setExtkey(ss[0].trim());
			  this.getAgtgrp().getPty().setEngnam(ss[1].trim());
			  this.getAgtgrp().getPty().setNam(ss[2].trim());
			  this.getAgtgrp().getPty().setPtytyp("5");
			  this.getAgtgrp().getPty().setStatus("0");
			  this.getAgtgrp().getPty().setBegdat(today);
			  this.getAgtgrp().getPty().setEtyinr(this.getSysmod().getEty().getInr());
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPty());

			  //存adr
			  this.getAgtgrp().getAdr().setInr(Platform.sdbCounter("adr"));
			  this.getAgtgrp().getAdr().setExtkey(this.getAgtgrp().getPty().getNcid());
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getAdr());

			  //存pta
			  this.getAgtgrp().getPta().setInr(Platform.sdbCounter("pta"));
			  this.getAgtgrp().getPta().setPtyinr(this.getAgtgrp().getPty().getInr());
			  this.getAgtgrp().getPta().setNam(this.getAgtgrp().getPty().getEngnam());
			  this.getAgtgrp().getPta().setObjinr(this.getAgtgrp().getAdr().getInr());
			  this.getAgtgrp().getPta().setObjkey(this.getAgtgrp().getAdr().getExtkey());
			  this.getAgtgrp().getPta().setPtytyp("4");
			  this.getAgtgrp().getPta().setPtyextkey(this.getAgtgrp().getPty().getExtkey());
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPta());

			  //存ptr
			  this.getAgtgrp().getPtr().setInr(Platform.sdbCounter("ptr"));
			  this.getAgtgrp().getPtr().setPreptyinr(this.getAgtgrp().getPty().getInr());

			  this.getAgtgrp().getPtr().setNxtptyinr(bankPtyinr);
			  this.getAgtgrp().getPtr().setPtrtyp("4");
			  this.getAgtgrp().getPtr().setDes("");
			  ctx.getDaoSession().dbInsert(this.getAgtgrp().getPtr());
			  log.debug("{}"," SAVE PTY:" + this.getAgtgrp().getPty().getInr()+", PTA:" +this.getAgtgrp().getPta().getInr() + ",ADR:"+  this.getAgtgrp().getAdr().getInr() + ",PTR:"+ this.getAgtgrp().getPtr().getInr() );
			  cnt ++;
			}
			ctx.getDaoSession().dbCommit();
			MdaUtils.clear(this.getAgtp().getAddlst());
			if(ctx.getErrorCode() != NO_ERROR)
			{
			  errinf=CR+"                            数据库提交失败，共成功上传  0 条记录！   ";
			  ctx.getDaoSession().dbRollback();
			}
			else
			{
			  errinf=CR+"                            共成功上传 "+cnt+" 条记录！    失败 "+errcnt+" 条记录！        " + "\r\n" +CR+ errinf;
			}
			this.getAgtp().setShwinf(NULLSTR);
			log.info("{}","dbbagt-ininf-"+errinf);
			this.getAgtp().setShwinf(errinf);
			
			initptyLst(cnt);
			

			return true;
        }

        /**
        *   source:dbbagt.@0009.script
        */
        @Rule(target="agtp.closep",order=100)
        public boolean ruleAgtpClosepN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:dbbagt.@0010.script
        */
        @Rule(target="agtp.alldel",order=100)
        public boolean ruleAgtpAlldelN100(){
            IContext ctx = MdaEnv.getContext();
            
			int length = this.getAgtgrp().getPtylst().fullSize();
			log.info("{}","length  all="+length);
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbbagt","CT000090"),MdaUtils.getI18NString("dbbagt","CT000091")))
			  return false;
			ctx.getDaoSession().dbBegin();
			for(int i=0;i<length;i++)
			{
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPta(),new Argument<String>("inr",this.getAgtgrp().getPtylst().getElement(i).getInr()));
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPty(),new Argument<String>("inr",this.getAgtgrp().getPta().getPtyinr()));
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getAdr(),new Argument<String>("inr",this.getAgtgrp().getPta().getObjinr()));
			  ctx.getDaoSession().dbRead(this.getAgtgrp().getPtr(),new Argument<String>("preptyinr",this.getAgtgrp().getPta().getPtyinr()),new Argument<String>("ptrtyp","4"));
			  ctx.getDaoSession().dbDelete(this.getAgtgrp().getPta());
			  ctx.getDaoSession().dbDelete(this.getAgtgrp().getPty());
			  ctx.getDaoSession().dbDelete(this.getAgtgrp().getAdr());
			  ctx.getDaoSession().dbDelete(this.getAgtgrp().getPtr());
			  log.info("{}","删除第"+(i+1)+"条记录");
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbbagt","CT000092"),MdaUtils.getI18NString("dbbagt","CT000093"));
			MdaUtils.clear(this.getAgtgrp().getPtylst());
			

			return true;
        }



        /**
        *   source:dbbagt.@0008.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			initptyLst(2000);

			return true;
        }


        /**
        *   source:dbbagt.@0005.script
        */
        public void initptyLst(int cntnum)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getAgtgrp().getPtylst());
			/*
			  String tmpsql="";
			  if(!Platform.isEmpty($agtp\\bic.getValue()))
			  {
			  tmpsql= "select count(*) count FROM pty b,adr c,pta a,ptr d WHERE d.ptrtyp = '4' AND b.inr = d.preptyinr AND a.ptyinr = b.inr AND c.inr = a.objinr AND d.nxtptyinr IN ( SELECT inr FROM pty WHERE cid = '08101') AND b.ncid like ? ";
			  Platform.dbExecuteSQL(tmpsql,"%"+$agtp\\bic.getValue()+"%");
			  }
			  else
			  {
			  tmpsql= "select count(*) count FROM pty b,adr c,pta a,ptr d WHERE d.ptrtyp = '4' AND b.inr = d.preptyinr AND a.ptyinr = b.inr AND c.inr = a.objinr AND d.nxtptyinr IN ( SELECT inr FROM pty WHERE cid = '08101') ";
			  Platform.dbExecuteSQL(tmpsql);
			  }
			  Argument<Integer> count = new Argument<Integer>("count");
			  Platform.dbFetchFields(count);
			  Platform.dbCloseCursor();
			  log.info("count============"+count.value);
			  String selClause ="";
			  if(count.value<=1000)
			  {
			  */
			String selClause ="";
			if(!MdaUtils.isEmpty(this.getAgtp().getBic()))
			{
			  selClause = "SELECT a.inr inr,b.ncid ncid,b.engnam engnam,b.nam nam FROM pty b,adr c,pta a,ptr d WHERE d.ptrtyp = '4' AND b.inr = d.preptyinr AND a.ptyinr = b.inr AND c.inr = a.objinr AND d.nxtptyinr IN ( SELECT inr FROM pty WHERE cid = ? ) AND b.ncid like ? order by b.inr desc";
			  ctx.getDaoSession().dbExecuteSQL(selClause,Platform.headBchcod(),"%"+this.getAgtp().getBic().toUpperCase()+"%");
			}
			else
			{
			  selClause = "SELECT a.inr inr,b.ncid ncid,b.engnam engnam,b.nam nam FROM pty b,adr c,pta a,ptr d WHERE d.ptrtyp = '4' AND b.inr = d.preptyinr AND a.ptyinr = b.inr AND c.inr = a.objinr AND d.nxtptyinr IN ( SELECT inr FROM pty WHERE cid = ? ) order by b.inr desc";
			  ctx.getDaoSession().dbExecuteSQL(selClause,Platform.headBchcod());
			}
			ctx.getErrorCode();
			log.info("{}","最终执行的selClause===================" + selClause);
			//Notice:此处将ptainr存储为inr
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> ncid = new Argument<String>("ncid");
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> engnam = new Argument<String>("engnam");
			int cnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,ncid,nam,engnam);
			  int errorCode  = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    if(cnt<cntnum)
			    {
			      this.getAgtgrp().getPtylst().add(inr,ncid,nam,engnam);
			      cnt++;
			    }
			    else
			      break;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			/*
			  if($agtgrp\\ptylst.fullSize() == 0)
			  {
			  Platform.message(#CT000024,#CT000025);
			  return;
			  }
			  */
			
			/*
			  }
			  else
			  {
			  Platform.error($agtp\\bic,#CT000067);
			  return;
			  }
			  */
		}
        /**
        *   source:dbbagt.@0012.script
        */
        public int  getListSize(List<String[]> list)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int count = 0 ;
			if(MdaUtils.isEmpty(list))
			{
			  return count;
			}
			for(int i= 0 ; i< list.size(); i++ )
			{
			  String[] ss = list.get(i);
			  String rowContent = "";
			  for(int j=0; j<ss.length; j ++)
			  {
			    String s = ss[j];
			    if(!MdaUtils.isEmpty(s))
			    {
			      rowContent  = rowContent + s ;
			      log.info("{}","rowContent"+rowContent);
			    }
			  }
			  if(!MdaUtils.isEmpty(rowContent))
			  {
			    count ++ ;
			  }
			}
			log.debug("{}","count =" + count );
			return count;
		}





}