package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbbautVO;

import com.ceb.gjjs.mda.manager.module.Sztp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Szdgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 电子保函处理权限管理
*/
@Transaction(vo= DbbautVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbbaut extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbbaut.class);

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Szdgrp szdgrp;

		@BDGetter
		private Sztp sztp;


		public Dbbaut()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getSztp().setSzdgrpHolder(()->this.getSzdgrp());
        }

        /**
        *   source:dbbaut.@0003.script
        */
        @Rule(target="sztp.download",order=100)
        public boolean ruleSztpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[6];
			tit[0] = "操作员号";
			tit[1] = "经办权限";
			tit[2] = "复核权限";
			tit[3] = "所属机构";
			tit[4] = "配置人员";
			tit[5] = "配置时间";

			lst.add(tit);
			int len = this.getSzdgrp().getUsrlst().fullSize();
			log.debug("{}","len="+len);
			for(int i=1;i<len;i++)
			{
			  String[] line = new String[6];
			  line[0] = this.getSzdgrp().getUsrlst().getElement(i).getLgnnam();

			  String aflg=this.getSzdgrp().getUsrlst().getElement(i).getAflg();
			  line[1] = MdaUtils.getCodetableLabel("flgs",aflg);

			  String bflg=this.getSzdgrp().getUsrlst().getElement(i).getBflg();
			  line[2] = MdaUtils.getCodetableLabel("flgs",bflg);

			  line[3] =this.getSzdgrp().getUsrlst().getElement(i).getPtynam();
			  line[4] =this.getSzdgrp().getUsrlst().getElement(i).getPeinam();

			  if(MdaUtils.isEmpty(this.getSzdgrp().getUsrlst().getElement(i).getSetdat()))
			    line[5] ="";
			  else
			    line[5] = MdaUtils.format(this.getSzdgrp().getUsrlst().getElement(i).getSetdat(),"yyyyMMdd-HH:mm:ss");
			  lst.add(line);
			}
			log.debug("{}","lst sive is:"+lst.size());
			IStream is=this.getSztp().getDownload();
			is.setType("xls");

			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH_mm_ss");
			String fileName = "操作员权限配置信息-"+today+".xls";
			try
			{
			  is.setName(new String(fileName.getBytes("GBK"),"GBK"));
			}
			catch(Exception e)
			{
			}
			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }

        /**
        *   source:dbbaut.@0004.script
        */
        @Rule(target="sztp.serach",order=100)
        public boolean ruleSztpSerachN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.flush();

			return true;
        }

        /**
        *   source:dbbaut.@0005.script
        */
        @Rule(target="szdgrp.usrlst",order=100)
        public boolean ruleSzdgrpUsrlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index=0;
			if(index>=0 && index<=this.getSzdgrp().getUsrlst().fullSize())
			{
			  this.getSzdgrp().getUsr().setLgnnam(this.getSzdgrp().getUsrlst().getElement(index).getLgnnam());
			  this.getSzdgrp().getRec().setAflg(this.getSzdgrp().getUsrlst().getElement(index).getAflg());
			  this.getSzdgrp().getRec().setBflg(this.getSzdgrp().getUsrlst().getElement(index).getBflg());
			  
			  
			  if(MdaUtils.isEmpty(this.getSzdgrp().getRec().getAflg()))
			  {
			    this.getSzdgrp().getRec().setAflg("0");
			  }

			  if(MdaUtils.isEmpty(this.getSzdgrp().getRec().getBflg()))
			  {
			    this.getSzdgrp().getRec().setBflg("0");
			  }

			  
			  
			  
			}

			return true;
        }

        /**
        *   source:dbbaut.@0006.script
        */
        @Rule(target="sztp.remove",order=100)
        public boolean ruleSztpRemoveN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSzdgrp().getUsr().setLgnnam(NULLSTR);
			this.getSzdgrp().getRec().setAflg(NULLSTR);
			this.getSzdgrp().getRec().setBflg(NULLSTR);

			
			
			

			this.flush();

			return true;
        }

        /**
        *   source:dbbaut.@0007.script
        */
        @Rule(target="sztp.save",order=100)
        public boolean ruleSztpSaveN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSzdgrp().getUsr().getLgnnam()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbaut","CT000002"),MdaUtils.getI18NString("dbbaut","CT000003"));
			  return true;
			}
			int index=0;
			int len=this.getSzdgrp().getUsrlst().fullSize();

			if(index<0||index>=len)
			{
			  ctx.setMessage("",MdaUtils.getI18NString("dbbaut","CT000045"));
			  return true;
			}

			if(len==1)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbaut","CT000046"),MdaUtils.getI18NString("dbbaut","CT000047"));
			  return true;
			}

			if(!this.cheakPtyinr(index,len))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbbaut","CT000048"),MdaUtils.getI18NString("dbbaut","CT000049"));
			  return true;
			}

			if(MdaUtils.prompt("",MdaUtils.getI18NString("dbbaut","CT000050")))
			  return true;

			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();

			String aflg=this.getSzdgrp().getRec().getAflg();
			String bflg=this.getSzdgrp().getRec().getBflg();
			if(index==0)   //选择所有操作员循环配置
			{
			  for(int i=1;i<len;i++)
			  {
			    String usrinr=this.getSzdgrp().getUsrlst().getElement(i).getInr();
			    String ptyinr=this.getSzdgrp().getUsrlst().getElement(i).getPtyinr();
			    this.setSaut(usrinr,ptyinr,aflg,bflg);
			  }
			}
			else
			{
			  String usrinr=this.getSzdgrp().getUsrlst().getElement(index).getInr();
			  String ptyinr=this.getSzdgrp().getUsrlst().getElement(index).getPtyinr();
			  this.setSaut(usrinr,ptyinr,aflg,bflg);
			}
			this.getSzdgrp().getUsr().setLgnnam(NULLSTR);
			this.getSzdgrp().getRec().setAflg(NULLSTR);
			this.getSzdgrp().getRec().setBflg(NULLSTR);

			ctx.getDaoSession().dbCommit();
			/*if(Platform.errorCode() != NO_ERROR)
			  {
			  Platform.dbRollback();
			  Platform.message(#CT000051,#CT000052);
			  return false;
			  }
			  */

			ctx.setMessage(MdaUtils.getI18NString("dbbaut","CT000053"),MdaUtils.getI18NString("dbbaut","CT000056"));
			this.flush();
			log.debug("{}","操作员权限配置成功！");

			return true;
        }

        /**
        *   source:dbbaut.@0010.script
        */
        @Rule(target="szdgrp.rec.aflg",order=100)
        public boolean ruleSzdgrpRecAflgN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getSzdgrp().getRec().getAflg()))
			{
			  this.getSzdgrp().getRec().setBflg("0");
			  
			}
			else
			{
			  
			}

			
			

			return true;
        }

        /**
        *   source:dbbaut.@0011.script
        */
        @Rule(target="szdgrp.rec.bflg",order=100)
        public boolean ruleSzdgrpRecBflgN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getSzdgrp().getRec().getBflg()))
			{
			  this.getSzdgrp().getRec().setAflg("0");
			  
			}
			else
			{
			  
			}

			
			

			return true;
        }



        /**
        *   source:dbbaut.@0002.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			
			
			

			List<CodetableItem> bchcod=this.getSysmod().getBranchList(this.getSysmod().getPty().getCid());
			MdaUtils.setValues(this.getSztp(),"ptynam",bchcod);
			if(!MdaUtils.isEmpty(bchcod))
			  this.getSztp().setPtynam(bchcod.get(0).getValue());

			this.flush();

			return true;
        }


        /**
        *   source:dbbaut.@0000.script
        */
        public void flush()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getSztp().getSzdgrp().getUsrlst());
			this.getSztp().getSzdgrp().getUsrlst().add();
			this.getSztp().getSzdgrp().getUsrlst().getElement(0).setLgnnam("所有操作员");

			String sql="select u.inr,lgnnam,aflg,bflg,peinam,setdat,u.ptyinr,u.ptynam from usr u left join szusraut s on usrinr = u.inr"
			  +" where usrflg = '0' and EXISTS (select inr from iamusr i where i.usrinr = u.inr)";

			//具体操作员
			if(!MdaUtils.isEmpty(this.getSztp().getLgnnam()))
			{
			  sql=sql+" and u.lgnnam='"+this.getSztp().getLgnnam()+"'";
			}

			//经办权限
			if("1".equals(this.getSztp().getAflg()))
			{
			  sql=sql+" and s.aflg='1' and s.bflg='0'";
			}
			else if("0".equals(this.getSztp().getAflg()))
			{
			  sql=sql+" and (s.aflg ='0' or s.aflg is null)";
			}
			else
			{
			}

			//复核权限
			if("1".equals(this.getSztp().getBflg()))
			{
			  sql=sql+" and s.bflg='1' and s.aflg='0'";
			}
			else if("0".equals(this.getSztp().getBflg()))
			{
			  sql=sql+" and (s.bflg ='0' or s.bflg is null)";
			}
			else
			{
			}

			//输入cid查询
			if(!MdaUtils.isEmpty(this.getSztp().getCid()))
			{
			  String cidinr=this.getInrByCid(this.getSztp().getCid());
			  sql=sql+" and u.ptyinr='"+cidinr+"'";
			}

			//机构条件
			String sysinr=this.getSysmod().getPty().getInr();
			String cid=this.getSysmod().getPty().getCid();
			String lvl=this.getSysmod().getPty().getLvl();
			if(!MdaUtils.isEmpty(this.getSztp().getPtynam()))
			{
			  sysinr=this.getSztp().getPtynam();
			  cid=this.getSysmod().getCidByInr(sysinr);
			  lvl=this.getSysmod().getBchmod().getBranchLvlByInr(sysinr);
			  log.debug("{}","sysinr is:"+sysinr);
			}
			if("0".equals(lvl))
			{
			  sql=sql+" and EXISTS(SELECT inr FROM pty p WHERE u.ptyinr = p.inr)";
			}
			else if("1".equals(lvl))
			{
			  sql=sql+" and EXISTS(SELECT inr FROM pty p WHERE u.ptyinr = p.inr and (p.inr = '"+sysinr+"' or pntinr = '"+cid+"'))";
			}
			else
			{
			  sql=sql+" AND u.ptyinr='"+sysinr+"'";
			}

			sql=sql+" ORDER  BY u.ptyinr DESC";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr =new Argument<String>("inr");
			Argument<String> lgnnam =new Argument<String>("lgnnam");
			Argument<String> aflg =new Argument<String>("aflg");
			Argument<String> bflg =new Argument<String>("bflg");
			Argument<String> peinam =new Argument<String>("peinam");
			Argument<String> ptynam =new Argument<String>("ptynam");
			Argument<String> ptyinr =new Argument<String>("ptyinr");
			Argument<Date> setdat =new Argument<Date>("setdat");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,lgnnam,aflg,bflg,peinam,setdat,ptyinr,ptynam);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getSztp().getSzdgrp().getUsrlst().add(inr,lgnnam,aflg,bflg,peinam,setdat,ptyinr,ptynam);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:dbbaut.@0001.script
        */
        public String getInrByCid(String cid)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(cid))
			{
			  return null;
			}
			Argument<String> inr=new Argument<String>("inr");
			ctx.getDaoSession().dbExecuteSQL("SELECT inr FROM pty WHERE cid='"+cid+"'");
			ctx.getDaoSession().dbFetchFields(inr);
			int e=ctx.getErrorCode();
			if(e==NO_ERROR)
			{
			  if(!MdaUtils.isEmpty(inr.value))
			  {
			    ctx.getDaoSession().dbCloseCursor();
			    return inr.value;
			  }
			  else
			  {
			    ctx.getDaoSession().dbCloseCursor();
			    return null;
			  }
			}
			else
			{
			  ctx.getDaoSession().dbCloseCursor();
			  return null;
			}
		}
        /**
        *   source:dbbaut.@0008.script
        */
        public boolean  cheakPtyinr(int index,int len)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean result=true;
			if(index==0 && len>2)
			{
			  String ptyinr=this.getSzdgrp().getUsrlst().getElement(1).getPtyinr();
			  for(int i=2;i<len;i++)
			  {
			    String  inrs=this.getSzdgrp().getUsrlst().getElement(i).getPtyinr();
			    if(!inrs.equals(ptyinr))
			    {
			      result= false;
			      break;
			    }
			  }
			}

			return result;
		}
        /**
        *   source:dbbaut.@0009.script
        */
        public void setSaut(String usrinr,String ptyinr,String aflg,String bflg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getSzdgrp().getRec());
			ctx.getDaoSession().dbRead(this.getSzdgrp().getRec(),new Argument<String>("usrinr",usrinr));

			this.getSzdgrp().getRec().setUsrinr(usrinr);
			this.getSzdgrp().getRec().setPtyinr(ptyinr);
			if(MdaUtils.isEmpty(aflg))
			{
			  aflg="0";
			}
			this.getSzdgrp().getRec().setAflg(aflg);

			if(MdaUtils.isEmpty(bflg))
			{
			  bflg="0";
			}
			this.getSzdgrp().getRec().setBflg(bflg);

			this.getSzdgrp().getRec().setSetdat(MdaUtils.today());
			this.getSzdgrp().getRec().setPeinam(this.getSysmod().getUsr().getLgnnam());

			if(MdaUtils.isEmpty(this.getSzdgrp().getRec().getInr()))
			{
			  String inr=Platform.sdbCounter("szusraut");
			  this.getSzdgrp().getRec().setInr(inr);
			  ctx.getDaoSession().dbInsert(this.getSzdgrp().getRec());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getSzdgrp().getRec());
			}
			log.debug("{}","szusraut set success,inr is:"+this.getSzdgrp().getRec().getInr());
		}




}