package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbblvlVO;

import com.ceb.gjjs.mda.manager.module.Lvlgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Lvlp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 交易经办机构配置交易
*/
@Transaction(vo= DbblvlVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbblvl extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbblvl.class);

		@BDGetter
		private Lvlgrp lvlgrp;

		@BDGetter
		private Lvlp lvlp;

		@BDGetter
		private Sysmod sysmod;


		public Dbblvl()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getLvlp().setLvlgrpHolder(()->this.getLvlgrp());
        }

        /**
        *   source:dbblvl.@0001.script
        */
        @Rule(target="lvlp.add",order=100)
        public boolean ruleLvlpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			int len = this.getLvlgrp().getOprlst().fullSize();
			this.getLvlgrp().getOprlst().add();
			

			return true;
        }

        /**
        *   source:dbblvl.@0002.script
        */
        @Rule(target="lvlp.del",order=100)
        public boolean ruleLvlpDelN100(){
            IContext ctx = MdaEnv.getContext();
            

			String delinrs = null;
			if(MdaUtils.isEmpty(this.getLvlp().getDelrprinrs()))
			  delinrs = "";
			else
			  delinrs = this.getLvlp().getDelrprinrs();
			int size=this.getLvlgrp().getOprlst().fullSize();
			if(size<=0)
			  return true;
			for(int i=0;i<size;i++ )
			{
			  if("X".equals(this.getLvlgrp().getOprlst().getElement(i).getSelflg()))
			  {
			    if("DefaultFrm".equals(this.getLvlgrp().getOprlst().getElement(i).getTxt()))
			    {
			      ctx.setMessage("提示","不得删除默认配置");
			      break;
			    }
			    delinrs = delinrs+";"+this.getLvlgrp().getOprlst().getElement(i).getInr();
			    log.debug("{}","remove "+this.getLvlgrp().getOprlst().getElement(i).getInr()+" frm"+this.getLvlgrp().getOprlst().getElement(i).getTxt());
			    this.getLvlgrp().getOprlst().remove(i);
			    size=this.getLvlgrp().getOprlst().fullSize();
			    i--;
			  }
			}
			this.getLvlp().setDelrprinrs(delinrs);
			

			return true;
        }

        /**
        *   source:dbblvl.@0003.script
        */
        @Rule(target="lvlp.submit",order=100)
        public boolean ruleLvlpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			LockInfo lockinf=ctx.getLocker().lock(MdaEnv.getLoginUser(),"stb_oprbchlvl");
			int errorCode = ctx.getErrorCode();
			log.debug("{}","lock errcode="+errorCode);
			if(errorCode==ERROR_LOCKED  ||  errorCode==ERROR_LOCK)
			{
			  ctx.setMessage("提示","记录已经被其他用户锁定,无法配置。");
			  return true;
			}

			int len = this.getLvlgrp().getOprlst().fullSize();
			ctx.getDaoSession().dbBegin();
			// 先得到已有的配置列表
			Object obj = this.getSysmod().getOprbchlvl();
			Map<String,String>  lvllst = (Map<String,String>)obj;
			log.debug("{}","lvllst size="+lvllst.size());
			// 删除已经移除的明细列表
			if(!MdaUtils.isEmpty(this.getLvlp().getDelrprinrs()))
			{
			  String alldelinr = this.getLvlp().getDelrprinrs();
			  log.debug("{}","alldelinr="+alldelinr);
			  String[] inrs = alldelinr.split(";");
			  for(String stbinr:inrs)
			  {
			    if("".equals(stbinr))
			      continue;
			    log.debug("{}","del stb"+stbinr);
			    MdaUtils.clear(this.getLvlgrp().getStb());
			    ctx.getDaoSession().dbRead(this.getLvlgrp().getStb(),new Argument<String>("inr",stbinr));
			    lvllst.remove(this.getLvlgrp().getStb().getTxt());
			    ctx.getDaoSession().dbDelete(this.getLvlgrp().getStb());
			  }
			}
			for(int i=0;i<len;i++)
			{
			  MdaUtils.clear(this.getLvlgrp().getStb());
			  if(MdaUtils.isEmpty(this.getLvlgrp().getOprlst().getElement(i).getInr()))
			  {
			    if(MdaUtils.isEmpty(this.getLvlgrp().getOprlst().getElement(i).getCod())  ||  MdaUtils.isEmpty(this.getLvlgrp().getOprlst().getElement(i).getTxt()))
			      continue;
			    if(lvllst.containsKey(this.getLvlgrp().getOprlst().getElement(i).getTxt()))
			    {
			      log.debug("{}","map contain "+this.getLvlgrp().getOprlst().getElement(i).getTxt()+" value "+lvllst.get(this.getLvlgrp().getOprlst().getElement(i).getTxt()));
			      ctx.setMessage("提示","不能重复添加同交易配置。");
			      ctx.getLocker().unlock(MdaEnv.getLoginUser());
			      return true;
			    }
			    String inr = Platform.sdbCounter("stb");
			    this.getLvlgrp().getStb().setInr(inr);
			    this.getLvlgrp().getStb().setTbl("oprbchlvl");
			    this.getLvlgrp().getStb().setTxt(this.getLvlgrp().getOprlst().getElement(i).getTxt());
			    this.getLvlgrp().getStb().setCod(this.getLvlgrp().getOprlst().getElement(i).getCod());
			    ctx.getDaoSession().dbInsert(this.getLvlgrp().getStb());
			    log.debug("{}","add stb inr="+inr+" "+this.getLvlgrp().getOprlst().getElement(i).getTxt()+""+this.getLvlgrp().getOprlst().getElement(i).getCod());
			  }
			  else
			  {
			    ctx.getDaoSession().dbRead(this.getLvlgrp().getStb(),new Argument<String>("inr",this.getLvlgrp().getOprlst().getElement(i).getInr()));
			    this.getLvlgrp().getStb().setTxt(this.getLvlgrp().getOprlst().getElement(i).getTxt());
			    this.getLvlgrp().getStb().setCod(this.getLvlgrp().getOprlst().getElement(i).getCod());
			    ctx.getDaoSession().dbUpdate(this.getLvlgrp().getStb());
			    log.debug("{}","update stb inr="+this.getLvlgrp().getStb().getInr()+" "+this.getLvlgrp().getOprlst().getElement(i).getTxt()+""+this.getLvlgrp().getOprlst().getElement(i).getCod());
			  }
			  lvllst.put(this.getLvlgrp().getStb().getTxt(),this.getLvlgrp().getStb().getCod());
			}
			ctx.getDaoSession().dbCommit();
			ctx.getLocker().unlock(MdaEnv.getLoginUser());
			log.debug("{}","lvllst final size="+lvllst.size());
			this.getSysmod().setOprbchlvl(lvllst);
			ctx.setMessage("提示","交易经办机构级别配置成功。");

			return true;
        }



        /**
        *   source:dbblvl.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			this.getLvlp().setDelrprinrs(NULLSTR);
			// 首先从stb表里面查询
			String sql = "SELECT * FROM STB WHERE tbl='oprbchlvl' ORDER BY txt";
			Argument<String> txt = new Argument<String>("txt");
			Argument<String> cod = new Argument<String>("cod");
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbExecuteSQL(sql);
			MdaUtils.clear(this.getLvlgrp().getOprlst());
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,cod,txt);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getLvlgrp().getOprlst().add(inr,txt,cod);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			log.debug("{}","查询配置 stb len="+this.getLvlgrp().getOprlst().size());
			if(this.getLvlgrp().getOprlst().size()>0)
			  return true;
			// 如果查询不到，说明这是第一次配置取oprogn.properties配置文件里面的值
			String path=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data");
			String filename=MdaUtils.catPath(path,"oprogn.properties");
			if(!MdaUtils.fileExists(filename))
			  return true;
			// 形如trans=defaultFrm,cptopn,cptimp,fxisll,fxibuy
			String trans=MdaUtils.getPropertyValue(filename,"trans");
			log.debug("{}","oprogn trans="+trans);
			if(MdaUtils.isEmpty(trans))
			  return true;
			for(String tran:trans.split(","))
			{
			  String lvl=MdaUtils.getPropertyValue(filename,tran);
			  if(!MdaUtils.isEmpty(lvl))
			  {
			    txt.value=tran;
			    cod.value=lvl;
			    log.debug("{}","add "+tran+" "+lvl);
			    this.getLvlgrp().getOprlst().add(txt,cod);
			  }
			}
			

			return true;
        }






}