package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbcmsgVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Msgmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Msggrp;
import com.ceb.gjjs.mda.manager.module.Msgp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 邮件短信订阅
*/
@Transaction(vo= DbcmsgVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbcmsg extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbcmsg.class);

		@BDGetter
		private Msggrp msggrp;

		@BDGetter
		private Msgmod msgmod;

		@BDGetter
		private Msgp msgp;

		@BDGetter
		private Sysmod sysmod;


		public Dbcmsg()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getMsgmod().setMsggrpHolder(()->this.getMsggrp());
           this.getMsgp().setMsggrpHolder(()->this.getMsggrp());
        }

        /**
        *   source:dbcmsg.@0001.script
        */
        @Rule(target="msgp.delete",order=100)
        public boolean ruleMsgpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getMsggrp().getMsglst().fullSize();
			if( index<0   ||   index>=length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000000"),MdaUtils.getI18NString("dbcmsg","CT000001"));
			  return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbcmsg","CT000041"),MdaUtils.getI18NString("dbcmsg","CT000042")))
			  return true;
			ctx.getDaoSession().dbBegin();
			//$msggrp\\msg.copyValue($msggrp\\msglst[index]);
			ctx.getDaoSession().dbRead(this.getMsggrp().getMsg(),new Argument<String>("inr",this.getMsggrp().getMsglst().getElement(index).getInr()));
			ctx.getDaoSession().dbDelete(this.getMsggrp().getMsg());
			ctx.getDaoSession().dbCommit();
			MdaUtils.clear(this.getMsggrp().getMsglst());
			this.getMsgp().loadMsgList();

			return true;
        }

        /**
        *   source:dbcmsg.@0002.script
        */
        @Rule(target="msgp.add",order=100)
        public boolean ruleMsgpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getMsggrp().getMsg());
			
			//$msggrp\\msg\\emlflg.setValue(TRUE);
			
			

			//$msggrp\\msg\\msgflg.setValue(TRUE);
			
			

			return true;
        }

        /**
        *   source:dbcmsg.@0003.script
        */
        @Rule(target="msgp.submit",order=100)
        public boolean ruleMsgpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getMsggrp()))
			  return false;
			if(!TRUE.equals(this.getMsggrp().getMsg().getEmlflg()) && !TRUE.equals(this.getMsggrp().getMsg().getMsgflg()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000008"),MdaUtils.getI18NString("dbcmsg","CT000009"));
			  return false;
			}
			if(hasBooked())
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000094"),MdaUtils.getI18NString("dbcmsg","CT000095"));
			  return true;
			}
			ctx.getDaoSession().dbBegin();
			this.getMsggrp().getMsg().setInr(Platform.sdbCounter("msg"));
			this.getMsggrp().getMsg().setPtyinr(this.getSysmod().getUsr().getPtyinr());
			//$msggrp\\msg\\frm.setValue($msggrp\\msg\\nam.getValue());
			this.getMsggrp().getMsg().setNam(MdaUtils.getCodetableLabel("trsdav",this.getMsggrp().getMsg().getFrm()));
			ctx.getDaoSession().dbInsert(this.getMsggrp().getMsg());
			log.info("{}","insert over" );
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000102"),MdaUtils.getI18NString("dbcmsg","CT000103"));
			
			this.getMsgp().loadMsgList();

			return true;
        }

        /**
        *   source:dbcmsg.@0004.script
        */
        @Rule(target="msgp.update",order=100)
        public boolean ruleMsgpUpdateN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getMsggrp()))
			  return false;
			if(!TRUE.equals(this.getMsggrp().getMsg().getEmlflg()) && !TRUE.equals(this.getMsggrp().getMsg().getMsgflg()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000085"),MdaUtils.getI18NString("dbcmsg","CT000086"));
			  return false;
			}
			ctx.getDaoSession().dbBegin();
			//$msggrp\\msg\\frm.setValue($msggrp\\msg\\nam.getValue());
			this.getMsggrp().getMsg().setNam(MdaUtils.getCodetableLabel("trsdav",this.getMsggrp().getMsg().getFrm()));
			ctx.getDaoSession().dbUpdate(this.getMsggrp().getMsg());
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000096"),MdaUtils.getI18NString("dbcmsg","CT000097"));
			
			this.getMsgp().loadMsgList();

			return true;
        }

        /**
        *   source:dbcmsg.@0005.script
        */
        @Rule(target="msgp.scantrs",order=100)
        public boolean ruleMsgpScantrsN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMsgp().loadModList();
			

			return true;
        }

        /**
        *   source:dbcmsg.@0006.script
        */
        @Rule(target="msgp.sure",order=100)
        public boolean ruleMsgpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getMsggrp().getModlst().fullSize();
			if( index<0   ||   index>=length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000002"),MdaUtils.getI18NString("dbcmsg","CT000003"));
			  return true;
			}
			this.getMsggrp().getMsg().setNam(this.getMsggrp().getModlst().getElement(index).getNam());
			this.getMsggrp().getMsg().setFrm(this.getMsggrp().getModlst().getElement(index).getFrm());
			
			

			return true;
        }

        /**
        *   source:dbcmsg.@0007.script
        */
        @Rule(target="msgp.show",order=100)
        public boolean ruleMsgpShowN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getMsggrp().getMsglst().fullSize();
			if(index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcmsg","CT000004"),MdaUtils.getI18NString("dbcmsg","CT000005"));
			  return true;
			}
			this.getMsggrp().getMsg().copyValue(this.getMsggrp().getMsglst().getElement(index));
			

			return true;
        }

        /**
        *   source:dbcmsg.@0016.script
        */
        @Rule(target="msggrp.msg.emlflg",order=100)
        public boolean ruleMsggrpMsgEmlflgN100(){
            IContext ctx = MdaEnv.getContext();
            
			//0-不订阅
			if(TRUE.equals(this.getMsggrp().getMsg().getEmlflg()))
			{
			  
			  
			}
			else
			{
			  this.getMsggrp().getMsg().setEml(NULLSTR);
			  
			  
			}
			

			return true;
        }

        /**
        *   source:dbcmsg.@0017.script
        */
        @Rule(target="msggrp.msg.msgflg",order=100)
        public boolean ruleMsggrpMsgMsgflgN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(TRUE.equals(this.getMsggrp().getMsg().getMsgflg()))
			{
			  
			  
			}
			else
			{
			  this.getMsggrp().getMsg().setMobile(NULLSTR);
			  
			  
			}
			

			return true;
        }


        /**
        *   source:dbcmsg.@0021.script
        */
        @Check(target="msggrp.msg.mobile",order=50)
        public boolean checkMsggrpMsgMobileN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","check  开始！");
			if(!MdaUtils.isEmpty(this.getMsggrp().getMsg().getMobile()))
			{
			  String value=this.getMsggrp().getMsg().getMobile();
			  String []vas=value.split(",");
			  String js="^[1][3|4|5|7|8]\\d{9}";
			  int len=vas.length;
			  if(len>2)
			  {
			    ctx.setFieldError(this,"msggrp.msg.mobile",MdaUtils.getI18NString("dbcmsg","CT000111"));
			    return true;
			  }

			  Pattern pattern=Pattern.compile(js);
			  for(int i=0;i<len;i++)
			  {
			    log.debug("{}","手机号："+vas[i].trim());
			    String mobil=vas[i].trim();
			    /*if(!Pattern.compile("\\\\d{11}").matcher(vas[i].trim()).matches())
			      {
			      Platform.error($msggrp\\msg\\mobile,#CT000112);
			      return;
			      }*/
			    Matcher matcher=pattern.matcher(vas[i].trim());
			    if(!matcher.matches())
			    {
			      ctx.setFieldError(this,"msggrp.msg.mobile",MdaUtils.getI18NString("dbcmsg","CT000122"));
			      return true;
			    }
			  }
			}

			return true;
        }

        /**
        *   source:dbcmsg.@0022.script
        */
        @Check(target="msggrp.msg.eml",order=100)
        public boolean checkMsggrpMsgEmlN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getMsggrp().getMsg().getEml()))
			{
			  String value=this.getMsggrp().getMsg().getEml();
			  String []vas=value.split(",");
			  int len=vas.length;
			  if(len>2)
			  {
			    ctx.setFieldError(this,"msggrp.msg.eml",MdaUtils.getI18NString("dbcmsg","CT000128"));
			    return true;
			  }
			  for(int i=0;i<len;i++)
			  {
			    if(!vas[i].contains("@"))
			    {
			      ctx.setFieldError(this,"msggrp.msg.eml",MdaUtils.getI18NString("dbcmsg","CT000129"));
			      return true;
			    }
			    String []va=vas[i].trim().split("@");
			    if(va.length!=2)
			    {
			      ctx.setFieldError(this,"msggrp.msg.eml",MdaUtils.getI18NString("dbcmsg","CT000130"));
			      return true;
			    }
			  }
			}

			return true;
        }


        /**
        *   source:dbcmsg.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.setValues($msggrp\\msg\\emlflg,Platform.getCodetable("msgflg"));
			//Platform.setValues($msggrp\\msg\\msgflg,Platform.getCodetable("msgflg"));
			this.getMsgp().loadMsgList();
			// $msgp.loadModList();
			
			return true;
        }

        /**
        *   source:dbcmsg.@0019.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			
			
			
			
			if(MdaUtils.isEmpty(this.getMsggrp().getMsg().getFrm()))
			  this.getMsggrp().getMsg().setFrm("litdav");

			return true;
        }

        /**
        *   source:dbcmsg.@0020.script
        */
        @Init(order=100)
        public boolean	init100R2(){
            IContext ctx = MdaEnv.getContext();
            
			if(TRUE.equals(this.getMsggrp().getMsg().getEmlflg()))
			{
			  
			  
			}
			else
			{
			  
			  
			}
			
			if(TRUE.equals(this.getMsggrp().getMsg().getMsgflg()))
			{
			  
			  
			}
			else
			{
			  
			  
			}
			

			return true;
        }


        /**
        *   source:dbcmsg.@0018.script
        */
        public boolean hasBooked()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean flg = false;
			String sql = "SELECT count(*) count FROM msg WHERE frm = '"+this.getMsggrp().getMsg().getFrm()+"' AND ptyinr = '"+this.getSysmod().getPty().getInr()+"' ";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> count = new Argument<String>("count");
			ctx.getDaoSession().dbFetchFields(count);
			if(!"0".equals(String.valueOf(count.value)))
			  flg = true ;
			ctx.getDaoSession().dbCloseCursor();
			return flg;
		}





}