package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbcsacVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Sacgrp;
import com.ceb.gjjs.mda.manager.module.Sacp;
import com.ceb.gjjs.mda.manager.module.Cnfgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Sacmod;
import com.ceb.gjjs.mda.manager.module.Cnfp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 企业签约E结算
*/
@Transaction(vo= DbcsacVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbcsac extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbcsac.class);

		@BDGetter
		private Sacgrp sacgrp;

		@BDGetter
		private Sacmod sacmod;

		@BDGetter
		private Sacp sacp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Cnfp cnfp;

		@BDGetter
		private Cnfgrp cnfgrp;


		public Dbcsac()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getSacmod().setSacgrpHolder(()->this.getSacgrp());
           this.getSacp().setSacgrpHolder(()->this.getSacgrp());
           this.getCnfp().setCnfgrpHolder(()->this.getCnfgrp());
        }

        /**
        *   source:dbcsac.@0008.script
        */
        @Rule(target="cnfp.nxt2",order=100)
        public boolean ruleCnfpNxt2N100(){
            IContext ctx = MdaEnv.getContext();
            
			savaCnfgrp();
			readclient();
			/*
			  Platform.clear($toegrp\\pty);
			  searchpty();
			  readPty();
			  */
			

			return true;
        }

        /**
        *   source:dbcsac.@0009.script
        */
        @Rule(target="cnfp.submit",order=100)
        public boolean ruleCnfpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getCnfgrp()))
			  return false;
			savaCnfgrp();
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0010.script
        */
        @Rule(target="sacp.add",order=100)
        public boolean ruleSacpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","add Begin=========");
			

			return true;
        }

        /**
        *   source:dbcsac.@0011.script
        */
        @Rule(target="sacp.addadr",order=100)
        public boolean ruleSacpAddadrN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getCnfgrp().getPty());
			MdaUtils.clear(this.getCnfgrp().getPta());
			MdaUtils.clear(this.getCnfgrp().getAdr());
			if(!ctx.checkAll(this.getSacp()))
			{
			  log.warn("{}","页面校验未通过！");
			  return false;
			}
			if(MdaUtils.isEmpty(this.getSacgrp().getPty().getInr()))
			{
			  searchstlpty();
			}
			else
			{
			  ctx.setFieldError(this,"sacp.cid",MdaUtils.getI18NString("dbcsac","CT000118"));
			  return false;
			}
			//if(!searchpty())
			//return;
			ctx.getDaoSession().dbRead(this.getSacgrp().getPty(),new Argument("cid",this.getSacp().getCid()));
			
			this.getCnfgrp().getPty().copyValue(this.getSacgrp().getPty());
			

			return true;
        }

        /**
        *   source:dbcsac.@0012.script
        */
        @Rule(target="sacp.addpty",order=100)
        public boolean ruleSacpAddptyN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getSacgrp().getPty());
			this.getSacp().setCid(NULLSTR);
			this.getSacp().setNam(NULLSTR);
			

			return true;
        }

        /**
        *   source:dbcsac.@0013.script
        */
        @Rule(target="sacp.del",order=100)
        public boolean ruleSacpDelN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getSacp().getSacgrp().getClient().fullSize();
			if( index<0   ||   index>=length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000036"),MdaUtils.getI18NString("dbcsac","CT000037"));
			  return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbcsac","CT000038"),MdaUtils.getI18NString("dbcsac","CT000039")))
			{
			  return true;
			}
			ctx.getDaoSession().dbRead(this.getCnfgrp().getPta(),new Argument<String>("inr",this.getSacp().getSacgrp().getClient().getElement(index).getTrsinr()));
			ctx.getDaoSession().dbRead(this.getCnfgrp().getAdr(),new Argument<String>("inr",this.getCnfgrp().getPta().getObjinr()));
			//根据选中的记录，删除pta表和adr表中的对应记录
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbDelete(this.getCnfgrp().getPta());
			ctx.getDaoSession().dbDelete(this.getCnfgrp().getAdr());
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000040"),MdaUtils.getI18NString("dbcsac","CT000041"));
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0014.script
        */
        @Rule(target="sacp.delete",order=100)
        public boolean ruleSacpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","delete Begin=========");
			int index = 0;
			int length = this.getSacgrp().getPtylst().fullSize();
			if( index<0   ||   index>=length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000060"),MdaUtils.getI18NString("dbcsac","CT000061"));
			  return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbcsac","CT000062"),MdaUtils.getI18NString("dbcsac","CT000063")))
			{
			  return true;
			}
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbDelete(this.getSacgrp().getPtr(),new Argument("inr",this.getSacgrp().getPtylst().getElement(index).getInr()));
			ctx.getDaoSession().dbCommit();
			MdaUtils.clear(this.getSacgrp().getPtylst());
			ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000064"),MdaUtils.getI18NString("dbcsac","CT000065"));
			readPty();
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0015.script
        */
        @Rule(target="sacp.excout",order=100)
        public boolean ruleSacpExcoutN100(){
            IContext ctx = MdaEnv.getContext();
            
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[6];
			tit[0] = "核心客户号";
			tit[1] = "客户名称";
			tit[2] = "归属机构号";
			tit[3] = "详细地址";
			tit[4] = "电话";
			tit[5] = "传真";
			lst.add(tit);
			int len = this.getSacgrp().getClient().fullSize();
			log.debug("{}","len="+len);
			for(int i=0;i<len;i++)
			{
			  log.debug("{}",""+i);
			  String[] line = new String[6];
			  line[0] = this.getSacgrp().getClient().getElement(i).getPtycid();
			  line[1] =this.getSacgrp().getClient().getElement(i).getPtynam();
			  line[2] =this.getSacgrp().getClient().getElement(i).getAllbch();
			  line[3] = this.getSacgrp().getClient().getElement(i).getAdr();
			  line[4] =this.getSacgrp().getClient().getElement(i).getTel();
			  line[5] =this.getSacgrp().getClient().getElement(i).getFax();
			  lst.add(line);
			}
			log.debug("{}","lst "+lst.size());
			IStream is=this.getSacp().getExcout();
			is.setType("xls");
			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH:mm:ss");
			String fileName = "客户信息"+today+".xls";
			is.setName(fileName);
			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }

        /**
        *   source:dbcsac.@0016.script
        */
        @Rule(target="sacp.nxt",order=100)
        public boolean ruleSacpNxtN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","dbcsac.sac.nxt start:");
			int index = 0;
			int size = this.getSacgrp().getClient().fullSize();
			if(index < 0   ||   index >= size)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000072"),MdaUtils.getI18NString("dbcsac","CT000073"));
			  return true;
			}
			/* old -->
			  Platform.clear($sacgrp\\pty);
			  Platform.dbRead($sacgrp\\pty,new Argument("cid",$sacgrp\\client[index]\\ptycid.getValue()));
			  readPty();
			  Platform.popup($sacp\\selsac);
			  */

			/* new -->
			  Platform.dbRead($cnfgrp\\pta,new Argument<String>("inr",$cnfgrp\\cnflst[index]\\trsinr.getValue()));
			  Platform.dbRead($cnfgrp\\pty,new Argument<String>("inr",$cnfgrp\\pta\\ptyinr.getValue()));
			  Platform.dbRead($cnfgrp\\adr,new Argument<String>("inr",$cnfgrp\\pta\\objinr.getValue()));
			  Platform.popup($cnfp\\shwcnf);
			  */

			log.debug("{}","sacgrp.pty:" + this.getSacgrp().getClient().getElement(index).getPtycid());
			log.debug("{}","cnfgrp.pta:" + this.getSacgrp().getClient().getElement(index).getTrsinr());
			log.debug("{}","cnfgrp.pty:" + this.getCnfgrp().getPta().getPtyinr());
			log.debug("{}","cnfgrp.pty:" + this.getCnfgrp().getPta().getObjinr());

			MdaUtils.clear(this.getSacgrp().getPty());
			ctx.getDaoSession().dbRead(this.getSacgrp().getPty(),new Argument<String>("cid",this.getSacgrp().getClient().getElement(index).getPtycid()));
			readPty();
			ctx.getDaoSession().dbRead(this.getCnfgrp().getPty(),new Argument<String>("cid",this.getSacgrp().getClient().getElement(index).getPtycid()));
			if(!MdaUtils.isEmpty(this.getSacgrp().getClient().getElement(index).getTrsinr()))
			{
			  MdaUtils.clear(this.getCnfgrp().getPta());
			  MdaUtils.clear(this.getCnfgrp().getAdr());
			  ctx.getDaoSession().dbRead(this.getCnfgrp().getPta(),new Argument<String>("inr",this.getSacgrp().getClient().getElement(index).getTrsinr()));
			  ctx.getDaoSession().dbRead(this.getCnfgrp().getAdr(),new Argument<String>("inr",this.getCnfgrp().getPta().getObjinr()));
			}
			else
			{
			  MdaUtils.clear(this.getCnfgrp().getPta());
			  MdaUtils.clear(this.getCnfgrp().getAdr());
			}
			

			log.debug("{}","dbcsac.sac.nxt end!");

			return true;
        }

        /**
        *   source:dbcsac.@0017.script
        */
        @Rule(target="sacp.nxt2",order=100)
        public boolean ruleSacpNxt2N100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getSacgrp().getPty());
			if(!searchpty())
			  return true;
			readPty();
			
			

			return true;
        }

        /**
        *   source:dbcsac.@0018.script
        */
        @Rule(target="sacp.query",order=100)
        public boolean ruleSacpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","query Begin=========");
			readBnk();
			this.getSacp().setSelbch(NULLSTR);
			

			return true;
        }

        /**
        *   source:dbcsac.@0019.script
        */
        @Rule(target="sacp.search2",order=100)
        public boolean ruleSacpSearch2N100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbRead(this.getSacgrp().getPty(),new Argument("cid",this.getSacp().getCid()));
			if(MdaUtils.isEmpty(this.getSacgrp().getPty().getInr()))
			{
			  searchpty();
			}
			else
			{
			  ctx.setFieldError(this,"sacp.cid",MdaUtils.getI18NString("dbcsac","CT000091"));
			}

			return true;
        }

        /**
        *   source:dbcsac.@0020.script
        */
        @Rule(target="sacp.search3",order=100)
        public boolean ruleSacpSearch3N100(){
            IContext ctx = MdaEnv.getContext();
            
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0021.script
        */
        @Rule(target="sacp.submit",order=100)
        public boolean ruleSacpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","submit Begin=========");
			ctx.getDaoSession().dbBegin();
			String ptrtyp="";
			if("1".equals(this.getSacgrp().getPty().getPtytyp()))
			{
			  //商行
			  ptrtyp="1";
			}
			else if("2".equals(this.getSacgrp().getPty().getPtytyp()))
			{
			  //本行企业
			  ptrtyp="0";
			}
			int length = this.getSacgrp().getBnklst().fullSize();
			log.info("{}","bnklst=========" + length);
			for(int i = 0; i < length; i++)
			{
			  log.info("{}","flg=========" + this.getSacgrp().getBnklst().getElement(i).getFlg());
			  if("X".equals(this.getSacgrp().getBnklst().getElement(i).getFlg()))
			  {
			    log.info("{}","第"+i+"行加入==============");
			    MdaUtils.clear(this.getSacgrp().getPtr());
			    this.getSacgrp().getPtr().setInr(Platform.sdbCounter("ptr"));
			    this.getSacgrp().getPtr().setPreptyinr(this.getSacgrp().getPty().getInr());
			    this.getSacgrp().getPtr().setNxtptyinr(this.getSacgrp().getBnklst().getElement(i).getPtyinr());
			    this.getSacgrp().getPtr().setPtrtyp(ptrtyp);
			    this.getSacgrp().getPtr().setDes("");
			    log.info("{}","inr======"+this.getSacgrp().getPtr().getInr());
			    log.info("{}","preptyinr======"+this.getSacgrp().getPtr().getPreptyinr());
			    log.info("{}","nxtptyinr======"+this.getSacgrp().getPtr().getNxtptyinr());
			    log.info("{}","ptrtyp======"+this.getSacgrp().getPtr().getPtrtyp());
			    log.info("{}","des======"+this.getSacgrp().getPtr().getDes());
			    ctx.getDaoSession().dbInsert(this.getSacgrp().getPtr());
			    log.info("{}","第"+i+"行加入End==============");
			  }
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000076"),MdaUtils.getI18NString("dbcsac","CT000077"));
			
			readPty();
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0024.script
        */
        @Rule(target="sacp.cancel",order=100)
        public boolean ruleSacpCancelN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getCnfgrp().getPty());
			MdaUtils.clear(this.getCnfgrp().getPta());
			MdaUtils.clear(this.getCnfgrp().getAdr());

			

			return true;
        }


        /**
        *   source:dbcsac.@0026.script
        */
        @Check(target="sacp.issign",order=100)
        public boolean checkSacpIssignN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSacp().getIssign()))
			{
			  ctx.setFieldError(this,"sacp.issign",MdaUtils.getI18NString("dbcsac","CT000140"));
			}

			return true;
        }


        /**
        *   source:dbcsac.@0006.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			readclient();

			return true;
        }

        /**
        *   source:dbcsac.@0007.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","selpty Begin=========");
			readBnk();

			return true;
        }


        /**
        *   source:dbcsac.@0000.script
        */
        public void readBnk()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//$sacp.loadPtyList();
			//Platform.setModified($sacgrp\\ptylst);
			//Platform.popup($sacp\\selpty);
			MdaUtils.clear(this.getSacgrp().getBnklst());
			//判断pty、ptr的类型
			String ptrtyp = "";
			String ptytyp = "";
			String lvl = "";
			if("1".equals(this.getSacgrp().getPty().getPtytyp()))
			{
			  //商行
			  ptrtyp = "1";
			  ptytyp = "0";
			}
			else if("2".equals(this.getSacgrp().getPty().getPtytyp()))
			{
			  //本行企业
			  ptrtyp = "0";
			  ptytyp = "0";
			}
			//String sql = "SELECT inr ptyinr,nam nam,cid ncid FROM pty WHERE etyinr = '" + $sysmod\\pty\\etyinr + "' AND ptytyp IN ('0','1') AND inr NOT IN (SELECT nxtptyinr FROM ptr WHERE preptyinr = '" + $sysmod\\pty\\inr + "' AND ptrtyp IN ('0','1','2'))";
			//String sql = "SELECT inr ptyinr,nam nam,cid ncid FROM pty WHERE lvl = '3' AND ptytyp = '" + ptytyp + "' AND inr NOT IN (SELECT nxtptyinr FROM ptr WHERE preptyinr = '" + $sacgrp\\pty\\inr + "' AND ptrtyp = '" + ptrtyp + "')";
			String sql = "SELECT inr ptyinr,nam nam,cid ncid FROM pty WHERE ptytyp = '" + ptytyp + "' AND inr NOT IN (SELECT nxtptyinr FROM ptr WHERE preptyinr = '" + this.getSacgrp().getPty().getInr()+ "' AND ptrtyp = '" + ptrtyp + "')";
			//
			/*cib -> ceb 20181205
			  if("1".equals($sacgrp\\pty\\lvl.getValue()))
			  {
			  }
			  else if("2".equals($sacgrp\\pty\\lvl.getValue()))
			  {
			  sql += "AND lvl IN(2,3)";
			  }
			  else
			  {
			  sql += "AND lvl = '3' ";
			  }
			  */
			sql += "AND lvl IN(1,2)";

			if(!MdaUtils.isEmpty(this.getSacp().getSelbch()))
			{
			  sql += " AND (cid LIKE '%" + this.getSacp().getSelbch()+ "%' OR nam LIKE '%" + this.getSacp().getSelbch()+ "%')";
			}

			if("1".equals(this.getSysmod().getPty().getBrhlvl()))
			  log.info("{}","read all clientPty:" );
			else if("2".equals(this.getSysmod().getPty().getBrhlvl()))
			{
			  sql=sql+" and substr(pty.cid,1,2) = '"+this.getSysmod().getPty().getCid().substring(0,2)+"' ";
			  log.info("{}","read 分行 clientPty:");
			}
			else if("3".equals(this.getSysmod().getPty().getBrhlvl()) ||  "4".equals(this.getSysmod().getPty().getBrhlvl()) )
			{
			  sql=sql+" and pty.inr='"+this.getSysmod().getPty().getInr()+"' ";
			  log.info("{}","read  clientPty:");
			}

			log.info("{}","query:"+sql );
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> ptyinr = new Argument<String>("ptyinr");
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> ncid = new Argument<String>("ncid");
			Argument<String> flg = new Argument<String>("");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(ptyinr,nam,ncid);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getSacgrp().getBnklst().add(ptyinr,nam,ncid,flg);
			  }
			  else if(errorCode == NO_MORE_ROW)
			  {
			    log.info("{}","no more row!!");
			    break;
			  }
			  else
			  {
			    log.error("{}","errorCode:"+errorCode);
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:dbcsac.@0001.script
        */
        public void readInf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getCnfgrp().getCnflst());
			String sql = "SELECT a.inr trsinr, y.engnam engnam, r.adr adr, y.nam chnnam, r.tel tel, r.fax fax FROM pty y,pta a,adr r WHERE a.ptyinr = y.inr AND a.objinr = r.inr AND y.inr = '" + this.getSysmod().getPty().getInr() + "'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> trsinr = new Argument<String>("trsinr");
			Argument<String> engnam = new Argument<String>("engnam");
			Argument<String> adr = new Argument<String>("adr");
			Argument<String> chnnam = new Argument<String>("chnnam");
			Argument<String> tel = new Argument<String>("tel");
			Argument<String> fax = new Argument<String>("fax");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(trsinr,engnam,adr,chnnam,tel,fax);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			    this.getCnfgrp().getCnflst().add(trsinr,engnam,adr,chnnam,tel,fax);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			if(this.getCnfgrp().getCnflst().fullSize() > 0)
			{
			  this.getCnfgrp().getPty().setNam(this.getCnfgrp().getCnflst().getElement(0).getChnnam());
			  this.getCnfgrp().getPty().setEngnam(this.getCnfgrp().getCnflst().getElement(0).getEngnam());
			  
			  
			}
		}
        /**
        *   source:dbcsac.@0002.script
        */
        public void readPty()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//清除数据列表
			MdaUtils.clear(this.getSacgrp().getPtylst());
			String sql = "SELECT ptr.inr inr,pty.nam nam FROM pty,ptr WHERE ptr.preptyinr = '" + this.getSacgrp().getPty().getInr() + "' and pty.inr = ptr.nxtptyinr and ptr.ptrtyp in ('0','1') ";
			log.info("{}","readPty:"+sql );
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> nam = new Argument<String>("nam");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,nam);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getSacgrp().getPtylst().add(inr,nam);
			  }
			  else if(errorCode == NO_MORE_ROW)
			  {
			    log.info("{}","no more row!!");
			    break;
			  }
			  else
			  {
			    log.error("{}","errorCode:"+errorCode);
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:dbcsac.@0003.script
        */
        public void readclient()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","dbcsac.readclient start:");
			MdaUtils.clear(this.getSacgrp().getClient());
			String sql = "SELECT clipty.cid cid,clipty.nam nam,bchpty.cid bchcod,adr.adr adr,adr.tel tel,adr.fax fax,pta.inr trsinr,clipty.acttyp flg  FROM pty bchpty,pty clipty left join pta on clipty.inr = pta.ptyinr left join adr on adr.inr = pta.objinr,ptr WHERE bchpty.inr = ptr.nxtptyinr and ptr.ptrtyp in ('0', '1')  and ptr.preptyinr = clipty.inr ";

			if(!MdaUtils.isEmpty(this.getSacp().getCid1()))
			  sql=sql+" and clipty.cid='"+this.getSacp().getCid1()+"' ";

			if("1".equals(this.getSysmod().getPty().getBrhlvl()))
			  log.info("{}","read all clientPty:" );
			else if("2".equals(this.getSysmod().getPty().getBrhlvl()))
			{
			  sql=sql+" and substr(bchpty.cid,1,2) = '"+this.getSysmod().getPty().getCid().substring(0,2)+"' ";
			  log.info("{}","read 分行 clientPty:");
			}
			else if("3".equals(this.getSysmod().getPty().getBrhlvl()) ||  "4".equals(this.getSysmod().getPty().getBrhlvl()) )
			{
			  sql=sql+" and bchpty.inr='"+this.getSysmod().getPty().getInr()+"' ";
			  log.info("{}","read  clientPty:");
			}

			sql=sql+" order by clipty.cid asc,bchcod desc";

			log.info("{}","end sql dbcsac = "+sql);

			ctx.getDaoSession().dbExecuteSQL(sql);

			Argument<String> cid = new Argument<String>("cid");
			Argument<String> bchcod = new Argument<String>("bchcod");
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> adr = new Argument<String>("adr");
			Argument<String> tel = new Argument<String>("tel");
			Argument<String> flg = new Argument<String>("flg");
			Argument<String> fax = new Argument<String>("fax");
			Argument<String> trsinr = new Argument<String>("trsinr");
			String ptycid="";
			String ptyflg="";
			String allbch="";
			String ptynam="";
			String prebch="";
			String [] alladr=new String[100];
			String [] alltel=new String[100];
			String [] allfax=new String[100];
			String [] allinr=new String[100];
			int cnt=0;
			int count=0;
			int flg1=0;
			int adrflg=0;
			int adrcnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cid,nam,bchcod,adr,tel,fax,trsinr,flg);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    log.info("{}","*****cid,nam,bchcod,adr,tel,fax,acttyp*****"+cid.value+" "+nam.value+" "+bchcod.value+" "+adr.value+" "+tel.value+" "+fax.value+" "+trsinr.value+" "+ptyflg);
			    if(ptycid.equals(cid.value))
			    {
			      if(prebch.equals(bchcod.value) && adrflg==0)
			      {
			        alladr[adrcnt]=adr.value;
			        alltel[adrcnt]=tel.value;
			        allfax[adrcnt]=fax.value;
			        allinr[adrcnt]=trsinr.value;
			        adrcnt++;
			        log.info("{}","adrcnt = "+ adrcnt);
			      }
			      else
			      {
			        adrflg=1;
			        if(!allbch.contains(bchcod.value))
			        {
			          allbch=allbch+bchcod.value+",";
			          log.info("{}","next usrcid  usrnam  allbch acttyp= "+ptycid+ptynam+allbch+ptyflg);
			        }
			      }
			      cnt++;
			    }
			    else
			    {
			      if(cnt==0)
			      {
			        if(flg1==1)
			        {
			          for(int tmp=0;tmp<adrcnt;tmp++)
			          {
			            this.getSacgrp().getClient().add(new Argument<String>("ptycid",ptycid),new Argument<String>("flg",ptyflg),new Argument<String>("ptynam",ptynam),new Argument<String>("allbch",allbch),new Argument<String>("adr",alladr[tmp]),new Argument<String>("tel",alltel[tmp]),new Argument<String>("fax",allfax[tmp]),new Argument<String>("trsinr",allinr[tmp]));
			            log.info("{}","end usrcid  usrnam  allbch adr tel fax acttyp= "+ptycid+" "+ptynam+" "+allbch+" "+alladr[tmp]+" "+alltel[tmp]+" "+allfax[tmp]+" "+allinr[tmp]+" "+ptyflg);
			          }
			          adrcnt=0;
			          flg1=0;
			          allbch="";
			          cnt=0;
			        }
			        allbch=allbch+bchcod.value+",";
			        ptycid=cid.value;
			        ptynam=nam.value;
			        ptyflg=flg.value;
			        prebch=bchcod.value;
			        alladr[0]=adr.value;
			        alltel[0]=tel.value;
			        allfax[0]=fax.value;
			        allinr[0]=trsinr.value;
			        flg1++;
			        adrflg=0;
			        adrcnt=1;
			        log.info("{}","first usrcid  usrnam  allbch adr tel fax acttyp= "+ptycid+" "+ptynam+" "+allbch+" "+alladr[0]+" "+alltel[0]+" "+allfax[0]+" "+ptyflg);
			      }
			      else
			      {
			        for(int tmp=0;tmp<adrcnt;tmp++)
			        {
			          this.getSacgrp().getClient().add(new Argument<String>("ptycid",ptycid),new Argument<String>("ptynam",ptynam),new Argument<String>("flg",ptyflg),new Argument<String>("allbch",allbch),new Argument<String>("adr",alladr[tmp]),new Argument<String>("tel",alltel[tmp]),new Argument<String>("fax",allfax[tmp]),new Argument<String>("trsinr",allinr[tmp]));
			          log.info("{}","end usrcid  usrnam  allbch adr tel fax adrcnt acttyp= "+ptycid+" "+ptynam+" "+allbch+" "+alladr[tmp]+" "+alltel[tmp]+" "+allfax[tmp]+" "+allinr[tmp]+" "+ptyflg);
			        }
			        allbch="";
			        cnt=0;
			        allbch=allbch+bchcod.value+",";
			        alladr[0]=adr.value;
			        alltel[0]=tel.value;
			        allfax[0]=fax.value;
			        allinr[0]=trsinr.value;
			        ptycid=cid.value;
			        ptynam=nam.value;
			        ptyflg=flg.value;
			        prebch=bchcod.value;
			        adrcnt=1;
			        adrflg=0;
			        flg1=1;
			        log.info("{}","first usrcid  usrnam  allbch adr tel fax acttyp= "+ptycid+" "+ptynam+" "+allbch+" "+alladr[0]+" "+alltel[0]+" "+allfax[0]+" "+ptyflg);
			      }
			    }
			    count++;
			  }
			  else
			  {
			    if(!"".equals(ptycid))
			    {
			      for(int tmp=0;tmp<adrcnt;tmp++)
			      {
			        this.getSacgrp().getClient().add(new Argument<String>("ptycid",ptycid),new Argument<String>("flg",ptyflg),new Argument<String>("ptynam",ptynam),new Argument<String>("allbch",allbch),new Argument<String>("adr",alladr[tmp]),new Argument<String>("tel",alltel[tmp]),new Argument<String>("fax",allfax[tmp]),new Argument<String>("trsinr",allinr[tmp]));
			        log.info("{}","last end usrcid  usrnam  allbch adr tel fax acttyp = "+ptycid+" "+ptynam+" "+allbch+" "+alladr[tmp]+" "+alltel[tmp]+" "+allfax[tmp]+" "+allinr[tmp]+" "+ptyflg);
			      }
			    }
			    log.error("{}","errorCode:"+errorCode);
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			
			if(count==0 && !MdaUtils.isEmpty(this.getSacp().getCid1()))
			  ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000004"),MdaUtils.getI18NString("dbcsac","CT000005"));
		}
        /**
        *   source:dbcsac.@0004.script
        */
        public void savaCnfgrp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbBegin();
			//update pty
			ctx.getDaoSession().dbUpdate(this.getCnfgrp().getPty());
			if(MdaUtils.isEmpty(this.getCnfgrp().getAdr().getInr()))
			{
			  //新增
			  //adr
			  this.getCnfgrp().getAdr().setInr(Platform.sdbCounter("adr"));
			  ctx.getDaoSession().dbInsert(this.getCnfgrp().getAdr());
			  //pta
			  this.getCnfgrp().getPta().setInr(Platform.sdbCounter("pta"));
			  this.getCnfgrp().getPta().setNam(this.getCnfgrp().getPty().getEngnam());
			  this.getCnfgrp().getPta().setObjinr(this.getCnfgrp().getAdr().getInr());
			  this.getCnfgrp().getPta().setObjkey(this.getCnfgrp().getAdr().getExtkey());
			  this.getCnfgrp().getPta().setPtyinr(this.getCnfgrp().getPty().getInr());
			  this.getCnfgrp().getPta().setPtytyp(this.getSysmod().getPty().getPtytyp());
			  this.getCnfgrp().getPta().setPtyextkey(this.getCnfgrp().getPty().getExtkey());
			  ctx.getDaoSession().dbInsert(this.getCnfgrp().getPta());
			}
			else
			{
			  //更新
			  //adr
			  ctx.getDaoSession().dbUpdate(this.getCnfgrp().getAdr());
			  //pta
			  this.getCnfgrp().getPta().setNam(this.getCnfgrp().getPty().getEngnam());
			  this.getCnfgrp().getPta().setObjkey(this.getCnfgrp().getAdr().getExtkey());
			  ctx.getDaoSession().dbUpdate(this.getCnfgrp().getPta());
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbcsac","CT000006"),MdaUtils.getI18NString("dbcsac","CT000007"));
			
			readInf();
		}
        /**
        *   source:dbcsac.@0005.script
        */
        public boolean searchpty()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","*********核心编号搜索开始********");
			if(MdaUtils.isEmpty(this.getSacp().getCid()))
			{
			  ctx.setFieldError(this,"sacp.cid",MdaUtils.getI18NString("dbcsac","CT000016"));
			  return false;
			}
			else
			{
			  ICallback callback = new ICallback() {
				@Override
				public Object invoke(Object... paramVarArgs) {
					getBranchName(paramVarArgs);
					return null;
				}
			};
			  //    ICallback callback = new ICallback(getBranchInformation).invoke();
			  Map retMsg = new HashMap() ;
			  String cid = null;
			  cid = this.getSacp().getCid();
			  try
			  {
			    //Object obj = Platform.invoke("com.brilliance.eibs.main.Client","scall","impcosto","impcosto",new Object[]{callback,cid});
			    Object obj = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","getstlbrcnam","getstlbrcnam",new Object[]{callback,cid});
			    //    Map<String,Object> data = (Map<String,Object>) obj;
			  }
			  catch(Exception e)
			  {
			    ctx.getErrorCode();
			    log.error("{}","errormsg:" + e.getMessage());
			    Platform.setErrorInfo(retMsg,"11005","接口平台调用异常");
			  }
			  return true;
			  // Platform.clear($sacgrp\\pty);
			  // Platform.dbRead($sacgrp\\pty,new Argument("cid",$sacp\\cid.getValue()));
			  /*    int err=Platform.errorCode();
			    log.info("errcod="+err);
			    if(err==NO_ERROR)
			    {
			    Platform.clear($sacp\\nam);
			    if(!Platform.isEmpty($sacgrp\\pty\\nam))
			    $sacp\\nam.setValue($sacgrp\\pty\\nam.getValue());
			    else
			    $sacp\\nam.setValue($sacgrp\\pty\\engnam.getValue());
			    Platform.setModified($sacp\\nam);
			    return true;
			    }
			    else
			    {
			    Platform.clear($sacp\\nam);
			    Platform.setModified($sacp\\nam);
			    Platform.error($sacp\\cid,#CT000017);
			    return false;
			    }*/
			}
		}
        /**
        *   source:dbcsac.@0022.script
        */
        public synchronized Map<String,Object> getBranchInformation(Object... obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in gettingBranchInformation...");
			Map<String,Object> response = new HashMap<String,Object>();
			List<Map>data = (List<Map>)obj[0];
			log.debug("{}","size"+data.size());
			String temp = null;
			ctx.getDaoSession().dbBegin();
			for(Map<String,String> brh:data)
			{
			  if((MdaUtils.isEmpty(temp)||("temp".equals(brh.get("cid")))))
			  {
			    log.debug("{}","cid="+brh.get("cid"));
			    log.info("{}","compareseq="+("temp".equals(brh.get("cid"))));
			    if(MdaUtils.isEmpty(brh.get("cid")))
			      continue;
			    MdaUtils.clear(this.getCnfgrp().getPty());
			    MdaUtils.clear(this.getCnfgrp().getAdr());
			    MdaUtils.clear(this.getCnfgrp().getPta());
			    this.getCnfgrp().getPty().setInr(Platform.sdbCounter("pty"));
			    // String time = Platform.format(Platform.today(),"yyMMddHHmmss");
			    String time = MdaUtils.format(MdaUtils.today(),"yyyyMMddHHmmss");
			    // Platform.parseDate(time,"yyyyMMddHHmmss");
			    this.getCnfgrp().getPty().setBegdat(MdaUtils.parseDate(time,"yyyyMMddHHmmss"));
			    // $cnfgrp\\pty\\begdat.setValue(time);
			    this.getCnfgrp().getPty().setEngnam(brh.get("engnam"));
			    String ptytmp = brh.get("ptytyp");
			    /*switch(ptytmp)
			      {
			      case "A" :
			      $cnfgrp\\pty\\ptytyp.setValue("4");
			      break;
			      case "B" :
			      $cnfgrp\\pty\\ptytyp.setValue("0");
			      break;
			      case "C" :
			      $cnfgrp\\pty\\ptytyp.setValue("2");
			      break;
			      case "F" :
			      $cnfgrp\\pty\\ptytyp.setValue("5");
			      break;
			      case "O" :
			      $cnfgrp\\pty\\ptytyp.setValue("6");
			      break;
			      default :
			      log.info("错误数据");
			      }*/
			    this.getCnfgrp().getPty().setCid(brh.get("cid"));
			    // $cnfgrp\\pty\\brhlvl.setValue(brh.get("brhlvl"));
			    this.getCnfgrp().getPty().setNam(brh.get("nam"));
			    // $cnfgrp\\pty\\pntinr.setValue(brh.get("pntinr"));
			    this.getCnfgrp().getPty().setBrhflg("0");
			    this.getCnfgrp().getPty().setLvl("3");
			    this.getCnfgrp().getPty().setStatus("0");
			    this.getCnfgrp().getPty().setAtccod(brh.get("juscod"));
			    this.getCnfgrp().getPty().setExtkey(brh.get("cid"));
			    this.getCnfgrp().getPty().setChkcls("A");
			    this.getCnfgrp().getPty().setEpable("1");
			    this.getCnfgrp().getPty().setEtyinr("00000000");
			    log.debug("{}","insert bch "+this.getCnfgrp().getPty().getInr());
			    //Platform.dbRead($cnfgrp\\pty,new Argument("cid",brh.get("cid")));
			
			    log.debug("{}","readinr "+this.getCnfgrp().getPty().getInr());
			    ctx.getDaoSession().dbInsert(this.getCnfgrp().getPty());
			    temp = brh.get("cid");
			    log.info("{}","temp="+temp);
			  }
			  /*$cnfgrp\\adr\\inr.setValue(Platform.sdbCounter("adr"));
			    $cnfgrp\\adr\\extkey.setValue(brh.get("extkey"));
			    if(Platform.isEmpty(brh.get("adr1")))
			    {
			    $cnfgrp\\adr\\adr.setValue(null);
			    }
			    else
			    {
			    $cnfgrp\\adr\\adr.setValue(brh.get("adr1"));
			    }
			    $cnfgrp\\adr\\tel.setValue(brh.get("tel"));
			    $cnfgrp\\adr\\fax.setValue(brh.get("fax"));
			    $cnfgrp\\adr\\eml.setValue(brh.get("eml"));
			    $cnfgrp\\adr\\pobzip.setValue(brh.get("pobzip"));
			    $cnfgrp\\pta\\inr.setValue(Platform.sdbCounter("pta"));
			    $cnfgrp\\pta\\ptytyp.setValue("0");
			    $cnfgrp\\pta\\nam.setValue(brh.get("adrnam"));
			    $cnfgrp\\pta\\objinr.setValue($cnfgrp\\adr\\inr.getValue());
			    $cnfgrp\\pta\\objkey.setValue(brh.get("objkey"));
			    $cnfgrp\\pta\\ptyinr.setValue($cnfgrp\\pty\\inr.getValue());
			    $cnfgrp\\pta\\ptyextkey.setValue($cnfgrp\\pty\\cid.getValue());
			    Platform.dbInsert($cnfgrp\\pta);
			    Platform.dbInsert($cnfgrp\\adr);
			    log.debug("insert pta "+$cnfgrp\\pta\\inr);
			    log.debug("insert adr "+$cnfgrp\\adr\\inr);*/
			}
			ctx.getDaoSession().dbCommit();
			// if(data==null||data.size()==0)
			//{
			// return;
			//}
			// Set<String> set = data.keySet();
			//for(String key:set)
			//{
			// log.info(key+"="+data.get(key));
			//}
			return response;
		}
        /**
        *   source:dbcsac.@0023.script
        */
        public synchronized Map<String,Object> getBranchName(Object... obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in gettingBranchName...");
			Map<String,Object> response = new HashMap<String,Object>();
			List<Map>data = (List<Map>)obj[0];
			log.debug("{}","size="+data.size());
			if(MdaUtils.isEmpty(data.size()))
			{
			  this.getSacp().setNam(NULLSTR);
			  
			  ctx.setFieldError(this,"sacp.cid",MdaUtils.getI18NString("dbcsac","CT000101"));
			}
			else
			{
			  String temp = null;
			  for(Map<String,String> brh:data)
			  {
			    if((MdaUtils.isEmpty(temp)||("temp".equals(brh.get("cid")))))
			    {
			      log.debug("{}","cid="+brh.get("cid"));
			      log.info("{}","compareseq="+("temp".equals(brh.get("cid"))));
			      if(MdaUtils.isEmpty(brh.get("cid")))
			        continue;
			      MdaUtils.clear(this.getCnfgrp().getPty());
			      this.getCnfgrp().getPty().setInr(Platform.sdbCounter("pty"));
			      this.getCnfgrp().getPty().setCid(brh.get("cid"));
			      this.getCnfgrp().getPty().setEngnam(brh.get("engnam"));
			      this.getCnfgrp().getPty().setNam(brh.get("nam"));
			      temp = brh.get("cid");
			      log.info("{}","temp="+temp);
			    }
			  }
			  this.getSacp().setNam(NULLSTR);
			  if(!MdaUtils.isEmpty(this.getCnfgrp().getPty().getNam()))
			    this.getSacp().setNam(this.getCnfgrp().getPty().getNam());
			  else
			    this.getSacp().setNam(this.getCnfgrp().getPty().getEngnam());
			  
			}
			return response;
		}
        /**
        *   source:dbcsac.@0025.script
        */
        public boolean searchstlpty()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","*********核心编号搜索开始********");
			if(MdaUtils.isEmpty(this.getSacp().getCid()))
			{
			  ctx.setFieldError(this,"sacp.cid",MdaUtils.getI18NString("dbcsac","CT000131"));
			  return false;
			}
			else
			{
			  //ICallback callback = new ICallback(getBranchName).invoke();
			  ICallback callback = new ICallback() {
				@Override
				public Object invoke(Object... paramVarArgs) {
					getBranchInformation(paramVarArgs);
					return null;
				}
			};

			  Map retMsg = new HashMap() ;
			  String cid = null;
			  cid = this.getSacp().getCid();
			  try
			  {
			    Object obj = MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","impcosto","impcosto",new Object[]{callback,cid});
			    log.debug("{}","=====begin stlame========");
			    MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","sigdzt","sigdzt",new Object[]{cid});
			    log.debug("{}","=====end stlame========");
			    //Object obj = Platform.invoke("com.brilliance.eibs.main.Client","scall","getstlbrcnam","getstlbrcnam",new Object[]{callback,cid});
			    //    Map<String,Object> data = (Map<String,Object>) obj;
			  }
			  catch(Exception e)
			  {
			    ctx.getErrorCode();
			    log.error("{}","errormsg:" + e.getMessage());
			    Platform.setErrorInfo(retMsg,"11005","接口平台调用异常");
			  }
			  return true;
			  /*Platform.clear($sacgrp\\pty);
			    Platform.dbRead($sacgrp\\pty,new Argument("cid",$sacp\\cid.getValue()));
			    log.info("sacpcid="+$sacp\\cid.getValue());
			    int err=Platform.errorCode();
			    log.info("errcod="+err);
			    if(err==NO_ERROR)
			    {
			    Platform.clear($sacp\\nam);
			    if(!Platform.isEmpty($sacgrp\\pty\\nam))
			    $sacp\\nam.setValue($sacgrp\\pty\\nam.getValue());
			    else
			    $sacp\\nam.setValue($sacgrp\\pty\\engnam.getValue());
			    Platform.setModified($sacp\\nam);
			    return true;
			    }
			    else
			    {
			    Platform.clear($sacp\\nam);
			    Platform.setModified($sacp\\nam);
			    Platform.error($sacp\\cid,#CT000132);
			    return false;
			    }*/
			}
		}







}