package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbmbepVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Eptp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Epdgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 电子交单开通/关闭
*/
@Transaction(vo= DbmbepVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbmbep extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbmbep.class);

        //交易说明
        private String note;
		@BDGetter
		private Epdgrp epdgrp;

		@BDGetter
		private Eptp eptp;

		@BDGetter
		private Sysmod sysmod;


		public Dbmbep()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getEptp().setEpdgrpHolder(()->this.getEpdgrp());
        }

        /**
        *   source:dbmbep.@0001.script
        */
        @Rule(target="eptp.dowexc",order=100)
        public boolean ruleEptpDowexcN100(){
            IContext ctx = MdaEnv.getContext();
            
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[9];
			//客户编号|客户名称|客户类型|所属业务机构号|机构可否办理电子交单业务|是否开通电子交单|客户属性|开通时间|关闭时间
			tit[0] = "客户编号";
			tit[1] = "客户名称";
			tit[2] = "客户类型";
			tit[3] = "所属业务机构";
			tit[4] = "机构可否开办电子交单";
			tit[5] = "是否开通电子交单";
			tit[6] = "客户属性";
			tit[7] = "开通电子交单日期";
			tit[8] = "关闭电子交单日期";
			lst.add(tit);
			int len = this.getEptp().getEpclst().fullSize();
			log.debug("{}","len=========="+len);
			for(int i=0;i<len;i++)
			{
			  log.debug("{}","***********  "+i+"  ***********");
			  String[] line = new String[9];
			  line[0] = this.getEptp().getEpclst().getElement(i).getCid();
			  line[1] = this.getEptp().getEpclst().getElement(i).getNam();
			  String typ =this.getEptp().getEpclst().getElement(i).getTyp();
			  log.debug("{}","========="+this.getEptp().getEpclst().getElement(i).getTyp()+"**************"+this.getEptp().getEpclst().getElement(i).getOpnflg());
			  line[2] = MdaUtils.getCodetableLabel("clityp",typ);
			  line[3] = this.getEptp().getEpclst().getElement(i).getPtybch();
			  if("√".equals(this.getEptp().getEpclst().getElement(i).getBchepable()))
			    line[4] ="是";
			  else
			    line[4] = "否";

			  if("√".equals(this.getEptp().getEpclst().getElement(i).getCliepable()))
			    line[5] ="是";
			  else
			    line[5] = "否";
			  line[6] = this.getEptp().getEpclst().getElement(i).getChkcls();

			  if(MdaUtils.isEmpty(this.getEptp().getEpclst().getElement(i).getOpndat()))
			    line[7] ="";
			  else
			    line[7] = MdaUtils.format(this.getEptp().getEpclst().getElement(i).getOpndat(),"yyyyMMdd HH:mm");
			  if(MdaUtils.isEmpty(this.getEptp().getEpclst().getElement(i).getClsdat()))
			    line[8] ="";
			  else
			    line[8] = MdaUtils.format(this.getEptp().getEpclst().getElement(i).getClsdat(),"yyyyMMdd HH:mm");
			  lst.add(line);
			}
			log.debug("{}","lst "+lst.size());
			IStream is=this.getEptp().getDowexc();
			is.setType("xls");
			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH:mm:ss");
			String fileName = "电子交单控制"+today+".xls";
			is.setName(fileName);
			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }

        /**
        *   source:dbmbep.@0003.script
        */
        @Rule(target="eptp.editep",order=100)
        public boolean ruleEptpEditepN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","*************新增修改功能******************");
			int index = 0;
			log.info("{}","current line selected is ="+index );
			int length = this.getEptp().getEpclst().fullSize();
			log.info("{}","size of tmplst is ="+length);
			MdaUtils.clear(this.getEpdgrp().getRec());
			if( index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000056"),MdaUtils.getI18NString("dbmbep","CT000057"));
			}
			else
			{
			  this.getEpdgrp().getRec().setCid(this.getEptp().getEpclst().getElement(index).getCid());
			  this.getEpdgrp().getRec().setPtybch(this.getEptp().getEpclst().getElement(index).getPtybch());
			  
			  // usrsel();
			  ctx.postRule(this,"eptp.selusr") ;
			  
			}
			log.info("{}","*************新增修改功能结束******************");

			return true;
        }

        /**
        *   source:dbmbep.@0004.script
        */
        @Rule(target="eptp.nxt",order=100)
        public boolean ruleEptpNxtN100(){
            IContext ctx = MdaEnv.getContext();
            
			//下一步根据客户号加载客户可选择的交易清单
			if(MdaUtils.isEmpty(this.getEpdgrp().getRec().getOpnflg()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000322"),MdaUtils.getI18NString("dbmbep","CT000323"));
			  return true;
			}
			// Load交易信息
			this.getEptp().getAvailableTrnList(this.getEpdgrp().getRec().getCid(),this.getEpdgrp().getRec().getPtybch());
			
			

			return true;
        }

        /**
        *   source:dbmbep.@0005.script
        */
        @Rule(target="eptp.allopn",order=100)
        public boolean ruleEptpAllopnN100(){
            IContext ctx = MdaEnv.getContext();
            
			// allctr("X");
			int size= this.getEptp().getAlllst().fullSize();
			log.info("{}","size of alllst is =" + size);
			ctx.getDaoSession().dbBegin();
			for(int i=0 ; i< size ;i++)
			{
			  MdaUtils.clear(this.getEptp().getTmp());
			  String inr = this.getEptp().getAlllst().getElement(i).getInr();
			  this.getEptp().getTmp().setCid( this.getEptp().getAlllst().getElement(i).getCid());
			  this.getEptp().getTmp().setNam( this.getEptp().getAlllst().getElement(i).getNam());
			  this.getEptp().getTmp().setTyp( this.getEptp().getAlllst().getElement(i).getTyp());
			  this.getEptp().getTmp().setTrnnam( this.getEptp().getAlllst().getElement(i).getTrnnam());
			  this.getEptp().getTmp().setTrncod( this.getEptp().getAlllst().getElement(i).getTrncod());
			  this.getEptp().getTmp().setOpnflg("X") ;
			  String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  this.getEptp().getTmp().setOpndat(MdaUtils.parseDate(time,"yyyyMMdd"));
			  this.getEptp().getTmp().setTrnopnflg("X");
			  this.getEptp().getTmp().setPtybch( this.getEptp().getAlllst().getElement(i).getPtybch());
			  this.getEptp().getTmp().setClsdat(null);
			  // 新增的纪录
			  if(MdaUtils.isEmpty(inr))
			  {
			    this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			    ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			  }
			  else
			  {
			    this.getEptp().getTmp().setInr( this.getEptp().getAlllst().getElement(i).getInr());
			    ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			  }
			}
			// 更新客户信息
			if(!MdaUtils.isEmpty(this.getEpdgrp().getCli().getInr()))
			{
			  String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  if(MdaUtils.isEmpty(this.getEpdgrp().getCli().getEpodat()))
			  {
			    this.getEpdgrp().getCli().setEpodat(MdaUtils.parseDate(time,"yyyyMMdd"));
			  }
			  this.getEpdgrp().getCli().setEpcdat(null);
			  ctx.getDaoSession().dbUpdate(this.getEpdgrp().getCli());
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000326"),MdaUtils.getI18NString("dbmbep","CT000327"));
			
			this.getCustomerWithBranch();

			return true;
        }

        /**
        *   source:dbmbep.@0006.script
        */
        @Rule(target="eptp.allcls",order=100)
        public boolean ruleEptpAllclsN100(){
            IContext ctx = MdaEnv.getContext();
            
			//allctr("O");
			int size= this.getEptp().getAlllst().fullSize();
			log.info("{}","size of alllst is =" + size);
			Date opndat= this.getEpdgrp().getRec().getOpndat();
			ctx.getDaoSession().dbBegin();
			for(int i=0 ; i< size ;i++)
			{
			  MdaUtils.clear(this.getEptp().getTmp());
			  String inr = this.getEptp().getAlllst().getElement(i).getInr();
			  this.getEptp().getTmp().setCid( this.getEptp().getAlllst().getElement(i).getCid());
			  this.getEptp().getTmp().setNam( this.getEptp().getAlllst().getElement(i).getNam());
			  this.getEptp().getTmp().setTyp( this.getEptp().getAlllst().getElement(i).getTyp());
			  this.getEptp().getTmp().setTrnnam( this.getEptp().getAlllst().getElement(i).getTrnnam());
			  this.getEptp().getTmp().setTrncod( this.getEptp().getAlllst().getElement(i).getTrncod());
			  this.getEptp().getTmp().setOpnflg("X") ;
			  this.getEptp().getTmp().setTrnopnflg("O");
			  this.getEptp().getTmp().setPtybch( this.getEptp().getAlllst().getElement(i).getPtybch());
			  String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  this.getEptp().getTmp().setClsdat(MdaUtils.parseDate(time,"yyyyMMdd"));
			  // 新增的纪录
			  if(MdaUtils.isEmpty(inr))
			  {
			    if(!MdaUtils.isEmpty(opndat))
			    {
			      this.getEptp().getTmp().setOpndat(opndat);
			    }
			    this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			    log.debug("{}","新增... ");
			    ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			  }
			  else
			  {
			    log.debug("{}","修改... ");
			    this.getEptp().getTmp().setInr(inr);
			    ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			  }
			}
			// 更新  PTY表的机构信息
			if(!MdaUtils.isEmpty(this.getEpdgrp().getCli().getInr()))
			{
			  String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  this.getEpdgrp().getCli().setEpcdat(MdaUtils.parseDate(time,"yyyyMMdd"));
			  ctx.getDaoSession().dbUpdate(this.getEpdgrp().getCli());
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000324"),MdaUtils.getI18NString("dbmbep","CT000325"));
			
			this.getCustomerWithBranch();


			return true;
        }

        /**
        *   source:dbmbep.@0007.script
        */
        @Rule(target="eptp.selusr",order=100)
        public boolean ruleEptpSelusrN100(){
            IContext ctx = MdaEnv.getContext();
            
			// usrsel();
			// 1.检查客户号必输
			if(MdaUtils.isEmpty(this.getEpdgrp().getRec().getCid()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000298"),MdaUtils.getI18NString("dbmbep","CT000299"));
			  return true;
			}
			// 2.获取该客户号的合法机构信息，并检查机构信息
			String bchcods= getCustomerBranchcodes(this.getEpdgrp().getRec().getCid());
			log.debug("{}","bchcods = " + bchcods);
			if(MdaUtils.isEmpty(bchcods) )
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000300"),MdaUtils.getI18NString("dbmbep","CT000301"));
			  return true;
			}

			if(MdaUtils.isEmpty(this.getEpdgrp().getRec().getPtybch()) || (!MdaUtils.isEmpty(this.getEpdgrp().getRec().getPtybch()) && bchcods.indexOf(this.getEpdgrp().getRec().getPtybch())< 0 ) )
			{
			  this.getEpdgrp().getRec().setPtybch(NULLSTR);
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000302"),MdaUtils.getI18NString("dbmbep","CT000303")+bchcods);
			  return true;
			}
			// 初始化 addmdf面板的数据
			getCustomerInfoByCidAndBchcod(this.getEpdgrp().getRec().getCid(), this.getEpdgrp().getRec().getPtybch());


			return true;
        }

        /**
        *   source:dbmbep.@0010.script
        */
        @Rule(target="eptp.delete",order=100)
        public boolean ruleEptpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","******删除开始********");
			int index = 0;
			int length=this.getEptp().getEpclst().fullSize();
			if( index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000048"),MdaUtils.getI18NString("dbmbep","CT000049"));
			  return true;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbmbep","CT000050"),MdaUtils.getI18NString("dbmbep","CT000051")))
			  return true;
			MdaUtils.clear(this.getEptp().getAlllst());
			ctx.getDaoSession().dbReadset(this.getEptp().getAlllst(),new Argument("cid",this.getEptp().getEpclst().getElement(index).getCid()),new Argument("ptybch",this.getEptp().getEpclst().getElement(index).getPtybch()));
			int len=this.getEptp().getAlllst().fullSize();
			log.info("{}","alllst - len  cid   ptybch =  "+len+" "+this.getEptp().getEpclst().getElement(index).getCid()+" "+this.getEptp().getEpclst().getElement(index).getPtybch());
			ctx.getDaoSession().dbBegin();
			for(int i=0;i<len;i++)
			{
			  ctx.getDaoSession().dbDelete(this.getEptp().getAlllst().getElement(i));
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000054"),MdaUtils.getI18NString("dbmbep","CT000055"));
			query();
			log.info("{}","******删除结束********");

			return true;
        }

        /**
        *   source:dbmbep.@0011.script
        */
        @Rule(target="eptp.add",order=100)
        public boolean ruleEptpAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getEpdgrp().getRec());
			

			return true;
        }

        /**
        *   source:dbmbep.@0012.script
        */
        @Rule(target="eptp.search",order=100)
        public boolean ruleEptpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			// query();
			//getCustomerWithBranch();
			frush();

			return true;
        }

        /**
        *   source:dbmbep.@0018.script
        */
        @Rule(target="eptp.sav",order=100)
        public boolean ruleEptpSavN100(){
            IContext ctx = MdaEnv.getContext();
            
			int size= this.getEptp().getAlllst().fullSize();
			log.info("{}","size of alllst is =" + size);
			Date opndat= this.getEpdgrp().getRec().getOpndat();
			ctx.getDaoSession().dbBegin();
			for(int i=0 ; i< size ;i++)
			{
			  MdaUtils.clear(this.getEptp().getTmp());
			  String inr = this.getEptp().getAlllst().getElement(i).getInr();
			  this.getEptp().getTmp().setCid( this.getEptp().getAlllst().getElement(i).getCid());
			  this.getEptp().getTmp().setNam( this.getEptp().getAlllst().getElement(i).getNam());
			  this.getEptp().getTmp().setTyp( this.getEptp().getAlllst().getElement(i).getTyp());
			  this.getEptp().getTmp().setTrnnam( this.getEptp().getAlllst().getElement(i).getTrnnam());
			  this.getEptp().getTmp().setTrncod( this.getEptp().getAlllst().getElement(i).getTrncod());
			  this.getEptp().getTmp().setPtybch( this.getEptp().getAlllst().getElement(i).getPtybch());
			  this.getEptp().getTmp().setOpnflg("X");
			  if(!MdaUtils.isEmpty(this.getEptp().getAlllst().getElement(i).getTrnopnflg()))
			  {
			    this.getEptp().getTmp().setTrnopnflg("X");
			  }
			  else
			  {
			    this.getEptp().getTmp().setTrnopnflg("O");
			  }
			  // 新增的纪录
			  if(MdaUtils.isEmpty(inr))
			  {
			    this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			    if(!MdaUtils.isEmpty(opndat))
			    {
			      this.getEptp().getTmp().setOpndat(opndat);
			    }
			    ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			  }
			  else
			  {
			    this.getEptp().getTmp().setInr(inr);
			    ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			  }
			}

			if(!MdaUtils.isEmpty(this.getEpdgrp().getCli().getInr()))
			{
			  String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			  if(MdaUtils.isEmpty(this.getEpdgrp().getCli().getEpodat()))
			  {
			    this.getEpdgrp().getCli().setEpodat(MdaUtils.parseDate(time,"yyyyMMdd"));
			  }
			  ctx.getDaoSession().dbUpdate(this.getEpdgrp().getCli());
			}

			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000328"),MdaUtils.getI18NString("dbmbep","CT000329"));
			
			this.getCustomerWithBranch();

			return true;
        }



        /**
        *   source:dbmbep.@0002.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			// query();
			//getCustomerWithBranch();
			List<CodetableItem>bchcod=this.getSysmod().getBranchList(this.getSysmod().getPty().getCid());
			MdaUtils.setValues(this.getEptp(),"ptynam",bchcod);
			if(!MdaUtils.isEmpty(bchcod))
			{
			  this.getEptp().setPtynam(bchcod.get(0).getValue());
			}
			
			frush();

			return true;
        }


        /**
        *   source:dbmbep.@0000.script
        */
        public void query()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// log.info("*************初始界面查询******************");
			MdaUtils.clear(this.getEptp().getEpclst());
			Argument<String> cid =new Argument<String>("cid");
			Argument<String> nam =new Argument<String>("nam");
			Argument<String> typ =new Argument<String>("typ");
			Argument<String> ptybch =new Argument<String>("ptybch");
			Argument<String> opnflg =new Argument<String>("opnflg");
			Argument<Date> opndat =new Argument<Date>("opndat");
			Argument<Date> clsdat =new Argument<Date>("clsdat");
			String sql="SELECT distinct cid,nam,typ,ptybch,opnflg,opndat,clsdat FROM epc ";
			String bchcod = this.getSysmod().getPty().getCid();
			String con =" AND " ;
			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  String lev = this.getSysmod().getPty().getBrhlvl();
			  if("1".equals(lev))
			  {
			    // 总行
			    sql = sql + " WHERE 1=1 " ;

			  }
			  else if("2".equals(lev))
			  {
			    // 分行
			    String cidArg = this.getSysmod().getPty().getCid();
			    sql = sql + " WHERE SUBSTR(ptybch,1,2)='" + this.getSysmod().getPty().getCid().substring(0,2) + "'" ;
			  }
			  else if("3".equals(lev) || "4".equals(lev))
			  {
			    // 支行
			    sql = sql + " WHERE ptybch = '"+bchcod+"' " ;
			  }
			}
			else
			{
			  con = " WHERE " ;
			}

			if(!MdaUtils.isEmpty(this.getEptp().getCid()))
			  sql=sql+ con + "  cid='"+this.getEptp().getCid()+"'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			int errCod =  ctx.getErrorCode() ;
			log.info("{}","查询语句 ="+sql);
			int cnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cid,nam,typ,ptybch,opnflg,opndat,clsdat);
			  int errCod1 = ctx.getErrorCode();
			  if(errCod1==NO_ERROR)
			  {
			    if("X".equals(opnflg.value))
			    {
			      opnflg.value="√";
			      this.getEptp().getEpclst().add(cid,nam,typ,ptybch,opnflg,opndat,clsdat);
			    }
			    else
			    {
			      opnflg.value="×";
			      this.getEptp().getEpclst().add(cid,nam,typ,ptybch,opnflg,opndat,clsdat);
			    }
			    cnt++;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			if(cnt==0 && !MdaUtils.isEmpty(this.getEptp().getCid()))
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000058"),MdaUtils.getI18NString("dbmbep","CT000059"));
			// log.info("*************初始界面查询结束******************"+$eptp\\epclst.fullSize());
					}
        /**
        *   source:dbmbep.@0008.script
        */
        public void usrsel()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","***************搜索开始****************");
			Argument<String> cid =new Argument<String>("cid");
			Argument<String> nam =new Argument<String>("nam");
			Argument<String> ptrtyp =new Argument<String>("ptrtyp");
			Argument<String> ptybch =new Argument<String>("ptybch");
			Argument<String> opnflg =new Argument<String>("opnflg");
			Argument<String> trnopnflg =new Argument<String>("trnopnflg");
			Argument<Date> opndat =new Argument<Date>("opndat");
			Argument<Date> clsdat =new Argument<Date>("clsdat");
			String bch="";
			//给机构号赋值
			if(!MdaUtils.isEmpty(this.getEpdgrp().getRec().getPtybch()))
			  bch=this.getEpdgrp().getRec().getPtybch();
			if(!MdaUtils.isEmpty(this.getEpdgrp().getRec().getCid()))
			{
			  // 已经开通过情况下，关联epc (此处可能有漏洞，若后续新增了新交易？？？)
			  String sql2="SELECT distinct clipty.cid cid,clipty.nam nam,ptr.ptrtyp ptrtyp,bchpty.cid ptybch,bchpty.epable opnflg,bchpty.epodat opndat,bchpty.epcdat clsdat,epc.trnopnflg trnopnflg FROM epc,pty clipty,ptr,pty bchpty WHERE epc.cid=clipty.cid and epc.ptybch=bchpty.cid and clipty.inr=ptr.preptyinr and bchpty.inr=ptr.nxtptyinr and clipty.cid = '"+this.getEpdgrp().getRec().getCid()+"' and bchpty.cid like '%"+bch+"%'";
			  // Platform.dbBegin();
			  ctx.getDaoSession().dbExecuteSQL(sql2);
			  int errCod =  ctx.getErrorCode();
			  log.debug("{}","****************errCod********************"+errCod);
			  log.info("{}","查询语句 ："+sql2);
			  int count=0;
			  String bchcod="";
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(cid,nam,ptrtyp,ptybch,opnflg,opndat,clsdat,trnopnflg);
			    int errCod22 = ctx.getErrorCode();
			    log.debug("{}","*********errCod22*********"+errCod22);
			    if(errCod22==NO_ERROR)
			    {
			      this.getEpdgrp().getRec().setTrnopnflg(trnopnflg.value);
			      this.getEptp().setTrnopnflg(trnopnflg.value);
			      this.getEpdgrp().getRec().setOpndat(opndat.value);
			      this.getEpdgrp().getRec().setClsdat(clsdat.value);
			      this.getEpdgrp().getRec().setCid(cid.value);
			      this.getEpdgrp().getRec().setNam(nam.value);
			      //客户类型判断0Q企业，1S商行
			      if("0".equals(ptrtyp.value))
			        this.getEpdgrp().getRec().setTyp("Q");
			      else if("1".equals(ptrtyp.value))
			        this.getEpdgrp().getRec().setTyp("S");
			      else
			        this.getEpdgrp().getRec().setTyp("");
			      //可否开通电子交单判断0O否，1X是
			      if("1".equals(opnflg.value))
			        this.getEpdgrp().getRec().setOpnflg("X");
			      else
			        this.getEpdgrp().getRec().setOpnflg("");
			      this.getEpdgrp().getRec().setPtybch(ptybch.value);
			      count++;
			      bchcod=bchcod+ptybch.value+"  ";
			    }
			    else
			    {
			      if(count>1)
			      {
			        ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000012"),MdaUtils.getI18NString("dbmbep","CT000013")+bchcod);
			        this.getEpdgrp().getRec().setPtybch(NULLSTR);
			        this.getEpdgrp().getRec().setOpnflg(NULLSTR);
			        this.getEpdgrp().getRec().setClsdat(null);
			        this.getEpdgrp().getRec().setOpndat(null);
			      }
			      break;
			    }
			  }
			  log.debug("{}","============count==========="+count);

			  // 第一次设置仅关联开通机构即可
			  String sql="select distinct clipty.cid cid,clipty.nam nam,ptr.ptrtyp ptrtyp,bchpty.cid ptybch,bchpty.epable opnflg,bchpty.epodat opndat,bchpty.epcdat clsdat FROM pty clipty,ptr,pty bchpty WHERE clipty.inr=ptr.preptyinr and bchpty.inr=ptr.nxtptyinr and clipty.cid = '"+this.getEpdgrp().getRec().getCid()+"' and bchpty.cid like '%"+bch+"%'";

			  if(count==0)
			  {
			    ctx.getDaoSession().dbCloseCursor();
			    ctx.getDaoSession().dbExecuteSQL(sql);
			    int errCod1 =  ctx.getErrorCode();
			    log.debug("{}","**********errCod1**********"+errCod1);
			    log.info("{}","查询语句 ："+sql);
			    while(true)
			    {
			      ctx.getDaoSession().dbFetchFields(cid,nam,ptrtyp,ptybch,opnflg,opndat,clsdat);
			      int errCod11 = ctx.getErrorCode();
			      log.debug("{}","*********errCod11*********"+errCod11);
			      if(errCod11==NO_ERROR)
			      {
			        this.getEptp().setTrnopnflg("");
			        this.getEpdgrp().getRec().setOpndat(opndat.value);
			        this.getEpdgrp().getRec().setClsdat(clsdat.value);
			        this.getEpdgrp().getRec().setCid(cid.value);
			        this.getEpdgrp().getRec().setNam(nam.value);
			        //客户类型判断0Q企业，1S商行
			        if("0".equals(ptrtyp.value))
			          this.getEpdgrp().getRec().setTyp("Q");
			        else if("1".equals(ptrtyp.value))
			          this.getEpdgrp().getRec().setTyp("S");
			        else
			          this.getEpdgrp().getRec().setTyp("");
			        //可否开通电子交单判断0O否，1X是
			        if("1".equals(opnflg.value))
			          this.getEpdgrp().getRec().setOpnflg("X");
			        else
			          this.getEpdgrp().getRec().setOpnflg("");
			        this.getEpdgrp().getRec().setPtybch(ptybch.value);
			        count=count+1;
			        bchcod=bchcod+ptybch.value+"  ";
			      }
			      else
			      {
			        if(count>1)
			        {
			          ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000014"),MdaUtils.getI18NString("dbmbep","CT000015")+bchcod);
			          this.getEpdgrp().getRec().setPtybch(NULLSTR);
			          this.getEpdgrp().getRec().setOpnflg(NULLSTR);
			          this.getEpdgrp().getRec().setClsdat(null);
			          this.getEpdgrp().getRec().setOpndat(null);
			        }
			        break;
			      }
			    }
			  }
			  if(count==0)
			  {
			    ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000024"),MdaUtils.getI18NString("dbmbep","CT000025"));
			    MdaUtils.clear(this.getEpdgrp().getRec());
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  // Platform.dbCommit();
			  
			  
			  
			  
			  
			}
			else
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000044"),MdaUtils.getI18NString("dbmbep","CT000045"));
			log.info("{}","***************搜索结束****************");
		}
        /**
        *   source:dbmbep.@0009.script
        */
        public void allctr(String flg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","**********************全部开通/关闭功能***********************");
			//flg可设置参数：X（开通） 和   ""（关闭）
			int length = this.getEptp().getAlllst().fullSize();
			log.info("{}","size of alllst is ="+length);
			ctx.getDaoSession().dbBegin();
			Date today=MdaUtils.today();
			for(int index = 0;index < length;index++)
			{
			  MdaUtils.clear(this.getEptp().getTmp());
			  this.getEpdgrp().getRec().setTrnnam(this.getEptp().getAlllst().getElement(index).getTrnnam());
			  this.getEpdgrp().getRec().setTrncod(this.getEptp().getAlllst().getElement(index).getTrncod());
			  this.getEptp().getTmp().setTrnnam(this.getEptp().getAlllst().getElement(index).getTrnnam());
			  this.getEptp().getTmp().setTrncod(this.getEptp().getAlllst().getElement(index).getTrncod());
			  this.getEptp().getTmp().setCid(this.getEpdgrp().getRec().getCid());
			  this.getEptp().getTmp().setNam(this.getEpdgrp().getRec().getNam());
			  this.getEptp().getTmp().setTyp(this.getEpdgrp().getRec().getTyp());
			  this.getEptp().getTmp().setOpnflg(this.getEpdgrp().getRec().getOpnflg());
			  this.getEptp().getTmp().setPtybch(this.getEpdgrp().getRec().getPtybch());
			  if("X".equals(flg))
			  {
			    if(!"X".equals(this.getEptp().getTrnopnflg()))
			    {
			      if("O".equals(this.getEptp().getTrnopnflg()))
			      {
			        ctx.getDaoSession().dbRead(this.getEptp().getTmp(),new Argument<String>("cid",this.getEpdgrp().getRec().getCid()),new Argument<String>("ptybch", this.getEpdgrp().getRec().getPtybch()),new Argument<String>("trncod", this.getEpdgrp().getRec().getTrncod()));
			        int err=ctx.getErrorCode();
			        if(err==NO_ERROR)
			        {
			          this.getEptp().getTmp().setTrnopnflg("X");
			          this.getEptp().getTmp().setOpndat(today);
			          this.getEptp().getTmp().setClsdat(null);
			          ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			          log.debug("{}","**************更新*************"+index);
			        }
			        else
			        {
			          this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			          this.getEptp().getTmp().setTrnnam(this.getEptp().getAlllst().getElement(index).getTrnnam());
			          this.getEptp().getTmp().setTrncod(this.getEptp().getAlllst().getElement(index).getTrncod());
			          this.getEptp().getTmp().setCid(this.getEpdgrp().getRec().getCid());
			          this.getEptp().getTmp().setNam(this.getEpdgrp().getRec().getNam());
			          this.getEptp().getTmp().setTyp(this.getEpdgrp().getRec().getTyp());
			          this.getEptp().getTmp().setOpnflg(this.getEpdgrp().getRec().getOpnflg());
			          this.getEptp().getTmp().setPtybch(this.getEpdgrp().getRec().getPtybch());
			          this.getEptp().getTmp().setTrnopnflg("X");
			          this.getEptp().getTmp().setOpndat(today);
			          this.getEptp().getTmp().setClsdat(null);
			          ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			          log.debug("{}","**********更新****插入*************"+index);
			        }
			      }
			      else
			      {
			        this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			        this.getEptp().getTmp().setTrnopnflg("X");
			        this.getEptp().getTmp().setOpndat(today);
			        this.getEptp().getTmp().setClsdat(null);
			        ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			        log.debug("{}","**************插入*************"+index);
			      }
			    }
			    if("X".equals(this.getEptp().getTrnopnflg()))
			    {
			      ctx.getDaoSession().dbRead(this.getEptp().getTmp(),new Argument<String>("cid",this.getEpdgrp().getRec().getCid()),new Argument<String>("ptybch", this.getEpdgrp().getRec().getPtybch()),new Argument<String>("trncod", this.getEpdgrp().getRec().getTrncod()));
			      int err2=ctx.getErrorCode();
			      if(err2==NO_ERROR)
			      {
			        this.getEptp().getTmp().setOpndat(today);
			        ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			        log.debug("{}","**************重复***更新**********");
			      }
			      else
			      {
			        this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			        this.getEptp().getTmp().setTrnnam(this.getEptp().getAlllst().getElement(index).getTrnnam());
			        this.getEptp().getTmp().setTrncod(this.getEptp().getAlllst().getElement(index).getTrncod());
			        this.getEptp().getTmp().setCid(this.getEpdgrp().getRec().getCid());
			        this.getEptp().getTmp().setNam(this.getEpdgrp().getRec().getNam());
			        this.getEptp().getTmp().setTyp(this.getEpdgrp().getRec().getTyp());
			        this.getEptp().getTmp().setOpnflg(this.getEpdgrp().getRec().getOpnflg());
			        this.getEptp().getTmp().setPtybch(this.getEpdgrp().getRec().getPtybch());
			        this.getEptp().getTmp().setTrnopnflg("X");
			        this.getEptp().getTmp().setOpndat(today);
			        this.getEptp().getTmp().setClsdat(null);
			        ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			        log.debug("{}","**********重复****插入*************"+index);
			      }
			    }
			  }
			  if ("O".equals(flg))
			  {
			    if("X".equals(this.getEptp().getTrnopnflg()))
			    {
			      ctx.getDaoSession().dbRead(this.getEptp().getTmp(),new Argument<String>("cid",this.getEpdgrp().getRec().getCid()),new Argument<String>("ptybch", this.getEpdgrp().getRec().getPtybch()),new Argument<String>("trncod", this.getEpdgrp().getRec().getTrncod()));
			      int err2=ctx.getErrorCode();
			      if(err2==NO_ERROR)
			      {
			        this.getEptp().getTmp().setTrnopnflg("O");
			        this.getEptp().getTmp().setOpndat(null);
			        this.getEptp().getTmp().setClsdat(today);
			        ctx.getDaoSession().dbUpdate(this.getEptp().getTmp());
			        log.debug("{}","**************关闭更新*************"+index);
			      }
			      else
			      {
			        this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			        this.getEptp().getTmp().setTrnnam(this.getEptp().getAlllst().getElement(index).getTrnnam());
			        this.getEptp().getTmp().setTrncod(this.getEptp().getAlllst().getElement(index).getTrncod());
			        this.getEptp().getTmp().setCid(this.getEpdgrp().getRec().getCid());
			        this.getEptp().getTmp().setNam(this.getEpdgrp().getRec().getNam());
			        this.getEptp().getTmp().setTyp(this.getEpdgrp().getRec().getTyp());
			        this.getEptp().getTmp().setOpnflg(this.getEpdgrp().getRec().getOpnflg());
			        this.getEptp().getTmp().setPtybch(this.getEpdgrp().getRec().getPtybch());
			        this.getEptp().getTmp().setTrnopnflg("O");
			        this.getEptp().getTmp().setOpndat(null);
			        this.getEptp().getTmp().setClsdat(today);
			        ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			        log.debug("{}","**************关闭  更新  插入*************"+index);
			      }
			    }
			    else
			    {
			      if("O".equals(this.getEptp().getTrnopnflg()))
			      {
			        log.debug("{}","**************重复*************");
			        ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000030"),MdaUtils.getI18NString("dbmbep","CT000031"));
			        ctx.getDaoSession().dbRollback();
			        return;
			      }
			      else
			      {
			        this.getEptp().getTmp().setInr(Platform.sdbCounter("epc"));
			        this.getEptp().getTmp().setTrnopnflg("O");
			        this.getEptp().getTmp().setOpndat(null);
			        this.getEptp().getTmp().setClsdat(today);
			        ctx.getDaoSession().dbInsert(this.getEptp().getTmp());
			        log.debug("{}","**************关闭插入*************"+index);
			      }
			    }
			  }
			}
			ctx.getDaoSession().dbCommit();
			if ("X".equals(flg))
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000032"),MdaUtils.getI18NString("dbmbep","CT000033"));
			if("O".equals(flg))
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000034"),MdaUtils.getI18NString("dbmbep","CT000035"));
			MdaUtils.clear(this.getEptp().getAlllst());
			
			log.info("{}","**********************全部开通/关闭功能结束***********************");
		}
        /**
        *   source:dbmbep.@0013.script
        */
        public void getCustomerInfoByCidAndBchcod(String cid, String bchcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 根据Cid 和 机构号 预设新增修该客户信息内容
			
			MdaUtils.clear(this.getEpdgrp().getCli());
			MdaUtils.clear(this.getEpdgrp().getBnk());
			ctx.getDaoSession().dbRead(this.getEpdgrp().getBnk(),new Argument<String>("cid", bchcod),new Argument("ptytyp", "0"));
			ctx.getDaoSession().dbRead(this.getEpdgrp().getCli(),new Argument<String>("cid", cid),new Argument("ptytyp",IN ,new String[]{"1","2"}));
			// $epdgrp\\rec\\cid.setValue(cid);
			this.getEpdgrp().getRec().setNam(this.getEpdgrp().getCli().getNam());

			if("1".equals(this.getEpdgrp().getBnk().getEpable()))
			{
			  this.getEpdgrp().getRec().setOpnflg("X");
			}
			else
			{
			  this.getEpdgrp().getRec().setOpnflg("");
			}
			if("1".equals(this.getEpdgrp().getCli().getPtytyp()))
			{
			  this.getEpdgrp().getRec().setTyp("S");
			}
			else
			{
			  this.getEpdgrp().getRec().setTyp("Q");
			}
			MdaUtils.setValues(this.getEpdgrp().getCli(),"chkcls",getChkClsCodetables(this.getEpdgrp().getRec().getTyp()));
			
			
			
			

		}
        /**
        *   source:dbmbep.@0015.script
        */
        public String getCustomerBranchcodes(String cid)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 查询指定客户的所有签约机构信息
			String branchCodes ="";
			String con = "" ;
			log.debug("{}","in dbmbep.getCustomerBranchcodes: cid =" + cid );
			String sql = "SELECT DISTINCT BCH.CID cid , BCH.NAM nam FROM PTR PTR , PTY BCH , PTY CLI WHERE  PREPTYINR= CLI.INR AND BCH.INR = PTR.NXTPTYINR AND BCH.CID IS NOT NULL " ;
			sql = sql + " AND BCH.EPABLE = '1' AND PTR.PTRTYP IN ('0','1') AND CLI.CID = ? ";
			log.info("{}", "最后执行的query语句===========" + sql);
			ctx.getDaoSession().dbExecuteSQL(sql,cid);
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> bchcod = new Argument<String>("cid");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(nam,bchcod);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    branchCodes =   branchCodes + con + bchcod.value  ;
			    con = "," ;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			log.debug("{}","in dbmbep.getCustomerBranchcodes: branchCodes =" + branchCodes);
			return branchCodes ;
		}
        /**
        *   source:dbmbep.@0016.script
        */
        public void nextStep()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","***************下一步开始****************"+this.getEpdgrp().getRec().getOpnflg());
			if(MdaUtils.isEmpty(this.getEpdgrp().getRec().getCid()))
			{
			  ctx.setFieldError(this,"epdgrp.rec.cid",MdaUtils.getI18NString("dbmbep","CT000304"));
			}
			else
			{
			  usrsel();
			  
			  
			  int cnt=0;
			  MdaUtils.clear(this.getEptp().getAlllst());
			  Argument<Integer> chkcnt =new Argument<Integer>("chkcnt");
			  Argument<String> frm =new Argument<String>("frm");
			  Argument<String> trnnam =new Argument<String>("trnnam");
			  Argument<String> trncod =new Argument<String>("trncod");
			  Argument<String> trnopnflg =new Argument<String>("trnopnflg",this.getEpdgrp().getRec().getTrnopnflg());
			  String sql="SELECT nam trnnam,frm trncod FROM modlst where modtyp='0' ";
			  if("S".equals(this.getEpdgrp().getRec().getTyp()))
			    sql=sql+" and ptytyp='1' ";
			  else if("Q".equals(this.getEpdgrp().getRec().getTyp()))
			  {
			    sql=sql+" and ptytyp='2' ";
			  }
			  else
			  {
			    ctx.setFieldError(this,"epdgrp.rec.typ",MdaUtils.getI18NString("dbmbep","CT000305"));
			    return;
			  }
			  ctx.getDaoSession().dbExecuteSQL(sql);
			  int errCod =  ctx.getErrorCode() ;
			  log.info("{}","查询语句 ="+sql);
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(trnnam,trncod);
			    int errCod1 = ctx.getErrorCode();
			    if(errCod1==NO_ERROR)
			    {
			      if("X".equals(this.getEpdgrp().getRec().getTrnopnflg()))
			      {
			        this.getEptp().getAlllst().add(trnnam,trncod,trnopnflg);
			        log.info("{}","**************"+trnnam.value+" "+trncod.value+" "+trnopnflg.value+" "+cnt+"**************");
			      }
			      else
			      {
			        this.getEptp().getAlllst().add(trnnam,trncod);
			        log.info("{}","**************"+trnnam.value+" "+trncod.value+" "+trnopnflg.value+" "+cnt+"**************");
			      }
			      cnt++;
			    }
			    else
			      break;
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  

			  String repeat="";
			  String chksql="SELECT count(frm) chkcnt,frm FROM modlst where modtyp='0' ";
			  if("S".equals(this.getEpdgrp().getRec().getTyp()))
			    chksql=chksql+" and ptytyp='1' ";
			  else if("Q".equals(this.getEpdgrp().getRec().getTyp()))
			  {
			    chksql=chksql+" and ptytyp='2' ";
			  }
			  else
			  {
			    ctx.setFieldError(this,"epdgrp.rec.typ",MdaUtils.getI18NString("dbmbep","CT000306"));
			    return;
			  }
			  chksql=chksql+" group by frm having count(frm)>'1' ";
			  ctx.getDaoSession().dbExecuteSQL(chksql);
			  int chkCod =  ctx.getErrorCode() ;
			  log.info("{}","校验查询语句 ="+chksql);
			  int crt=0;
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(chkcnt,frm);
			    int fetCod =  ctx.getErrorCode() ;
			    log.info("{}","校验fetch语句 ="+fetCod);
			    if(fetCod==NO_ERROR)
			    {
			      crt++;
			      repeat=repeat+frm.value;
			      log.info("{}","frm-chkcnt="+frm.value+" "+chkcnt.value);
			    }
			    else
			      break;
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  if(crt>0)
			  {
			    ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000307"),MdaUtils.getI18NString("dbmbep","CT000308")+repeat+MdaUtils.getI18NString("dbmbep","CT000309"));
			    
			    
			  }
			  if(MdaUtils.isEmpty(this.getEpdgrp().getRec().getPtybch()))
			  {
			    ctx.setFieldError(this,"epdgrp.rec.ptybch",MdaUtils.getI18NString("dbmbep","CT000310"));
			    return;
			  }
			  if("X".equals(this.getEpdgrp().getRec().getOpnflg()))
			  {
			    
			    
			  }
			  else
			    ctx.setFieldError(this,"epdgrp.rec.opnflg",MdaUtils.getI18NString("dbmbep","CT000311"));
			}
			log.info("{}","***************下一步结束****************");

		}
        /**
        *   source:dbmbep.@0019.script
        */
        public void getCustomerWithBranch()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 根据条件输出客户信息及机构信息
			// 客户编号|客户名称|客户类型|所属业务机构号|机构可否办理电子交单业务|是否开通电子交单|客户属性|开通时间|关闭时间
			// SELECT distinct cid,nam,typ,ptybch,opnflg,opndat,clsdat FROM epc
			MdaUtils.clear(this.getEptp().getEpclst());

			String sql = "SELECT DISTINCT CLI.CID cid ,CLI.NAM nam, CLI.PTYTYP typ ,BCH.CID ptybch,BCH.EPABLE bchepable,CLI.EPABLE cliepable,CLI.chkcls chkcls,CLI.epodat opndat, CLI.epcdat clsdat " ;
			sql = sql + " FROM PTR PTR , PTY BCH , PTY CLI WHERE  PREPTYINR= CLI.INR AND BCH.INR = PTR.NXTPTYINR AND BCH.CID IS NOT NULL " ;
			sql = sql + " AND BCH.EPABLE = '1' AND PTR.PTRTYP IN ('0','1') " ;

			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  String lev = this.getSysmod().getPty().getBrhlvl();
			  if("0".equals(lev))
			  {
			    // 查询全行
			  }
			  else if("1".equals(lev))
			  {
			    // 分行
			    String cidArg = this.getSysmod().getPty().getCid();
			    // sql = sql + " AND SUBSTR(BCH.CID,1,2)='" + $sysmod\\pty\\cid.getValue().substring(0,2) + "'" ;
			    sql = sql + "AND( BCH.pntinr='"+cidArg+"' or BCH.CID='"+cidArg+"')";
			  }
			  else
			  {
			    // 支行
			    sql = sql + " AND BCH.CID = '"+this.getSysmod().getPty().getCid()+"' " ;
			  }
			  /*
			    if("1".equals(lev))
			    {
			    // 查询全行
			    }
			    else if("2".equals(lev))
			    {
			    // 分行
			    String cidArg = $sysmod\\pty\\cid.getValue();
			    sql = sql + " AND SUBSTR(BCH.CID,1,2)='" + $sysmod\\pty\\cid.getValue().substring(0,2) + "'" ;
			    }
			    else if("3".equals(lev) || "4".equals(lev))
			    {
			    // 支行
			    sql = sql + " AND BCH.CID = '"+$sysmod\\pty\\cid.getValue()+"' " ;
			    }
			    */
			}
			if(!MdaUtils.isEmpty(this.getEptp().getCid()))
			{
			  sql=sql+" AND CLI.CID LIKE  '%" + this.getEptp().getCid() + "%' ";
			  //sql = sql + " AND CLI.CID = '"+$eptp\\cid.getValue() +"'";
			}

			if(!MdaUtils.isEmpty(this.getEptp().getClsflg()))
			{
			  sql = sql + " AND CLI.epcdat is not null " ;
			}

			log.debug("{}","in getCustomerWithBranch: sql= " + sql );

			Argument<String> cid =new Argument<String>("cid");  // 客户编号
			Argument<String> nam =new Argument<String>("nam");  // 客户名称
			Argument<String> typ =new Argument<String>("typ");	// 客户类型
			Argument<String> ptybch =new Argument<String>("ptybch");	//归属机构
			Argument<String> bchepable =new Argument<String>("bchepable");	//机构可否办理电子交单
			Argument<String> cliepable =new Argument<String>("cliepable");  // 客户可否开通电子交单
			Argument<String> chkcls =new Argument<String>("chkcls"); //客户属性
			Argument<Date> clsdat =new Argument<Date>("clsdat");  // 开通时间
			Argument<Date> opndat =new Argument<Date>("opndat");	// 关闭时间
			
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cid,nam,typ,ptybch,bchepable,cliepable,chkcls,opndat,clsdat);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    if("1".equals(bchepable.value))
			    {
			      bchepable.value="√";
			    }
			    else
			    {
			      bchepable.value="×";
			    }
			    if("1".equals(cliepable.value))
			    {
			      cliepable.value="√";
			    }
			    else
			    {
			      cliepable.value="×";
			    }
			    String level = MdaUtils.getCodetableLabel("ptylvl",chkcls.value);
			    chkcls.value = level;
			    log.debug("{}","level =" + level ) ;
			    this.getEptp().getEpclst().add(cid,nam,typ,ptybch,bchepable,cliepable,chkcls,opndat,clsdat);
			    cnt++;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			if(cnt==0 && !MdaUtils.isEmpty(this.getEptp().getCid()))
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000346"),MdaUtils.getI18NString("dbmbep","CT000347"));

		}
        /**
        *   source:dbmbep.@0020.script
        */
        public List<CodetableItem> getChkClsCodetables(String type)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in getChkClsCodetables ... typ =" + type ) ;
			List<CodetableItem> items =  new ArrayList<CodetableItem>();
			if("S".equals(type))
			{
			  items.add(new CodetableItem("A","1"));
			  items.add(new CodetableItem("B+","2"));
			  items.add(new CodetableItem("B","3"));
			  items.add(new CodetableItem("B-","4"));
			  items.add(new CodetableItem("C","5"));
			}
			else
			  if("Q".equals(type))
			{
			  items.add(new CodetableItem("A","A"));
			  items.add(new CodetableItem("B","B"));
			  items.add(new CodetableItem("C","C"));
			  items.add(new CodetableItem("FT","D"));
			  items.add(new CodetableItem("NRA","E"));
			}
			return items;
		}
        /**
        *   source:dbmbep.@0022.script
        */
        public void frush()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 根据条件输出客户信息及机构信息
			// 客户编号|客户名称|客户类型|所属业务机构号|机构可否办理电子交单业务|是否开通电子交单|客户属性|开通时间|关闭时间
			MdaUtils.clear(this.getEptp().getEpclst());

			String sql = "SELECT DISTINCT CLI.CID cid ,CLI.NAM nam, CLI.PTYTYP typ ,BCH.CID ptybch,BCH.EPABLE bchepable,CLI.EPABLE cliepable,CLI.chkcls chkcls,CLI.epodat opndat, CLI.epcdat clsdat " ;
			sql = sql + " FROM PTR PTR , PTY BCH , PTY CLI WHERE  PREPTYINR= CLI.INR AND BCH.INR = PTR.NXTPTYINR AND BCH.CID IS NOT NULL " ;
			sql = sql + " AND BCH.EPABLE = '1' AND PTR.PTRTYP IN ('0','1') " ;

			String ptyinrs="";
			String cids="";
			String lvls="";
			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  if(!MdaUtils.isEmpty(this.getEptp().getPtynam()))
			    ptyinrs=this.getEptp().getPtynam();
			  else
			    ptyinrs=this.getSysmod().getPty().getInr();
			  cids=this.getSysmod().getCidByInr(ptyinrs);
			  lvls=this.getSysmod().getTransLevel(cids);

			  if("0".equals(lvls))
			  {
			    // 查询全行
			    sql=sql+" and BCH.ptytyp='0'";
			  }
			  else if("1".equals(lvls))
			  {
			    // 分行
			    sql = sql + "AND BCH.ptytyp='0' and ( BCH.pntinr='"+cids+"' or BCH.CID='"+cids+"')";
			  }
			  else
			  {
			    // 支行
			    sql = sql + " AND BCH.CID = '"+cids+"' " ;
			  }
			}
			if(!MdaUtils.isEmpty(this.getEptp().getCid()))
			{
			  sql=sql+" AND CLI.CID LIKE  '%" + this.getEptp().getCid() + "%' ";
			}

			if(!MdaUtils.isEmpty(this.getEptp().getClsflg()))
			{
			  sql = sql + " AND CLI.epcdat is not null " ;
			}

			log.debug("{}","in getCustomerWithBranch: sql= " + sql );

			Argument<String> cid =new Argument<String>("cid");  // 客户编号
			Argument<String> nam =new Argument<String>("nam");  // 客户名称
			Argument<String> typ =new Argument<String>("typ");	// 客户类型
			Argument<String> ptybch =new Argument<String>("ptybch");	//归属机构
			Argument<String> bchepable =new Argument<String>("bchepable");	//机构可否办理电子交单
			Argument<String> cliepable =new Argument<String>("cliepable");  // 客户可否开通电子交单
			Argument<String> chkcls =new Argument<String>("chkcls"); //客户属性
			Argument<Date> clsdat =new Argument<Date>("clsdat");  // 开通时间
			Argument<Date> opndat =new Argument<Date>("opndat");	// 关闭时间
			
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cid,nam,typ,ptybch,bchepable,cliepable,chkcls,opndat,clsdat);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    if("1".equals(bchepable.value))
			    {
			      bchepable.value="√";
			    }
			    else
			    {
			      bchepable.value="×";
			    }
			    if("1".equals(cliepable.value))
			    {
			      cliepable.value="√";
			    }
			    else
			    {
			      cliepable.value="×";
			    }
			    String level = MdaUtils.getCodetableLabel("ptylvl",chkcls.value);
			    chkcls.value = level;
			    log.debug("{}","level =" + level ) ;
			    this.getEptp().getEpclst().add(cid,nam,typ,ptybch,bchepable,cliepable,chkcls,opndat,clsdat);
			    cnt++;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			if(cnt==0 && !MdaUtils.isEmpty(this.getEptp().getCid()))
			  ctx.setMessage(MdaUtils.getI18NString("dbmbep","CT000350"),MdaUtils.getI18NString("dbmbep","CT000351"));

		}





}