package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbmmsgVO;

import com.ceb.gjjs.mda.manager.module.Mstp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 银行端短信与邮件监控
*/
@Transaction(vo= DbmmsgVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbmmsg extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbmmsg.class);

		@BDGetter
		private Mstp mstp;

		@BDGetter
		private Sysmod sysmod;


		public Dbmmsg()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:dbmmsg.@0001.script
        */
        @Rule(target="mstp.search",order=100)
        public boolean ruleMstpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			query();

			return true;
        }

        /**
        *   source:dbmmsg.@0002.script
        */
        @Rule(target="mstp.download",order=100)
        public boolean ruleMstpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[10];
			tit[0] = "核心客户号";
			tit[1] = "客户名称";
			tit[2] = "所属机构号";
			tit[3] = "机构名称";
			tit[4] = "交易代码";
			tit[5] = "交易名称";
			tit[6] = "是否短信订阅";
			tit[7] = "对应手机号";
			tit[8] = "是否邮件订阅";
			tit[9] = "对应邮箱地址";
			lst.add(tit);
			int len = this.getMstp().getTemplst().fullSize();
			log.debug("{}","len=========="+len);
			for(int i=0;i<len;i++)
			{
			  log.debug("{}","***********  "+i+"  ***********");
			  String[] line = new String[10];
			  line[0] = this.getMstp().getTemplst().getElement(i).getUsrcid();
			  line[1] = this.getMstp().getTemplst().getElement(i).getUsrnam();
			  line[2] = this.getMstp().getTemplst().getElement(i).getCid();
			  line[3] =this.getMstp().getTemplst().getElement(i).getNam();
			  line[4] =this.getMstp().getTemplst().getElement(i).getFrmcod();
			  line[5] =this.getMstp().getTemplst().getElement(i).getFrmnam();
			  if("X".equals(this.getMstp().getTemplst().getElement(i).getMsgflg()))
			    line[6] ="订阅";
			  else
			    line[6] ="不订阅";
			  line[7] =this.getMstp().getTemplst().getElement(i).getMobile();
			  if("X".equals(this.getMstp().getTemplst().getElement(i).getEmlflg()))
			    line[8] ="订阅";
			  else
			    line[8] ="不订阅";
			  line[9] =this.getMstp().getTemplst().getElement(i).getEml();
			  lst.add(line);
			}
			log.debug("{}","lst "+lst.size());
			IStream is=this.getMstp().getDownload();
			is.setType("xls");
			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH:mm:ss");
			String fileName = "短信与邮件监控"+today+".xls";
			is.setName(fileName);
			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }



        /**
        *   source:dbmmsg.@0003.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			List<CodetableItem> bchtyp = new ArrayList<CodetableItem>();
			bchtyp.add(new CodetableItem("全行","1"));
			bchtyp.add(new CodetableItem("分行","2"));
			bchtyp.add(new CodetableItem("支行","3"));
			MdaUtils.setValues(this.getMstp(),"bchtyp",bchtyp);
			this.getMstp().setBchtyp("1");
			

			return true;
        }


        /**
        *   source:dbmmsg.@0000.script
        */
        public void query()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","*************初始界面查询******************");
			MdaUtils.clear(this.getMstp().getTemplst());
			Argument<String> usrcid =new Argument<String>("usrcid");
			Argument<String> usrnam =new Argument<String>("usrnam");
			Argument<String> cid =new Argument<String>("cid");
			Argument<String> nam =new Argument<String>("nam");
			Argument<String> frmcod =new Argument<String>("frmcod");
			Argument<String> frmnam =new Argument<String>("frmnam");
			Argument<String> mobile =new Argument<String>("mobile");
			Argument<String> msgflg =new Argument<String>("msgflg");
			Argument<String> eml =new Argument<String>("eml");
			Argument<String> emlflg =new Argument<String>("emlflg");
			String sql="select distinct prepty.cid usrcid,prepty.nam usrnam,nxtpty.cid cid,nxtpty.nam nam,msg.frm frmcod,msg.nam frmnam,msg.msgflg msgflg,msg.mobile mobile,msg.emlflg emlflg,msg.eml eml from pty nxtpty,pty prepty,ptr,msg where ptr.nxtptyinr=nxtpty.inr and prepty.inr = ptr.preptyinr and ptr.ptrtyp in ('0','1') and msg.ptyinr=prepty.inr and prepty.ptytyp in ('1','2') ";
			String bchcod=this.getMstp().getBrhnam();
			if(!MdaUtils.isEmpty(this.getMstp().getBrhnam()))
			  sql=sql+" and (nxtpty.cid like'%"+bchcod+"%' OR nxtpty.nam like '%"+bchcod+"%' ) ";
			if(!MdaUtils.isEmpty(this.getMstp().getCid()))
			  sql=sql+" and prepty.cid = '"+this.getMstp().getCid()+"' ";
			if(!MdaUtils.isEmpty(this.getMstp().getBchtyp()))
			{
			  if(!"1".equals(this.getMstp().getBchtyp()))
			    sql=sql+" and nxtpty.lvl = '"+this.getMstp().getBchtyp()+"'";
			}
			if("1".equals(this.getSysmod().getPty().getBrhlvl()))
			  log.info("{}","read all clientPty:" );
			else if("2".equals(this.getSysmod().getPty().getBrhlvl()))
			{
			  sql=sql+" and substr(nxtpty.cid,1,2) = '"+this.getSysmod().getPty().getCid().substring(0,2)+"' ";
			  log.info("{}","read 分行 clientPty:");
			}
			else if("3".equals(this.getSysmod().getPty().getBrhlvl()) ||  "4".equals(this.getSysmod().getPty().getBrhlvl()) )
			{
			  sql=sql+" and nxtpty.inr='"+this.getSysmod().getPty().getInr()+"' ";
			  log.info("{}","read  clientPty:");
			}
			ctx.getDaoSession().dbExecuteSQL(sql);
			int errCod =  ctx.getErrorCode() ;
			log.info("{}","查询语句 ="+sql);
			int cnt=0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(usrcid,usrnam,cid,nam,frmcod,frmnam,msgflg,mobile,emlflg,eml);
			  int errCod1 = ctx.getErrorCode();
			  if(errCod1==NO_ERROR)
			  {
			    this.getMstp().getTemplst().add(usrcid,usrnam,cid,nam,frmcod,frmnam,msgflg,mobile,emlflg,eml);
			    cnt++;
			  }
			  else
			    break;
			}
			if(cnt==0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmmsg","CT000000"),MdaUtils.getI18NString("dbmmsg","CT000001"));
			}
			ctx.getDaoSession().dbCloseCursor();
			
			log.info("{}","*************初始界面查询结束******************");
		}



}