package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbmoprVO;

import com.ceb.gjjs.mda.manager.module.Oprmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Oprgrp;
import com.ceb.gjjs.mda.manager.module.Oprp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 企业操作员权限配置
*/
@Transaction(vo= DbmoprVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbmopr extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbmopr.class);

		@BDGetter
		private Oprgrp oprgrp;

		@BDGetter
		private Oprmod oprmod;

		@BDGetter
		private Oprp oprp;

		@BDGetter
		private Sysmod sysmod;


		public Dbmopr()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getOprmod().setOprgrpHolder(()->this.getOprgrp());
           this.getOprp().setOprgrpHolder(()->this.getOprgrp());
        }

        /**
        *   source:dbmopr.@0001.script
        */
        @Rule(target="oprp.sel",order=100)
        public boolean ruleOprpSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getOprgrp().getUsrlst().fullSize();
			if(length == 0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000004"),MdaUtils.getI18NString("dbmopr","CT000005"));
			  return true;
			}
			if( index < 0   ||   index >= length )
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000006"),MdaUtils.getI18NString("dbmopr","CT000007"));
			  return true;
			}
			//$oprgrp\\usr.copyValue($oprgrp\\usrlst[index]);
			MdaUtils.clear(this.getOprgrp().getUsr());
			ctx.getDaoSession().dbRead(this.getOprgrp().getUsr(),new Argument<String>("inr",this.getOprgrp().getUsrlst().getElement(index).getInr()));
			ctx.storeData("com.brilliance.dbmopr0.usr",this.getOprgrp().getUsr());
			

			return true;
        }

        /**
        *   source:dbmopr.@0005.script
        */
        @Rule(target="oprp.getuser",order=100)
        public boolean ruleOprpGetuserN100(){
            IContext ctx = MdaEnv.getContext();
            
			savORUPdateUserList();
			ctx.getDaoSession().dbReadset(this.getOprgrp().getUsrlst(),new Argument<String>("ptyinr",this.getSysmod().getPty().getInr()),new Argument<String>("usrflg","0"),new Argument<String>("otype","2"));
			

			return true;
        }

        /**
        *   source:dbmopr.@0006.script
        */
        @Rule(target="oprp.search",order=100)
        public boolean ruleOprpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getOprp().getUsrnam()))
			{
			  //Platform.dbReadset($oprgrp\\usrlst,new Argument<String>("ptyinr",$sysmod\\pty\\inr.getValue()),new Argument<String>("usrflg","0"),new Argument<String>("otype","2"));
			  ctx.getDaoSession().dbReadset(this.getOprgrp().getUsrlst(),new CacheOption(0, true),new Argument<String>("ptyinr",this.getSysmod().getPty().getInr()));
			  
			}
			else
			{
			  //Platform.dbReadset($oprgrp\\usrlst,new Argument<String>("ptyinr",$sysmod\\pty\\inr.getValue()),new Argument<String>("usrflg","0"),new Argument<String>("otype","2"),new Argument<String>("lgnnam",$oprp\\usrnam.getValue()));
			  //String sql = "where lgnnam like '%" + $oprp\\usrnam.getValue() + "%' and ptyinr = '" + $sysmod\\pty\\inr.getValue() + "' and usrflg = '0'" ;
			
			  /*
			    List argVal = new ArrayList();
			    argVal.add("'%" + $oprp\\usrnam.getValue() + "%'");
			    String sql = "where lgnnam like ? and ptyinr = '" + $sysmod\\pty\\inr.getValue() + "' and usrflg = '0'";
			    Platform.dbReadset($oprgrp\\usrlst,0,sql,argVal.toArray());
			    Platform.setModified($oprgrp\\usrlst);
			    */

			  MdaUtils.clear(this.getOprgrp().getUsrlst());
			  String sql = "SELECT u.inr inr,u.lgnnam lgnnam,u.oprnam oprnam,u.usrflg usrflg "
			    +"FROM usr u where lgnnam like '%" + this.getOprp().getUsrnam().trim() + "%'  and ptyinr = '" + this.getSysmod().getPty().getInr()+"'";
			  ctx.getDaoSession().dbExecuteSQL(sql);
			  Argument<String> inr = new Argument<String>("inr");
			  Argument<String> lgnnam = new Argument<String>("lgnnam");
			  Argument<String> oprnam = new Argument<String>("oprnam");
			  Argument<String> usrflg = new Argument<String>("usrflg");

			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(inr,lgnnam,oprnam,usrflg);
			    int errorCode = ctx.getErrorCode();
			    if(errorCode == NO_ERROR)
			    {
			      this.getOprgrp().getUsrlst().add(inr,lgnnam,oprnam,usrflg);
			    }
			    else if(errorCode == NO_MORE_ROW)
			    {
			      log.info("{}","no more row!!");
			      break;
			    }
			    else
			    {
			      log.error("{}","errorCode"+errorCode+":操作员信息查询出错！");
			      break;
			    }
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  

			}

			return true;
        }



        /**
        *   source:dbmopr.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.message(#CT000118,#CT000119);
			log.debug("{}","ptyytp:"+ this.getSysmod().getPty().getPtytyp());
			/*if("0".equals($sysmod\\pty\\ptytyp.getValue()))
			  {
			  Platform.visible($oprp\\getuser);
			  }
			  else */
			if(!"3".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  
			  log.debug("{}","当前用户的类型otype:" + this.getSysmod().getUsr().getOtype());
			  if(!"0".equals(this.getSysmod().getUsr().getOtype()))
			  {
			    ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000120"),MdaUtils.getI18NString("dbmopr","CT000121"));
			    
			  }
			}
			else
			{
			  
			}
			//读取当前登录管理员所属机构的全部下辖操作员
			//Platform.dbReadset($oprgrp\\usrlst,new Argument<String>("ptyinr",$sysmod\\pty\\inr.getValue()),new Argument<String>("usrflg","0"),new Argument<String>("otype","2"));
			//Platform.dbReadset($oprgrp\\usrlst,new Argument<String>("ptyinr",$sysmod\\pty\\inr.getValue()),new Argument<String>("otype","2"));
			
			return true;
        }

        /**
        *   source:dbmopr.@0002.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.dbReadset($oprgrp\\usrlst,new Argument<String>("ptyinr",$sysmod\\pty\\inr.getValue()),new Argument<String>("usrflg","0"),new Argument<String>("otype","2"));
			ctx.getDaoSession().dbReadset(this.getOprgrp().getUsrlst(),new Argument<String>("ptyinr",this.getSysmod().getPty().getInr()));
			

			return true;
        }


        /**
        *   source:dbmopr.@0003.script
        */
        public void savORUPdateUserList()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","开始同步操作员....,NCID["+this.getSysmod().getUsr().getNcid()+"]");
			//ArrayList<HashMap> list = (ArrayList<HashMap>)Platform.getLoginData("usrList");
			ICallback callback = new ICallback() {
				@Override
				public Object invoke(Object... paramVarArgs) {
					getLoginData(paramVarArgs);
					return null;
				}
			};
			String cls  = "com.brilliance.eibs.main.Client";
			String vv0a12 = "";
			String vv0a04 = this.getSysmod().getPty().getCid();
			String vv0a03 = this.getSysmod().getPty().getNam();
			//int  vv0a12 = 5;
			String qishbs = "0";
			String cxunbs = "99";
			Map retMsg = new HashMap() ;
			try
			{
			  Object obj = MdaUtils.invoke(cls,"scall","WY_5082","WY_5082",new Object[]{callback,vv0a04,vv0a03,vv0a12,qishbs,cxunbs});
			}
			catch(Exception e)
			{
			  ctx.getErrorCode();
			  log.error("{}","errormsg:" + e.getMessage());
			  Platform.setErrorInfo(retMsg,"11005","接口平台调用异常");
			}
			/*if(list == null   ||   list.size() == 0)
			  {
			  log.error("没有从企业网银找到操作员信息！");
			  return;
			  }
			  log.info("从企业网银获取的操作员个数为:"+list.size());
			  Platform.dbBegin();
			  int count = 0;
			  for(HashMap user:list)
			  {
			  log.info("开始同步操作员[oid="+user.get("Id").toString()+"],[登录名:"+user.get("LoginName").toString()+"]");
			  Platform.clear($oprgrp\\usr);
			  Platform.dbRead($oprgrp\\usr,new Argument<String>("oid",user.get("Id").toString())
			  ,new Argument<String>("ncid",$sysmod\\usr\\ncid.getValue()));
			  if(user.get("Id")!=null)
			  $oprgrp\\usr\\oid.setValue(user.get("Id").toString());
			  if(user.get("Ncid")!=null)
			  {
			  $oprgrp\\usr\\ncid.setValue(user.get("Ncid").toString());
			  $oprgrp\\usr\\cid.setValue(user.get("Ncid").toString());
			  }
			  log.debug("ncid,cid="+$oprgrp\\usr\\ncid);
			  if(user.get("Name")!=null)
			  $oprgrp\\usr\\oprnam.setValue(user.get("Name").toString());
			  log.debug("oprnam="+$oprgrp\\usr\\oprnam);
			  if(user.get("LoginName")!=null)
			  $oprgrp\\usr\\lgnnam.setValue(user.get("LoginName").toString());
			  log.debug("lgnnam="+$oprgrp\\usr\\lgnnam);
			  if(user.get("Type")!=null)
			  $oprgrp\\usr\\otype.setValue(String.valueOf(user.get("Type")));
			  log.debug("otype="+$oprgrp\\usr\\otype);
			  if(user.get("DepartMent")!=null)
			  $oprgrp\\usr\\depnam.setValue(user.get("DepartMent").toString());
			  log.debug("depnam="+$oprgrp\\usr\\depnam);
			  Date createDate = null;
			  if(user.get("CreateDate")!=null)
			  createDate = (Date)user.get("CreateDate");
			  if(user.get("Email")!=null)
			  $oprgrp\\usr\\eml.setValue(user.get("Email").toString());
			  log.debug("eml="+$oprgrp\\usr\\eml);
			  Date updateTime=null;
			  if(user.get("UpdateTime")!=null)
			  updateTime = (Date)user.get("UpdateTime");
			  if(user.get("Status")!=null)
			  $oprgrp\\usr\\usrflg.setValue(String.valueOf(user.get("Status")));
			  log.debug("usrflg="+$oprgrp\\usr\\usrflg);
			  if(user.get("Tel")!=null)
			  $oprgrp\\usr\\tel.setValue(user.get("Tel").toString());
			  log.debug("tel="+$oprgrp\\usr\\tel);
			  if(!Platform.isEmpty($oprgrp\\usr\\inr))
			  {
			  log.info("此操作员信息已经存在，开始更新操作！");
			  //DATE1在DATE2之前
			  if(Platform.isEmpty($oprgrp\\usr\\updtim)  ||  (!Platform.isEmpty(updateTime) && Platform.diff($oprgrp\\usr\\updtim.getValue(),updateTime)<0))
			  {
			  //return not null value
			  $oprgrp\\usr\\updtim.setValue(updateTime);
			  log.debug("Update USR inr = "+$oprgrp\\usr\\inr+"\\t"+count);
			  log.info("操作员信息有变化，进行更新！");
			  Platform.dbUpdate($oprgrp\\usr);
			  }
			  else
			  {
			  log.info("操作员信息无变化，不执行更新！");
			  }
			  }
			  else
			  {
			  log.info("操作员信息在本地不存在，开始进行insert");
			  $oprgrp\\usr\\ptyinr.setValue($sysmod\\pty\\inr.getValue());
			  $oprgrp\\usr\\ptynam.setValue($sysmod\\pty\\nam.getValue());
			  $oprgrp\\usr\\inr.setValue(Platform.sdbCounter("usr"));
			  $oprgrp\\usr\\updtim.setValue(updateTime);
			  log.info("新增操作员inr="+$oprgrp\\usr\\inr);
			  Platform.dbInsert($oprgrp\\usr);
			  if("2".equals($oprgrp\\usr\\otype.getValue()))
			  {
			  savUsraut("trsque");
			  savUsraut("xpthis");
			  }
			  }
			  count++;
			  if(count%50 == 0)
			  {
			  Platform.dbCommit();
			  Platform.dbBegin();
			  }
			  }
			  log.debug("新增或更新的操作员数目：" + count);
			  Platform.dbCommit();*/
		}
        /**
        *   source:dbmopr.@0004.script
        */
        public void savUsraut(String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","Usr "+this.getOprgrp().getUsr().getInr()+" frm = "+frm);
			MdaUtils.clear(this.getOprgrp().getUsraut());
			ctx.getDaoSession().dbRead(this.getOprgrp().getUsraut(),new Argument<String>("objinr",this.getOprgrp().getUsr().getInr()),new Argument<String>("objtyp","usr"),new Argument<String>("frm",frm));
			if(MdaUtils.isEmpty(this.getOprgrp().getUsraut().getInr())&&"2".equals(this.getOprgrp().getUsr().getOtype()))
			{
			  this.getOprgrp().getUsraut().setInr(Platform.sdbCounter("usraut"));
			  this.getOprgrp().getUsraut().setObjinr(this.getOprgrp().getUsr().getInr());
			  this.getOprgrp().getUsraut().setObjtyp("usr");
			  this.getOprgrp().getUsraut().setPtyinr(this.getOprgrp().getUsr().getPtyinr());
			  this.getOprgrp().getUsraut().setFlg1("0");
			  this.getOprgrp().getUsraut().setFlg2("0");
			  this.getOprgrp().getUsraut().setFrm(frm);
			  this.getOprgrp().getUsraut().setCur("USD");
			  this.getOprgrp().getUsraut().setLvl("5");
			  this.getOprgrp().getUsraut().setAmt(new BigDecimal("0"));
			  ctx.getDaoSession().dbInsert(this.getOprgrp().getUsraut());
			  log.debug("{}","Insert Usraut "+this.getOprgrp().getUsraut().getInr());
			}
		}
        /**
        *   source:dbmopr.@0007.script
        */
        public synchronized Object getLoginData(Object... obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  同步企业网银操作员
			  obj[0]:接口查询成功为查询到的条数，查询失败会返回-1
			  obj[1]:查询成功则是用户数据List<Map>，失败则是失败描述信息String
			  1.判断接口返回成功失败
			  2.成功则先进行销户操作
			  3.再进行用户的新增和更新
			  */
			log.debug("{}","in getLoginData...");
			//Map<String,Object> response = new HashMap<String,Object>();
			//返回的错误判断标志cnt
			Integer cnta = (Integer)obj[0];
			int cnt = cnta.intValue();
			int upd = 0;//更新条数
			int que = 0;//新增条数
			int det = 0;//销户条数
			if(cnt < 0)
			{
			  String errorCode = (String)obj[1];
			  log.debug("{}","errodCode:" + errorCode);
			  ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000288"),MdaUtils.getI18NString("dbmopr","CT000289"));
			  return null;
			}
			else
			{
			  List<Map> list = (List<Map>)obj[1];
			  if(cnt==0||list.size()==0)
			  {
			    log.error("{}","没有从企业网银找到操作员信息！");
			    ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000290"),MdaUtils.getI18NString("dbmopr","CT000291"));
			    return null;
			  }
			  log.info("{}","从企业网银获取的操作员个数为:"+list.size());
			  //String cid = $sysmod\\pty\\cid.getValue();
			  //String cid = "2008061107";
			  String cid = this.getSysmod().getPty().getCid();
			  log.debug("{}","pty.cid:" + cid);
			  //将此客户号下的：在库中的，不在网银用户列表中的用户销户
			  String sql = "update usr set usrflg = '1' where lgnnam = ? and cid = ?";
			  if(!MdaUtils.isEmpty(cid))
			  {
			    ctx.getDaoSession().dbReadset(this.getOprgrp().getUsrlst(),new Argument("cid",cid));
			    int index = this.getOprgrp().getUsrlst().size();
			    for(int i = 0;i < index; i++ )
			    {
			      boolean isExists = false;
			      String lgnnam = this.getOprgrp().getUsrlst().getElement(i).getLgnnam();
			      String usrflg = this.getOprgrp().getUsrlst().getElement(i).getUsrflg();
			      log.debug("{}","库中的用户：" + lgnnam);
			      for(int j = 0;j < list.size();j++)
			      {
			        String lstlgnam =(String)list.get(j).get("VV0A12");
			        log.debug("{}","网银同步的用户："+ lstlgnam);
			        if(!MdaUtils.isEmpty(lgnnam))
			        {
			          if(lgnnam.equals(lstlgnam))
			          {
			            isExists = true;
			            break;
			          }
			        }
			      }
			      //需要销户且没被销户的用户
			      if(!isExists&&"0".equals(usrflg))
			      {
			        ctx.getDaoSession().dbExecuteSQL(sql,lgnnam,cid);
			        ctx.getDaoSession().dbCloseCursor();
			        if(ctx.getErrorCode() ==NO_ERROR)
			        {
			          det = det + 1;
			          log.debug("{}","已经将 "+lgnnam+" 销户");
			        }
			        else
			          log.debug("{}",lgnnam+":销户失败");
			      }
			    }
			  }
			  ctx.getDaoSession().dbBegin();
			  int count = 0;
			  for(Map user:list)
			  {
			    log.info("{}","开始同步操作员[姓名="+user.get("VV0A11").toString()+"],[登录名:"+user.get("VV0A12").toString()+"]");
			    MdaUtils.clear(this.getOprgrp().getUsr());
			    //Platform.dbRead($oprgrp\\usr,new Argument<String>("lgnnam",user.get("VV0A12").toString()));
			    //原获取这条用户信息的条件没有限制客户号，会导致其它客户在同步
			    //操作员的时候会把其它客户号下同名的操作员更新，并且不会插入本客户号下的操作员，导致新增操作员无法登录。
			    ctx.getDaoSession().dbRead(this.getOprgrp().getUsr(),new Argument<String>("lgnnam",user.get("VV0A12").toString()),new Argument<String>("cid",cid));
			    //企业核心编号/网银编号
			    if(!MdaUtils.isEmpty(cid))
			    {
			      this.getOprgrp().getUsr().setCid(cid);
			      this.getOprgrp().getUsr().setNcid(cid);
			    }
			    log.debug("{}","cid="+this.getOprgrp().getUsr().getCid());
			    //操作员名称
			    if(user.get("VV0A11")!=null)
			      this.getOprgrp().getUsr().setOprnam(user.get("VV0A11").toString());
			    log.debug("{}","oprnam="+this.getOprgrp().getUsr().getOprnam());
			    //用户状态
			    this.getOprgrp().getUsr().setUsrflg("0");
			    log.debug("{}","oprnam="+this.getOprgrp().getUsr().getUsrflg());
			    //登录名
			    if(user.get("VV0A12")!=null)
			    {
			      this.getOprgrp().getUsr().setLgnnam(user.get("VV0A12").toString());
			      //操作员编号
			      this.getOprgrp().getUsr().setOid(user.get("VV0A12").toString());
			    }
			    log.debug("{}","lgnnam="+this.getOprgrp().getUsr().getLgnnam());
			    //用户类型
			    if(user.get("VV0G03")!=null)
			    {
			      String otype = String.valueOf(user.get("VV0G03"));
			      if("1".equals(otype))
			        this.getOprgrp().getUsr().setOtype("0");
			      else
			        this.getOprgrp().getUsr().setOtype("2");
			    }
			    else
			    {
			      this.getOprgrp().getUsr().setOtype("2");
			    }
			    log.debug("{}","otype="+this.getOprgrp().getUsr().getOtype());
			    //证书序号
			    if(user.get("VV0G11")!=null)
			      this.getOprgrp().getUsr().setSer(user.get("VV0G11").toString());
			    log.debug("{}","ser:"+this.getOprgrp().getUsr().getSer());
			    //部门
			    if(user.get("VV0G06")!=null)
			      this.getOprgrp().getUsr().setDepnam(user.get("VV0G06").toString());
			    log.debug("{}","depnam="+this.getOprgrp().getUsr().getDepnam());
			    //电子邮件
			    if(user.get("VV0A10")!=null)
			      this.getOprgrp().getUsr().setEml(user.get("VV0A10").toString());
			    log.debug("{}","eml="+this.getOprgrp().getUsr().getEml());
			    //电话
			    if(user.get("VV0G10")!=null)
			      this.getOprgrp().getUsr().setTel(user.get("VV0G10").toString());
			    log.debug("{}","tel="+this.getOprgrp().getUsr().getTel());
			    //企业编号
			    this.getOprgrp().getUsr().setPtyinr(this.getSysmod().getPty().getInr());
			    //企业名称
			    this.getOprgrp().getUsr().setPtynam(this.getSysmod().getPty().getNam());
			    //当天日期
			    Date updateTime = MdaUtils.today();
			    if(!MdaUtils.isEmpty(this.getOprgrp().getUsr().getInr()))
			    {
			      log.info("{}","此操作员信息已经存在，开始更新操作！");
			      //DATE1在DATE2之前
			      if(MdaUtils.isEmpty(this.getOprgrp().getUsr().getUpdtim())  ||  (!MdaUtils.isEmpty(updateTime) && MdaUtils.diff(this.getOprgrp().getUsr().getUpdtim(),updateTime)<0))
			      {
			        //return not null value
			        this.getOprgrp().getUsr().setUpdtim(updateTime);
			        log.debug("{}","Update USR inr = "+this.getOprgrp().getUsr().getInr()+"\t"+count);
			        log.info("{}","操作员信息有变化，进行更新！");
			        ctx.getDaoSession().dbUpdate(this.getOprgrp().getUsr());
			        upd = upd + 1;
			      }
			      else
			      {
			        log.info("{}","操作员信息无变化，不执行更新！");
			      }
			    }
			    else
			    {
			      log.info("{}","操作员信息在本地不存在，开始进行insert");
			      this.getOprgrp().getUsr().setInr(Platform.sdbCounter("usr"));
			      this.getOprgrp().getUsr().setUpdtim(updateTime);
			      log.info("{}","新增操作员inr="+this.getOprgrp().getUsr().getInr());
			      ctx.getDaoSession().dbInsert(this.getOprgrp().getUsr());
			      que = que + 1;
			      /* if("2".equals($oprgrp\\usr\\otype.getValue()))
			        {
			        savUsraut("trsque");
			        savUsraut("xpthis");
			        }
			        */
			    }
			    count++;
			    //更新或新增50条提交一次
			    if(count%50 == 0)
			    {
			      ctx.getDaoSession().dbCommit();
			      ctx.getDaoSession().dbBegin();
			    }
			  }
			  ctx.getDaoSession().dbCommit();
			  log.debug("{}","errorCode:" + ctx.getErrorCode());
			  if(ctx.getErrorCode() == NO_ERROR)
			  {
			    ctx.setMessage(MdaUtils.getI18NString("dbmopr","CT000306"),MdaUtils.getI18NString("dbmopr","CT000307")+det+MdaUtils.getI18NString("dbmopr","CT000308")+upd+MdaUtils.getI18NString("dbmopr","CT000309")+que+MdaUtils.getI18NString("dbmopr","CT000310"));
			  }
			}
			return null;
		}





}