package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DbmrelVO;

import com.ceb.gjjs.mda.manager.module.Autgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Autp;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 银行端业务授权模式定制
*/
@Transaction(vo= DbmrelVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Dbmrel extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Dbmrel.class);

        //机构信息
        private List bchcod;
        //交易名称
        private List trnnam;
		@BDGetter
		private Autgrp autgrp;

		@BDGetter
		private Autp autp;

		@BDGetter
		private Sysmod sysmod;


		public Dbmrel()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAutp().setAutgrpHolder(()->this.getAutgrp());
        }

        /**
        *   source:dbmrel.@0002.script
        */
        @Rule(target="autgrp.modlstlst",order=100)
        public boolean ruleAutgrpModlstlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in evt modlstlst ");
			if(MdaUtils.isEmpty(this.getAutp().getBchnam()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmrel","CT000014"),MdaUtils.getI18NString("dbmrel","CT000015"));
			  return true;
			}
			int index = 0;
			if(index < 0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmrel","CT000016"),MdaUtils.getI18NString("dbmrel","CT000017"));
			}
			String frm = this.getAutgrp().getModlstlst().getElement(index).getFrm();
			this.getAutp().setFrmnam(frm);
			
			log.debug("{}","in evt frm =" + frm);
			loadShwautFromDB(this.getAutp().getBchnam(),frm);


			return true;
        }

        /**
        *   source:dbmrel.@0006.script
        */
        @Rule(target="autp.submit",order=100)
        public boolean ruleAutpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			/**
			  *	保存银行端授权模式
			  */
			if(ctx.checkAll(ctx.getRoot()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("dbmrel","CT000042"),MdaUtils.getI18NString("dbmrel","CT000043"));
			  return true;
			}

			String flg = this.getAutp().getReleaseFlg(this.getAutp().getSptflg(),this.getAutp().getSptflg2());
			String flg2 = this.getAutp().getReleaseFlg(this.getAutp().getMgrflg(),this.getAutp().getMgrflg2());
			String flg3 = this.getAutp().getReleaseFlg(this.getAutp().getRelflg(),this.getAutp().getRelflg2());
			String frmnam = this.getAutp().getFrmnam();
			String bnkinr = this.getAutp().getBchnam();
			ctx.getDaoSession().dbBegin();
			if("all".equals(frmnam))
			{
			  for(int i=0 ;i<this.getAutgrp().getModlstlst().fullSize();i++)
			  {
			    this.savePtyaut(bnkinr,this.getAutgrp().getModlstlst().getElement(i).getFrm(),"bnkspt",flg);
			    this.savePtyaut(bnkinr,this.getAutgrp().getModlstlst().getElement(i).getFrm(),"trnmgr",flg2);
			    this.savePtyaut(bnkinr,this.getAutgrp().getModlstlst().getElement(i).getFrm(),"bnkrel",flg3);
			  }
			}
			else
			{
			  this.savePtyaut(bnkinr,frmnam,"bnkspt",flg);
			  this.savePtyaut(bnkinr,frmnam,"trnmgr",flg2);
			  this.savePtyaut(bnkinr,frmnam,"bnkrel",flg3);
			}
			ctx.getDaoSession().dbCommit();
			ctx.setMessage(MdaUtils.getI18NString("dbmrel","CT000052"),MdaUtils.getI18NString("dbmrel","CT000053"));
			loadShwautFromDB(bnkinr,frmnam);

			return true;
        }

        /**
        *   source:dbmrel.@0008.script
        */
        @Rule(target="autp.delete",order=100)
        public boolean ruleAutpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			/**
			  *	删除银行端授权模式
			  */
			if(MdaUtils.prompt(MdaUtils.getI18NString("dbmrel","CT000056"),MdaUtils.getI18NString("dbmrel","CT000057")))
			{
			  return false;
			}
			ctx.getDaoSession().dbBegin();
			for(int i=0;i<this.getAutgrp().getShwaut().fullSize();i++)
			{
			  ctx.getDaoSession().dbDelete(this.getAutgrp().getShwaut().getElement(i));
			}
			ctx.getDaoSession().dbCommit();
			MdaUtils.clear(this.getAutgrp().getShwaut());
			
			//$this.loadShwautFromDB($autp\\bchnam.getValue(),$autp\\frmnam.getValue());
			

			return true;
        }

        /**
        *   source:dbmrel.@0009.script
        */
        @Rule(target="autp.frmnam",order=100)
        public boolean ruleAutpFrmnamN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getAutp().getFrmnam()))
			{
			  loadShwautFromDB(this.getAutp().getBchnam(),this.getAutp().getFrmnam());
			}

			return true;
        }



        /**
        *   source:dbmrel.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			loadFinModlst();
			// 初始化交易名称
			List<CodetableItem> items = getFinTransactionList();
			MdaUtils.setValues(this.getAutp(),"frmnam",items);
			
			// 初始化机构信息
			List<CodetableItem> bchItem = getOwnBranchList();
			MdaUtils.setValues(this.getAutp(),"bchnam",bchItem);
			

			return true;
        }


        /**
        *   source:dbmrel.@0001.script
        */
        public void loadFinModlst()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 加载融资类交易列表
			  */

			ctx.getDaoSession().dbReadset(this.getAutgrp().getModlstlst(),new Argument("fintyp","F"),new Argument("modtyp","0"),new Argument("ptytyp","2"));
			
		}
        /**
        *   source:dbmrel.@0003.script
        */
        public List<CodetableItem> getFinTransactionList()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 获取融资交易列表（企业端）
			  */
			List<CodetableItem> list =null ;
			list =(List<CodetableItem>) this.getTrnnam();
			if(list == null || list.size()==0)
			{
			  list = new ArrayList<CodetableItem>();
			  CodetableItem item = new CodetableItem("全部","all");
			  list.add(item);
			  for(int i=0 ;i<this.getAutgrp().getModlstlst().fullSize();i++)
			  {
			    list.add(new CodetableItem(this.getAutgrp().getModlstlst().getElement(i).getNam(),this.getAutgrp().getModlstlst().getElement(i).getFrm()));
			  }
			  this.setTrnnam(list);
			}
			return list;
		}
        /**
        *   source:dbmrel.@0004.script
        */
        public List<CodetableItem> getOwnBranchList()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 获取当前机构的下辖机构
			  */
			log.debug("{}","in getOwnbranchList .... ");
			List<CodetableItem> branchList = null;
			branchList =(List<CodetableItem>) this.getBchcod();
			log.debug("{}","branchList=" + branchList  +",branch.size =" + branchList.size() );
			if(branchList == null || branchList.size()==0)
			{
			  branchList = new ArrayList<CodetableItem>();
			  String sql="SELECT pty.inr inr,pty.cid cid,pty.nam nam FROM pty WHERE  pty.ptytyp='0' ";
			  if("1".equals(this.getSysmod().getPty().getBrhlvl()))
			  {
			    log.info("{}","read all Pty:"+sql );
			  }
			  else if("2".equals(this.getSysmod().getPty().getBrhlvl()))
			  {
			    sql=sql+" and substr(pty.cid,1,2) = '"+this.getSysmod().getPty().getCid().substring(0,2)+"' ";
			  }
			  else if("3".equals(this.getSysmod().getPty().getBrhlvl()) || "4".equals(this.getSysmod().getPty().getBrhlvl())  )
			  {
			    sql=sql+" and pty.inr='"+this.getSysmod().getPty().getInr()+"' ";
			  }
			  ctx.getDaoSession().dbExecuteSQL(sql);
			  Argument<String> inr = new Argument<String>("inr");
			  Argument<String> cid = new Argument<String>("cid");
			  Argument<String> nam = new Argument<String>("nam");
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(inr,cid,nam);
			    if(ctx.getErrorCode() == NO_ERROR)
			    {
			      branchList.add(new CodetableItem(nam.getValue(),inr.getValue()));
			    }
			    else
			      break;
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  this.setBchcod(branchList);
			}
			return branchList;
		}
        /**
        *   source:dbmrel.@0005.script
        */
        public void loadShwautFromDB(String bnkptyinr, String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *  从数据库中加载当前选择的交易到交易列表中
			  */
			log.debug("{}","in loadShwautFromDB... bnkptinr="+bnkptyinr +",frm="+frm);
			if("all".equals(frm))
			{
			  ctx.getDaoSession().dbReadset(this.getAutgrp().getShwaut(),new Argument("objtyp","pty"),new Argument("objinr",bnkptyinr));
			  for(com.ceb.gjjs.mda.bo.Ptyaut obj: this.getAutgrp().getShwaut())
			  {
			    MdaUtils.setValues(obj,"frm",this.getFinTransactionList());
			    MdaUtils.setValues(obj,"objinr",this.getOwnBranchList());
			  }
			  this.getAutp().clearAllFlg();
			}
			else
			{
			  ctx.getDaoSession().dbReadset(this.getAutgrp().getShwaut(),new Argument("objtyp","pty"),new Argument("objinr",bnkptyinr),new Argument("frm",frm));
			  this.getAutp().clearAllFlg();
			  for(int i =0; i<this.getAutgrp().getShwaut().fullSize();i++)
			  {

			    this.getAutp().setReleaseFlg(this.getAutgrp().getShwaut().getElement(i).getFlg(),this.getAutgrp().getShwaut().getElement(i).getBnkfrm() );
			    MdaUtils.setValues(this.getAutgrp().getShwaut().getElement(i),"objinr",this.getOwnBranchList());
			    MdaUtils.setValues(this.getAutgrp().getShwaut().getElement(i),"frm",this.getFinTransactionList());
			    log.debug("{}","in list setFlgAnd ptynam");
			  }
			}
			
		}
        /**
        *   source:dbmrel.@0007.script
        */
        public void savePtyaut(String bnkinr,String frm, String bnkfrm ,String flg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getAutgrp().getPtyaut());
			ctx.getDaoSession().dbRead(this.getAutgrp().getPtyaut(),new Argument("objtyp","pty"),new Argument("objinr",bnkinr),new Argument("frm",frm),new Argument("bnkfrm",bnkfrm),new Argument("ptytyp","0"));
			this.getAutgrp().getPtyaut().setFlg(flg);
			this.getAutgrp().getPtyaut().setObjtyp("pty");
			this.getAutgrp().getPtyaut().setObjinr(bnkinr);
			this.getAutgrp().getPtyaut().setFrm(frm);
			this.getAutgrp().getPtyaut().setBnkfrm(bnkfrm);
			this.getAutgrp().getPtyaut().setPtytyp("0");
			if(MdaUtils.isEmpty(this.getAutgrp().getPtyaut().getInr()))
			{
			  this.getAutgrp().getPtyaut().setInr(MdaUtils.format(ctx.getDaoSession().dbCounter("ptyaut"),"00000000"));
			  ctx.getDaoSession().dbInsert(this.getAutgrp().getPtyaut());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getAutgrp().getPtyaut());
			}
		}






}