package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.DitdamVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Ditp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ditmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Didgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 买方信用证修改申请(商行)
*/
@Transaction(vo= DitdamVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Ditdam extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Ditdam.class);

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Didgrp didgrp;

		@BDGetter
		private Ditmod ditmod;

		@BDGetter
		private Ditp ditp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Ditdam()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getDitp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getDitp().setDidgrpHolder(()->this.getDidgrp());
           this.getMtabut().setRecHolder(()->this.getDidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("DC"));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.isscur");}
 				public void setValue(String arg){Ditdam.this.getDidgrp().getRec().setIsscur(arg);}
 				public String getValue(){return Ditdam.this.getDidgrp().getRec().getIsscur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.issameamt");}
 				public void setValue(BigDecimal arg){Ditdam.this.getDidgrp().getRec().setIssameamt(arg);}
 				public BigDecimal getValue(){return Ditdam.this.getDidgrp().getRec().getIssameamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("afdgrp.rec.ownref");}
 				public void setValue(String arg){Ditdam.this.getAfdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Ditdam.this.getAfdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.bchcod");}
 				public void setValue(String arg){Ditdam.this.getDidgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Ditdam.this.getDidgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.inr");}
 				public void setValue(String arg){Ditdam.this.getDidgrp().getRec().setInr(arg);}
 				public String getValue(){return Ditdam.this.getDidgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.ptyinr");}
 				public void setValue(String arg){Ditdam.this.getDidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Ditdam.this.getDidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Ditdam.this.getFieldPath("didgrp.rec.stlref");}
 				public void setValue(String arg){Ditdam.this.getDidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Ditdam.this.getDidgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:ditdam.@0004.script
        */
        @Rule(target="didgrp.rec.amenbr",order=100)
        public boolean ruleDidgrpRecAmenbrN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:ditdam.@0005.script
        */
        @Rule(target="didgrp.rec.decamt",order=100)
        public boolean ruleDidgrpRecDecamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","decamt的default校验==============");
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getDecamt()))
			{
			  this.getDidgrp().getRec().setIncamt(new BigDecimal("0"));
			  BigDecimal tmp = (this.getDidgrp().getRec().getIssamt()).subtract(this.getDidgrp().getRec().getDecamt());
			  log.info("{}",tmp.longValue()+">0?"+(tmp.longValue()>0));
			  if(tmp.doubleValue()>0)
			  {
			    this.getDidgrp().getRec().setIssameamt(tmp);
			  }
			  else
			  {
			    this.getDidgrp().getRec().setDecamt(new BigDecimal(0));
			  }
			  
			  
			  
			}

			return true;
        }

        /**
        *   source:ditdam.@0006.script
        */
        @Rule(target="didgrp.rec.incamt",order=100)
        public boolean ruleDidgrpRecIncamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","incamt的default校验==============");
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getIncamt()))
			{
			  this.getDidgrp().getRec().setDecamt(new BigDecimal("0"));
			  BigDecimal tmp = (this.getDidgrp().getRec().getIssamt()).add(this.getDidgrp().getRec().getIncamt());
			  this.getDidgrp().getRec().setIssameamt(tmp);
			  
			  
			}

			return true;
        }

        /**
        *   source:ditdam.@0009.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","sav200开始,trnmod bchcod = "+this.getTrnmod().getBchcod());
			if(!ctx.checkAll(this.getDidgrp()))
			  return false;
			//更新原记录
			ctx.getDaoSession().dbUpdate(this.getDidgrp().getRec());
			//Platform.dbUpdate($didgrp\\blk);
			String objinr = this.getDidgrp().getRec().getInr();
			String objtyp = "did";
			if(this.getSysmod().sptIsLoaded("B"))
			  this.getMtabut().UpdatePtsForBack(this.getDidgrp().getMben().getPts(),objinr);
			else
			  this.getDidgrp().getMben().savpts(objinr,objtyp);
			//trnBegin-->
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);
			log.info("{}", "sav200结束!" );

			return true;
        }

        /**
        *   source:ditdam.@0012.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getDitp().setCredat(NULLSTR);
			String credat = MdaUtils.format(this.getDidgrp().getRec().getCredat(),"yyyy年MM月dd日");
			this.getDitp().setCredat(credat);

			this.getDitp().setCreamedat(NULLSTR);
			String creamedat = MdaUtils.format(this.getDidgrp().getRec().getCreamedat(),"yyyy年MM月dd日");
			this.getDitp().setCreamedat(creamedat);

			this.getDitp().setDetails(NULLSTR);
			int num=1;
			String alldet="";
			if(!MdaUtils.isEmpty(this.getDidgrp().getMben().getPts().getAdrblk()))
			{
			  alldet=alldet+num+" : 修改后受益人为  "+this.getDidgrp().getMben().getPts().getAdrblk()+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getExpamedat()))
			{
			  alldet=alldet+num+" : 修改后有效期为  "+MdaUtils.format(this.getDidgrp().getRec().getExpamedat(),"yyyy年MM月dd日")+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getShpamedat()))
			{
			  alldet=alldet+num+" : 修改后最迟装运期为  "+MdaUtils.format(this.getDidgrp().getRec().getShpamedat(),"yyyy年MM月dd日")+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getShpamefro()))
			{
			  alldet=alldet+num+" : 修改后货物起运地/货物接收地为  "+this.getDidgrp().getRec().getShpamefro()+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getShpameto()))
			{
			  alldet=alldet+num+" : 修改后最终目的地/运往.../交货地点为  "+this.getDidgrp().getRec().getShpameto()+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getIncamt()))
			{
			  alldet=alldet+num+" : 增额为  "+this.getDidgrp().getRec().getIncamt()+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getIssameamt()))
			{
			  alldet=alldet+num+" : 修改后金额为  "+this.getDidgrp().getRec().getIssameamt()+"\r\n";
			  num++;
			}
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getDetails()))
			{
			  alldet=alldet+num+" : 其他修改细节有   "+this.getDidgrp().getRec().getDetails()+"\r\n";
			  num++;
			}
			this.getDitp().setDetails(alldet);

			IStream stream=this.getMtabut().getApldoc();
			ctx.absGet(Sysmod.class).generatorPdf("","ditdam",stream,false );

			return true;
        }

        /**
        *   source:ditdam.@0013.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in  images 50 ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }


        /**
        *   source:ditdam.@0002.script
        */
        @Check(target="didgrp.rec.expamedat",order=100)
        public boolean checkDidgrpRecExpamedatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getDidgrp().getRec().getExpamedat()))
			  return true;
			/*
			  if(Platform.isEmpty($didgrp\\rec\\shpamedat) && Platform.isEmpty($didgrp\\rec\\shpdat))
			  return;
			  else if(Platform.isEmpty($didgrp\\rec\\shpamedat) && (Platform.diff($didgrp\\rec\\shpdat.getValue(), $didgrp\\rec\\expamedat.getValue())>0))
			  */
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getShpamedat()) && (MdaUtils.diff(this.getDidgrp().getRec().getExpamedat(),this.getDidgrp().getRec().getShpamedat())<0))
			  ctx.setFieldError(this,"didgrp.rec.expamedat",MdaUtils.getI18NString("ditdam","CT000000"));

			return true;
        }

        /**
        *   source:ditdam.@0003.script
        */
        @Check(target="didgrp.rec.shpamedat",order=100)
        public boolean checkDidgrpRecShpamedatN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","shpamedat的check校验======");
			if(MdaUtils.isEmpty(this.getDidgrp().getRec().getShpamedat()))
			  return true;
			/*
			  if(Platform.diff($didgrp\\rec\\shpamedat.getValue(),$didgrp\\rec\\expdat.getValue())<0)
			  Platform.error($didgrp\\rec\\shpamedat,#CT000001);
			  else if(!Platform.isEmpty($didgrp\\rec\\expamedat) && Platform.diff($didgrp\\rec\\shpamedat.getValue(),$didgrp\\rec\\expamedat.getValue())>0)
			  */
			if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getExpamedat()) && MdaUtils.diff(this.getDidgrp().getRec().getShpamedat(),this.getDidgrp().getRec().getExpamedat())>0)
			  ctx.setFieldError(this,"didgrp.rec.shpamedat",MdaUtils.getI18NString("ditdam","CT000002"));

			return true;
        }


        /**
        *   source:ditdam.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			
			
			
			
			
			if(this.getSysmod().sptIsLoaded("B")  ||   this.getSysmod().sptIsLoaded("P")  ||  this.getSysmod().sptIsLoaded("T"))
			  return true;
			IModule mdl = (IModule)ctx.restoreData("com.brilliance.ditdam.ref");
			if(!MdaUtils.isEmpty(mdl))
			  this.getDidgrp().getRec().copyValue(mdl);
			//Platform.dbRead($didgrp\\blk,new Argument<String>("inr",$didgrp\\rec\\inr));
			ctx.getDaoSession().dbRead(this.getDidgrp().getApl().getPts(),new Argument<String>("objinr",this.getDidgrp().getRec().getInr()),new Argument<String>("objtyp","did"),new Argument<String>("rol","apl"));
			ctx.getDaoSession().dbRead(this.getDidgrp().getAdv().getPts(),new Argument<String>("objinr",this.getDidgrp().getRec().getInr()),new Argument<String>("objtyp","did"),new Argument<String>("rol","adv"));
			//Platform.errorCode();
			//$didgrp\\dap.initDap("did");
			//$didgrp\\apl.copyValues($didgrp\\dap);
			//$didgrp\\apl\\pts\\rol.setValue("apl");
			// if(Platform.isEmpty($didgrp\\apl\\pts\\ref))
			//  $didgrp\\apl\\pts\\ref.setValue($didgrp\\rec\\ownref.getValue());
			this.getDidgrp().getRec().setCreamedat(MdaUtils.today());
			this.getDidgrp().getRec().setAmenbr(this.getDidgrp().getRec().getAmenbr()+1);
			
			
			
			ctx.getDaoSession().dbRead(this.getDidgrp().getBen().getPts(),new Argument<String>("objinr",this.getDidgrp().getRec().getInr()),new Argument<String>("objtyp","did"),new Argument<String>("rol","ben"));
			//Platform.setValues($didgrp\\rec\\sndtyp,Platform.getCodetable("sndtyp"));
			this.getDidgrp().getRec().setSndtyp("1");
			
			
			
			
			
			
			this.getDidgrp().getRec().setIssameamt(this.getDidgrp().getRec().getIssamt());
			//Platform.setValues($didgrp\\rec\\chrgameby,Platform.getCodetable("chrgameby"));
			this.getDidgrp().getRec().setChrgameby("1");
			
			//Platform.disable($didgrp\\apl\\pts\\adrblk);
			this.getDidgrp().getApl().getPty().setNam(ctx.absGet(Sysmod.class).getPty().getNam());
			
			this.getDidgrp().getRec().setExpamedat(null);
			this.getDidgrp().getRec().setShpamedat(null);
			this.getDidgrp().getRec().setShpamefro(NULLSTR);
			this.getDidgrp().getRec().setPorameloa(NULLSTR);
			this.getDidgrp().getRec().setPoramedis(NULLSTR);
			this.getDidgrp().getRec().setShpameto(NULLSTR);
			this.getDidgrp().getRec().setIncamt(new BigDecimal(0));
			this.getDidgrp().getRec().setDecamt(new BigDecimal(0));
			this.getDidgrp().getRec().setDetails(NULLSTR);
			//$didgrp\\apl\\pts\\nam.setValue($sysmod\\pty\\nam.getValue());
			
			return true;
        }

        /**
        *   source:ditdam.@0001.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","bchcod="+this.getDidgrp().getRec().getBchcod());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getDidgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  //$didgrp\\rec\\bchcod.setValue(bchcod.get(0).getValue());
			{
			  if("3".equals(this.getSysmod().getPty().getPtytyp()))
			  {
			    if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getIbchcod()))
			      this.getDidgrp().getRec().setBchcod(this.getDidgrp().getRec().getIbchcod());
			    else
			    {
			      this.getDidgrp().getRec().setBchcod(bchcod.get(0).getValue());
			      this.getDidgrp().getRec().setIbchcod(this.getDidgrp().getRec().getBchcod());
			    }
			  }
			  else
			  {
			    if(!MdaUtils.isEmpty(this.getDidgrp().getRec().getDbchcod()))
			      this.getDidgrp().getRec().setBchcod(this.getDidgrp().getRec().getDbchcod());
			    else
			      this.getDidgrp().getRec().setDbchcod(this.getDidgrp().getRec().getBchcod());
			    
			  }
			  log.info("{}","bchocd="+this.getDidgrp().getRec().getBchcod()+",dbchocd="+this.getDidgrp().getRec().getDbchcod()+",ibchcod="+this.getDidgrp().getRec().getIbchcod());
			}


			return true;
        }











}