package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.ErsfreVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ersp;
import com.ceb.gjjs.mda.manager.module.Ersgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Ers;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 查询查复报文发起
*/
@Transaction(vo= ErsfreVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Ersfre extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Ersfre.class);

		@BDGetter
		private Ersgrp ersgrp;

		@BDGetter
		private Ersp ersp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Ers ers;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Sysmod sysmod;


		public Ersfre()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getErsp().setErsHolder(()->this.getErsgrp().getRec());
           this.getMtabut().setRecHolder(()->this.getErsgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("EQ"));
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Ersfre.this.getFieldPath("ersgrp.rec.ownref");}
 				public void setValue(String arg){Ersfre.this.getErsgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Ersfre.this.getErsgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Ersfre.this.getFieldPath("ersgrp.rec.bchcod");}
 				public void setValue(String arg){Ersfre.this.getErsgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Ersfre.this.getErsgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Ersfre.this.getFieldPath("ersgrp.rec.inr");}
 				public void setValue(String arg){Ersfre.this.getErsgrp().getRec().setInr(arg);}
 				public String getValue(){return Ersfre.this.getErsgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Ersfre.this.getFieldPath("ersgrp.rec.ptyinr");}
 				public void setValue(String arg){Ersfre.this.getErsgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Ersfre.this.getErsgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:ersfre.@0002.script
        */
        @Rule(target="mtabut.chk",order=100)
        public boolean ruleMtabutChkN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(ctx.checkAll(this.getErsgrp()))
			  ctx.setMessage(MdaUtils.getI18NString("ersfre","CT000014"),MdaUtils.getI18NString("ersfre","CT000015"));

			return true;
        }

        /**
        *   source:ersfre.@0006.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","业务处理开始，编号200");
			if(!ctx.checkAll(this.getErsgrp()))
			{
			  log.warn("{}","页面校验未通过，退出！");
			  return false;
			}
			log.info("{}","页面校验完成");
			//数据赋值
			this.getErsgrp().getRec().setHnglbh(this.getSysmod().getErsHNGLBH("EQ",this.getErsgrp().getRec().getBchcod()));//生成行内关联编号；
			this.getErsgrp().getRec().setDir(">");//生成往报标识；
			this.getErsgrp().getRec().setMsgtyp("0402");//0402：事务报文；
			this.getErsgrp().getRec().setCredat(MdaUtils.today());//生成创建日期；
			this.getErsgrp().getRec().setRecsta("W");
			this.getErsgrp().getRec().setMsgref(this.getErsgrp().getRec().getOwnref());

			//将Module数据入库 Begin==========
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  ctx.getDaoSession().dbUpdate(this.getErsgrp().getRec());
			}
			else
			  if(!"3".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  this.getErsgrp().getRec().setInr(Platform.sdbCounter("ers"));
			  ctx.getDaoSession().dbInsert(this.getErsgrp().getRec());
			}
			//将Module数据入库 End==========
			if(!this.getTrnmod().trnSetFromContract())
			  return false;

			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","zul文件已经生成，文件名："+filename);
			ctx.saveDisplay(filename);
			log.info("{}","业务处理结束，编号200");

			return true;
        }

        /**
        *   source:ersfre.@0007.script
        */
        @Rule(target="mtabut.ped",order=200)
        public boolean ruleMtabutPedN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(ctx.absGet(Sysmod.class).getSpt().getInr()))
			{
			  String typ=ctx.getTransName().substring(0,2);
			  this.getSysmod().getSpt().setObjtyp(MdaDriver.getModuleType(MdaDriver.getModule(this,ctx.getRoot(),"mtabut\\rec")));
			  this.getSysmod().getSpt().setObjinr("");
			}

			return true;
        }

        /**
        *   source:ersfre.@0018.script
        */
        @Rule(target="ersp.exi",order=100)
        public boolean ruleErspExiN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }


        /**
        *   source:ersfre.@0014.script
        */
        @Check(target="ersgrp.rec.agtact",order=100)
        public boolean checkErsgrpRecAgtactN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getErsgrp().getRec().getAgtact()))
			  ctx.setFieldError(this,"ersgrp.rec.agtact",MdaUtils.getI18NString("ersfre","CT000036"));

			return true;
        }

        /**
        *   source:ersfre.@0016.script
        */
        @Check(target="ersgrp.rec.relref",order=100)
        public boolean checkErsgrpRecRelrefN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getErsgrp().getRec().getRelref()))
			{
			  int len =this.getErsgrp().getRec().getRelref().length();
			  if (len>16)
			    ctx.setFieldError(this,"ersgrp.rec.relref",MdaUtils.getI18NString("ersfre","CT000041"));
			}

			return true;
        }

        /**
        *   source:ersfre.@0017.script
        */
        @Check(target="ersgrp.rec.matinf",order=100)
        public boolean checkErsgrpRecMatinfN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  if(Platform.isEmpty($ersgrp\\rec\\matinf))
			  {
			  Platform.error($ersgrp\\rec\\matinf,#CT000047);
			  }
			  else
			  {
			  boolean res = $sysmod.checkMaxTextField($ersgrp\\rec\\matinf,1750) ;
			  }
			  */
			if(!MdaUtils.isEmpty(this.getErsgrp().getRec().getMatinf()))
			{
			  boolean res = this.getSysmod().checkMaxTextField(MdaDriver.getDatafield(this.getErsgrp().getRec(),"matinf"),1750) ;
			}

			return true;
        }


        /**
        *   source:ersfre.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			{
			  this.getTrnmod().ordNew();
			}
			//获取归属机构
			log.info("{}","bchcod="+this.getErsgrp().getRec().getBchcod());
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getErsgrp().getRec(),"bchcod",bchcod);

			//载入ers表数据
			IModule mdl = (IModule)ctx.restoreData("com.brilliance.ersfre.ref");
			if(!MdaUtils.isEmpty(mdl))
			{
			  this.getErs().copyValue(mdl);
			  this.getErsgrp().getRec().setOldhnglbh(this.getErs().getHnglbh());
			  this.getErsgrp().getRec().setOldmsgref(this.getErs().getMsgref());
			  this.getErsgrp().getRec().setAgtextkey(this.getErs().getAgtextkey());
			  this.getErsgrp().getRec().setAgtact(this.getErs().getAgtact());
			  //$ersgrp\\rec\\relref.setValue($ers\\relref.getValue());
			  this.getErsgrp().getRec().setBusref(this.getErs().getOwnref());
			  this.getErsgrp().getRec().setBchcod(this.getErs().getBchcod());
			  
			  
			  
			  
			}
			//判断报文类型：自由格式，往报查询，来报查复；并对关联类型和事物类型赋值
			if (MdaUtils.isEmpty(this.getErsgrp().getRec().getOldhnglbh()))
			{
			  this.getErsgrp().getRec().setAsctyp("0");
			  this.getErsgrp().getRec().setMattyp("21");
			  
			  
			  
			}
			else
			  if (">".equals(this.getErs().getDir()))
			{
			  this.getErsgrp().getRec().setAsctyp("1");//查询，关联业务来报；
			  this.getErsgrp().getRec().setMattyp("01");
			  this.getErsgrp().getRec().setRelref(this.getErs().getMsgref());
			}
			else
			  if("<".equals(this.getErs().getDir()))
			{
			  if("0401".equals(this.getErs().getMsgtyp()))
			  {
			    this.getErsgrp().getRec().setAsctyp("2");//查询，关联业务往报
			    this.getErsgrp().getRec().setMattyp("01");
			    this.getErsgrp().getRec().setRelref(this.getErs().getMsgref());
			  }
			  else
			  {
			    this.getErsgrp().getRec().setAsctyp("0");//答复，关联事务
			    this.getErsgrp().getRec().setMattyp("02");
			    this.getErsgrp().getRec().setRelref(this.getErs().getMsgref());
			  }
			}
			this.getErsgrp().getRec().setAgtextkey(ctx.absGet(Sysmod.class).getPty().getBic());
			
			
			
			
			

			return true;
        }


        /**
        *   source:ersfre.@0012.script
        */
        public String  getDLHZH(String ptyinr , String bchcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String actval = "" ;

			String sql = "SELECT acc.cur cur,acc.act act FROM acc,pty  WHERE acc.ownptyinr= ? and pty.cid = ? and pty.inr= acc.opnptyinr and acc.cur is not null" ;
			ctx.getDaoSession().dbExecuteSQL(sql,ptyinr,bchcod);
			Argument<String> cur = new Argument<String>("cur");
			Argument<String> act = new Argument<String>("act");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cur,act);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    String curval = cur.value ;
			    actval = act.value;
			    if(curval.equals("CNY"))
			    {
			      actval = act.value;
			      break;
			    }
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			return  actval ;
		}








}