package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.ErsselVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Ersp;
import com.ceb.gjjs.mda.manager.module.Ersgrp;
import com.ceb.gjjs.mda.bo.Smh;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 跨境汇款查询查复入口
*/
@Transaction(vo= ErsselVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Erssel extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Erssel.class);

		@BDGetter
		private Ersgrp ersgrp;

		@BDGetter
		private Ersp ersp;

		@BDGetter
		private Smh smh;

		@BDGetter
		private Sysmod sysmod;


		public Erssel()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getErsp().setErsHolder(()->this.getErsgrp().getRec());
        }

        /**
        *   source:erssel.@0000.script
        */
        @Rule(target="ersp.sel",order=100)
        public boolean ruleErspSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getErsp()))
			  return true;
			log.info("{}","查询开始");
			String ptyinr=this.getSysmod().getPty().getInr();
			//机构分离，用户只能查找该用户相关的业务；
			String sql = "where ptyinr='"+ptyinr+"'";
			List argVal = new ArrayList();
			MdaUtils.clear(this.getErsp().getErslst());

			if(!MdaUtils.isEmpty(this.getErsp().getBchcod()))
			{
			  sql+="AND bchcod= ? ";
			  argVal.add(this.getErsp().getBchcod());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getDir()))
			{
			  sql+="AND dir= ? ";
			  argVal.add(this.getErsp().getDir());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getRecsta()))
			{
			  sql+="AND recsta= ? ";
			  argVal.add(this.getErsp().getRecsta());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getMsgtyp()))
			{
			  sql+="AND msgtyp= ? ";
			  argVal.add(this.getErsp().getMsgtyp());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getMattyp()))
			{
			  sql+="AND mattyp= ? ";
			  argVal.add(this.getErsp().getMattyp());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getRecbnkcod()))
			{
			  sql+="AND recbnkcod= ? ";
			  argVal.add(this.getErsp().getRecbnkcod());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getHnglbh()))
			{
			  sql+="AND hnglbh= ? ";
			  argVal.add(this.getErsp().getHnglbh());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getOwnref()))
			{
			  sql+="AND ownref= ? ";
			  argVal.add(this.getErsp().getOwnref());
			}

			if(!MdaUtils.isEmpty(this.getErsp().getRelref()))
			{
			  sql+="AND relref = ? ";
			  argVal.add(this.getErsp().getRelref());
			}
			if(!MdaUtils.isEmpty(this.getErsp().getCredat()))
			{
			  sql+="AND credat >= ? ";
			  argVal.add(MdaUtils.sqlDate(this.getErsp().getCredat(),GT));
			}
			if(!MdaUtils.isEmpty(this.getErsp().getEnddat()))
			{
			  sql+="AND credat <= ?";
			  argVal.add(MdaUtils.sqlDate(this.getErsp().getEnddat(),LT));
			}
			sql+=" order by credat desc";
			ctx.getDaoSession().dbReadset(this.getErsp().getErslst(),sql,argVal.toArray());
			log.info("{}","q="+argVal.toArray());
			log.info("{}","sql="+sql);

			int errorcode=ctx.getErrorCode();
			ctx.getDaoSession().dbCloseCursor();
			
			int length=this.getErsp().getErslst().fullSize();
			if(length<=0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("erssel","CT000009"),MdaUtils.getI18NString("erssel","CT000010"));
			}

			return true;
        }

        /**
        *   source:erssel.@0003.script
        */
        @Rule(target="ersp.dosrch",order=100)
        public boolean ruleErspDosrchN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getErsp().sureBtn("ersgrp","ersfre");


			return true;
        }

        /**
        *   source:erssel.@0004.script
        */
        @Rule(target="ersp.doans",order=100)
        public boolean ruleErspDoansN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getErsp().sureBtn("ersgrp","ersfre");

			return true;
        }

        /**
        *   source:erssel.@0005.script
        */
        @Rule(target="ersp.dofree",order=100)
        public boolean ruleErspDofreeN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:erssel.@0006.script
        */
        @Rule(target="ersp.detmsg",order=100)
        public boolean ruleErspDetmsgN100(){
            IContext ctx = MdaEnv.getContext();
            

			this.getErsp().showBtn("ersgrp");


			return true;
        }

        /**
        *   source:erssel.@0013.script
        */
        @Rule(target="ersp.erslst",order=100)
        public boolean ruleErspErslstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			log.info("{}","current line selected is ="+index );
			int length = this.getErsp().getErslst().fullSize();
			log.info("{}","size of erslst is ="+length);
			if( index<0   ||   index >= length)
			{//无数据，则能发自由报文
			  log.info("{}","只能发自由报文");
			  
			  
			  
			}
			else
			{
			  ctx.getDaoSession().dbRead(this.getErsgrp().getRec(),new Argument<String>("inr",this.getErsp().getErslst().getElement(index).getInr()));
			  ctx.getErrorCode();
			  if("0401".equals(this.getErsgrp().getRec().getMsgtyp()))
			  {//若为业务报文，则只能发起查询；
			    log.info("{}","只能发起查询");
			    
			    
			    
			  }
			  else if("<".equals(this.getErsgrp().getRec().getDir())&&"0402".equals(this.getErsgrp().getRec().getMsgtyp()))
			  {//事务来报
			    if(!"02".equals(this.getErsgrp().getRec().getMattyp()))
			    {//事务报文来报（非查复电），则能发起查复，并展示报文;
			      log.info("{}","事务报文来报（非查复电），能发起查复，并展示报文");
			      
			      
			      
			    }
			    else
			    {
			      log.info("{}","事务报文来报（查复电），则能并展示报文，不能发起查复");
			      //事务报文来报（查复电），则能并展示报文，不能发起查复；
			      
			      
			      
			    }
			  }
			  else if(">".equals(this.getErsgrp().getRec().getDir())&&"0402".equals(this.getErsgrp().getRec().getMsgtyp()))
			  {//事务往报,只能查看报文
			    log.info("{}","事务往报,只能查看报文");
			    
			    
			    
			  }
			  else
			  {
			    log.info("{}","其他类型报文，无法操作；");
			    //其他类型报文，无法操作；
			    
			    
			    
			  }
			  if(!"A".equals(this.getErsgrp().getRec().getRecsta()))
			  {
			    
			    
			  }
			}

			return true;
        }


        /**
        *   source:erssel.@0008.script
        */
        @Check(target="ersp.credat",order=100)
        public boolean checkErspCredatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getErsp().getCredat()))
			  ctx.setFieldError(this,"ersp.credat",MdaUtils.getI18NString("erssel","CT000001"));


			return true;
        }

        /**
        *   source:erssel.@0009.script
        */
        @Check(target="ersp.enddat",order=100)
        public boolean checkErspEnddatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getErsp().getEnddat()))
			  ctx.setFieldError(this,"ersp.enddat",MdaUtils.getI18NString("erssel","CT000002"));
			if(!MdaUtils.isEmpty(this.getErsp().getCredat())&&!MdaUtils.isEmpty(this.getErsp().getEnddat()))
			{
			  if(MdaUtils.diff(this.getErsp().getEnddat(),this.getErsp().getCredat())<0)
			  {
			    ctx.setFieldError(this,"ersp.enddat",MdaUtils.getI18NString("erssel","CT000012"));
			  }
			}

			return true;
        }


        /**
        *   source:erssel.@0007.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//查找柜员所属机构
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getErsp(),"bchcod",bchcod);

			//查询日期默认系统日期
			this.getErsp().setCredat(MdaUtils.today());
			this.getErsp().setEnddat(MdaUtils.today());


			return true;
        }







}