package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.FeqapiVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Btnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Feqgrp;
import com.ceb.gjjs.mda.manager.module.Feqtp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 购汇额度申请交易
*/
@Transaction(vo= FeqapiVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Feqapi extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Feqapi.class);

		@BDGetter
		private Feqgrp feqgrp;

		@BDGetter
		private Feqtp feqtp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Btnmod btnmod;


		public Feqapi()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getFeqtp().setFeqgrpHolder(()->this.getFeqgrp());
           this.getMtabut().setRecHolder(()->this.getFeqtp().getFeqgrp());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.currency");}
 				public void setValue(String arg){Feqapi.this.getFeqgrp().getRec().setCurrency(arg);}
 				public String getValue(){return Feqapi.this.getFeqgrp().getRec().getCurrency();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.businessno");}
 				public void setValue(String arg){Feqapi.this.getFeqgrp().getRec().setBusinessno(arg);}
 				public String getValue(){return Feqapi.this.getFeqgrp().getRec().getBusinessno();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.bchcod");}
 				public void setValue(String arg){Feqapi.this.getFeqgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Feqapi.this.getFeqgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.inr");}
 				public void setValue(String arg){Feqapi.this.getFeqgrp().getRec().setInr(arg);}
 				public String getValue(){return Feqapi.this.getFeqgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.ptyinr");}
 				public void setValue(String arg){Feqapi.this.getFeqgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Feqapi.this.getFeqgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Feqapi.this.getFieldPath("feqgrp.rec.paysum");}
 				public void setValue(BigDecimal arg){Feqapi.this.getFeqgrp().getRec().setPaysum(arg);}
 				public BigDecimal getValue(){return Feqapi.this.getFeqgrp().getRec().getPaysum();}}
			 );
        }

        /**
        *   source:feqapi.@0001.script
        */
        @Rule(target="mtabut.imgviw",order=100)
        public boolean ruleMtabutImgviwN100(){
            IContext ctx = MdaEnv.getContext();
            
			//影像查询
			log.debug("{}"," in imgviw....");
			this.getTrnmod().getItfmod().getImgmod().imgScans(this.getTrnmod().getTrninr());

			return true;
        }

        /**
        *   source:feqapi.@0012.script
        */
        @Rule(target="feqtp.fback",order=100)
        public boolean ruleFeqtpFbackN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!Platform.isFromApp())
			{
			  if(MdaUtils.prompt(MdaUtils.getI18NString("feqapi","CT000137"),MdaUtils.getI18NString("feqapi","CT000138")))
			  {
			    return false;
			  }
			}
			Date date=MdaUtils.parseDate(MdaUtils.format(MdaUtils.today(),"yyyyMMdd"),"yyyyMMdd");
			//经办退回，要修改业务状态为2
			if("O".equals(this.getTrnmod().getTrn().getNxtreq()))
			{
			  //判断退回原因非空
			  if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getBackreason()))
			  {
			    //Platform.message("提示","退回原因不能为空");
			    ctx.setFieldError(this,"feqgrp.rec.backreason","退回原因不能为空！");
			    return false;
			  }
			  //判断退回原因长度
			  if(this.getFeqgrp().getRec().getBackreason().length()>500)
			  {
			    //Platform.message("提示","退回原因不能超过500个字符");
			    ctx.setFieldError(this,"feqgrp.rec.backreason","退回原因不能超过500个字符！");
			    return false;
			  }
			  //20230420 如果结售汇统计代码是332或国际收支申报交易编码是226000，则外汇局批件号必填。
			  if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getWhjno())
			    && ("332".equals(this.getFeqgrp().getRec().getJshno()) || "226000".equals(this.getFeqgrp().getRec().getGjszsbnewno())))
			  {
			    //Platform.message("提示","外汇局批件号不能为空！");
			    ctx.setFieldError(this,"feqgrp.rec.whjno","外汇局批件号不能为空！");
			    return false;
			  }
			  if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getJshno()))
			  {
			    ctx.setFieldError(this,"feqgrp.rec.jshno","结售汇统计代码不能为空！");
			    //Platform.message("提示","结售汇统计代码不能为空！");
			    return false;
			  }
			  if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getGjszsbnewno()))
			  {
			    ctx.setFieldError(this,"feqgrp.rec.gjszsbnewno","国际收支申报交易编码不能为空！");
			    //Platform.message("提示","国际收支申报交易编码不能为空！");
			    return false;
			  }
			  //更新单据表
			  for(int i=0;i<this.getFeqgrp().getShdlst().fullSize();i++)
			  {
			    //判断最迟付汇时间
			    if(MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhdat(),this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat())!=0)
			    {
			      if(MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat(),date)<0)
			      {
			        ctx.setMessage("提示","最迟付汇日期不能早于当前日期");
			        return false;
			      }
			    }
			    //如果最迟付汇日期>最迟购汇日期，将最迟购汇日期修改为最迟付汇日期
			    if(MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat(),this.getFeqgrp().getRec().getZcghnewdat())>0 &&
			      MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat(),this.getFeqgrp().getShdlst().getElement(i).getZcfhdat())!=0)
			    {
			      this.getFeqgrp().getRec().setZcghnewdat(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat());
			      
			    }
			    ctx.getDaoSession().dbUpdate(this.getFeqgrp().getShdlst().getElement(i));
			    if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			    {
			      ctx.getDaoSession().dbRollback();
			      ctx.setMessage("E9999","数据库异常，请联系管理员！");
			      return true;
			    }
			  }
			  ctx.getDaoSession().dbBegin();
			  //如果重新生效、作废后再退回，业务状态应该还是失效状态;
			  if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()) && ("1".equals(this.getFeqgrp().getRec().getEduflag()) || "2".equals(this.getFeqgrp().getRec().getEduflag())))
			  {
			    this.getFeqgrp().getRec().setApplystatus("4");
			  }
			  else
			  {
			    this.getFeqgrp().getRec().setApplystatus("2");
			  }
			  this.getFeqgrp().getRec().setJiehsign("0");
			  this.getFeqgrp().getRec().setUpddat(MdaUtils.today());
			  ctx.getDaoSession().dbUpdate(this.getFeqgrp().getRec());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return true;
			  }

			  this.getTrnmod().getTrn().setSta("b");
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return true;
			  }

			  //ord、ore处理
			  this.updateOrd(this.getFeqgrp().getRec().getInr(),"B","20",this.getRmkmod().getNtext());

			  //记录操作历史
			  this.dormk(this.getTrnmod().getOrdmod().getOrd().getInr(),this.getTrnmod().getTrn().getInr(),"11");

			}
			else if("B".equals(this.getTrnmod().getTrn().getNxtreq()))//复核退回
			{
			  //修改trn为原始状态,relreq=OB，relres=NULL，nxtreq=O，nxtlev=NULL
			  ctx.getDaoSession().dbBegin();
			  this.getTrnmod().getTrn().setRelreq("OB");
			  this.getTrnmod().getTrn().setRelres("");
			  this.getTrnmod().getTrn().setNxtreq("O");
			  this.getTrnmod().getTrn().setIniusr("");
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return true;
			  }
			  //ord、ore处理
			  this.updateOrd(this.getFeqgrp().getRec().getInr(),"E","19",this.getRmkmod().getNtext());
			  //记录操作历史
			  this.dormk(this.getTrnmod().getOrdmod().getOrd().getInr(),this.getTrnmod().getTrn().getInr(),"09");
			}

			ctx.getDaoSession().dbCommit();
			MdaUtils.showMainPanel();
			this.refresh();

			return true;
        }

        /**
        *   source:feqapi.@0013.script
        */
        @Rule(target="feqtp.fsearch",order=100)
        public boolean ruleFeqtpFsearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			Date sqbegdat=this.getFeqtp().getSqbegdat();
			Date sqenddat =this.getFeqtp().getSqendbat();
			Date zcghbegdat=this.getFeqtp().getZcghbegdat();
			Date zcghenddat =this.getFeqtp().getZcghenddat();
			String busno = this.getFeqtp().getBusino();
			String ptyinr=this.getSysmod().getPty().getInr();
			String cid=this.getSysmod().getUsr().getCid();
			String ptynam = this.getFeqtp().getPtynam();
			ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("cid",cid));
			ctx.getErrorCode();
			if(!MdaUtils.isEmpty(sqbegdat) && !MdaUtils.isEmpty(sqenddat)&& MdaUtils.diff(sqbegdat,sqenddat)>0)
			{
			  ctx.setFieldError(this,"feqtp.sqbegdat","申请开始日期不能晚于结束日期！");
			  return true;
			}
			if(!MdaUtils.isEmpty(zcghbegdat) && !MdaUtils.isEmpty(zcghenddat)&& MdaUtils.diff(zcghbegdat,zcghenddat)>0)
			{
			  ctx.setFieldError(this,"feqtp.zcghbegdat","最迟购汇开始日期不能晚于结束日期！");
			  return true;
			}
			MdaUtils.clear(this.getFeqgrp().getFsqlst());
			String cur = this.getFeqtp().getCur();
			String status = this.getFeqtp().getApplystatus();
			//查询列表数据
			List objs = new ArrayList();
			String sql = "SELECT m2.inr, m1.sta,m2.businessno,m2.ecifname,m2.currency,m2.paysum,m2.havesale,m2.cansaleed,m2.applydat,m2.zcghnewdat,m2.applystatus from trn m1,shs m2  WHERE m1.ownref = m2.businessno ";
			//申请日期
			//申请起始日期不为空，申请结束日期为空
			if(!MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && MdaUtils.isEmpty(this.getFeqtp().getSqendbat()))
			{
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') >= '" + MdaUtils.format(sqbegdat,"yyyyMMdd") + "' ";
			}
			else if(MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getSqendbat()))//申请起始日期为空，申请结束日期不为空
			{
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') <= '" + MdaUtils.format(sqenddat,"yyyyMMdd") + "' ";
			}
			else if(!MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getSqendbat()))//申请起始日期不为空，申请结束日期不为空
			{
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') >= '" + MdaUtils.format(sqbegdat,"yyyyMMdd") + "' ";
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') <= '" + MdaUtils.format(sqenddat,"yyyyMMdd") + "' ";
			}

			//最迟购汇日期
			//最迟购汇日期不为空，最迟购汇日期为空
			if(!MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && MdaUtils.isEmpty(this.getFeqtp().getZcghenddat()))
			{
			  sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') >= '" + MdaUtils.format(zcghbegdat,"yyyyMMdd") + "' ";
			}
			else if(MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getZcghenddat()))//最迟购汇起始日期为空，最迟购汇结束日期不为空
			{
			  sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') <= '" + MdaUtils.format(zcghenddat,"yyyyMMdd") + "' ";
			}
			else if(!MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getZcghenddat()))//最迟购汇起始日期不为空，最迟购汇结束日期不为空
			{
			  sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') >= '" + MdaUtils.format(zcghbegdat,"yyyyMMdd") + "' ";
			  sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') <= '" + MdaUtils.format(zcghenddat,"yyyyMMdd") + "' ";
			}
			//币种
			if(!MdaUtils.isEmpty(this.getFeqtp().getCur()))
			{
			  sql = sql + " AND m2.currency = '" + cur + "' ";
			}
			//业务参考号 
			if(!MdaUtils.isEmpty(this.getFeqtp().getBusino()))
			{
			  sql = sql + " AND m2.businessno = '" + busno.trim() + "' ";
			}
			//申请状态
			if(!MdaUtils.isEmpty(this.getFeqtp().getApplystatus()) && !"all".equals(this.getFeqtp().getApplystatus()))
			{
			  sql = sql + " AND m1.sta = '" + status + "' ";
			}
			else
			{
			  sql = sql + " AND m1.sta in('w','d','b')";
			}
			//申请类型
			if(!"4".equals(this.getFeqtp().getApplytyp()) && !MdaUtils.isEmpty(this.getFeqtp().getApplytyp()))
			{
			  sql = sql + " AND m2.applytyp = '" + this.getFeqtp().getApplytyp() + "' ";
			}

			//机构名称
			if(!MdaUtils.isEmpty(ptynam))
			{
			  //sql = sql + " AND m2.orgname like '%" + orgname + "%' ";
			  sql= sql+" AND m2.orginr = (SELECT inr FROM pty p WHERE p.inr='"+ptynam+"')";
			}
			if("1".equals(this.getSysmod().getPty().getLvl()))
			{
			  sql = sql + " AND (m2.bchcod in (select cid from pty where pntinr=m2.bchcod) or m2.bchcod='" + cid + "')  ";
			}
			else if("2".equals(this.getSysmod().getPty().getLvl()))
			{
			  sql = sql + " AND m2.orginr = '" + this.getSysmod().getPty().getInr() + "' ";
			}
			sql = sql + " AND m2.deleted = '0' order by m2.applydat desc";
			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getErrorCode();
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> sta = new Argument<String>("sta");
			Argument<String> businessno = new Argument<String>("businessno");
			Argument<String> currency = new Argument<String>("currency");
			Argument<BigDecimal> paysum = new Argument<BigDecimal>("paysum")  ;
			Argument<BigDecimal> cansaleed = new Argument<BigDecimal>("cansaleed");
			Argument<BigDecimal> havesale = new Argument<BigDecimal>("havesale");
			Argument<Date> applydat = new Argument<Date>("applydat");
			Argument<Date> zcghnewdat = new Argument<Date>("zcghnewdat");
			Argument<String> applystatus = new Argument<String>("applystatus");
			Argument<String> ecifname = new Argument<String>("ecifname");

			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			    this.getFeqgrp().getFsqlst().add(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			for(int i=0;i<this.getFeqgrp().getFsqlst().fullSize();i++)
			{
			  this.getFeqgrp().getFsqlst().getElement(i).setSta(MdaUtils.getCodetableLabel("trnftaf",this.getFeqgrp().getFsqlst().getElement(i).getSta()));
			}
			

			return true;
        }

        /**
        *   source:feqapi.@0014.script
        */
        @Rule(target="feqtp.mtabut.show",order=100)
        public boolean ruleFeqtpMtabutShowN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index =-1;
			int count=0;
			for(int i=0;i<this.getFeqgrp().getFsqlst().fullSize();i++)
			{
			  if("X".equals(this.getFeqgrp().getFsqlst().getElement(i).getSelf()))
			  {
			    index=i;
			    count++;
			  }
			}
			if(count>1)
			{
			  ctx.setMessage("操作提示","不能同时查看多笔业务！");
			  return true;
			}
			//index=Platform.getSelectedRowIndex($bsplst);
			log.debug("{}","in evt btnmod.show ... index =" +index);
			if(index<0  ||  index>=this.getFeqgrp().getFsqlst().fullSize())
			{
			  index=0;
			  if(index<0||index>=this.getFeqgrp().getFsqlst().fullSize())
			  {
			    ctx.setMessage("操作提示","请选择一条要操作的记录！");
			    return true;
			  }
			}
			String sptinr = this.getFeqgrp().getFsqlst().getElement(index).getInr();
			MdaUtils.clear(this.getSysmod().getSpt());
			ctx.getDaoSession().dbRead(this.getSysmod().getSpt(),new Argument<Object>("inr",sptinr));

			showDetailPanel(index);

			return true;
        }

        /**
        *   source:feqapi.@0018.script
        */
        @Rule(target="feqgrp.fsqlst",order=100)
        public boolean ruleFeqgrpFsqlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			//W-待审核，D-已完成，B-退回修改
			//1.如果状态是待审核，跳转到审批页面
			//根据inr获取业务数据
			MdaUtils.clear(this.getFeqgrp().getRec());
			MdaUtils.clear(this.getSysmod().getPty());
			MdaUtils.clear(this.getTrnmod().getOrdmod().getOrd());
			MdaUtils.clear(this.getFeqgrp().getShdlst());
			MdaUtils.clear(this.getTrnmod().getTrn());
			ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<String>("inr",this.getFeqgrp().getFsqlst().getElement(index).getInr()));
			ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("cid",this.getSysmod().getUsr().getCid()));
			ctx.getDaoSession().dbRead(this.getTrnmod().getOrdmod().getOrd(),new Argument("objinr",this.getFeqgrp().getRec().getInr()),new Argument("objtyp","shs"));
			ctx.getDaoSession().dbReadset(this.getFeqgrp().getShdlst(),new Argument("edbusno",this.getFeqgrp().getRec().getBusinessno()),new Argument("deleted","0"));
			ctx.getDaoSession().dbRead(this.getTrnmod().getTrn(),new Argument<Object>("ownref",this.getFeqgrp().getRec().getBusinessno()));
			ctx.getErrorCode();
			//国际收支申报交易编码
			String val = MdaUtils.getCodetableLabel("dgml",this.getFeqgrp().getRec().getJshno());
			if(!MdaUtils.isEmpty(val))
			{
			  MdaUtils.setValues(this.getFeqgrp().getRec(),"gjszsbnewno",MdaUtils.getCodetable(val));
			}
			//结售汇统计代码
			String valj = MdaUtils.getCodetableLabel("ldgj",this.getFeqgrp().getRec().getSalexz());
			if(!MdaUtils.isEmpty(valj))
			{
			  MdaUtils.setValues(this.getFeqgrp().getRec(),"jshno",MdaUtils.getCodetable(valj));
			}
			// 加载RMK
			this.loadRmk(this.getTrnmod().getOrdmod().getOrd().getInr());
			this.getFeqtp().setBhname(this.getFeqgrp().getRec().getOrgname());
			//if("W".equals($feqgrp\\fsqlst[index]\\sta.getValue()))
			//{
			//Platform.showPanel($feqtp\\feqtp);
			//}
			//设置不可编辑
			
			
			
			
			
			
			
			
			//Platform.disable($feqgrp\\rec\\salexz);
			//Platform.disable($feqgrp\\rec\\jshno);
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			//重新生效-结汇要显示结汇申请书按钮，非结汇操作要隐藏结汇申请书按钮
			if(!"1".equals(this.getFeqgrp().getRec().getJiehsign()))
			{
			  
			}
			else
			{
			  
			  this.getFeqgrp().setOthcno(ctx.absGet(Sysmod.class).getPty().getAtccod());
			}
			if("d".equals(this.getTrnmod().getTrn().getSta()) || "b".equals(this.getTrnmod().getTrn().getSta()))
			{
			  //查看页面设置业务状态不可编辑
			  
			  
			  
			  
			  
			}
			else
			{
			  
			  /*
			    1.如果是经办环节，国际收支申报交易编码、单据编号、最迟购汇日期、给下步操作人员的提示、退回原因可修改
			    2.如果是总行、分行可以跳到审批页面，否则只能跳转查看页面
			    */
			  if("O".equals(this.getTrnmod().getTrn().getNxtreq()))
			  {
			    if("1".equals(this.getSysmod().getPty().getLvl()) || "0".equals(this.getSysmod().getPty().getLvl()))
			    {
			      
			      
			      
			      
			      
			      
			      //20230420 如果国际收支申报交易编码的值是321000，外汇局批件号默认回显
			      if("321000".equals(this.getFeqgrp().getRec().getGjszsbnewno()))
			      {
			        
			      }
			      
			    }
			    else
			    {
			      
			      
			      
			      
			      
			    }
			  }
			  else if("B".equals(this.getTrnmod().getTrn().getNxtreq()))
			  {
			    //如果是复核环节、给下步操作人员的提示可修改
			    String logusrinr=this.getSysmod().getUsr().getInr();
			    
			    
			    if(logusrinr.equals(this.getTrnmod().getTrn().getIniusr()) || "2".equals(this.getSysmod().getPty().getLvl()))
			    {
			      
			      
			      
			      
			      
			    }
			    else
			    {
			      
			      
			    }
			  }
			}
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()))
			{
			  this.getFeqtp().setBustyp("0");
			}
			else if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()) && !"1".equals(this.getFeqgrp().getRec().getJiehsign()))
			{
			  this.getFeqtp().setBustyp(this.getFeqgrp().getRec().getEduflag());
			}
			else if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getJiehsign()))
			{
			  this.getFeqtp().setBustyp("3");
			}
			
			

			return true;
        }

        /**
        *   source:feqapi.@0019.script
        */
        @Rule(target="feqtp.btnmod.imgviw",order=100)
        public boolean ruleFeqtpBtnmodImgviwN100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.absGet(Trnmod.class).getItfmod().getImgmod().imgScans(this.getTrnmod().getTrn().getInr());
			log.debug("{}"," out trninr...."+this.getTrnmod().getTrn().getInr());

			return true;
        }

        /**
        *   source:feqapi.@0020.script
        */
        @Rule(target="feqtp.submit",order=100)
        public boolean ruleFeqtpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!Platform.isFromApp())
			{
			  if(MdaUtils.prompt("提示","确定提交该笔交易吗？"))
			  {
			    return false;
			  }
			}
			String status = ctx.absGet(Trnmod.class).getTrn().getNxtreq();
			//经办提交
			if("O".equals(status))
			{
			  if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getBackreason()))
			  {
			    this.getFeqgrp().getRec().setBackreason(NULLSTR);
			  }
			  //作废不做校验
			  if(!"2".equals(this.getFeqgrp().getRec().getEduflag()) && !"1".equals(this.getFeqgrp().getRec().getJiehsign()))
			  {
			    //校验
			    String message = this.checkshs();
			    if(!MdaUtils.isEmpty(message))
			    {
			      ctx.setMessage("提示",message);
			      return false;
			    }
			  }

			  ctx.getDaoSession().dbBegin();
			  //更新单据表
			  for(int i=0;i<this.getFeqgrp().getShdlst().fullSize();i++)
			  {
			    this.getFeqgrp().getShdlst().getElement(i).setUpddat(MdaUtils.today());
			    ctx.getDaoSession().dbUpdate(this.getFeqgrp().getShdlst().getElement(i));
			    if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			    {
			      ctx.getDaoSession().dbRollback();
			      ctx.setMessage("E9999","数据库异常，请联系管理员！");
			      return false;
			    }
			  }
			  //对重新生效、作废的处理
			  if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()))
			  {
			    //ord、ore处理
			    this.updateOrd(this.getFeqgrp().getRec().getInr(),"E","16","");
			    //修改trn
			    this.getTrnmod().getTrn().setNxtreq("B");
			    this.getTrnmod().getTrn().setRelres("O");
			  }
			  else if("1".equals(this.getFeqgrp().getRec().getEduflag()))//重新生效
			  {
			    //修改trn
			    this.getTrnmod().getTrn().setNxtreq("");
			    this.getTrnmod().getTrn().setRelres("O");
			    this.getTrnmod().getTrn().setSta("d");
			    this.getFeqgrp().getRec().setApplystatus("3");
			    //ord、ore处理
			    this.updateOrd(this.getFeqgrp().getRec().getInr(),"D","16","");
			  }
			  else if("2".equals(this.getFeqgrp().getRec().getEduflag())) //作废
			  {
			    //修改trn
			    this.getTrnmod().getTrn().setNxtreq("");
			    this.getTrnmod().getTrn().setRelres("O");
			    this.getTrnmod().getTrn().setSta("d");
			    this.getFeqgrp().getRec().setApplystatus("6");
			    //ord、ore处理
			    this.updateOrd(this.getFeqgrp().getRec().getInr(),"R","11","");

			  }
			  ctx.getDaoSession().dbUpdate(this.getFeqgrp().getRec());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			  //更新trn的创建用户
			  this.getTrnmod().getTrn().setIniusr(this.getSysmod().getUsr().getInr());
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());

			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			  //结汇时，如果可购金额>0，修改业务状态为审核完成，如果可购金额=0，修改业务状态为已完成.
			  //if("1".equals($feqgrp\\rec\\jiehsign.getValue()) && $feqgrp\\rec\\cansaleed.getValue().compareTo(new BigDecimal(0.00))==0)
			  //{
			  //$feqgrp\\rec\\applystatus.setValue("5");
			  //}
			  //$feqgrp\\rec\\upddat.setValue(Platform.today());
			  //Platform.dbUpdate($feqgrp\\rec);
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			  //记录操作历史
			  this.dormk(this.getTrnmod().getOrdmod().getOrd().getInr(),this.getTrnmod().getTrn().getInr(),"03");
			}
			//8.复核环节调用国结接口，判断额度是否超过限额，调用国结接口
			if("B".equals(status))
			{
			  //复核时处理人和经办人不能是同一人
			  String logusrinr=this.getSysmod().getUsr().getInr();
			  if(logusrinr.equals(this.getTrnmod().getTrn().getIniusr()))
			  {
			    ctx.setMessage("提示","复核人和经办人不能是同一人");
			    return false;
			  }

			  //1.修改业务状态
			  ctx.getDaoSession().dbBegin();
			  this.getFeqgrp().getRec().setApplystatus("3");
			  this.getFeqgrp().getRec().setUpddat(MdaUtils.today());
			  //2.调用接口，判断限额
			  Object object =  MdaUtils.invoke("com.brilliance.eibs.main.Client","scall","eg03","eg03",new Object[]{this.getFeqgrp().getRec().getEcifno()});
			  Map retMsg = (Map)MdaUtils.invoke(object,"getContent");
			  //String jiayjg = (String)retMsg.get("JIAYJG");
			  String jiayjg =String.valueOf(retMsg.get("JIAYJG"));
			  if("AAAAAAA".equals(jiayjg))
			  {
			    String value = (String)retMsg.get(this.getFeqgrp().getRec().getCurrency());
			    if(MdaUtils.isEmpty(value))
			    {
			      ctx.setMessage("提示","没有获取到限额额度，请联系管理员！");
			      return false;
			    }
			    BigDecimal amt1 = MdaUtils.parseDecimal(value);
			    BigDecimal amt2 = this.getFeqgrp().getRec().getPaysum();
			    if(amt2.compareTo(amt1)>0)
			    {
			      if(MdaUtils.prompt("提示","超分行权限，请确认是否已通过总行审批？"))
			      {
			        return false;
			      }
			    }
			  }
			  else
			  {
			    ctx.setMessage("提示","没有获取到限额额度，请联系管理员！");
			    return false;
			  }
			  ctx.getDaoSession().dbUpdate(this.getFeqgrp().getRec());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			  //ord、ore处理
			  this.updateOrd(this.getFeqgrp().getRec().getInr(),"D","17",this.getRmkmod().getNtext());
			  //记录操作历史
			  this.dormk(this.getTrnmod().getOrdmod().getOrd().getInr(),this.getTrnmod().getTrn().getInr(),"04");
			  //修改trn
			  this.getTrnmod().getTrn().setNxtreq("");
			  this.getTrnmod().getTrn().setSta("d");
			  this.getTrnmod().getTrn().setRelres("OB");
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());
			  if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			  {
			    ctx.getDaoSession().dbRollback();
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			}

			ctx.getDaoSession().dbCommit();
			MdaUtils.showMainPanel();
			this.refresh();

			return true;
        }

        /**
        *   source:feqapi.@0022.script
        */
        @Rule(target="feqtp.return",order=100)
        public boolean ruleFeqtpReturnN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.showMainPanel();
			//$this.refresh();
			
			return true;
        }

        /**
        *   source:feqapi.@0026.script
        */
        @Rule(target="feqtp.appbook",order=100)
        public boolean ruleFeqtpAppbookN100(){
            IContext ctx = MdaEnv.getContext();
            
			//是否结汇标记=1时，生成结汇申请书
			//$feqtp\\credat.setValue(Platform.today());
			//int cnt = 1;
			//String labels = "即期结汇申请书";
			//String tempfiles = "A:fpdsll2";
			//$trnmod\\apldoc.setPDFInfo(cnt,labels,tempfiles);
			//$trnmod\\apldoc.generatorAllPDF();
			
			this.getFeqgrp().setCredat(MdaUtils.today());
			String jieshtjno = this.getFeqgrp().getRec().getJieshtjno();
			this.getFeqgrp().setShbody(jieshtjno.substring(4,5));
			this.getFeqgrp().setUsage("099");
			this.getFeqtp().getPdfviw().callPDFComponent("","feqapi","结汇申请",1);


			return true;
        }

        /**
        *   source:feqapi.@0029.script
        */
        @Rule(target="feqtp.detail",order=100)
        public boolean ruleFeqtpDetailN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index =-1;
			int count=0;
			for(int i=0;i<this.getFeqgrp().getFsqlst().fullSize();i++)
			{
			  if("X".equals(this.getFeqgrp().getFsqlst().getElement(i).getSelf()))
			  {
			    index=i;
			    count++;
			  }
			}
			if(count>1)
			{
			  ctx.setMessage("操作提示","不能同时查看多笔业务！");
			  return true;
			}
			if(index<0  ||  index>=this.getFeqgrp().getFsqlst().fullSize())
			{
			  index=0;
			  if(index<0||index>=this.getFeqgrp().getFsqlst().fullSize())
			  {
			    ctx.setMessage("操作提示","请选择一条要操作的记录！");
			    return true;
			  }
			}
			//读取trn
			ctx.getDaoSession().dbRead(this.getTrnmod().getTrn(),new Argument<Object>("ownref",this.getFeqgrp().getFsqlst().getElement(index).getBusinessno()));
			ctx.getErrorCode();
			if(!"d".equals(this.getTrnmod().getTrn().getSta()))
			{
			  ctx.setMessage("操作提示","只能查看审批通过的额度明细！");
			  return true;
			}
			this.getFeqtp().setJytyp(NULLSTR);
			this.getFeqtp().setBusinessno(this.getFeqgrp().getFsqlst().getElement(index).getBusinessno());
			MdaUtils.clear(this.getFeqtp().getGhmlst());
			showlst(this.getFeqgrp().getFsqlst().getElement(index).getBusinessno(),"0");

			return true;
        }

        /**
        *   source:feqapi.@0030.script
        */
        @Rule(target="feqtp.mxsearch",order=100)
        public boolean ruleFeqtpMxsearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			showlst(this.getFeqtp().getBusinessno(),this.getFeqtp().getJytyp());

			return true;
        }

        /**
        *   source:feqapi.@0032.script
        */
        @Rule(target="feqtp.view",order=100)
        public boolean ruleFeqtpViewN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index =-1;
			int count=0;
			for(int i=0;i<this.getFeqtp().getGhmlst().fullSize();i++)
			{
			  if("X".equals(this.getFeqtp().getGhmlst().getElement(i).getSelfs()))
			  {
			    index=i;
			    count++;
			  }
			}
			if(count>1)
			{
			  ctx.setMessage("操作提示","不能同时查看多笔业务！");
			  return true;
			}
			if(index<0  ||  index>=this.getFeqtp().getGhmlst().fullSize())
			{
			  index=0;
			  if(index<0||index>=this.getFeqtp().getGhmlst().fullSize())
			  {
			    ctx.setMessage("操作提示","请选择一条要操作的记录！");
			    return true;
			  }
			}
			if("7".equals(this.getFeqtp().getGhmlst().getElement(index).getJytyp()) || "8".equals(this.getFeqtp().getGhmlst().getElement(index).getJytyp()) ||
			  "9".equals(this.getFeqtp().getGhmlst().getElement(index).getJytyp()))
			{
			  ctx.setMessage("提示","线下发起的交易信息请去国结系统查看！");
			  return true;
			}
			showmxdetail(this.getFeqtp().getGhmlst().getElement(index).getInr(),this.getFeqtp().getGhmlst().getElement(index).getJytyp());

			return true;
        }

        /**
        *   source:feqapi.@0034.script
        */
        @Rule(target="feqtp.viewback",order=100)
        public boolean ruleFeqtpViewbackN100(){
            IContext ctx = MdaEnv.getContext();
            
			showlst(this.getFeqgrp().getRec().getBusinessno(),this.getFeqtp().getJytyp());

			return true;
        }

        /**
        *   source:feqapi.@0035.script
        */
        @Rule(target="feqtp.hisview",order=100)
        public boolean ruleFeqtpHisviewN100(){
            IContext ctx = MdaEnv.getContext();
            
			//加载单据历史数据
			MdaUtils.clear(this.getFeqtp().getHislst());
			String businessno = this.getFeqgrp().getRec().getBusinessno();
			//String sql = "select billtype,billnewno,billsum,zcfhnewdat,credat from(select  a.billtype,a.billnewno,a.billsum,a.zcfhnewdat,a.credat,ROW_NUMBER() OVER(PARTITION BY a.billnewno,a.billsum,a.zcfhnewdat ORDER BY a.zcfhnewdat ) rk from shd a where a.deleted='1' and edbusno='"+businessno+"') where rk=1 ";
			String sql = "select billtype,billnewno,billsum,zcfhnewdat,credat from shd where deleted='2' and edbusno='"+businessno+"'";

			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getErrorCode();
			Argument<String> billtype = new Argument<String>("billtype");
			Argument<String> billnewno = new Argument<String>("billnewno");
			Argument<BigDecimal> billsum = new Argument<BigDecimal>("billsum");
			Argument<Date> zcfhnewdat = new Argument<Date>("zcfhnewdat");
			Argument<Date> credat = new Argument<Date>("credat");

			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(billtype,billnewno,billsum,zcfhnewdat,credat);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			    this.getFeqtp().getHislst().add(billtype,billnewno,billsum,zcfhnewdat,credat);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			/*for(int i=0;i<$feqtp\\feqgrp\\shdlst.fullSize();i++)
			  {
			  for(int j=0;j<$feqtp\\hislst.fullSize();j++)
			  {
			  BigDecimal hissum = $feqtp\\hislst[j]\\billsum.getValue();
			  BigDecimal sum = Platform.parseDecimal($feqtp\\feqgrp\\shdlst[i]\\billsum.getValue());
			  if($feqtp\\feqgrp\\shdlst[i]\\billtype.getValue().equals($feqtp\\hislst[j]\\billtype.getValue()) &&
			  $feqtp\\feqgrp\\shdlst[i]\\billnewno.getValue().equals($feqtp\\hislst[j]\\billnewno.getValue()) &&
			  hissum.compareTo(sum)==0 &&
			  Platform.diff($feqgrp\\shdlst[i]\\zcfhnewdat.getValue(),$feqtp\\hislst[j]\\zcfhnewdat.getValue())==0)
			  {
			  $feqtp\\hislst.remove(j);
			  }
			  }
			  }*/
			
			

			return true;
        }

        /**
        *   source:feqapi.@0036.script
        */
        @Rule(target="feqtp.czview",order=100)
        public boolean ruleFeqtpCzviewN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = -1;
			int count = 0;
			for(int i = 0; i < this.getFeqtp().getGhmlst().fullSize(); i++)
			{
			  if("X".equals(this.getFeqtp().getGhmlst().getElement(i).getSelfs()))
			  {
			    index = i;
			    count++;
			  }
			}
			if(count > 1)
			{
			  ctx.setMessage("操作提示","不能同时查看多笔业务！");
			  return true;
			}
			if(index < 0 || index >= this.getFeqtp().getGhmlst().fullSize())
			{
			  index = 0;
			  if(index < 0 || index >= this.getFeqtp().getGhmlst().fullSize())
			  {
			    ctx.setMessage("操作提示","请选择一条要操作的记录！");
			    return true;
			  }
			}
			if(!"1".equals(this.getFeqtp().getGhmlst().getElement(index).getJytyp()))
			{
			  ctx.setMessage("提示","只能查看购汇交易！");
			  return true;
			}
			if(!"3".equals(this.getFeqtp().getGhmlst().getElement(index).getSta()))
			{
			  ctx.setMessage("提示","只能查看购汇状态是未名的交易！");
			  return true;
			}

			String businessno = this.getFeqtp().getGhmlst().getElement(index).getBusno();//购汇业务参考号
			MdaUtils.clear(this.getFeqgrp().getFqd());
			ctx.getDaoSession().dbRead(this.getFeqgrp().getFqd(),new Argument<String>("businessno", businessno));
			ctx.getErrorCode(); //清空errorCode,防止影响后边errorCode的取值
			if(MdaUtils.isEmpty(this.getFeqgrp().getFqd().getInr()))
			{
			  ctx.setMessage("提示","未查询到相关购汇申请数据！");
			  return false;
			}
			MdaUtils.clear(this.getFeqgrp().getRec());
			ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<String>("businessno", this.getFeqgrp().getFqd().getEdbusno()));
			ctx.getErrorCode(); //清空errorCode,防止影响后边errorCode的取值
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getInr()))
			{
			  ctx.setMessage("提示","未查询到相关购汇额度数据！");
			  return false;
			}
			BigDecimal bankmcje = this.getFeqgrp().getFqd().getBankmcje();//银行卖出金额
			BigDecimal paysum = this.getFeqgrp().getRec().getPaysum();//金额
			BigDecimal cansaleed = this.getFeqgrp().getRec().getCansaleed();//可购汇额度
			BigDecimal havesale = this.getFeqgrp().getRec().getHavesale();//累计购汇金额
			BigDecimal havegwfed = this.getFeqgrp().getRec().getHavegwfed();//已购未付金额
			BigDecimal havesaleNew = havesale.add(bankmcje);//累计购汇金额新
			BigDecimal havegwfedNew = havegwfed.add(bankmcje);//已购未付金额新
			BigDecimal cansaleedNew = paysum.subtract(havesaleNew);//可购汇额度新
			
			//获取要解锁的key
			String lockKey = "shs" + this.getFeqgrp().getRec().getInr();
			String lockName = "";
			String sql = "SELECT nam FROM lck where txt='" + lockKey + "'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			int err1 = ctx.getErrorCode();
			log.debug("{}","err1=" + err1);
			Argument<String> nam = new Argument<String>("nam");
			ctx.getDaoSession().dbFetchFields(nam);
			int err2 = ctx.getErrorCode();
			log.debug("{}","err2=" + err2);
			ctx.getDaoSession().dbCloseCursor();
			if(err2 == NO_ERROR)
			{
			  if(MdaUtils.isEmpty(nam.value))
			  {
			    ctx.setMessage("提示","该笔业务未锁定，无法解锁！");
			    return false;
			  }
			  lockName = nam.value;
			}
			else if(err2 == NO_MORE_ROW)
			{
			  ctx.setMessage("提示","该笔业务未锁定，无法解锁！");
			  return false;
			}
			else
			{
			  ctx.setMessage("提示","获取加锁记录异常，请联系管理员！");
			  return false;
			}
			this.getFeqgrp().getRec().setLockflag("1");
			//查证交易
			Map<String,String> czMap = new HashMap<String,String>();
			czMap = cZh9970();
			String retcod = czMap.get("retcod");
			String zhangt = czMap.get("zhangt");
			if("0000000".equals(retcod))
			{
			  try
			  {
			    ctx.getDaoSession().dbBegin();
			    if("0".equals(zhangt))
			    {
			      this.getFeqgrp().getFqd().setShjiayjg("0");//购汇申请交易结果
			      //更新购汇业务表
			      this.getFeqgrp().getFqd().setUpddat(MdaUtils.today());//修改日期
			      //插入登记簿明细表
			      this.getFeqgrp().getShm().setInr(Platform.sdbCounter("shm")); //主键
			      this.getFeqgrp().getShm().setEdbusno(this.getFeqgrp().getFqd().getEdbusno()); //自助购汇额度申请参考号
			      this.getFeqgrp().getShm().setGhbusno(this.getFeqgrp().getFqd().getBusinessno()); //购汇业务编号
			      this.getFeqgrp().getShm().setOpertype("1"); //操作类型
			      this.getFeqgrp().getShm().setPaysum(this.getFeqgrp().getRec().getPaysum()); //金额
			      this.getFeqgrp().getShm().setHavesalenew(bankmcje); //已购金额
			      this.getFeqgrp().getShm().setCansaleed(this.getFeqgrp().getRec().getCansaleed()); //可购汇额度(原金额)
			      this.getFeqgrp().getShm().setHavesale(this.getFeqgrp().getRec().getHavesale()); //已购金额(原金额)
			      this.getFeqgrp().getShm().setHavegwfed(this.getFeqgrp().getRec().getHavegwfed()); //已购未付金额(原金额)
			      this.getFeqgrp().getShm().setYifhje(this.getFeqgrp().getRec().getYifhje()); //已付汇金额(原金额)
			      this.getFeqgrp().getShm().setYijhje(this.getFeqgrp().getRec().getYijhje()); //已结汇金额(原金额)
			      this.getFeqgrp().getShm().setCusno(this.getFeqgrp().getFqd().getEcifno()); //客户号
			      this.getFeqgrp().getShm().setOperno(this.getFeqgrp().getFqd().getJio1gy()); //柜员号
			      this.getFeqgrp().getShm().setZhjnmc(this.getFeqgrp().getFqd().getZhjnmc()); //填报人
			      this.getFeqgrp().getShm().setReason("查证修改"); //修改原因
			      this.getFeqgrp().getShm().setCredat(MdaUtils.today()); //创建日期
			      //更新额度表
			      this.getFeqgrp().getRec().setUpddat(MdaUtils.today());
			      this.getFeqgrp().getRec().setCansaleed(cansaleedNew); //可购汇额度
			      this.getFeqgrp().getRec().setHavesale(havesaleNew); //累计购汇金额新
			      this.getFeqgrp().getRec().setHavegwfed(havegwfedNew); //已购未付金额
			      this.getFeqgrp().getRec().setDuifzh(this.getFeqgrp().getFqd().getDuifzh());
			      //交易成功   更新并解锁额度数据
			      ctx.getDaoSession().dbUpdate(this.getFeqgrp().getFqd());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","czview购汇业务表更新数据失败0");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbUpdate(this.getFeqgrp().getRec());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","czview购汇额度申请表更新数据失败0");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbInsert(this.getFeqgrp().getShm());
			      log.debug("{}","业务表入库");
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","czview登记簿明细表插入时数据库异常0");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbCommit();
			      log.debug("{}","-------dbCommit0---------");
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        log.error("{}","czview提交事务时数据库异常0");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        ctx.getDaoSession().dbRollback();
			        return false;
			      }
			      ctx.setMessage("提示","购汇交易查证结果：购汇成功!");
			      showlst(this.getFeqgrp().getFqd().getEdbusno(), this.getFeqtp().getJytyp());
			    }
			    else
			    {
			      this.getFeqgrp().getFqd().setShjiayjg("1");//购汇申请交易结果
			      //交易成功   更新并解锁额度数据
			      ctx.getDaoSession().dbUpdate(this.getFeqgrp().getFqd());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","czview购汇业务表更新数据失败1");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbUpdate(this.getFeqgrp().getRec());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","czview购汇额度申请表更新数据失败1");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbCommit();
			      log.debug("{}","-------dbCommit1---------");
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        log.error("{}","czview提交事务时数据库异常1");
			        ctx.setMessage("提示","数据库异常，请联系管理员！");
			        ctx.getDaoSession().dbRollback();
			        return false;
			      }
			      ctx.setMessage("提示","购汇交易查证结果：购汇失败!");
			      showlst(this.getFeqgrp().getFqd().getEdbusno(), this.getFeqtp().getJytyp());
			      return false;
			    }
			  }
			  finally
			  {
			    log.info("{}","手工查证交易结束，释放未解开的锁");
			    ctx.getLocker().unlock(lockName);
			  }
			}
			else
			{
			  //不修改数据，可继续手工发查证接口
			  log.debug("{}","查证接口调用失败");
			  ctx.setMessage("提示","查证接口调用失败，请重新查证");
			  return false;
			}

			return true;
        }

        /**
        *   source:feqapi.@0038.script
        */
        @Rule(target="feqtp.feqgrp.rec.salexz",order=100)
        public boolean ruleFeqtpFeqgrpRecSalexzN100(){
            IContext ctx = MdaEnv.getContext();
            
			//结售汇统计代码
			String valj = MdaUtils.getCodetableLabel("ldgj",this.getFeqgrp().getRec().getSalexz());
			if(!MdaUtils.isEmpty(valj))
			{
			  this.getFeqgrp().getRec().setJshno(NULLSTR);
			  MdaUtils.setValues(this.getFeqgrp().getRec(),"jshno",MdaUtils.getCodetable(valj));
			}
			this.getFeqgrp().getRec().setGjszsbnewno(NULLSTR);
			
			

			return true;
        }

        /**
        *   source:feqapi.@0039.script
        */
        @Rule(target="feqtp.feqgrp.rec.jshno",order=100)
        public boolean ruleFeqtpFeqgrpRecJshnoN100(){
            IContext ctx = MdaEnv.getContext();
            
			String val = MdaUtils.getCodetableLabel("dgml",this.getFeqgrp().getRec().getJshno());
			if(!MdaUtils.isEmpty(val))
			{
			  this.getFeqgrp().getRec().setGjszsbnewno(NULLSTR);
			  MdaUtils.setValues(this.getFeqgrp().getRec(),"gjszsbnewno",MdaUtils.getCodetable(val));
			}
			//拼接结售汇统计代码
			String old = this.getFeqgrp().getRec().getJieshtjnol();
			this.getFeqgrp().getRec().setJieshtjno(this.getFeqgrp().getRec().getJshno()+old.substring(3,5));
			

			return true;
        }

        /**
        *   source:feqapi.@0040.script
        */
        @Rule(target="feqtp.feqgrp.rec.whjno",order=100)
        public boolean ruleFeqtpFeqgrpRecWhjnoN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getJshno()))
			{
			  ctx.setFieldError(this,"feqgrp.rec.jshno","结售汇统计代码不能为空！");
			  return false;
			}
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getGjszsbnewno()))
			{
			  ctx.setFieldError(this,"feqgrp.rec.gjszsbnewno","国际收支申报交易编码不能为空！");
			  return false;
			}
			//如果结售汇统计代码是332或国际收支申报交易编码是226000，则外汇局批件号必填。
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getWhjno())
			  && ("332".equals(this.getFeqgrp().getRec().getJshno()) || "226000".equals(this.getFeqgrp().getRec().getGjszsbnewno())))
			{
			  ctx.setFieldError(this,"feqgrp.rec.whjno","外汇局批件号不能为空！");
			  return false;
			}

			return true;
        }

        /**
        *   source:feqapi.@0041.script
        */
        @Rule(target="feqtp.feqgrp.rec.gjszsbnewno",order=100)
        public boolean ruleFeqtpFeqgrpRecGjszsbnewnoN100(){
            IContext ctx = MdaEnv.getContext();
            
			//首先查询数据库中记录的值
			if("321000".equals(this.getFeqgrp().getRec().getGjszsbnewno()))
			{
			  this.getFeqgrp().getRec().setWhjno("N/A");
			  
			}
			else
			{
			  this.getFeqgrp().getRec().setWhjno(this.getFeqgrp().getRec().getWhjnol());
			  
			}
			

			return true;
        }



        /**
        *   source:feqapi.@0017.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			MdaUtils.clear(this.getFeqgrp().getFsqlst());
			String ptyinr=this.getSysmod().getPty().getInr();
			String ptytyp=ctx.absGet(Sysmod.class).getPty().getPtytyp();
			String cid = this.getSysmod().getUsr().getCid();
			List<CodetableItem> bchcod=this.getSysmod().getBranchList(this.getSysmod().getPty().getCid());
			MdaUtils.setValues(this.getFeqtp(),"ptynam",bchcod);
			ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("cid",cid));
			ctx.getErrorCode();
			/*if(!Platform.isEmpty(bchcod))
			  {
			  $feqtp\\ptynam.setValue(bchcod.get(0).getValue());
			  }*/
			//加载列表数据
			StringBuffer args=new StringBuffer();
			String sql = "SELECT m2.inr, m1.sta,m2.businessno,m2.ecifname,m2.currency,m2.paysum,m2.havesale,m2.cansaleed,m2.applydat,m2.zcghnewdat,m2.applystatus from trn m1,shs m2  WHERE m1.ownref = m2.businessno ";
			//w-待审核，。d-已完成，b-退回修改   
			//sql = sql + " AND m2.bchcod = '" + cid + "' ";
			sql = sql + " AND m1.sta in('w','d','b')";
			sql = sql + " AND m2.deleted = '0' ";
			/*机构隔离：
			  1.总行能查看、审批分行、支行的交易
			  2.分行能查看、审批本分行和本分行下支行的交易
			  3.支行能查看本支行下的交易
			  */
			//分行
			if("1".equals(this.getSysmod().getPty().getLvl()))
			{

			  sql = sql + " AND (m2.bchcod in (select cid from pty where pntinr=m2.bchcod) or m2.bchcod='" + cid + "')  ";
			}
			else if("2".equals(this.getSysmod().getPty().getLvl()))
			{
			  sql = sql + " AND m2.orginr = '" + this.getSysmod().getPty().getInr() + "' ";
			}
			sql = sql + " order by m2.applydat desc ";
			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getErrorCode();
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> sta = new Argument<String>("sta");
			Argument<String> businessno = new Argument<String>("businessno");
			Argument<String> ecifname = new Argument<String>("ecifname");
			Argument<String> currency = new Argument<String>("currency");
			Argument<BigDecimal> paysum = new Argument<BigDecimal>("paysum");
			Argument<BigDecimal> cansaleed = new Argument<BigDecimal>("cansaleed");
			Argument<BigDecimal> havesale = new Argument<BigDecimal>("havesale");
			Argument<Date> applydat = new Argument<Date>("applydat");
			Argument<Date> zcghnewdat = new Argument<Date>("zcghnewdat");
			Argument<String> applystatus = new Argument<String>("applystatus");

			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			    this.getFeqgrp().getFsqlst().add(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			for(int i=0;i<this.getFeqgrp().getFsqlst().fullSize();i++)
			{
			  this.getFeqgrp().getFsqlst().getElement(i).setSta(MdaUtils.getCodetableLabel("trnftaf",this.getFeqgrp().getFsqlst().getElement(i).getSta()));
			}
			

			return true;
        }


        /**
        *   source:feqapi.@0015.script
        */
        public void showDetailPanel(int index)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//加载数据
			loadMessage(this.getFeqgrp().getFsqlst().getElement(index).getBusinessno());
			
		}
        /**
        *   source:feqapi.@0016.script
        */
        public void loadMessage(String businessno)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getFeqgrp().getRec(),"bchcod",bchcod);
			//查询业务表数据回写模型
			//清空模型
			MdaUtils.clear(this.getFeqgrp().getRec());
			MdaUtils.clear(this.getTrnmod().getTrn());
			MdaUtils.clear(this.getTrnmod().getOrdmod().getOrd());
			MdaUtils.clear(this.getSysmod().getPty());
			MdaUtils.clear(this.getFeqgrp().getShdlst());
			//加载模型
			ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<Object>("businessno",businessno));
			ctx.getDaoSession().dbRead(this.getTrnmod().getTrn(),new Argument<Object>("ownref",businessno));
			ctx.getDaoSession().dbRead(this.getTrnmod().getOrdmod().getOrd(),new Argument("objinr",this.getFeqgrp().getRec().getInr()),new Argument("objtyp","shs"));
			ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("idc",this.getFeqgrp().getRec().getOrgcode()));
			ctx.getDaoSession().dbReadset(this.getFeqgrp().getShdlst(),new Argument("edbusno",businessno),new Argument("deleted","0"));
			ctx.getErrorCode();
			// 加载RMK
			this.loadRmk(this.getTrnmod().getOrdmod().getOrd().getInr());
			this.getFeqtp().setBhname(this.getFeqgrp().getRec().getOrgname());
			//设置不可编辑
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			//结汇操作时显示结汇申请书按钮，否则隐藏结汇申请书按钮
			if("1".equals(this.getFeqgrp().getRec().getJiehsign()))
			{
			  
			}
			else
			{
			  
			}
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()))
			{
			  this.getFeqtp().setBustyp("0");
			}
			else if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getEduflag()) && !"1".equals(this.getFeqgrp().getRec().getJiehsign()))
			{
			  this.getFeqtp().setBustyp(this.getFeqgrp().getRec().getEduflag());
			}
			else if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getJiehsign()))
			{
			  this.getFeqtp().setBustyp("3");
			}
			
			
		}
        /**
        *   source:feqapi.@0021.script
        */
        public void updateOrd(String ordinr,String ordsta,String action,String remark)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：更新ORD状态并新增ORE
			  * 参数：ordinr - 业务主键
			  *       ordsta - 订单更新状态
			  *       action - 更新订单状态变更的操作
			  *       remark - 操作员备注
			  */
			log.debug("{}","in updateOrd ...ordinr="+ordinr+",ordsta="+ordsta +",action="+ action+",remark="+ remark);
			ctx.getDaoSession().dbRead(this.getTrnmod().getOrdmod().getOrd(),new Argument("objinr",ordinr),new Argument("objtyp","shs"));
			ctx.getErrorCode();
			Date predattim = this.getTrnmod().getOrdmod().getOrd().getStadattim();
			String transname = ctx.getTransName();
			this.getTrnmod().getOrdmod().getOrd().setStadattim(new Date());
			this.getTrnmod().getOrdmod().getOrd().setSta(ordsta);
			this.getTrnmod().getOrdmod().getOrd().setOptptyinr(ctx.absGet(com.ceb.gjjs.mda.manager.module.Sysmod.class).getPty().getInr());
			if("D".equals(ordsta))
			{
			  this.getTrnmod().getOrdmod().getOrd().setCpldattim(MdaUtils.today());
			}
			ctx.getDaoSession().dbUpdate(this.getTrnmod().getOrdmod().getOrd());
			if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			{
			  ctx.getDaoSession().dbRollback();
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return;
			}
			log.info("{}","update ord OK!");
			this.getTrnmod().getOrdmod().getOre().setWaitim(MdaUtils.today().getTime() - predattim.getTime());
			this.getTrnmod().getOrdmod().getOre().setUsrinr( ctx.absGet(com.ceb.gjjs.mda.manager.module.Sysmod.class).getUsr().getInr());
			this.getTrnmod().getOrdmod().getOre().setTyp( this.getTrnmod().getOrdmod().getOrd().getSta());
			this.getTrnmod().getOrdmod().getOre().setTxt(remark);
			this.getTrnmod().getOrdmod().getOre().setPtyinr( ctx.absGet(com.ceb.gjjs.mda.manager.module.Sysmod.class).getUsr().getPtyinr());
			this.getTrnmod().getOrdmod().getOre().setOrdinr( this.getTrnmod().getOrdmod().getOrd().getInr());
			this.getTrnmod().getOrdmod().getOre().setFrm(transname);
			this.getTrnmod().getOrdmod().getOre().setBegdattim(predattim);
			this.getTrnmod().getOrdmod().getOre().setEnddattim(MdaUtils.today());
			this.getTrnmod().getOrdmod().getOre().setObjinr( this.getTrnmod().getOrdmod().getOrd().getObjinr());
			this.getTrnmod().getOrdmod().getOre().setObjtyp( this.getTrnmod().getOrdmod().getOrd().getObjtyp());
			this.getTrnmod().getOrdmod().getOre().setOprnam( ctx.absGet(com.ceb.gjjs.mda.manager.module.Sysmod.class).getUsr().getOprnam());
			this.getTrnmod().getOrdmod().getOre().setAction(action);
			String oreinr=Platform.sdbCounter("ore");
			log.info("{}"," Insert ore! oreinr = " + oreinr);
			this.getTrnmod().getOrdmod().getOre().setInr(oreinr);
			ctx.getDaoSession().dbInsert(this.getTrnmod().getOrdmod().getOre());
			if(ctx.getErrorCode()!= NO_ERROR && ctx.getErrorCode()!=0)
			{
			  ctx.getDaoSession().dbRollback();
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return;
			}
		}
        /**
        *   source:feqapi.@0023.script
        */
        public void refresh()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//1.清空数据
			//Platform.clear($feqtp\\sqbegdat);
			//Platform.clear($feqtp\\sqendbat);
			//Platform.clear($feqtp\\zcghbegdat);
			//Platform.clear($feqtp\\zcghenddat);
			//Platform.clear($feqtp\\applystatus);
			//Platform.clear($feqtp\\cur);
			//Platform.clear($feqtp\\orgname);
			MdaUtils.clear(this.getFeqtp().getFeqgrp().getFsqlst());
			String ptyinr=this.getSysmod().getPty().getInr();
			String cid = this.getSysmod().getUsr().getCid();
			Date sqbegdat=this.getFeqtp().getSqbegdat();
			Date sqenddat =this.getFeqtp().getSqendbat();
			Date zcghbegdat=this.getFeqtp().getZcghbegdat();
			Date zcghenddat =this.getFeqtp().getZcghenddat();
			String ptynam = this.getFeqtp().getPtynam();
			String cur = this.getFeqtp().getCur();
			String status = this.getFeqtp().getApplystatus();
			String busno = this.getFeqtp().getBusino();
			ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("cid",cid));
			ctx.getErrorCode();
			//加载列表数据
			StringBuffer args=new StringBuffer();
			String sql = "SELECT m2.inr, m1.sta,m2.businessno,m2.ecifname,m2.currency,m2.paysum,m2.havesale,m2.cansaleed,m2.applydat,m2.zcghnewdat,m2.applystatus from trn m1,shs m2  WHERE m1.ownref = m2.businessno ";
			//w-待审核，。d-已完成，b-退回修改
			/*机构隔离：
			  1.总行能查看、审批分行、支行的交易
			  2.分行能查看、审批本分行和本分行下支行的交易
			  3.支行能查看本支行下的交易
			  */
			//分行
			if("1".equals(this.getSysmod().getPty().getLvl()))
			{
			  sql = sql + " AND (m2.bchcod in (select cid from pty where pntinr=m2.bchcod) or m2.bchcod='" + cid + "')  ";
			}
			else if("2".equals(this.getSysmod().getPty().getLvl()))
			{
			  sql = sql + " AND m2.orginr = '" + this.getSysmod().getPty().getInr() + "' ";
			}

			//申请日期
			//申请起始日期不为空，申请结束日期为空
			if(!MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && MdaUtils.isEmpty(this.getFeqtp().getSqendbat()))
			{
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') >= '" + MdaUtils.format(sqbegdat,"yyyyMMdd") + "' ";
			}
			else if(MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getSqendbat()))//申请起始日期为空，申请结束日期不为空
			{
			  sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') <= '" + MdaUtils.format(sqenddat,"yyyyMMdd") + "' ";
			}
			else if(!MdaUtils.isEmpty(this.getFeqtp().getSqbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getSqendbat())
			  && MdaUtils.diff(this.getFeqtp().getSqendbat(),this.getFeqtp().getSqbegdat())>0)//申请起始日期不为空，申请结束日期不为空
			  {
			    sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') >= '" + MdaUtils.format(sqbegdat,"yyyyMMdd") + "' ";
			    sql = sql + " AND to_char(m2.applydat,'yyyyMMdd') <= '" + MdaUtils.format(sqenddat,"yyyyMMdd") + "' ";
			  }

			  //最迟购汇日期
			  //最迟购汇日期不为空，最迟购汇日期为空
			  if(!MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && MdaUtils.isEmpty(this.getFeqtp().getZcghenddat()))
			  {
			    sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') >= '" + MdaUtils.format(zcghbegdat,"yyyyMMdd") + "' ";
			  }
			  else if(MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getZcghenddat()))//最迟购汇起始日期为空，最迟购汇结束日期不为空
			  {
			    sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') <= '" + MdaUtils.format(zcghenddat,"yyyyMMdd") + "' ";
			  }
			  else if(!MdaUtils.isEmpty(this.getFeqtp().getZcghbegdat()) && !MdaUtils.isEmpty(this.getFeqtp().getZcghenddat())
			    && MdaUtils.diff(this.getFeqtp().getZcghenddat(),this.getFeqtp().getZcghbegdat())>0)//最迟购汇起始日期不为空，最迟购汇结束日期不为空
			    {
			      sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') >= '" + MdaUtils.format(zcghbegdat,"yyyyMMdd") + "' ";
			      sql = sql + " AND to_char(m2.zcghnewdat,'yyyyMMdd') <= '" + MdaUtils.format(zcghenddat,"yyyyMMdd") + "' ";
			    }
			    //申请状态  
			    if(!MdaUtils.isEmpty(this.getFeqtp().getApplystatus()) && !"all".equals(this.getFeqtp().getApplystatus()))
			    {
			      sql = sql + " AND m1.sta = '" + status + "' ";
			    }
			    else
			    {
			      sql = sql + " AND m1.sta in('w','d','b')";
			    }
			    //业务参考号
			    if(!MdaUtils.isEmpty(busno))
			    {
			      sql = sql + " AND m2.businessno = '" + busno.trim() + "' ";
			    }
			    //币种
			    if(!MdaUtils.isEmpty(this.getFeqtp().getCur()))
			    {
			      sql = sql + " AND m2.currency = '" + cur + "' ";
			    }
			    //申请类型
			    if(!"4".equals(this.getFeqtp().getApplytyp()) && !MdaUtils.isEmpty(this.getFeqtp().getApplytyp()))
			    {
			      sql = sql + " AND m2.applytyp = '" + this.getFeqtp().getApplytyp() + "' ";
			    }
			    //机构名称
			    if(!MdaUtils.isEmpty(ptynam))
			    {
			      //sql = sql + " AND m2.orgname like '%" + orgname + "%' ";
			      sql= sql+" AND m2.orginr = (SELECT inr FROM pty p WHERE p.inr='"+ptynam+"')";
			    }

			    sql = sql + " AND m2.deleted = '0' ";
			    sql = sql + " order by m2.applydat desc ";
			    ctx.getDaoSession().dbExecuteSQL(sql);
			    ctx.getErrorCode();
			    Argument<String> inr = new Argument<String>("inr");
			    Argument<String> sta = new Argument<String>("sta");
			    Argument<String> businessno = new Argument<String>("businessno");
			    Argument<String> currency = new Argument<String>("currency");
			    Argument<BigDecimal> paysum = new Argument<BigDecimal>("paysum");
			    Argument<BigDecimal> cansaleed = new Argument<BigDecimal>("cansaleed");
			    Argument<BigDecimal> havesale = new Argument<BigDecimal>("havesale");
			    Argument<Date> applydat = new Argument<Date>("applydat");
			    Argument<Date> zcghnewdat = new Argument<Date>("zcghnewdat");
			    Argument<String> applystatus = new Argument<String>("applystatus");
			    Argument<String> ecifname = new Argument<String>("ecifname");
			    while(true)
			    {
			      ctx.getDaoSession().dbFetchFields(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			      int errorCode = ctx.getErrorCode();
			      if(errorCode == NO_ERROR)
			        this.getFeqgrp().getFsqlst().add(inr,sta,businessno,ecifname,currency,paysum,cansaleed,havesale,applydat,zcghnewdat,applystatus);
			      else
			        break;
			    }
			    ctx.getDaoSession().dbCloseCursor();
			    for(int i=0;i<this.getFeqgrp().getFsqlst().fullSize();i++)
			    {
			      this.getFeqgrp().getFsqlst().getElement(i).setSta(MdaUtils.getCodetableLabel("trnftaf",this.getFeqgrp().getFsqlst().getElement(i).getSta()));
			    }
			    
			  		}
        /**
        *   source:feqapi.@0024.script
        */
        public void dormk(String ordinr,String trninr,String rvl)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//首先根据ordinr和trninr查下rmk，如果有数据则更新，如果没有则新增
			ctx.getDaoSession().dbRead(this.getRmkmod().getRmk(),new Argument<String>("ordinr",ordinr));
			//如果rmk为空，则做新增操作
			if(MdaUtils.isEmpty(this.getRmkmod().getRmk().getInr()))
			{
			  this.getRmkmod().setRmkMseeage(ordinr,trninr,"",rvl,"NEW");   //新增rmk
			}
			else
			{
			  this.getRmkmod().setRmkMseeage(ordinr,trninr,"",rvl,"OLD");   //更新rmk
			}

		}
        /**
        *   source:feqapi.@0025.script
        */
        public void loadRmk(String ordinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 根据订单号加载交易备注信息
			  */
			this.getRmkmod().setNtext(NULLSTR);
			this.getRmkmod().setOtext(NULLSTR);
			MdaUtils.clear(this.getRmkmod().getRmk());
			ctx.getDaoSession().dbRead(this.getRmkmod().getRmk(),new Argument<String>("ordinr",ordinr));
			ctx.getErrorCode();
			if(!MdaUtils.isEmpty(this.getRmkmod().getRmk().getInr()))
			{
			  this.getRmkmod().setOtext( this.getRmkmod().getRmk().getTxt());  // 处理历史备注信息
			  
			  
			}
		}
        /**
        *   source:feqapi.@0027.script
        */
        public String checkshs()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int lstsize=this.getFeqgrp().getShdlst().fullSize();
			//校验单据信息
			Date date=MdaUtils.parseDate(MdaUtils.format(MdaUtils.today(),"yyyyMMdd"),"yyyyMMdd");
			String message="";
			//校验最迟购汇日期不能早于当前系统时间
			if(MdaUtils.diff(this.getFeqgrp().getRec().getZcghnewdat(),date)<0)
			{
			  message ="最迟购汇日期不能早于当前日期";
			  return message;
			}
			for(int i=0;i<lstsize;i++)
			{
			  //判断单据编号非空
			  if(MdaUtils.isEmpty(this.getFeqgrp().getShdlst().getElement(i).getBillnewno()))
			  {
			    message ="单据编号不能为空";
			    break;
			  }
			  //判断单据编号长度
			  if(this.getFeqgrp().getShdlst().getElement(i).getBillnewno().length()>32)
			  {
			    message ="单据编号长度为32位";
			    break;
			  }
			  //如果修改了单据编号，则不能提交
			  if(!this.getFeqgrp().getShdlst().getElement(i).getBillnewno().equals(this.getFeqgrp().getShdlst().getElement(i).getBillno()))
			  {
			    message ="单据编号已修改不能提交，只能退回";
			    break;
			  }

			  //判断最迟付汇日期非空
			  if(MdaUtils.isEmpty(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat()))
			  {
			    message ="最迟付汇日期不能为空";
			    break;
			  }
			  //判断最迟付汇时间
			  if(MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhdat(),this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat())!=0)
			  {
			    if(MdaUtils.diff(this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat(),date)<0)
			    {
			      message ="最迟付汇日期不能早于当前日期";
			      break;
			    }
			  }
			  //判断最迟付汇日期是否修改，如果修改不能提交只能退回
			  if(!this.getFeqgrp().getShdlst().getElement(i).getZcfhnewdat().equals(this.getFeqgrp().getShdlst().getElement(i).getZcfhdat()))
			  {
			    message ="最迟付汇日期已修改不能提交，只能退回";
			    break;
			  }
			}
			if(!MdaUtils.isEmpty(message))
			{
			  return message;
			}
			//结售汇统计代码不能为空
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getJshno()))
			{
			  message="结售汇统计代码不能为空！";
			  return message;
			}
			//国际收支申报交易编码不能为空
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getGjszsbnewno()))
			{
			  message="国际收支申报交易编码不能为空！";
			  return message;
			}
			//判断购汇性质是否修改，如果修改不能提交只能退回
			if(!this.getFeqgrp().getRec().getSalexzl().equals(this.getFeqgrp().getRec().getSalexz()))
			{
			  message="购汇性质已修改不能提交，只能退回";
			  return message;
			}
			//判断结售汇统计代码是否修改，如果修改不能提交只能退回
			String str = (this.getFeqgrp().getRec().getJieshtjnol()).substring(0,3);
			if(!str.equals(this.getFeqgrp().getRec().getJshno()))
			{
			  message="结售汇统计代码已修改不能提交，只能退回";
			  return message;
			}

			//判断国际收支申报交易编码是否修改，如果修改不能提交只能退回
			if(!this.getFeqgrp().getRec().getGjszsbno().equals(this.getFeqgrp().getRec().getGjszsbnewno()))
			{
			  message="国际收支申报交易编码已修改不能提交，只能退回";
			  return message;
			}

			//判断外汇局批件号是否修改，如果修改不能提交只能退回
			if(!MdaUtils.isEmpty(this.getFeqgrp().getRec().getWhjnol()) && !this.getFeqgrp().getRec().getWhjnol().equals(this.getFeqgrp().getRec().getWhjno()))
			{
			  message="外汇局批件号已修改不能提交，只能退回";
			  return message;
			}
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getWhjnol()) && !MdaUtils.isEmpty(this.getFeqgrp().getRec().getWhjno()))
			{
			  message="外汇局批件号已修改不能提交，只能退回";
			  return message;
			}
			if(MdaUtils.isEmpty(this.getFeqgrp().getRec().getPaytype()))
			{
			  message="付汇方式不能为空！";
			  return message;
			}
			if(!this.getFeqgrp().getRec().getPaytypel().equals(this.getFeqgrp().getRec().getPaytype()))
			{
			  message="付汇方式已修改不能提交，只能退回";
			  return message;
			}
			return message;
		}
        /**
        *   source:feqapi.@0031.script
        */
        public void showlst(String businessno,String typ)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getFeqtp().getGhmlst());
			String sql="";
			if(!MdaUtils.isEmpty(typ) && !"0".equals(typ))
			{
			  //1--加载购汇列表数据
			  if("1".equals(typ))
			  {
			    sql = "select inr,businessno as busno,'1' as jytyp,shjiayjg as sta,credat,bankmcje as amount from fqd where edbusno='"+businessno+"' ";
			  }
			  else if("3".equals(typ))//3--加载人工列表数据
			  {
			    sql = "select inr,edbusno as busno,opertype as jytyp,'0' as sta,credat,havegwfednew as amount from shm where opertype='3' and edbusno='"+businessno+"' ";
			  }
			  else if("4".equals(typ))//4--加载结汇列表数据
			  {
			    sql = "select inr,jhbusno as busno,opertype as jytyp,'0' as sta,credat,yijhjenew as amount from shm where opertype='4' and edbusno='"+businessno+"' ";
			  }
			  else//2--汇出汇款付汇5--信用证付款6--托收付款7-线下汇出汇款8-线下信用证付款9-线下托收付款
			  {
			    sql = "select inr,fjbusno as busno,opertype as jytyp,'0' as sta,credat,yifhjenew as amount from shm where opertype='"+typ+"' and edbusno='"+businessno+"'  ";
			  }

			}
			else
			{
			  sql = "select inr,businessno as busno,'1' as jytyp,shjiayjg as sta,credat,bankmcje as amount from fqd where edbusno='"+businessno+"'";
			  sql += "union all select inr,edbusno as busno,opertype as jytyp,'0' as sta,credat,havegwfednew as amount from shm where opertype='3' and  edbusno='"+businessno+"' ";
			  sql += "union all select inr,jhbusno as busno,opertype as jytyp,'0' as sta,credat,yijhjenew as amount from shm where opertype='4' and  edbusno='"+businessno+"'  ";
			  sql += "union all select inr,fjbusno as busno,opertype as jytyp,'0' as sta,credat,yifhjenew as amount from shm where opertype in ('2','5','6','7','8','9') and  edbusno='"+businessno+"' ";

			}
			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getErrorCode();
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> sta = new Argument<String>("sta");
			Argument<String> busno = new Argument<String>("busno");
			Argument<String> jytyp = new Argument<String>("jytyp");
			Argument<Date> credat = new Argument<Date>("credat");
			Argument<BigDecimal> amount = new Argument<BigDecimal>("amount");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,sta,sta,busno,jytyp,credat,amount);
			  if(ctx.getErrorCode() == NO_ERROR)
			    this.getFeqtp().getGhmlst().add(inr,sta,sta,busno,jytyp,credat,amount);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			ctx.getErrorCode();
			
			
		}
        /**
        *   source:feqapi.@0033.script
        */
        public void showmxdetail(String inr,String jytyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//1-购汇
			if("1".equals(jytyp))
			{
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getFqd(),new Argument<String>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<String>("businessno",this.getFeqgrp().getFqd().getEdbusno()));
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getFeqgrp().getFqd().setCurrency("RMB");
			  
			  this.getFeqgrp().getFqd().setMcbiz(MdaUtils.getCodetableLabel("ghhbdm",this.getFeqgrp().getFqd().getMcbiz()));
			  
			}
			//2-付汇
			if("2".equals(jytyp))
			{
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getShm(),new Argument<Object>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getCpd(),new Argument<String>("ownref",this.getFeqgrp().getShm().getFjbusno()));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<String>("businessno",this.getFeqgrp().getCpd().getWyghedno()));
			  this.getFeqtp().setBhname(this.getFeqgrp().getRec().getOrgname());
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			}
			//3-人工
			if("3".equals(jytyp))
			{
			  //查询业务表数据回写模型
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getShm(),new Argument<String>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<Object>("businessno",this.getFeqgrp().getShm().getEdbusno()));
			  ctx.getDaoSession().dbRead(this.getSysmod().getPty(),new Argument<String>("idc",this.getFeqgrp().getRec().getOrgcode()));
			  this.getFeqtp().setBhname(this.getSysmod().getPty().getNam());
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			}
			// 4-结汇
			if("4".equals(jytyp))
			{
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getShm(),new Argument<Object>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<Object>("businessno",this.getFeqgrp().getShm().getEdbusno()));
			  loadMessage(this.getFeqgrp().getRec().getBusinessno());
			  
			}
			//信用证付款
			if("5".equals(jytyp))
			{
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getShm(),new Argument<Object>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqtp().getFeqgrp().getBrd(),new Argument<Object>("ownref",this.getFeqgrp().getShm().getFjbusno()));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<Object>("businessno",this.getFeqtp().getFeqgrp().getBrd().getWyghedno()));
			  this.getFeqtp().setOprtyp("付款");
			  this.getFeqgrp().getAfd().setCredat(this.getFeqgrp().getBrd().getAdvdat());
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			}
			//托收付款
			if("6".equals(jytyp))
			{
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getShm(),new Argument<Object>("inr",inr));
			  ctx.getDaoSession().dbRead(this.getFeqtp().getFeqgrp().getBcd(),new Argument<Object>("ownref",this.getFeqgrp().getShm().getFjbusno()));
			  ctx.getDaoSession().dbRead(this.getFeqgrp().getRec(),new Argument<Object>("businessno",this.getFeqtp().getFeqgrp().getBcd().getWyghedno()));
			  this.getFeqtp().setOprtyp("付款");
			  this.getFeqgrp().getAfd().setCredat(this.getFeqgrp().getBcd().getRcvdat());
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			}
		}
        /**
        *   source:feqapi.@0037.script
        */
        public Map<String,String> cZh9970()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String cls="com.brilliance.eibs.main.Client";
			Map<String,String> map = new HashMap<String,String>();
			log.debug("{}","人工调用查证接口ynjyrq=" + this.getFeqgrp().getFqd().getYnjyrq() + "qantls=" + this.getFeqgrp().getFqd().getQantls());
			//调用查证接口再判断交易是否成功
			Object czRtnVal = MdaUtils.invoke(cls,"scall","9970","9970",new Object[]{this.getFeqgrp().getFqd().getYnjyrq(),this.getFeqgrp().getFqd().getQantls()});
			Map czRtnMsg = (Map)MdaUtils.invoke(czRtnVal,"getContent");
			String errcod = (String)czRtnMsg.get("ERRCOD");
			String zhangt = (String)czRtnMsg.get("RESULT");
			String errmsg = (String)czRtnMsg.get("ERRMSG");
			log.debug("{}","errcod=" + errcod + "zhangt=" + zhangt);
			if("0000000".equals(errcod))
			{
			  if("0".equals(zhangt))
			  {
			    map.put("retcod", "0000000"); //响应码
			    map.put("zhangt", "0"); //原交易结果
			    map.put("errmsg", "");
			    return map;
			  }
			  else
			  {
			    map.put("retcod", "0000000");
			    map.put("zhangt", "2");
			    map.put("errmsg", "");
			    return map;
			  }
			}
			else
			{
			  log.error("{}",czRtnMsg.get("ERRMSG"));
			  map.put("retcod", errcod);
			  map.put("zhangt", "");
			  map.put("errmsg", errmsg);
			  return map;
			}
		}








}