package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.FftcfmVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Fsdgrp;
import com.ceb.gjjs.mda.manager.module.Fstp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Spt;
import com.ceb.gjjs.mda.manager.module.Bedgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 福费廷申请报价表制作
*/
@Transaction(vo= FftcfmVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Fftcfm extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Fftcfm.class);

        //承兑行标志
        private String acbflg;
        //付款行标志
        private String payflg;
        //保兑行标志
        private String conflg;
        //保付行标志
        private String accflg;
        //原币标志
        private String oriflg;
        //结汇标志
        private String soeflg;
		@BDGetter
		private Fsdgrp fsdgrp;

		@BDGetter
		private Bedgrp bedgrp;

		@BDGetter
		private Fstp fstp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Spt wrkspt;


		public Fftcfm()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getFstp().setFsdgrpHolder(()->this.getFsdgrp());
           this.getFstp().setBedgrpHolder(()->this.getBedgrp());
           this.getMtabut().setRecHolder(()->this.getFsdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("FF"));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.fincur");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setFincur(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getFincur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.finamt");}
 				public void setValue(BigDecimal arg){Fftcfm.this.getFsdgrp().getRec().setFinamt(arg);}
 				public BigDecimal getValue(){return Fftcfm.this.getFsdgrp().getRec().getFinamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.ownref");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.bchcod");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.inr");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setInr(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.ptyinr");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Fftcfm.this.getFieldPath("fsdgrp.rec.stlref");}
 				public void setValue(String arg){Fftcfm.this.getFsdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Fftcfm.this.getFsdgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:fftcfm.@0007.script
        */
        @Rule(target="fstp.sqspdf",order=100)
        public boolean ruleFstpSqspdfN100(){
            IContext ctx = MdaEnv.getContext();
            
			String pdfName = "" ;
			// 非信用证
			if("2".equals(this.getFsdgrp().getRec().getFsddocflg()))
			{
			  pdfName = "fftapn1" ;
			}
			else
			{
			  // 信用证
			  pdfName ="fftapn";
			}
			this.getFstp().getPdfviw().callPDFComponent("",pdfName,"福费廷业务申请书",0);

			return true;
        }

        /**
        *   source:fftcfm.@0008.script
        */
        @Rule(target="fstp.bjbpdf",order=100)
        public boolean ruleFstpBjbpdfN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getFstp().getPdfviw().callPDFComponent("","yhbjb","福费廷银行报价表",0);

			return true;
        }

        /**
        *   source:fftcfm.@0015.script
        */
        @Rule(target="mtabut.bnkcfm",order=200)
        public boolean ruleMtabutBnkcfmN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","在matbut模块bnkcfm按钮order[200].......");
			if(!( ctx.checkAll(this.getFsdgrp().getRec())))
			{
			  ctx.setMessage(MdaUtils.getI18NString("fftcfm","CT000004"),MdaUtils.getI18NString("fftcfm","CT000005"));
			  return false;
			}
			ctx.getDaoSession().dbUpdate(this.getFsdgrp().getRec());
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.debug("{}","filename is "+filename);
			//获得当前显示步骤条所对应的面板
			IPanel[] panels=this.getFstp().getStpmod().getAllPanelsName();
			ctx.saveDisplay(filename);
			//保存trn
			ctx.absGet(Trnmod.class).setTrnForSecondConfirm();
			// 更新SPT记录
			String trnnam = ctx.getTransName();
			String sptinr = (String)ctx.restoreData("com.brilliance."+trnnam+".trnsrv");
			log.debug("{}","sptinr =" + sptinr);
			ctx.getDaoSession().dbRead(this.getWrkspt(),new Argument<String>("inr",sptinr));
			this.getWrkspt().setSta("D");
			this.getWrkspt().setNxtreq("");
			ctx.getDaoSession().dbUpdate(this.getWrkspt());

			return true;
        }



        /**
        *   source:fftcfm.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			// 根据前手的交易传入inr关联FSD BED 和角色
			//bchcod应该是前手 但是时间应该是今天
			readModAndPts();
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  ctx.absGet(Trnmod.class).ordNew();
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return false;
			this.getFsdgrp().getRec().setCredat(MdaUtils.today());
			

			return true;
        }


        /**
        *   source:fftcfm.@0005.script
        */
        public void readModAndPts()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String inr = (String)ctx.restoreData("com.brilliance.fftapn.inr");
			log.info("{}","com.brilliance.fftapn.inr======="+inr);
			ctx.getDaoSession().dbRead(this.getFsdgrp().getRec(),new Argument<String>("inr", EQ, inr));
			String pntinr = this.getFsdgrp().getRec().getPntinr();
			log.info("{}","pntinr.value======="+pntinr);
			ctx.getDaoSession().dbRead(this.getBedgrp().getRec(),new Argument<String>("inr", EQ, pntinr));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getIsb().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","isb"));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getAcb().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","acb"));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getDap().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","dap"));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getCon().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","con"));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getPay().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","pay"));
			ctx.getDaoSession().dbRead(this.getFsdgrp().getAcc().getPts(),new Argument<String>("objinr",this.getFsdgrp().getRec().getInr()),new Argument<String>("objtyp","lid"),new Argument<String>("rol","acc"));

		}
        /**
        *   source:fftcfm.@0014.script
        */
        public void flags()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(!MdaUtils.isEmpty(this.getFsdgrp().getAcb().getPts().getAdrblk()))
			{
			  this.setAcbflg("√");
			}
			else
			{
			  this.setAcbflg(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getFsdgrp().getCon().getPts().getAdrblk()))
			{
			  this.setConflg("√");
			}
			else
			{
			  this.setConflg(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getFsdgrp().getPay().getPts().getAdrblk()))
			{
			  this.setPayflg("√");
			}
			else
			{
			  this.setPayflg(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getFsdgrp().getAcc().getPts().getAdrblk()))
			{
			  this.setAccflg("√");
			}
			else
			{
			  this.setAccflg(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getFsdgrp().getRec().getOrigno()))
			{
			  this.setOriflg("√");
			}
			else
			{
			  this.setOriflg(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getFsdgrp().getRec().getSoexno()))
			{
			  this.setSoeflg("√");
			}
			else
			{
			  this.setOriflg(NULLSTR);
			}
		}















}