package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.FytopnVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Fytp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Fydgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 福费廷总协议签订
*/
@Transaction(vo= FytopnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Fytopn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Fytopn.class);

		@BDGetter
		private Fydgrp fydgrp;

		@BDGetter
		private Fytp fytp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Rmkmod rmkmod;


		public Fytopn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getFytp().setFydgrpHolder(()->this.getFydgrp());
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new BigDecimal("0")));
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Fytopn.this.getFieldPath("fydgrp.rec.inr");}
 				public void setValue(String arg){Fytopn.this.getFydgrp().getRec().setInr(arg);}
 				public String getValue(){return Fytopn.this.getFydgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Fytopn.this.getFieldPath("fydgrp.rec.ptyinr");}
 				public void setValue(String arg){Fytopn.this.getFydgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Fytopn.this.getFydgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Fytopn.this.getFieldPath("fydgrp.rec.ownref");}
 				public void setValue(String arg){Fytopn.this.getFydgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Fytopn.this.getFydgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Fytopn.this.getFieldPath("fydgrp.rec.bchcod");}
 				public void setValue(String arg){Fytopn.this.getFydgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Fytopn.this.getFydgrp().getRec().getBchcod();}}
			 );
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("FY"));
           this.getMtabut().setRecHolder(()->this.getFydgrp().getRec());
        }

        /**
        *   source:fytopn.@0006.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            

			log.info("{}","业务处理开始，编号200");
			this.getMtabut().getBusmod().dealFile();
			if(!ctx.checkAll(this.getFydgrp()))
			{
			  log.debug("{}","fytopn start,page check error!");
			  return false;
			}
			//保存协议的PTYINR
			this.getFydgrp().getRec().setPtyinr(this.getSysmod().getPty().getInr());
			//更新操作
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  ctx.getDaoSession().dbUpdate(this.getFydgrp().getRec());
			  String objinr = this.getFydgrp().getRec().getInr();
			}
			//插入操作
			else
			{
			  this.getFydgrp().getRec().setInr(Platform.sdbCounter("fyd"));
			  log.debug("{}","---------fydgrp--rec--inr-------------"+this.getFydgrp().getRec().getInr());
			  this.getFydgrp().getRec().setCredat(MdaUtils.today());
			  ctx.getDaoSession().dbInsert(this.getFydgrp().getRec());
			}
			//保存TRN
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","zul文件已经生成，文件名："+filename);
			ctx.saveDisplay(filename);
			log.info("{}","业务处理结束，编号200");


			return true;
        }

        /**
        *   source:fytopn.@0012.script
        */
        @Rule(target="fytp.xypdf",order=100)
        public boolean ruleFytpXypdfN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getFytp().getPdfviw().callPDFComponent("","fytxy","福费廷协议",1);

			return true;
        }

        /**
        *   source:fytopn.@0016.script
        */
        @Rule(target="fytp.stpmod.next",order=50)
        public boolean ruleFytpStpmodNextN50(){
            IContext ctx = MdaEnv.getContext();
            

			int panelidx=this.getFytp().getStpmod().getPanelidx();
			log.debug("{}","当前面板索引panelidx="+panelidx);
			switch(panelidx)
			{
			  case 0:
			  return ctx.checkAll(this.getFydgrp().getRec()) ;
			}
			log.debug("{}","next Order[50] 执行完毕");


			return true;
        }


        /**
        *   source:fytopn.@0015.script
        */
        @Check(target="fytp.fydgrp.rec.rcvnum",order=100)
        public boolean checkFytpFydgrpRecRcvnumN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(  MdaUtils.isEmpty(this.getFydgrp().getRec().getRcvnum()) && MdaUtils.isEmpty(this.getFydgrp().getRec().getFaxnum())&& MdaUtils.isEmpty(this.getFydgrp().getRec().getWecnum())
			  && MdaUtils.isEmpty(this.getFydgrp().getRec().getEmails()) && MdaUtils.isEmpty(this.getFydgrp().getRec().getQqsnum()) )
			{
			  ctx.setFieldError(this,"fytp.fydgrp.rec.rcvnum",MdaUtils.getI18NString("fytopn","CT000055"));
			  return false;
			}

			return true;
        }


        /**
        *   source:fytopn.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			
			
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getFydgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getFydgrp().getRec().setBchcod(bchcod.get(0).getValue());
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			  return true;

			//定义步骤条
			this.getFytp().getStpmod().storePanel(this.getFytp().getFytopn02(),this.getFytp().getFytopn08());
			String steps = "0:福费廷协议;1:合同展示";
			this.getFytp().getStpmod().setPages(steps);
			this.getFytp().getStpmod().calcSteps();
			this.getFytp().getStpmod().setStepBtnSta();

			return true;
        }









}