package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.GitcxmVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Cxmgrp;
import com.ceb.gjjs.mda.manager.module.Cxmmod;
import com.ceb.gjjs.mda.manager.module.Cxmp;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 保函查询
*/
@Transaction(vo= GitcxmVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Gitcxm extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Gitcxm.class);

		@BDGetter
		private Cxmgrp cxmgrp;

		@BDGetter
		private Cxmmod cxmmod;

		@BDGetter
		private Cxmp cxmp;

		@BDGetter
		private Sysmod sysmod;


		public Gitcxm()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getCxmmod().setCxmgrpHolder(()->this.getCxmgrp());
           this.getCxmp().setCxmgrpHolder(()->this.getCxmgrp());
        }

        /**
        *   source:gitcxm.@0002.script
        */
        @Rule(target="cxmp.serachs",order=100)
        public boolean ruleCxmpSerachsN100(){
            IContext ctx = MdaEnv.getContext();
            
			refrush();

			return true;
        }

        /**
        *   source:gitcxm.@0003.script
        */
        @Rule(target="cxmp.frush",order=100)
        public boolean ruleCxmpFrushN100(){
            IContext ctx = MdaEnv.getContext();
            
			refrush();

			return true;
        }

        /**
        *   source:gitcxm.@0004.script
        */
        @Rule(target="cxmp.download",order=100)
        public boolean ruleCxmpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream is=this.getCxmp().getDownload();
			is.setType("xls");
			is.setName(MdaUtils.format(MdaUtils.today(),"yyyyMMdd")+"_baohan.xls");

			List<Object[]>list=new ArrayList<Object[]>();
			String []tit=new String[10];
			tit[0] = "保函编号";
			tit[1] = "保函查询码";
			tit[2] = "客户号";
			tit[3] = "查询次数";
			//tit[3] = "是否可查";
			tit[4] = "保函币种";
			tit[5] = "保函金额";
			tit[6] = "开立日期";
			tit[7] = "效期";
			tit[8] = "被保证人";
			tit[9] = "受益人";
			list.add(tit);
			int len=this.getCxmgrp().getCxmlst().fullSize();
			log.debug("{}","数据条数：  "+len);
			for(int i=0;i<len;i++)
			{
			  String []lins=new String[10];
			  lins[0]=this.getCxmgrp().getCxmlst().getElement(i).getOwnref();
			  lins[1]=this.getCxmgrp().getCxmlst().getElement(i).getQuycod();
			  lins[2]=this.getCxmgrp().getCxmlst().getElement(i).getCid();
			  lins[3]=this.getCxmgrp().getCxmlst().getElement(i).getSearchtimes().toString();
			  //lins[3]=Platform.getCodetableLabel("cxmflg",$cxmgrp\\cxmlst[i]\\cxmflg.getValue());
			  lins[4]=this.getCxmgrp().getCxmlst().getElement(i).getCur();

			  if(MdaUtils.isEmpty(this.getCxmgrp().getCxmlst().getElement(i).getAmt()))
			    lins[5] ="0.00";
			  else
			    lins[5] = MdaUtils.format(this.getCxmgrp().getCxmlst().getElement(i).getAmt(),"##0.00");

			  if(!MdaUtils.isEmpty(this.getCxmgrp().getCxmlst().getElement(i).getOpndat()))
			    lins[6]=MdaUtils.format(this.getCxmgrp().getCxmlst().getElement(i).getOpndat(),"yyyy-MM-dd");
			  else
			    lins[6]="";

			  if(!MdaUtils.isEmpty(this.getCxmgrp().getCxmlst().getElement(i).getExpdat()))
			    lins[7]=MdaUtils.format(this.getCxmgrp().getCxmlst().getElement(i).getExpdat(),"yyyy-MM-dd");
			  else
			    lins[7]="";

			  lins[8]=this.getCxmgrp().getCxmlst().getElement(i).getWarran();
			  lins[9]=this.getCxmgrp().getCxmlst().getElement(i).getBenefi();
			  list.add(lins);
			}
			MdaUtils.unloadExcel(list,is,false);


			return true;
        }



        /**
        *   source:gitcxm.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getCxmp().setStadat(MdaUtils.add(MdaUtils.today(),-7));
			this.getCxmp().setStodat(MdaUtils.today());
			
			
			refrush();

			return true;
        }


        /**
        *   source:gitcxm.@0000.script
        */
        public void refrush()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			Date sta=this.getCxmp().getStadat();
			Date sto=this.getCxmp().getStodat();
			if(MdaUtils.isEmpty(sta) || MdaUtils.isEmpty(sto))
			{
			  if(MdaUtils.isEmpty(sta))
			    ctx.setFieldError(this,"cxmp.stadat",MdaUtils.getI18NString("gitcxm","CT000027"));
			  else
			    ctx.setFieldError(this,"cxmp.stodat",MdaUtils.getI18NString("gitcxm","CT000028"));
			  return ;
			}

			MdaUtils.clear(this.getCxmgrp().getCxmlst());

			String sql="SELECT INR,QUYCOD,OWNREF,CUR,AMT,OPNDAT,EXPDAT,WARRAN,BENEFI,SEARCHTIMES,CID FROM GIDCXM WHERE OPNDAT>=? AND OPNDAT<=?";

			sql=sql+" and cxmflg='Y' ORDER BY OPNDAT DESC";
			Argument<String> inr=new Argument<String>("inr");
			Argument<String> ownref = new Argument<String>("ownref");
			Argument<String>quycod=new Argument<String>("quycod");
			Argument<String> cur= new Argument<String>("cur");
			Argument<BigDecimal> amt=new Argument<BigDecimal>("amt");
			Argument<Date> opndat= new Argument<Date>("opndat");
			Argument<Date> expdat=new Argument<Date>("expdat");
			Argument<String> warran= new Argument<String>("warran");
			Argument<String> benefi= new Argument<String>("benefi");
			//Argument<String> cxmflg= new Argument<String>("cxmflg");
			Argument<Integer> searchtimes=new Argument<Integer>("searchtimes");
			Argument<String> cid=new Argument<String>("cid");

			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getCxmp().getStadat(),GT),MdaUtils.sqlDate(this.getCxmp().getStodat(),LT));
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,ownref,quycod,cur,amt,opndat,expdat,warran,benefi,searchtimes,cid);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getCxmgrp().getCxmlst().add(inr,ownref,quycod,cur,amt,opndat,expdat,warran,benefi,searchtimes,cid);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			//log.debug("cnt   值1："+cnt);
			

		}





}