package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.HyfqueVO;

import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Hyfp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Hyfgrp;
import com.ceb.gjjs.mda.manager.module.Hyfmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 海运费详细查询
*/
@Transaction(vo= HyfqueVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Hyfque extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Hyfque.class);

		@BDGetter
		private Hyfgrp hyfgrp;

		@BDGetter
		private Hyfmod hyfmod;

		@BDGetter
		private Hyfp hyfp;

		@BDGetter
		private Sysmod sysmod;


		public Hyfque()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getHyfmod().setHyfgrpHolder(()->this.getHyfgrp());
           this.getHyfp().setHyfgrpHolder(()->this.getHyfgrp());
        }

        /**
        *   source:hyfque.@0000.script
        */
        @Rule(target="hyfp.search",order=100)
        public boolean ruleHyfpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			Date stadat = this.getHyfp().getStadat();
			Date enddat = this.getHyfp().getEnddat();
			if(MdaUtils.isEmpty(stadat) || MdaUtils.isEmpty(enddat))
			{
			  if(MdaUtils.isEmpty(stadat))
			    ctx.setFieldError(this,"hyfp.stadat",MdaUtils.getI18NString("hyfque","CT000000"));
			  else
			    ctx.setFieldError(this,"hyfp.enddat",MdaUtils.getI18NString("hyfque","CT000001"));
			  return true;
			}
			if(MdaUtils.diff(stadat,enddat)>0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("hyfque","CT000002"),MdaUtils.getI18NString("hyfque","CT000003"));
			  return true;
			}
			refresh();


			return true;
        }

        /**
        *   source:hyfque.@0002.script
        */
        @Rule(target="hyfp.download",order=100)
        public boolean ruleHyfpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream is=this.getHyfp().getDownload();
			is.setType("xls");
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[16];
			tit[0] = "参考号";
			tit[1] = "交易时间";
			tit[2] = "银行业务编码";
			tit[3] = "汇款人名称";
			tit[4] = "收款人名称";
			tit[5] = "汇款币种";
			tit[6] = "汇款金额";
			// tit[7] = "折美元金额";
			//tit[8] = "购汇汇率";
			tit[7] = "购汇金额";
			tit[8] = "现汇金额";
			tit[9] = "收款人常驻国家或地区代码";
			tit[10] = "交易编码1";
			tit[11] = "相关金额1";
			tit[12] = "交易编码2";
			tit[13] = "相关金额2";
			tit[14] = "分行名称";
			tit[15] = "支行名称";
			lst.add(tit);
			int len = this.getHyfgrp().getHyflst().fullSize();
			log.debug("{}","len="+len);
			for(int i=0;i<len;i++)
			{
			  log.debug("{}",""+i);
			  String[] line = new String[16];

			  line[0] = this.getHyfgrp().getHyflst().getElement(i).getOwnref();
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getCredat()))
			    line[1] ="";
			  else
			    line[1] = MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getCredat(),"yyyyMMdd");
			  line[2] = this.getHyfgrp().getHyflst().getElement(i).getStlref();
			  line[3] = this.getHyfgrp().getHyflst().getElement(i).getPaynam();
			  line[4] = this.getHyfgrp().getHyflst().getElement(i).getPayeenameapp();
			  line[5] = this.getHyfgrp().getHyflst().getElement(i).getRemcur();
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getRemamt()))
			    line[6]="0.00";
			  else
			    line[6] =MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getRemamt(),"##0.00");
			  /* if(Platform.isEmpty($hyfgrp\\hyflst[i]\\gfrmat))
			    line[7]="0.00";
			    else
			    line[7] =Platform.format($hyfgrp\\hyflst[i]\\gfrmat.getValue(),"##0.00");
			    if(Platform.isEmpty($hyfgrp\\hyflst[i]\\rat))
			    line[8]="0.00";
			    else
			    line[8] =Platform.format($hyfgrp\\hyflst[i]\\rat.getValue(),"##0.00");
			    */
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getPuramt()))
			    line[7]="0.00";
			  else
			    line[7] =MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getPuramt(),"##0.00");
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getFxamt()))
			    line[8]="0.00";
			  else
			    line[8] =MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getFxamt(),"##0.00");
			  line[9] = this.getHyfgrp().getHyflst().getElement(i).getCountryname();
			  line[10] = MdaUtils.getCodetableLabel("bopcod",this.getHyfgrp().getHyflst().getElement(i).getBopcod1());
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getBopamt1()))
			    line[11]="0.00";
			  else
			    line[11] = MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getBopamt1(),"##0.00");
			  line[12] = MdaUtils.getCodetableLabel("bopcod",this.getHyfgrp().getHyflst().getElement(i).getBopcod2());
			  if(MdaUtils.isEmpty(this.getHyfgrp().getHyflst().getElement(i).getBopamt2()))
			    line[13]="0.00";
			  else
			    line[13] = MdaUtils.format(this.getHyfgrp().getHyflst().getElement(i).getBopamt2(),"##0.00");
			  line[14] = this.getHyfgrp().getHyflst().getElement(i).getBrhnam();
			  line[15] = this.getHyfgrp().getHyflst().getElement(i).getSbrhnam();
			  lst.add(line);
			}
			String today = MdaUtils.format(MdaUtils.today(),"yyyyMMdd-HH:mm:ss");
			String fileName = "海运费记录"+today+".xls";
			is.setName(fileName);
			log.debug("{}","lst "+lst.size());
			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }



        /**
        *   source:hyfque.@0003.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			//银行机构
			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  List<CodetableItem> bchtyp = new ArrayList<CodetableItem>();
			  //String lvl = $sysmod\\pty\\brhlvl.getValue();
			  String lvl = this.getSysmod().getPty().getLvl();
			  if("0".equals(lvl))
			  {
			    bchtyp.add(new CodetableItem("全行","0"));
			    bchtyp.add(new CodetableItem("分行","1"));
			    this.getHyfp().setBrhtyp("0");
			  }
			  else if("1".equals(lvl))
			  {
			    bchtyp.add(new CodetableItem("分行","1"));
			    this.getHyfp().setBrhtyp("1");
			  }
			  else
			  {
			    this.getHyfp().setBrhtyp("2");
			  }
			  bchtyp.add(new CodetableItem("支行","2"));
			  

			  MdaUtils.setValues(this.getHyfp(),"brhtyp",bchtyp);
			  //载入机构
			  List<CodetableItem> bchcod=this.getSysmod().getBranchList(this.getSysmod().getPty().getCid());
			  MdaUtils.setValues(this.getHyfp(),"orgnam",bchcod);
			  if(!MdaUtils.isEmpty(bchcod))
			    this.getHyfp().setOrgnam(bchcod.get(0).getValue());

			  

			}
			else
			{

			  

			}

			this.getHyfp().setStadat(MdaUtils.add(MdaUtils.today(),-7));
			this.getHyfp().setEnddat(MdaUtils.today());

			
			
			
			refresh();

			return true;
        }


        /**
        *   source:hyfque.@0001.script
        */
        public void refresh()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getHyfgrp().getHyflst());

			String sql="SELECT t.ownref ,c.credat ,t.stlref ,c.paynam ,c.payeenameapp ,c.remcur ," ;
			sql=sql+"c.remamt ,c.puramt ,c.fxamt ,c.countryname,c.bopcod1 ,c.bopamt1 ,c.bopcod2 ,c.bopamt2 ,py.brhnam ,py.sbrhnam ";
			sql=sql+"from trn t,cpd c,(select pty.cid,";
			sql=sql+" CASE 	WHEN pty.brhlvl='1' THEN pty.nam 	ELSE null  END as brhnam,";
			sql=sql+" CASE 	WHEN pty.brhlvl='2' THEN pty.nam ELSE null  END as sbrhnam from pty";
			sql=sql+" where pty.ptytyp='0')  py";
			sql=sql+" where t.objinr=c.inr and t.objtyp='cpd' and t.inifrm='cpthyf'and c.bchcod=py.cid";
			sql=sql+" AND credat>=? AND credat<=?";
			sql=sql+getBankSql();
			sql=sql+" order by credat desc";

			Argument<String> ownref=new Argument<String>("ownref");
			Argument<Date> credat=new Argument<Date>("credat");
			Argument<String> stlref=new Argument<String>("stlref");
			Argument<String> paynam=new Argument<String>("paynam");
			Argument<String> payeenameapp=new Argument<String>("payeenameapp");
			Argument<String> remcur=new Argument<String>("remcur");
			Argument<BigDecimal> remamt=new Argument<BigDecimal>("remamt");
			//Argument<BigDecimal> gfrmat=new Argument<BigDecimal>("gfrmat");
			//Argument<BigDecimal> rat=new Argument<BigDecimal>("rat");
			Argument<BigDecimal> puramt=new Argument<BigDecimal>("puramt");
			Argument<BigDecimal> fxamt=new Argument<BigDecimal>("fxamt");
			Argument<String> countryname=new Argument<String>("countryname");
			Argument<String> bopcod1=new Argument<String>("bopcod1");
			Argument<BigDecimal> bopamt1=new Argument<BigDecimal>("bopamt1");
			Argument<String> bopcod2=new Argument<String>("bopcod2");
			Argument<BigDecimal> bopamt2=new Argument<BigDecimal>("bopamt2");
			Argument<String> brhnam=new Argument<String>("brhnam");
			Argument<String> sbrhnam=new Argument<String>("sbrhnam");

			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getHyfp().getStadat(),GT),MdaUtils.sqlDate(this.getHyfp().getEnddat(),LT));
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(ownref,credat,stlref,paynam,payeenameapp,remcur,remamt,puramt,fxamt,countryname,bopcod1,bopamt1,bopcod2,bopamt2,brhnam,sbrhnam);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getHyfgrp().getHyflst().add(ownref,credat,stlref,paynam,payeenameapp,remcur,remamt,puramt,fxamt,countryname,bopcod1,bopamt1,bopcod2,bopamt2,brhnam,sbrhnam);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:hyfque.@0005.script
        */
        public String getBankSql()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 企业端不用此类查询条件
			if(!"0".equals(this.getSysmod().getPty().getPtytyp()))
			  return "";

			String pinr="";
			if(!MdaUtils.isEmpty(this.getHyfp().getOrgnam()))
			{
			  pinr=this.getHyfp().getOrgnam();
			  log.debug("{}","orgnam  值:"+pinr);
			}
			else
			  pinr=this.getSysmod().getPty().getInr();

			String cid=this.getSysmod().getCidByInr(pinr);
			String lvl = this.getSysmod().getTransLevel(cid);
			String sql = "";
			// 拼装银行机构查询条件
			// 总行查全部,分行查自己和其下属，支行查自己
			if("0".equals(lvl))
			{
			  sql=sql+" AND EXISTS (SELECT inr FROM pty WHERE t.optptyinr=inr or t.optptyinr='"+pinr+"')";
			}
			else if("1".equals(lvl))
			{
			  sql=sql+" AND EXISTS (SELECT inr FROM pty WHERE t.optptyinr=inr and (inr='"+pinr+"' or pntinr='"+cid+"'))";//or optptyinr='"+ptyinr+"'))";
			}
			else
			{
			  sql=sql+" AND t.optptyinr='"+pinr+"'";
			}

			return sql;
		}





}