package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.IrfopnVO;

import com.ceb.gjjs.mda.manager.module.Aptmod;
import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Aptp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Apdgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口代付申请(一级客户对我行)
*/
@Transaction(vo= IrfopnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Irfopn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Irfopn.class);

		@BDGetter
		private Apdgrp apdgrp;

		@BDGetter
		private Aptmod aptmod;

		@BDGetter
		private Aptp aptp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Irfopn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAptmod().setApdgrpHolder(()->this.getApdgrp());
           this.getAptp().setApdgrpHolder(()->this.getApdgrp());
           this.getMtabut().setRecHolder(()->this.getApdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("IF"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.payamt");}
 				public void setValue(BigDecimal arg){Irfopn.this.getApdgrp().getRec().setPayamt(arg);}
 				public BigDecimal getValue(){return Irfopn.this.getApdgrp().getRec().getPayamt();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.bchcod");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.paycur");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setPaycur(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getPaycur();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.inr");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setInr(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.ownref");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.ptyinr");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn.this.getFieldPath("apdgrp.rec.stlref");}
 				public void setValue(String arg){Irfopn.this.getApdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Irfopn.this.getApdgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:irfopn.@0001.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","sav200开始================");
			this.getApdgrp().getRec().setStlref(this.getApdgrp().getRec().getPntref());
			if(!ctx.checkAll(this.getApdgrp()))
			  return false;
			//
			this.dealPDFData();

			//
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  ctx.getDaoSession().dbUpdate(this.getApdgrp().getRec());
			}
			else
			{
			  this.getApdgrp().getRec().setInr(Platform.sdbCounter("apd"));
			  ctx.getDaoSession().dbInsert(this.getApdgrp().getRec());
			  String objinr=this.getApdgrp().getRec().getInr();
			  this.getApdgrp().getDap().getPts().setInr(Platform.sdbCounter("pts"));
			  this.getApdgrp().getDap().getPts().setObjinr(objinr);
			  this.getApdgrp().getDap().getPts().setObjtyp("apd");
			  ctx.getDaoSession().dbInsert(this.getApdgrp().getDap().getPts());
			  log.info("{}", "sav200入库结束================" );
			}
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);
			log.info("{}", "sav200结束================");

			return true;
        }

        /**
        *   source:irfopn.@0002.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.dealPDFData();
			String fintyp=this.getApdgrp().getRec().getFintyp();
			IStream stream=this.getMtabut().getApldoc();

			if("2".equals(fintyp))
			{
			  ctx.absGet(Sysmod.class).generatorPdf("","irfopn2",stream,false );
			}
			else if("3".equals(fintyp))
			{
			  ctx.absGet(Sysmod.class).generatorPdf("","irfopn3",stream,false );
			}
			else
			{
			  //默认申请书为信用证
			  ctx.absGet(Sysmod.class).generatorPdf("","irfopn",stream,false );
			}

			return true;
        }

        /**
        *   source:irfopn.@0003.script
        */
        @Rule(target="apdgrp.rec.fintyp",order=100)
        public boolean ruleApdgrpRecFintypN100(){
            IContext ctx = MdaEnv.getContext();
            
			changeFintyp();

			return true;
        }

        /**
        *   source:irfopn.@0006.script
        */
        @Rule(target="aptp.consel",order=100)
        public boolean ruleAptpConselN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getAptp().getTmplst());
			this.getAptp().setPntref(this.getApdgrp().getRec().getPntref());
			

			return true;
        }

        /**
        *   source:irfopn.@0007.script
        */
        @Rule(target="aptp.queryref",order=100)
        public boolean ruleAptpQueryrefN100(){
            IContext ctx = MdaEnv.getContext();
            
			String fintyp = this.getAptp().getFintyp();
			String pntref = this.getAptp().getPntref();
			String queryClause = null;
			//String queryLid ="SELECT s.objtyp nam, rec.inr trsinr,rec.stlref ref,rec.isscur cur,rec.issamt amt,rec.opndat dat ,substr(s.adrblk,0,35) bennam FROM lid rec,pts s WHERE  s.rol = 'ben' AND s.objtyp = 'lid' and s.objinr =rec.inr";
			String queryBrd  ="SELECT s.objtyp nam, rec.inr trsinr,rec.stlref ref,rec.advcur cur,rec.advamt amt,rec.advdat dat ,substr(s.adrblk,0,35) bennam FROM brd rec,pts s WHERE  s.rol = 'ben' AND s.objtyp = 'brd' and s.objinr =rec.inr and rec.stlref not like '%RB%'";
			String queryBcd ="SELECT s.objtyp nam, rec.inr trsinr,rec.stlref ref,rec.doccur cur,rec.docamt amt,rec.rcvdat dat ,substr(s.adrblk,0,35) bennam FROM bcd rec,pts s WHERE  s.rol = 'drr' AND s.objtyp = 'bcd' and s.objinr =rec.inr";
			String queryCpd ="SELECT s.objtyp nam, rec.inr trsinr,rec.stlref ref,rec.remcur cur,rec.remamt amt,rec.opndat dat ,substr(s.adrblk,0,35) bennam FROM cpd rec,pts s WHERE  s.rol = 'ben' AND s.objtyp = 'cpd' and s.objinr =rec.inr";
			if("1".equals(fintyp))
			{
			  //信用证下代付业务
			  queryClause=queryBrd;
			  //queryClause=queryLid;
			}
			else if("2".equals(fintyp))
			{
			  //代收下代付业务
			  queryClause=queryBcd;

			}
			else if("3".equals(fintyp))
			{
			  //汇出汇款项下进口代付业务
			  queryClause=queryCpd;

			}
			else
			{
			  ctx.setMessage("",MdaUtils.getI18NString("irfopn","CT000035"));
			  return true;
			}
			queryClause=queryClause+ctx.absGet(Sysmod.class).getSelection();
			if(!MdaUtils.isEmpty(pntref))
			{
			  queryClause = queryClause + " AND rec.stlref LIKE '%" + pntref.toUpperCase() + "%'";
			}
			if(queryClause.contains("rec.opndat"))
			  queryClause = queryClause + " order by rec.opndat desc ";
			else if(queryClause.contains("rec.rcvdat"))
			  queryClause = queryClause + " order by rec.rcvdat desc ";
			MdaUtils.clear(this.getAptp().getTmplst());

			ctx.getDaoSession().dbExecuteSQL(queryClause);
			int tmp = ctx.getErrorCode();
			log.info("{}","最终执行的queryClause语句==========" + queryClause);

			Argument<String> trsinr = new Argument<String>("trsinr");
			Argument<String> ref = new Argument<String>("ref");
			Argument<Date> dat = new Argument<Date>("dat");
			Argument<String> cur = new Argument<String>("cur");
			Argument<BigDecimal> amt = new Argument<BigDecimal>("amt");
			Argument<String> bennam = new Argument<String>("bennam");
			//表名
			Argument<String> nam = new Argument<String>("nam");

			while(true)
			{

			  ctx.getDaoSession().dbFetchFields(nam,trsinr,ref,dat,cur,amt,bennam);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getAptp().getTmplst().add(nam,trsinr,ref,dat,cur,amt,bennam);
			  }
			  else if(errorCode == ERROR_SQL)
			  {
			    break;
			  }
			  else
			  {
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			/*
			  if($tmplst.fullSize() == 0)
			  {
			  return;
			  }
			  */
			


			return true;
        }

        /**
        *   source:irfopn.@0008.script
        */
        @Rule(target="aptp.chance",order=100)
        public boolean ruleAptpChanceN100(){
            IContext ctx = MdaEnv.getContext();
            
			//int index=$mdllst.getSelectedRowIndex();
			String fintyp =this.getAptp().getFintyp();
			int index=-1;
			index=0;
			log.info("{}","index="+index);

			if("3".equals(fintyp))
			{
			  this.getApdgrp().getRec().setFintyp("3");
			  this.getApdgrp().getRec().setPntref(NULLSTR);
			  this.getApdgrp().getRec().setAmt(new BigDecimal(0));
			  this.getApdgrp().getRec().setCur(NULLSTR);
			  
			  
			  
			  
			  
			  return true;
			}

			if(index!=-1)
			{
			  String ref =this.getAptp().getTmplst().getElement(index).getRef();
			  String tableName=this.getAptp().getTmplst().getElement(index).getNam();
			  this.getApdgrp().getRec().setAmt(this.getAptp().getTmplst().getElement(index).getAmt());
			  this.getApdgrp().getRec().setCur(this.getAptp().getTmplst().getElement(index).getCur());
			  this.getApdgrp().getRec().setPntref(ref);
			  this.getApdgrp().getRec().setFintyp(fintyp);
			  log.debug("{}","change image  amt======"+this.getApdgrp().getRec().getAmt()+"pntref======="+this.getApdgrp().getRec().getPntref()+"fintyp====="+this.getApdgrp().getRec().getFintyp());
			  
			  
			  
			  
			  

			}
			else
			{
			  ctx.setMessage("",MdaUtils.getI18NString("irfopn","CT000025"));
			}

			return true;
        }

        /**
        *   source:irfopn.@0009.script
        */
        @Rule(target="aptp.tmplst",order=100)
        public boolean ruleAptpTmplstN100(){
            IContext ctx = MdaEnv.getContext();
            
			//int index=$mdllst.getSelectedRowIndex();
			int index=-1;
			index=0;
			String fintyp =this.getAptp().getFintyp();
			log.info("{}","index="+index);
			if(index!=-1)
			{
			  String ref =this.getAptp().getTmplst().getElement(index).getRef();
			  String tableName=this.getAptp().getTmplst().getElement(index).getNam();
			  String tableName1=null;
			  if("1".equals(fintyp))
			  {
			    tableName1="brd";
			  }
			  else if("2".equals(fintyp))
			  {
			    tableName1="bcd";

			  }
			  else if("3".equals(fintyp))
			  {
			    tableName1="cpd";

			  }
			  else
			  {
			    ctx.setMessage("",MdaUtils.getI18NString("irfopn","CT000032"));
			    return true;
			  }
			  if(tableName1.equals(tableName))
			  {

			    this.getApdgrp().getRec().setPntref(ref);
			    this.getApdgrp().getRec().setFintyp(fintyp);
			    this.getApdgrp().getRec().setAmt(this.getAptp().getTmplst().getElement(index).getAmt());
			    this.getApdgrp().getRec().setCur(this.getAptp().getTmplst().getElement(index).getCur());
			    
			    
			    
			    
			    
			  }
			  else
			  {
			    ctx.setMessage("",MdaUtils.getI18NString("irfopn","CT000048"));
			  }
			}
			else
			{
			  ctx.setMessage("",MdaUtils.getI18NString("irfopn","CT000049"));
			}

			return true;
        }

        /**
        *   source:irfopn.@0010.script
        */
        @Rule(target="aptp.fintyp",order=100)
        public boolean ruleAptpFintypN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getApdgrp().getRec().setAmt(new BigDecimal(0));
			this.getApdgrp().getRec().setCur(NULLSTR);
			MdaUtils.clear(this.getAptp().getTmplst());
			this.getAptp().setPntref(NULLSTR);
			
			
			String fintyp =this.getAptp().getFintyp();
			log.debug("{}","fintyp========="+fintyp);
			if("3".equals(fintyp))
			{
			  
			  

			  
			  
			  
			  
			  
			  
			  
			  this.getApdgrp().getRec().setDoctypcod(NULLSTR);
			  this.getApdgrp().getRec().setExpdat(null);
			  
			  
			  

			}
			else if("2".equals(fintyp))
			{
			  
			  
			  this.getApdgrp().getRec().setExpdat(null);
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  

			}
			else
			{
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getApdgrp().getRec().setDoctypcod(NULLSTR);
			  
			  
			  

			}

			return true;
        }


        /**
        *   source:irfopn.@0011.script
        */
        @Check(target="aptp.apdgrp.rec.matdat",order=100)
        public boolean checkAptpApdgrpRecMatdatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getApdgrp().getRec().getOpndat()) && !MdaUtils.isEmpty(this.getApdgrp().getRec().getMatdat()))
			{
			  if(MdaUtils.diff(this.getApdgrp().getRec().getOpndat(),this.getApdgrp().getRec().getMatdat())>0)
			  {
			    ctx.setFieldError(this,"apdgrp.rec.matdat",MdaUtils.getI18NString("irfopn","CT000062"));
			  }
			}

			return true;
        }

        /**
        *   source:irfopn.@0013.script
        */
        @Check(target="aptp.apdgrp.rec.fintyp",order=100)
        public boolean checkAptpApdgrpRecFintypN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getApdgrp().getRec().getFintyp()))
			{
			  ctx.setFieldError(this,"apdgrp.rec.fintyp",MdaUtils.getI18NString("irfopn","CT000063"));
			}

			return true;
        }

        /**
        *   source:irfopn.@0014.script
        */
        @Check(target="apdgrp.rec.finrat",order=100)
        public boolean checkApdgrpRecFinratN100(){
            IContext ctx = MdaEnv.getContext();
            
			// $sysmod.checkNumericField($yxygrp\\rec\\yhll,5);
			BigDecimal amt = this.getApdgrp().getRec().getFinrat();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.00000"));
			this.getApdgrp().getRec().setFinrat(amt);
			

			return true;
        }

        /**
        *   source:irfopn.@0015.script
        */
        @Check(target="apdgrp.rec.amt",order=100)
        public boolean checkApdgrpRecAmtN100(){
            IContext ctx = MdaEnv.getContext();
            
			// $sysmod.checkNumericField($yxygrp\\rec\\yhll,5);
			BigDecimal amt = this.getApdgrp().getRec().getAmt();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.00"));
			this.getApdgrp().getRec().setAmt(amt);
			

			return true;
        }

        /**
        *   source:irfopn.@0016.script
        */
        @Check(target="apdgrp.rec.payamt",order=100)
        public boolean checkApdgrpRecPayamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			BigDecimal amt = this.getApdgrp().getRec().getPayamt();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.00"));
			this.getApdgrp().getRec().setPayamt(amt);
			

			return true;
        }


        /**
        *   source:irfopn.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getApdgrp().setAplnam(this.getSysmod().getPty().getNam());
			
			
			
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getApdgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getApdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return false;
			this.getApdgrp().getRec().setCredat(MdaUtils.today());
			this.getApdgrp().getRec().setCur("USD");
			this.getApdgrp().getRec().setPaycur("USD");
			this.getApdgrp().getRec().setFintyp("1");
			
			this.getApdgrp().getRec().setFintyp(NULLSTR);
			/*
			  Object o = Platform.restoreData("com.brilliance.irtopn.ref");
			  String ref = "";
			  if(Platform.isEmpty(o))
			  {
			  ref = $\\sysmod.getRefrence("IF");
			  $apdgrp\\rec\\ownref.setValue(ref);
			  Platform.storeData("com.brilliance.irfopn.ref",ref);
			  }
			  else
			  {
			  $apdgrp\\rec\\ownref.setValue(o.toString());
			  }
			  */
			this.getAptp().getIrfcnd().setClstyp("irfopn");
			if(MdaUtils.isEmpty(this.getApdgrp().getRec().getIrfcnd()))
			{
			  //Platform.dbRead($aptp\\irfcnd\\cls,new Argument<String>("flg","3"),new Argument<String>("typ","irfopn"),new Argument<String>("status","0"));
			  ctx.getDaoSession().dbRead(this.getAptp().getIrfcnd().getCls(),new Argument<String>("inr",this.getAptp().getIrfcnd().readDefaultClsInr("irfopn")));
			  this.getApdgrp().getRec().setIrfcnd(this.getAptp().getIrfcnd().getCls().getClstxt());
			}

			return true;
        }

        /**
        *   source:irfopn.@0005.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			changeFintyp();

			return true;
        }


        /**
        *   source:irfopn.@0004.script
        */
        public void changeFintyp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String fintyp = this.getApdgrp().getRec().getFintyp();
			if("1".equals(fintyp))
			{//信用证项下
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getApdgrp().getRec().setDoctypcod(NULLSTR);

			  
			  
			  
			  
			}
			else if("2".equals(fintyp))
			{//代收项下
			  
			  
			  
			  
			  
			  
			  
			  

			  
			  
			  
			  
			}
			else if("3".equals(fintyp))
			{//汇出汇款项下
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getApdgrp().getRec().setDoctypcod(NULLSTR);
			  this.getApdgrp().getRec().setExpdat(null);

			  
			  
			  
			  
			}
		}
        /**
        *   source:irfopn.@0017.script
        */
        public void dealPDFData()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String ref=this.getApdgrp().getRec().getRef();
			String cur=this.getApdgrp().getRec().getCur();
			String amt=this.getApdgrp().getRec().getAmt().toString();
			String expdat=MdaUtils.format(this.getApdgrp().getRec().getExpdat(),"yyyyMMdd");
			String paycur=this.getApdgrp().getRec().getPaycur();
			String payamt=this.getApdgrp().getRec().getPayamt().toString();
			String payexpdat=this.getApdgrp().getRec().getPayexpdat().toString();
			String fintyp=this.getApdgrp().getRec().getFintyp();
			String doctypcod=this.getApdgrp().getRec().getDoctypcod();
			String typ="";
			if("1".equals(fintyp))
			{
			  if(!MdaUtils.isEmpty(ref)&&!MdaUtils.isEmpty(expdat))
			  {
			    typ="信用证项下进口代付业务，信用证号为"+ref+
			      "信用证金额为 " +cur+""+amt+ "，到单付款日期为"+expdat +
			      "，申请代付金额为"+paycur+""+payamt+" ,申请代付期限为"+payexpdat+"天。";
			  }
			}
			if("2".equals(fintyp))
			{
			  if(!MdaUtils.isEmpty(ref))
			  {
			    typ="代收项下进口代付业务，发票号为"+ref+
			      "到单金额为 " +cur+""+amt+ "，交单方式为"+doctypcod +
			      "，申请代付金额为"+paycur+""+payamt+"  ,申请代付期限为"+payexpdat+"天。";
			  }
			}
			if("3".equals(fintyp))
			{
			  if(!MdaUtils.isEmpty(ref))
			  {
			    typ="汇出汇款项下进口代付业务，发票号为"+ref+
			      "汇出金额为 " +cur+""+amt+ "，申请代付金额为"+paycur+""+payamt+"  ,申请代付期限为"+payexpdat+"天。";
			  }
			}

			//获取被代理行名称
			this.getApdgrp().getRec().setApldoc(typ);
		}








}