package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.Irfopn1VO;

import com.ceb.gjjs.mda.manager.module.Aptmod;
import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Aptp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Apdgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口代付申请(二级客户对一级客户)
*/
@Transaction(vo= Irfopn1VO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Irfopn1 extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Irfopn1.class);

		@BDGetter
		private Apdgrp apdgrp;

		@BDGetter
		private Aptmod aptmod;

		@BDGetter
		private Aptp aptp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Irfopn1()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAptmod().setApdgrpHolder(()->this.getApdgrp());
           this.getAptp().setApdgrpHolder(()->this.getApdgrp());
           this.getMtabut().setRecHolder(()->this.getApdgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("IF"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.payamt");}
 				public void setValue(BigDecimal arg){Irfopn1.this.getApdgrp().getRec().setPayamt(arg);}
 				public BigDecimal getValue(){return Irfopn1.this.getApdgrp().getRec().getPayamt();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.paycur");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setPaycur(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getPaycur();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.bchcod");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.inr");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setInr(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.ownref");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.ptyinr");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Irfopn1.this.getFieldPath("apdgrp.rec.stlref");}
 				public void setValue(String arg){Irfopn1.this.getApdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Irfopn1.this.getApdgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:irfopn1.@0001.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getApdgrp()))
			  return false;
			this.getApdgrp().getRec().setInr(Platform.sdbCounter("apd"));
			ctx.getDaoSession().dbInsert(this.getApdgrp().getRec());
			String objinr=this.getApdgrp().getDap().getPts().getInr();
			this.getApdgrp().getDap().getPts().setInr(Platform.sdbCounter("pts"));
			this.getApdgrp().getDap().getPts().setObjinr(objinr);
			this.getApdgrp().getDap().getPts().setObjtyp("apd");
			ctx.getDaoSession().dbInsert(this.getApdgrp().getDap().getPts());
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:irfopn1.@0002.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream stream=this.getMtabut().getApldoc();
			ctx.absGet(Sysmod.class).generatorPdf("","irfopn1",stream,false );

			return true;
        }



        /**
        *   source:irfopn1.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			{
			  this.getTrnmod().ordNew();
			}
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return true;
			else
			{
			  this.getApdgrp().getRec().setCredat(MdaUtils.today());
			  this.getApdgrp().getRec().setCur("USD");
			  this.getApdgrp().getRec().setPaycur("USD");
			  List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			  MdaUtils.setValues(this.getApdgrp().getRec(),"bchcod",bchcod);
			  if(!MdaUtils.isEmpty(bchcod))
			    this.getApdgrp().getRec().setBchcod(bchcod.get(0).getValue());
			  /*
			    Object o = Platform.restoreData("com.brilliance.irtopn1.ref");
			    String ref = "";
			    if(Platform.isEmpty(o))
			    {
			    ref = $\\sysmod.getRefrence("IF");
			    $apdgrp\\rec\\ownref.setValue(ref);
			    Platform.storeData("com.brilliance.irfopn1.ref",ref);
			    }
			    else
			    {
			    $apdgrp\\rec\\ownref.setValue(o.toString());
			    }
			    */
			}

			return true;
        }










}