package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.JstpayVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Jsdgrp;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Jstmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Jstp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 远期结售汇提前部分交割申请
*/
@Transaction(vo= JstpayVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Jstpay extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Jstpay.class);

		@BDGetter
		private Jsdgrp jsdgrp;

		@BDGetter
		private Jstmod jstmod;

		@BDGetter
		private Jstp jstp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Jstpay()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getJstmod().setJsdgrpHolder(()->this.getJsdgrp());
           this.getJstp().setJsdgrpHolder(()->this.getJsdgrp());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("JS"));
           this.getMtabut().setRecHolder(()->this.getJsdgrp().getRec());
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.cur");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setCur(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getCur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.sompayamt");}
 				public void setValue(BigDecimal arg){Jstpay.this.getJsdgrp().getRec().setSompayamt(arg);}
 				public BigDecimal getValue(){return Jstpay.this.getJsdgrp().getRec().getSompayamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.ownref");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.bchcod");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.inr");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setInr(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.ptyinr");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Jstpay.this.getFieldPath("jsdgrp.rec.stlref");}
 				public void setValue(String arg){Jstpay.this.getJsdgrp().getRec().setStlref(arg);}
 				public String getValue(){return Jstpay.this.getJsdgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:jstpay.@0001.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","业务处理开始，编号200");
			if(!ctx.checkAll(this.getJsdgrp()))
			{
			  log.warn("{}","申请页面校验未通过，退出");
			  return false;
			}

			BigDecimal amt = this.getJsdgrp().getRec().getSombuyamt();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.00"));
			this.getJsdgrp().getRec().setSombuyamt(amt);

			BigDecimal amt1 = this.getJsdgrp().getRec().getSomselamt();
			amt1 = MdaUtils.parseDecimal(MdaUtils.format(amt1,"#0.00"));
			this.getJsdgrp().getRec().setSomselamt(amt1);

			this.getJsdgrp().getRec().setPaysta("1");
			ctx.getDaoSession().dbUpdate(this.getJsdgrp().getRec());

			if(!this.getTrnmod().trnSetFromContract()) return false;
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);
			//Platform.saveDisplay($cptp\\cptp01,filename);
			log.info("{}", "sav200结束================" );


			return true;
        }

        /**
        *   source:jstpay.@0002.script
        */
        @Rule(target="jsdgrp.rec.sfltyp",order=100)
        public boolean ruleJsdgrpRecSfltypN100(){
            IContext ctx = MdaEnv.getContext();
            
			if("1".equals(this.getJsdgrp().getRec().getSfltyp()))
			{
			  
			  this.getJsdgrp().getRec().setSomselamt(new BigDecimal(0));
			  

			  
			  
			}
			else if("0".equals(this.getJsdgrp().getRec().getSfltyp()))
			{
			  
			  this.getJsdgrp().getRec().setSombuyamt(new BigDecimal(0));
			  

			  
			  
			}
			else
			{
			  
			  this.getJsdgrp().getRec().setSombuyamt(new BigDecimal(0));
			  

			  
			  this.getJsdgrp().getRec().setSomselamt(new BigDecimal(0));
			  
			}

			
			

			return true;
        }

        /**
        *   source:jstpay.@0003.script
        */
        @Rule(target="mtabut.apldocs",order=100)
        public boolean ruleMtabutApldocsN100(){
            IContext ctx = MdaEnv.getContext();
            
			BigDecimal amt = this.getJsdgrp().getRec().getSombuyamt();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.00"));
			this.getJsdgrp().getRec().setSombuyamt(amt);
			

			BigDecimal amt1 = this.getJsdgrp().getRec().getSomselamt();
			amt1 = MdaUtils.parseDecimal(MdaUtils.format(amt1,"#0.00"));
			this.getJsdgrp().getRec().setSomselamt(amt1);
			

			//$jstp\\pdfviw.callPDFComponent("","jstpay","远期外汇买卖分批交割申请书",1);
			this.getJstp().getPdfviw().callPDFComponent("","jstpay1","远期结售汇分批交割申请书",1);

			return true;
        }

        /**
        *   source:jstpay.@0004.script
        */
        @Rule(target="mtabut.sav",order=210)
        public boolean ruleMtabutSavN210(){
            IContext ctx = MdaEnv.getContext();
            
			int cnt = 1;
			String labels = "远期结售汇分批交割申请书";
			String tempfiles = "A:jstpay1";

			this.getTrnmod().getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().getApldoc().generatorAllPDF();

			return true;
        }

        /**
        *   source:jstpay.@0007.script
        */
        @Rule(target="jsdgrp.rec.sombuyamt",order=100)
        public boolean ruleJsdgrpRecSombuyamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getJsdgrp().getRec().getSombuyamt()))
			{
			  this.getJsdgrp().getRec().setSompayamt(this.getJsdgrp().getRec().getSombuyamt());
			  
			}

			return true;
        }

        /**
        *   source:jstpay.@0008.script
        */
        @Rule(target="jsdgrp.rec.somselamt",order=100)
        public boolean ruleJsdgrpRecSomselamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getJsdgrp().getRec().getSomselamt()))
			{
			  this.getJsdgrp().getRec().setSompayamt(this.getJsdgrp().getRec().getSomselamt());
			  
			}

			return true;
        }

        /**
        *   source:jstpay.@0009.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in  images 50 ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }


        /**
        *   source:jstpay.@0005.script
        */
        @Check(target="jsdgrp.rec.sombuyamt",order=100)
        public boolean checkJsdgrpRecSombuyamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getJsdgrp().getRec().getSombuyamt()))
			{
			  BigDecimal som=this.getJsdgrp().getRec().getSombuyamt();
			  if(!(som.compareTo(this.getJsdgrp().getRec().getAmt())<0))
			  {
			    ctx.setFieldError(this,"jsdgrp.rec.sombuyamt",MdaUtils.getI18NString("jstpay","CT000003"));
			    return false;
			  }
			}

			return true;
        }

        /**
        *   source:jstpay.@0006.script
        */
        @Check(target="jsdgrp.rec.somselamt",order=100)
        public boolean checkJsdgrpRecSomselamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getJsdgrp().getRec().getSomselamt()))
			{
			  BigDecimal som=this.getJsdgrp().getRec().getSomselamt();
			  if(!(som.compareTo(this.getJsdgrp().getRec().getAmt())<0))
			  {
			    ctx.setFieldError(this,"jsdgrp.rec.somselamt",MdaUtils.getI18NString("jstpay","CT000009"));
			    return false;
			  }
			}

			return true;
        }

        /**
        *   source:jstpay.@0012.script
        */
        @Check(target="jstp.jsdgrp.rec.sombuyamt",order=100)
        public boolean checkJstpJsdgrpRecSombuyamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkIllegalAmt(MdaDriver.getDatafield(this.getJstp().getJsdgrp().getRec(),"sombuyamt"));

			return true;
        }

        /**
        *   source:jstpay.@0013.script
        */
        @Check(target="jstp.jsdgrp.rec.somselamt",order=100)
        public boolean checkJstpJsdgrpRecSomselamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getSysmod().checkIllegalAmt(MdaDriver.getDatafield(this.getJstp().getJsdgrp().getRec(),"somselamt"));

			return true;
        }


        /**
        *   source:jstpay.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();

			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getJsdgrp().getRec(),"bchcod",bchcod);

			this.getJstp().setPaydat(MdaUtils.today());

			
			
			

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			{
			  if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			  {
			    this.getTrnmod().getApldoc().loadApldocByOrdinr(this.getSysmod().getSpt().getOrdinr());
			  }

			  if(MdaUtils.isEmpty(this.getJsdgrp().getRec().getPayamt()))
			  {
			    this.getJstp().setPayttm("1");
			    log.debug("{}","paytim 1");
			  }
			  else
			  {
			    int ptim=MdaUtils.parseInt(this.getJsdgrp().getRec().getPaytim().trim());
			    this.getJstp().setPayttm(String.valueOf(ptim+1));
			  }

			  ctx.postRule(this,"jsdgrp.rec.sfltyp");
			  return true;
			}

			IModule jsd = (IModule)ctx.restoreData("com.brilliance.jstpay.ref");
			if(!MdaUtils.isEmpty(jsd))
			  this.getJsdgrp().getRec().copyValue(jsd);

			this.getJstp().setNam(this.getSysmod().getPty().getNam());
			ctx.postRule(this,"jsdgrp.rec.sfltyp");
			this.getJsdgrp().getRec().setSomselamt(new BigDecimal(0));
			this.getJsdgrp().getRec().setSombuyamt(new BigDecimal(0));
			this.inidelpdf();

			if(MdaUtils.isEmpty(this.getJsdgrp().getRec().getPayamt()))
			{
			  this.getJstp().setPayttm("1");
			  log.debug("{}","paytim 1");
			}
			else
			{
			  int ptim=MdaUtils.parseInt(this.getJsdgrp().getRec().getPaytim().trim());
			  this.getJstp().setPayttm(String.valueOf(ptim+1));
			}
			ctx.getDaoSession().dbRead(this.getJsdgrp().getApl().getPts(),new Argument<String>("objinr",this.getJsdgrp().getRec().getInr()),new Argument<String>("objtyp","jsd"),new Argument<String>("rol","apl"));


			return true;
        }


        /**
        *   source:jstpay.@0017.script
        */
        public void inidelpdf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//1：买入，0：卖出
			if("1".equals(this.getJsdgrp().getRec().getSfltyp()))
			{
			  this.getJstp().setSelsta("2");
			  this.getJstp().setJspaycur(this.getJsdgrp().getRec().getBuycur());
			  this.getJstp().setJspayamt(this.getJsdgrp().getRec().getSombuyamt());
			}
			else if("0".equals(this.getJsdgrp().getRec().getSfltyp()))
			{
			  this.getJstp().setSelsta("1");
			  this.getJstp().setJspaycur(this.getJsdgrp().getRec().getSelcur());
			  this.getJstp().setJspayamt(this.getJsdgrp().getRec().getSomselamt());
			}
			else
			{
			  this.getJstp().setSelsta(NULLSTR);
			  this.getJstp().setJspaycur(NULLSTR);
			  this.getJstp().setJspayamt(new BigDecimal(0));
			}
		}








}