package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.LitcfmVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Litmod;
import com.ceb.gjjs.mda.manager.module.Busmod;
import com.ceb.gjjs.mda.manager.module.Litp;
import com.ceb.gjjs.mda.manager.module.Lidgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 进口信用证保兑申请
*/
@Transaction(vo= LitcfmVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Litcfm extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Litcfm.class);

		@BDGetter
		private Lidgrp lidgrp;

		@BDGetter
		private Litmod litmod;

		@BDGetter
		private Litp litp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Busmod busmod;

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Rmkmod rmkmod;


		public Litcfm()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getLitmod().setLidgrpHolder(()->this.getLidgrp());
           this.getLitmod().setAfdgrpHolder(()->this.getAfdgrp());
           this.getLitp().setLidgrpHolder(()->this.getLidgrp());
           this.getLitp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getMtabut().setRecHolder(()->this.getLidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("CF"));
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.issamt");}
 				public void setValue(BigDecimal arg){Litcfm.this.getLidgrp().getRec().setIssamt(arg);}
 				public BigDecimal getValue(){return Litcfm.this.getLidgrp().getRec().getIssamt();}}
			 );
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.isscur");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setIsscur(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getIsscur();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.bchcod");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.inr");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setInr(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.ownref");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.ptyinr");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Litcfm.this.getFieldPath("lidgrp.rec.stlref");}
 				public void setValue(String arg){Litcfm.this.getLidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Litcfm.this.getLidgrp().getRec().getStlref();}}
			 );
        }

        /**
        *   source:litcfm.@0003.script
        */
        @Rule(target="lidgrp.rec.cfmflg",order=100)
        public boolean ruleLidgrpRecCfmflgN100(){
            IContext ctx = MdaEnv.getContext();
            
			onChangeCfmflg(true);

			return true;
        }

        /**
        *   source:litcfm.@0004.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			//Platform.checkAll($\\);
			//Platform.dbBegin();
			if(!ctx.checkAll(this.getLidgrp()))
			  return false;
			if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getStlref())&&MdaUtils.isEmpty(this.getLidgrp().getRec().getInr()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("litcfm","CT000071"),MdaUtils.getI18NString("litcfm","CT000072"));
			  return false;
			}
			String lidinr = null;
			if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getStlref()))
			{
			  lidinr = this.getLidgrp().getRec().getInr();
			  log.info("{}","up "+lidinr);
			  String isbnam = this.getLidgrp().getIsb().getPts().getNam();
			  ctx.getDaoSession().dbRead(this.getLidgrp().getIsb().getPts(),new Argument("rol","isb"),new Argument("objtyp","lid"),new Argument("objinr",lidinr));
			  this.getLidgrp().getIsb().getPts().setNam(isbnam);
			  ctx.getDaoSession().dbUpdate(this.getLidgrp().getRec());
			  ctx.getDaoSession().dbUpdate(this.getLidgrp().getBlk());
			}
			else if(!MdaUtils.isEmpty(this.getLidgrp().getApl().getPts().getRef()))
			{
			  lidinr = Platform.sdbCounter("lid");
			  log.info("{}","in "+lidinr);
			  this.getLidgrp().getRec().setInr(lidinr);
			  ctx.getDaoSession().dbInsert(this.getLidgrp().getRec());
			  this.getLidgrp().getBlk().setInr(lidinr);
			  ctx.getDaoSession().dbInsert(this.getLidgrp().getBlk());
			  this.getLidgrp().getApl().savRolPts(lidinr,"lid","apl");
			}
			else
			  return false;
			this.getLidgrp().getIsb().savRolPts(lidinr,"lid","isb");
			if(!this.getTrnmod().trnSetFromContract()) return false;
			//String filename="/data/dsp/"+$trnmod\\trn\\inr.getValue()+".zul";
			//filename=Platform.catPath(Platform.getRootPath(),filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			ctx.saveDisplay(filename);

			return true;
        }

        /**
        *   source:litcfm.@0005.script
        */
        @Rule(target="mtabut.apldoc",order=100)
        public boolean ruleMtabutApldocN100(){
            IContext ctx = MdaEnv.getContext();
            
			IStream stream=this.getMtabut().getApldoc();
			ctx.absGet(Sysmod.class).generatorPdf("","litcfm",stream,false );

			return true;
        }

        /**
        *   source:litcfm.@0008.script
        */
        @Rule(target="lidgrp.rec.conamt",order=100)
        public boolean ruleLidgrpRecConamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  if(!Platform.isEmpty($lidgrp\\rec\\issamt)   ||   !Platform.isEmpty($lidgrp\\rec\\conamt))
			  {
			  BigDecimal camt = $lidgrp\\rec\\conamt.getValue();
			  BigDecimal lamt = $lidgrp\\rec\\issamt.getValue();
			  if(lamt.compareTo(camt)>0)
			  Platform.error($lidgrp\\rec\\conamt,#CT000015);
			  }
			  */

			return true;
        }

        /**
        *   source:litcfm.@0009.script
        */
        @Rule(target="lidgrp.rec.issamt",order=100)
        public boolean ruleLidgrpRecIssamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getConamt()))
			{
			  BigDecimal camt = this.getLidgrp().getRec().getConamt();
			  BigDecimal lamt = this.getLidgrp().getRec().getIssamt();
			  if(lamt.compareTo(camt)>0)
			    ctx.setFieldError(this,"lidgrp.rec.issamt",MdaUtils.getI18NString("litcfm","CT000037"));
			}
			else if (!MdaUtils.isEmpty(this.getLidgrp().getRec().getCfmamt()))
			{
			  BigDecimal camt = this.getLidgrp().getRec().getCfmamt();
			  BigDecimal lamt = this.getLidgrp().getRec().getIssamt();
			  if(lamt.compareTo(camt)<0)
			    ctx.setFieldError(this,"lidgrp.rec.issamt",MdaUtils.getI18NString("litcfm","CT000038"));
			}


			return true;
        }

        /**
        *   source:litcfm.@0010.script
        */
        @Rule(target="lidgrp.rec.cfmamt",order=100)
        public boolean ruleLidgrpRecCfmamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getIssamt())   ||   !MdaUtils.isEmpty(this.getLidgrp().getRec().getCfmamt()))
			{
			  BigDecimal camt = this.getLidgrp().getRec().getCfmamt();
			  BigDecimal lamt = this.getLidgrp().getRec().getIssamt();
			  if(lamt.compareTo(camt)<0)
			    ctx.setFieldError(this,"lidgrp.rec.cfmamt",MdaUtils.getI18NString("litcfm","CT000042"));
			}

			return true;
        }

        /**
        *   source:litcfm.@0012.script
        */
        @Rule(target="litp.sel",order=100)
        public boolean ruleLitpSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getLidgrp().getRec().getStlref()))
			  return true;
			log.debug("{}","stlref = "+this.getLidgrp().getRec().getStlref());
			String cfmflg= this.getLidgrp().getRec().getCfmflg();
			ctx.getDaoSession().dbRead(this.getLidgrp().getRec(),new Argument<String>("stlref",this.getLidgrp().getRec().getStlref()));
			log.debug("{}","inr="+this.getLidgrp().getRec().getInr());
			String trstxt = this.getLidgrp().getBlk().getTrstxt();
			ctx.getDaoSession().dbRead(this.getLidgrp().getBlk(),new Argument<String>("inr",this.getLidgrp().getRec().getInr()));
			this.getLidgrp().getBlk().setTrstxt(trstxt);
			int rt = ctx.getErrorCode();
			//log.debug("rt=="+rt);
			//if(rt==NO_MORE_ROW)
			// Platform.message(#CT000051,#CT000052);
			if(MdaUtils.isEmpty(this.getLidgrp().getRec().getConcur()))
			  this.getLidgrp().getRec().setConcur(this.getLidgrp().getRec().getIsscur());
			this.getLidgrp().getRec().setCfmcur(this.getLidgrp().getRec().getIsscur());
			this.getLidgrp().getRec().setCfmflg(cfmflg);
			this.getLidgrp().getRec().setOwnref(NULLSTR);
			
			
			
			
			//Platform.setModified($lidgrp\\rec\\likman);
			// Platform.setModified($lidgrp\\rec\\moble);
			
			
			
			
			
			
			

			return true;
        }

        /**
        *   source:litcfm.@0015.script
        */
        @Rule(target="mtabut.xptslt",order=100)
        public boolean ruleMtabutXptsltN100(){
            IContext ctx = MdaEnv.getContext();
            
			MdaUtils.clear(this.getMtabut().getXptqna());
			this.getMtabut().getXptqna().setRef(this.getLidgrp().getRec().getOwnref());
			log.debug("{}","ref="+this.getMtabut().getXptqna().getRef());
			ctx.storeData("com.brilliance.xptlst.ref",this.getMtabut().getXptqna());
			

			return true;
        }

        /**
        *   source:litcfm.@0016.script
        */
        @Rule(target="lidgrp.rec.bchcod",order=100)
        public boolean ruleLidgrpRecBchcodN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }


        /**
        *   source:litcfm.@0001.script
        */
        @Check(target="lidgrp.rec.cfmcur",order=100)
        public boolean checkLidgrpRecCfmcurN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!(this.getLidgrp().getRec().getIsscur()).equals(this.getLidgrp().getRec().getCfmcur()))
			  ctx.setFieldError(this,"lidgrp.rec.cfmcur",MdaUtils.getI18NString("litcfm","CT000001"));

			return true;
        }

        /**
        *   source:litcfm.@0002.script
        */
        @Check(target="lidgrp.rec.cfmamt",order=100)
        public boolean checkLidgrpRecCfmamtN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getLidgrp().getRec().getIssamt())   ||   !MdaUtils.isEmpty(this.getLidgrp().getRec().getCfmamt()))
			{
			  BigDecimal camt = this.getLidgrp().getRec().getCfmamt();
			  BigDecimal lamt = this.getLidgrp().getRec().getIssamt();
			  if(lamt.compareTo(camt)<0)
			    ctx.setFieldError(this,"lidgrp.rec.cfmamt",MdaUtils.getI18NString("litcfm","CT000002"));
			}

			return true;
        }

        /**
        *   source:litcfm.@0007.script
        */
        @Check(target="lidgrp.rec.concur",order=100)
        public boolean checkLidgrpRecConcurN100(){
            IContext ctx = MdaEnv.getContext();
            
			// log.debug("concur=="+$lidgrp\\rec\\concur);
			//$lidgrp\\rec\\isscur.setValue($lidgrp\\rec\\concur.getValue());
			// $lidgrp\\rec\\cfmcur.setValue($lidgrp\\rec\\concur.getValue());
			//Platform.setModified($lidgrp\\rec\\isscur);
			//Platform.setModified($lidgrp\\rec\\cfmcur);
			
			return true;
        }


        /**
        *   source:litcfm.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getLidgrp().setTrsflg("3");
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getLidgrp().getRec(),"bchcod",bchcod);
			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getLidgrp().getRec().setBchcod(bchcod.get(0).getValue());
			if("1".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  
			  
			}
			else
			{
			  
			  
			}
			if(MdaUtils.isEmpty(this.getLidgrp().getRec().getCfmflg()))
			  this.getLidgrp().getRec().setCfmflg("1");
			onChangeCfmflg(false);
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  return true;
			
			this.getLidgrp().getDap().initDap("lid");
			this.getLidgrp().getIsb().getPts().copyValue(this.getLidgrp().getDap().getPts());
			this.getLidgrp().getIsb().getPts().setRol("isb");
			this.getLidgrp().getRec().setCredat(MdaUtils.today());
			
			this.getLidgrp().getRec().setConcur("USD");
			//Platform.setValues($lidgrp\\rec\\cfmflg,Platform.getCodetable("cfmtyp"));
			this.getLidgrp().getRec().setIsscur("USD");
			this.getLidgrp().getRec().setCfmcur("USD");
			//Platform.dbRead($litp\\trstxt\\cls,new Argument<String>("flg","3"),new Argument<String>("typ","litcfm"),new Argument<String>("status","0"));
			this.getLitp().getTrstxt().setClstyp("litcfm");
			if(MdaUtils.isEmpty(this.getLidgrp().getBlk().getTrstxt()))
			{
			  ctx.getDaoSession().dbRead(this.getLitp().getTrstxt().getCls(),new Argument<String>("inr",this.getLitp().getTrstxt().readDefaultClsInr("litcfm")));
			  this.getLidgrp().getBlk().setTrstxt(this.getLitp().getTrstxt().getCls().getClstxt());
			}

			return true;
        }

        /**
        *   source:litcfm.@0011.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            

			return true;
        }


        /**
        *   source:litcfm.@0013.script
        */
        public void onChangeCfmflg(boolean needClear)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if("1".equals(this.getLidgrp().getRec().getCfmflg()))
			{
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  
			  this.getLidgrp().getBlk().setLctxt(NULLSTR);
			  this.getLidgrp().getRec().setNomtop(0);
			  this.getLidgrp().getRec().setNomton(0);
			  this.getLidgrp().getRec().setConcur(NULLSTR);
			  this.getLidgrp().getRec().setConamt(new BigDecimal(0));

			  this.getLidgrp().getApl().getPts().setRef(NULLSTR);
			  this.getLidgrp().getRec().setConno(NULLSTR);
			}
			else
			{
			  
			  
			  
			  
			  if(needClear)
			  {
			    this.getLidgrp().getRec().setStlref(NULLSTR);
			    this.getLidgrp().getBlk().setLctxt(NULLSTR);
			    this.getLidgrp().getRec().setNomtop(0);
			    this.getLidgrp().getRec().setNomton(0);
			    this.getLidgrp().getRec().setConcur("USD");
			    this.getLidgrp().getRec().setConamt(new BigDecimal(0));
			    this.getLidgrp().getRec().setIsscur("USD");
			    this.getLidgrp().getRec().setIssamt(new BigDecimal(0));
			    this.getLidgrp().getApl().getPts().setRef(NULLSTR);
			    this.getLidgrp().getRec().setConno(NULLSTR);
			    this.getLidgrp().getRec().setInr(NULLSTR);
			  }
			  
			  
			  
			  
			  

			  
			  
			}
			
			
			
			
			
			
			
			
			
			
			
		}










}