package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.LxtcfmVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Afdgrp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Litp;
import com.ceb.gjjs.mda.manager.module.Lidgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 银行端开立信用证交易（综）
*/
@Transaction(vo= LxtcfmVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Lxtcfm extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Lxtcfm.class);

		@BDGetter
		private Lidgrp lidgrp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Afdgrp afdgrp;

		@BDGetter
		private Litp litp;


		public Lxtcfm()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getMtabut().setRecHolder(()->this.getLidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("LX"));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.isscur");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setIsscur(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getIsscur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.issamt");}
 				public void setValue(BigDecimal arg){Lxtcfm.this.getLidgrp().getRec().setIssamt(arg);}
 				public BigDecimal getValue(){return Lxtcfm.this.getLidgrp().getRec().getIssamt();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.ownref");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.bchcod");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.inr");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setInr(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.ptyinr");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Lxtcfm.this.getFieldPath("lidgrp.rec.stlref");}
 				public void setValue(String arg){Lxtcfm.this.getLidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Lxtcfm.this.getLidgrp().getRec().getStlref();}}
			 );
           this.getLitp().setAfdgrpHolder(()->this.getAfdgrp());
           this.getLitp().setLidgrpHolder(()->this.getLidgrp());
        }

        /**
        *   source:lxtcfm.@0001.script
        */
        @Rule(target="mtabut.bnkcfm",order=200)
        public boolean ruleMtabutBnkcfmN200(){
            IContext ctx = MdaEnv.getContext();
            
			String flags =this.getLidgrp().getRec().getMarginflg();
			log.debug("{}","在matbut模块bnkcfm按钮order[200]，flags="+flags);
			ctx.getDaoSession().dbUpdate(this.getLidgrp().getLxd());
			if("0001".equals(flags))
			{
			  ctx.getDaoSession().dbUpdate(this.getLidgrp().getBxd());
			}
			//保存trn
			ctx.absGet(Trnmod.class).setTrnForSecondConfirm();
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.debug("{}","filename is "+filename);
			//获得当前显示步骤条所对应的面板
			IPanel[] panels=this.getLitp().getStpmod().getAllPanelsName();
			ctx.saveDisplay(filename);


			return true;
        }

        /**
        *   source:lxtcfm.@0002.script
        */
        @Rule(target="mtabut.bnkcfm",order=190)
        public boolean ruleMtabutBnkcfmN190(){
            IContext ctx = MdaEnv.getContext();
            

			/**
			  *检查及校验
			  */
			String flags =this.getLidgrp().getRec().getMarginflg();
			log.debug("{}","在matbut模块bnkcfm按钮order[190]，flags="+flags);
			if("0001".equals(flags))
			{//有保证金相关业务
			  if(!ctx.checkAll(this.getLidgrp().getLxd())&&!ctx.checkAll(this.getLidgrp().getBxd()))
			  {
			    ctx.setMessage(MdaUtils.getI18NString("lxtcfm","CT000004"),MdaUtils.getI18NString("lxtcfm","CT000005"));
			    return false;
			  }
			}
			else if("0000".equals(flags))
			{//无保证金相关业务
			  if( !ctx.checkAll(this.getLidgrp().getLxd()))
			  {
			    ctx.setMessage(MdaUtils.getI18NString("lxtcfm","CT000006"),MdaUtils.getI18NString("lxtcfm","CT000007"));
			    return false;
			  }
			}

			return true;
        }



        /**
        *   source:lxtcfm.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			String objinr=(String)ctx.restoreData("com.brilliance.lxtcfm.inr");
			if(!MdaUtils.isEmpty(objinr))
			{
			  ctx.getDaoSession().dbRead(this.getLidgrp().getRec(),new Argument<String>("inr",objinr));
			  ctx.getDaoSession().dbRead(this.getLidgrp().getLxd(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp","lid"));
			  //定义步骤条
			  this.getLitp().getStpmod().storePanel(this.getLitp().getLxtcfm01(),this.getLitp().getLxtcfm02(),this.getLitp().getLxtcfm03());
			  String steps=null;
			  String flags=this.getLidgrp().getRec().getMarginflg();
			  //签订了保证金协议
			  if("0001".equals(flags))
			  {
			    ctx.getDaoSession().dbRead(this.getLidgrp().getBxd(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp","lid"));
			    // Platform.visible($litp\\pdfbxd);
			    steps = "0:信用证协议;1:保证金协议;2:合同展示";
			  }
			  else if("0000".equals(flags))
			  {
			    
			    steps = "0:信用证协议;2:合同展示";
			  }
			  this.getLitp().getStpmod().setPages(steps);
			  this.getLitp().getStpmod().calcSteps();
			  //隐藏出口押汇协议界面上是否签订保证金勾选项
			  
			}

			return true;
        }










}