package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.MaropnVO;

import com.ceb.gjjs.mda.manager.module.Marp;
import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Marmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Margrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 保证金委托开户及扣划申请
*/
@Transaction(vo= MaropnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Maropn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Maropn.class);

		@BDGetter
		private Margrp margrp;

		@BDGetter
		private Marmod marmod;

		@BDGetter
		private Marp marp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Rmkmod rmkmod;


		public Maropn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getMarmod().setMargrpHolder(()->this.getMargrp());
           this.getMarp().setMargrpHolder(()->this.getMargrp());
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.ownref");}
 				public void setValue(String arg){Maropn.this.getMargrp().getMar().setOwnref(arg);}
 				public String getValue(){return Maropn.this.getMargrp().getMar().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.bchcod");}
 				public void setValue(String arg){Maropn.this.getMargrp().getMar().setBchcod(arg);}
 				public String getValue(){return Maropn.this.getMargrp().getMar().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.inr");}
 				public void setValue(String arg){Maropn.this.getMargrp().getMar().setInr(arg);}
 				public String getValue(){return Maropn.this.getMargrp().getMar().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.ptyinr");}
 				public void setValue(String arg){Maropn.this.getMargrp().getMar().setPtyinr(arg);}
 				public String getValue(){return Maropn.this.getMargrp().getMar().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.cur");}
 				public void setValue(String arg){Maropn.this.getMargrp().getMar().setCur(arg);}
 				public String getValue(){return Maropn.this.getMargrp().getMar().getCur();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Maropn.this.getFieldPath("margrp.mar.amt");}
 				public void setValue(BigDecimal arg){Maropn.this.getMargrp().getMar().setAmt(arg);}
 				public BigDecimal getValue(){return Maropn.this.getMargrp().getMar().getAmt();}}
			 );
           this.getMtabut().setRecHolder(()->this.getMargrp().getMar());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>("MZ"));
        }

        /**
        *   source:maropn.@0002.script
        */
        @Rule(target="marp.bzjpdf",order=100)
        public boolean ruleMarpBzjpdfN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMarp().getPdfviw().callPDFComponent("","bxdpdf","保证金协议",0);

			return true;
        }

        /**
        *   source:maropn.@0003.script
        */
        @Rule(target="mtabut.sav",order=200)
        public boolean ruleMtabutSavN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，编号200");
			if(!ctx.checkAll(this.getMargrp()))
			{
			  log.debug("{}","页面校验未通过，退出！");
			  return false;
			}

			//$mtabut\\busmod.dealFile();
			
			if(!this.getMarp().checkMxdlist())
			{
			  log.debug("{}","mxdlist check error!");
			  return false;
			}
			log.debug("{}","页面校验完成");

			if(!MdaUtils.isEmpty(this.getMtabut().getBusmod().getIsdel()))
			{
			  ctx.getDaoSession().dbDelete(this.getMtabut().getBusmod().getWrkmdl(),new Argument<String>("inr",this.getMtabut().getBusmod().getTmpinr()));
			  if(MdaUtils.fileExists(this.getMtabut().getBusmod().getTmpfilnam()))
			  {
			    MdaUtils.fileDelete(this.getMtabut().getBusmod().getTmpfilnam());
			  }
			}

			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))  //暂存
			{
			  ctx.getDaoSession().dbUpdate(this.getMargrp().getMar());
			  ctx.getDaoSession().dbUpdate(this.getMargrp().getBxd());

			  //保证金账户扣划信息入库
			  int size=this.getMargrp().getMxdlst().fullSize();
			  for(int i=0;i<size;i++)
			  {
			    if(MdaUtils.isEmpty(this.getMargrp().getMxdlst().getElement(i).getInr()))
			    {
			      this.getMargrp().getMxd().copyValue(this.getMargrp().getMxdlst().get(i));
			      this.getMargrp().getMxd().setInr(Platform.sdbCounter("mxd"));
			      this.getMargrp().getMxd().setObjtyp("mar");
			      this.getMargrp().getMxd().setObjinr(this.getMargrp().getMxd().getInr());
			      ctx.getDaoSession().dbInsert(this.getMargrp().getMxd());
			    }
			    else
			    {
			      log.info("{}","update mxd");
			      ctx.getDaoSession().dbUpdate(this.getMargrp().getMxdlst().getElement(i));
			    }
			  }
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMargrp().getBxd().getInr()))
			  {
			    this.getMargrp().getBxd().setInr(Platform.sdbCounter("bxd"));
			    this.getMargrp().getMar().setInr(Platform.sdbCounter("mar"));

			    this.getMargrp().getBxd().setObjtyp("mar");
			    this.getMargrp().getBxd().setObjinr(this.getMargrp().getMar().getInr());
			    //$margrp\\mar\\stlref.setValue();
			
			    ctx.getDaoSession().dbInsert(this.getMargrp().getBxd());
			    ctx.getDaoSession().dbInsert(this.getMargrp().getMar());
			  }
			  else
			  {
			    this.getMargrp().getBxd().setObjtyp("mar");
			    this.getMargrp().getBxd().setObjinr(this.getMargrp().getMar().getInr());

			    ctx.getDaoSession().dbUpdate(this.getMargrp().getBxd());
			    ctx.getDaoSession().dbUpdate(this.getMargrp().getMar());
			  }

			  this.getMargrp().getBxd().setTyp("0");//主记录表示
			
			  //保证金账户扣划信息入库
			  int size=this.getMargrp().getMxdlst().fullSize();
			  for(int i=0;i<size;i++)
			  {
			    if(MdaUtils.isEmpty(this.getMargrp().getMxdlst().getElement(i).getInr()))
			    {
			      this.getMargrp().getMxd().copyValue(this.getMargrp().getMxdlst().get(i));
			      this.getMargrp().getMxd().setInr(Platform.sdbCounter("mxd"));
			      this.getMargrp().getMxd().setObjtyp("mar");
			      this.getMargrp().getMxd().setObjinr(this.getMargrp().getMxd().getInr());
			      ctx.getDaoSession().dbInsert(this.getMargrp().getMxd());
			    }
			    else
			    {
			      log.info("{}","update mxd");
			      ctx.getDaoSession().dbUpdate(this.getMargrp().getMxdlst().getElement(i));
			    }
			  }

			  String objinr=this.getMargrp().getBxd().getInr();
			  this.getMargrp().getDap().getPts().setInr(Platform.sdbCounter("pts"));
			  this.getMargrp().getDap().getPts().setObjinr(this.getMargrp().getMxd().getInr());
			  this.getMargrp().getDap().getPts().setObjtyp( "mar");
			  ctx.getDaoSession().dbInsert(this.getMargrp().getDap().getPts());
			  log.info("{}","sav200入库结束================");
			}

			//将Module数据入库 End==========
			if(!this.getTrnmod().trnSetFromContract()) return false;
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"zul");
			log.info("{}","filename is "+filename);
			IPanel[]  panels = panels=this.getMarp().getStpmod().getAllPanelsName();
			ctx.saveDisplay(filename);
			log.info("{}","业务处理结束，编号200");

			return true;
        }

        /**
        *   source:maropn.@0004.script
        */
        @Rule(target="margrp.dap.pts.adrblk",order=100)
        public boolean ruleMargrpDapPtsAdrblkN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMarp().getAplp().refreshApl(this.getMargrp());

			return true;
        }

        /**
        *   source:maropn.@0005.script
        */
        @Rule(target="marp.khkhpdf",order=100)
        public boolean ruleMarpKhkhpdfN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMarp().encode();
			this.flags();
			this.getMarp().getPdfviw().callPDFComponent("","marpdf","保证金协议",0);

			return true;
        }

        /**
        *   source:maropn.@0008.script
        */
        @Rule(target="mtabut.imgtp.images",order=50)
        public boolean ruleMtabutImgtpImagesN50(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in evt bptrpn.mtabut.imgtp.images ... ");
			log.debug("{}","imgref=" +this.getSysmod().getSpt().getImgref());
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getImgref()) && MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			{
			  this.getMtabut().getImgtp().getImageReference();
			}
			else
			{
			  if(MdaUtils.isEmpty(this.getMtabut().getImgtp().getDztimgref()))
			  {
			    this.getMtabut().getImgtp().setDztimgref(this.getSysmod().getSpt().getImgref());
			  }
			}
			log.debug("{}","生成的影像批次号为：" + this.getMtabut().getImgtp().getDztimgref());

			return true;
        }

        /**
        *   source:maropn.@0012.script
        */
        @Rule(target="mtabut.add",order=100)
        public boolean ruleMtabutAddN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getMargrp().getMar().getWtkhbzj()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("maropn","CT000037"),MdaUtils.getI18NString("maropn","CT000038"));
			  return false;
			}
			log.info("{}","账户列表开始");
			int size = this.getMargrp().getMxdlst().fullSize();
			if(size>=5)
			{
			  ctx.setMessage(MdaUtils.getI18NString("maropn","CT000039"),MdaUtils.getI18NString("maropn","CT000040"));
			  return false;
			}
			this.getMargrp().getMxdlst().add();
			
			log.info("{}","账户列表结束");

			return true;
        }

        /**
        *   source:maropn.@0013.script
        */
        @Rule(target="mtabut.del",order=100)
        public boolean ruleMtabutDelN100(){
            IContext ctx = MdaEnv.getContext();
            

			//加入标志字段  删除行数据    把删除的行数据插入另一张表
			int size=this.getMargrp().getMxdlst().fullSize();
			//int select = Platform.getSelectedRowIndex($margrp\\mxdlst);
			log.info("{}",MdaUtils.getI18NString("maropn","CT000003")+size);
			//log.info(#CT000004+select);
			if(size>0)
			{
			  boolean delflag=false;
			  for(int i=0;i<size;i++ )
			  {
			    log.info("{}",MdaUtils.getI18NString("maropn","CT000005")+size);
			    log.info("{}",MdaUtils.getI18NString("maropn","CT000025")+i);
			    if("X".equals(this.getMargrp().getMxdlst().getElement(i).getModflg()))
			    {
			      delflag=true;
			      if(!MdaUtils.isEmpty(this.getMargrp().getMxdlst().getElement(i).getInr()))
			      {
			        log.info("{}","src mxdbak inr:"+this.getMargrp().getMxdbak().size());
			        this.getMargrp().getMxdbak().add(this.getMargrp().getMxdlst().getElement(i));
			        log.info("{}","mxdbak inr:"+this.getMargrp().getMxdbak().size());
			      }
			      this.getMargrp().getMxdlst().remove(i);
			      size=this.getMargrp().getMxdlst().fullSize();
			      i--;
			    }
			  }
			  
			  if (!delflag)
			  {
			    ctx.setMessage(MdaUtils.getI18NString("maropn","CT000026"),MdaUtils.getI18NString("maropn","CT000045"));
			  }
			}
			//int size = Platform.getSelectedRowIndex($margrp\\mxdlst);
			//if(size < 0)
			//{
			//  Platform.message(#CT000046,#CT000047);
			//}
			//else
			//{
			// if(!Platform.isEmpty($margrp\\mxdlst[size]\\inr))
			//  {
			//   log.info("src mxdbak inr:"+$margrp\\mxdbak.size());
			//    $margrp\\mxdbak.add($margrp\\mxdlst[size]);
			//    log.info("mxdbak inr:"+$margrp\\mxdbak.size());
			//  }
			//  $margrp\\mxdlst.remove(size);
			//}
			//Platform.setModified($margrp\\mxdlst);
			

			return true;
        }

        /**
        *   source:maropn.@0020.script
        */
        @Rule(target="margrp.mar.wtkhbzj",order=100)
        public boolean ruleMargrpMarWtkhbzjN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMarp().marWtkhbzjDeal();

			return true;
        }

        /**
        *   source:maropn.@0019.script
        */
        @Rule(target="margrp.mar.wtklbzjzh",order=100)
        public boolean ruleMargrpMarWtklbzjzhN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMarp().marWtklbzjzhDeal();

			return true;
        }

        /**
        *   source:maropn.@0026.script
        */
        @Rule(target="mtabut.busmod.select",order=110)
        public boolean ruleMtabutBusmodSelectN110(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","execute  marp bummod sure    order 110 .......");
			this.getMarp().marWtkhbzjDeal();
			this.getMarp().marWtklbzjzhDeal();


			return true;
        }


        /**
        *   source:maropn.@0014.script
        */
        @Check(target="margrp.bxd.yfzrr",order=100)
        public boolean checkMargrpBxdYfzrrN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getMargrp().getBxd().getYf())&&MdaUtils.isEmpty(this.getMargrp().getBxd().getYfzrr()))
			{
			  ctx.setFieldError(this,"margrp.bxd.yf",MdaUtils.getI18NString("maropn","CT000013"));
			}
			else
			{
			  //乙方(自然人)信息
			  
			  
			  
			  //乙方(自然人)收件信息
			  
			  
			  
			  
			  //乙方(自然人)代收人信息
			  
			  
			  
			  
			  //乙方（单位）信息
			  
			  
			  //乙方（单位）收件信息
			  
			  
			  
			  
			  
			  //乙方（单位）代收人信息
			  
			  
			  
			  
			}


			return true;
        }

        /**
        *   source:maropn.@0015.script
        */
        @Check(target="margrp.bxd.yfczhm",order=100)
        public boolean checkMargrpBxdYfczhmN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getMargrp().getBxd().getYfczhm())&&MdaUtils.isEmpty(this.getMargrp().getBxd().getYfdzyj())&&MdaUtils.isEmpty(this.getMargrp().getBxd().getYfsjhm()))
			  ctx.setFieldError(this,"margrp.bxd.yfczhm",MdaUtils.getI18NString("maropn","CT000016"));

			return true;
        }

        /**
        *   source:maropn.@0016.script
        */
        @Check(target="margrp.mar.wtklbzjzh",order=100)
        public boolean checkMargrpMarWtklbzjzhN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getMargrp().getMar().getWtklbzjzh())&&MdaUtils.isEmpty(this.getMargrp().getMar().getWtkhbzj()))
			  // Platform.error($margrp\\mar\\wtklbzjzh,#CT000018);
			ctx.setMessage(MdaUtils.getI18NString("maropn","CT000041"),MdaUtils.getI18NString("maropn","CT000042"));

			return true;
        }


        /**
        *   source:maropn.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getSysmod().getSpt().getOrdinr()))
			  this.getTrnmod().ordNew();
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodvals();
			MdaUtils.setValues(this.getMargrp().getMar(),"bchcod",bchcod);

			if(!MdaUtils.isEmpty(bchcod)&&!ctx.absGet(Sysmod.class).sptIsLoaded("B")&&!ctx.absGet(Sysmod.class).sptIsLoaded("P"))
			  this.getMargrp().getMar().setBchcod(bchcod.get(0).getValue());
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("P")  ||  ctx.absGet(Sysmod.class).sptIsLoaded("T"))
			  return true;
			String seltyp= (ctx.restoreData("com.brilliance.maropn.seltyp")).toString();
			IModule rec = (IModule)ctx.restoreData("com.brilliance.maropn.ref");
			//Platform.invisible($mtabut\\getref);
			if("0".equals(seltyp))
			{// 新建
			  this.getMargrp().getMar().setRef(NULLSTR);
			  
			}
			else if("1".equals(seltyp))//进口信用证
			{
			  if(!MdaUtils.isEmpty(rec))
			  {
			    this.getMarmod().getLidgrp().getRec().copyValue(rec);
			    this.getMargrp().getMar().setRef(this.getMarmod().getLidgrp().getRec().getStlref());
			    this.getMargrp().getMar().setObjtyp("lid");
			    this.getMargrp().getMar().setObjinr(this.getMarmod().getLidgrp().getRec().getInr());
			    this.getMargrp().getBxd().setRef(this.getMarmod().getLidgrp().getRec().getStlref());
			  }
			}

			else if( "2".equals(seltyp))//保函
			{
			  if(!MdaUtils.isEmpty(rec))
			  {
			    this.getMarmod().getGidgrp().getRec().copyValue(rec);
			    this.getMargrp().getMar().setRef(this.getMarmod().getGidgrp().getRec().getStlref());
			    this.getMargrp().getMar().setObjtyp("gid");
			    this.getMargrp().getMar().setObjinr(this.getMarmod().getGidgrp().getRec().getInr());
			    this.getMargrp().getBxd().setRef(this.getMarmod().getGidgrp().getRec().getStlref());
			  }
			}
			else if( "3".equals(seltyp))//出口押汇
			{
			  if(!MdaUtils.isEmpty(rec))
			  {
			    this.getMarmod().getBpdgrp().getRec().copyValue(rec);
			    this.getMargrp().getMar().setRef(this.getMarmod().getBpdgrp().getRec().getStlref());
			    this.getMargrp().getMar().setObjtyp("bpd");
			    this.getMargrp().getMar().setObjinr(this.getMarmod().getBpdgrp().getRec().getInr());
			    this.getMargrp().getBxd().setRef(this.getMarmod().getBpdgrp().getRec().getStlref());
			  }
			}
			else if( "4".equals(seltyp))//进口代付
			{
			  if(!MdaUtils.isEmpty(rec))
			  {
			    this.getMarmod().getApdgrp().getRec().copyValue(rec);
			    this.getMargrp().getMar().setRef(this.getMarmod().getApdgrp().getRec().getStlref());
			    this.getMargrp().getMar().setObjtyp("apd");
			    this.getMargrp().getMar().setObjinr(this.getMarmod().getApdgrp().getRec().getInr());
			    this.getMargrp().getBxd().setRef(this.getMarmod().getApdgrp().getRec().getStlref());
			  }
			}
			else if( "5".equals(seltyp))//福费廷
			{
			  if(!MdaUtils.isEmpty(rec))
			  {
			    this.getMarmod().getFsdgrp().getRec().copyValue(rec);
			    this.getMargrp().getMar().setRef(this.getMarmod().getFsdgrp().getRec().getStlref());
			    this.getMargrp().getMar().setObjtyp("fsd");
			    this.getMargrp().getMar().setObjinr(this.getMarmod().getFsdgrp().getRec().getInr());
			    this.getMargrp().getBxd().setRef(this.getMarmod().getFsdgrp().getRec().getStlref());
			  }
			}

			//$margrp\\mar\\marcur1.setValue("USD");
			//$margrp\\mar\\marcur2.setValue("USD");
			// $margrp\\mar\\marcur3.setValue("USD");
			this.getMargrp().getMar().setNote("可填写保证金用途等");
			this.getMargrp().getMar().setCredat(MdaUtils.today());
			this.getMargrp().getApl().getPts().setNam(this.getSysmod().getPty().getNam());

			//设置界面描述
			this.getMarp().bxdDescription();
			this.getMarp().marDescription();
			//设置界面限制
			
			this.getMarp().marWtkhbzjDeal();
			this.getMarp().marWtklbzjzhDeal();


			return true;
        }

        /**
        *   source:maropn.@0007.script
        */
        @Init(order=90)
        public boolean	init90(){
            IContext ctx = MdaEnv.getContext();
            
			//  定义步骤条
			this.getMarp().getStpmod().storePanel(this.getMarp().getMaropn09(),this.getMarp().getMaropn02(),this.getMarp().getMaropn04(),this.getMarp().getMaropn10());
			String steps = "0:保证金协议;1:开户及扣划;2:合同展示";
			this.getMarp().getStpmod().setPages(steps);
			this.getMarp().getStpmod().calcSteps();
			this.getMarp().getStpmod().setStepBtnSta();

			return true;
        }


        /**
        *   source:maropn.@0025.script
        */
        public void flags()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(!MdaUtils.isEmpty(this.getMargrp().getMar().getWtklbzjzh()))
			{
			  this.getMargrp().setWtklbzjzh("√");
			}
			else
			{
			  this.getMargrp().setWtklbzjzh(NULLSTR);
			}
			if(!MdaUtils.isEmpty(this.getMargrp().getMar().getWtkhbzj()))
			{
			  this.getMargrp().setWtkhbzj("√");
			}
			else
			{
			  this.getMargrp().setWtkhbzj(NULLSTR);
			}

			if("0".equals(this.getMargrp().getMar().getFddbr())||"法定代表人".equals(this.getMargrp().getMar().getFddbr())||"Legal person repreenetative".equals(this.getMargrp().getMar().getFddbr()))
			{
			  log.info("{}","margrp  fddbr1.setValue .......  ===" + this.getMargrp().getFddbr1());
			  this.getMargrp().setFddbr1("√");

			}
			else if("1".equals(this.getMargrp().getMar().getFddbr())||"单位负责人".equals(this.getMargrp().getMar().getFddbr())||"Unit head".equals(this.getMargrp().getMar().getFddbr()))
			{
			  log.info("{}","margrp  fddbr2.setValue .......  ===" + this.getMargrp().getFddbr2());
			  this.getMargrp().setFddbr2("√");
			}
			else
			{
			  this.getMargrp().setFddbr1(NULLSTR);
			  this.getMargrp().setFddbr2(NULLSTR);
			}

		}








}