package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.MatchkVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Matmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Madgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Matp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 跨境汇款对账管理
*/
@Transaction(vo= MatchkVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Matchk extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Matchk.class);

		@BDGetter
		private Madgrp madgrp;

		@BDGetter
		private Matmod matmod;

		@BDGetter
		private Matp matp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Matchk()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getMatmod().setMadgrpHolder(()->this.getMadgrp());
           this.getMatp().setMadgrpHolder(()->this.getMadgrp());
           this.getMtabut().setRecHolder(()->this.getMadgrp());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new java.math.BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:matchk.@0010.script
        */
        @Rule(target="matp.repchk",order=100)
        public boolean ruleMatpRepchkN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","in repchk...");
			ctx.getDaoSession().dbBegin();
			int index = 0;
			log.info("{}","current line selected is =" +index );
			int length = this.getMadgrp().getMadlst().fullSize();
			log.info("{}","size of madlst is =" +length);
			String sigchk = "D";
			log.info("{}","size of sigchk  =" +this.getMadgrp().getMadlst().getElement(index).getSigchk());
			if(index < 0 || index >= this.getMadgrp().getMadlst().fullSize())
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000022"),MdaUtils.getI18NString("matchk","CT000023"));
			  return true;
			}
			if (!sigchk.equals(this.getMadgrp().getMadlst().getElement(index).getSigchk()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000024"),MdaUtils.getI18NString("matchk","CT000025"));
			  return true;
			}
			if(!"0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  ctx.getDaoSession().dbRead(this.getTrnmod().getTrn(),new Argument<String>("inr",this.getMadgrp().getMadlst().getElement(index).getTrninr()));
			  String ordinr = this.getTrnmod().getTrn().getOrdinr();
			  log.info("{}","ordinr =" +ordinr);
			  String curpty = this.getSysmod().getPty().getInr();
			  log.info("{}","curpty =" +curpty);
			  createSpt();
			  //cancel the trn records
			  String inr = this.getMadgrp().getMadlst().getElement(index).getTrninr();
			  log.info("{}","trninr =" +inr);
			  ctx.getDaoSession().dbRead(this.getTrnmod().getWfmmod().getWfs(),new Argument<String>("objinr",inr),new Argument<String>("objtyp","trn"));
			  String wfsinr=this.getTrnmod().getWfmmod().getWfs().getInr();
			  log.info("{}","wfsinr =" +wfsinr);
			  ctx.getDaoSession().dbDelete(ctx.absGet(Trnmod.class).getWfmmod().getWfe(),new Argument<String>("wfsinr",wfsinr));
			  ctx.getDaoSession().dbDelete(this.getTrnmod().getWfmmod().getWfs());
			  ctx.getDaoSession().dbDelete(this.getTrnmod().getUsrsig(),new Argument("ownref",this.getTrnmod().getTrn().getOwnref()),new Argument("trninr",inr));
			  this.getTrnmod().getTrn().setCpldattim(new Date());
			  this.getTrnmod().getTrn().setSta("B");
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());
			  //delete dat file
			  this.getTrnmod().getOrdmod().updateOrd(ordinr,"B","8",this.getRmkmod().getNtext());
			  this.getRmkmod().updateRmk("8");
			  String filename = ctx.absGet(Sysmod.class).createFilename(inr,"dat");
			  if(MdaUtils.fileExists(filename))
			  {
			    //Platform.fileDelete(filename);
			  }
			  //delete disPlay file
			  String disname = "/data/dsp/"+inr.substring(0,4)+"/"+inr+".zul";
			  if(MdaUtils.fileExists(disname))
			  {
			    MdaUtils.fileDelete(disname);
			  }
			}
			else
			{
			  ctx.getDaoSession().dbRead(this.getTrnmod().getTrn(),new Argument<String>("inr",this.getMadgrp().getMadlst().getElement(index).getTrninr()));
			  if(!"spt".equals(this.getTrnmod().getTrn().getObjtyp()))
			    return false;
			  this.getTrnmod().sdbRead(this.getSysmod().getSpt(),this.getTrnmod().getTrn().getObjinr());
			  if(MdaUtils.isEmpty(this.getSysmod().getSpt().getInr()))
			    return false;
			  if(!MdaUtils.isEmpty(this.getTrnmod().getTrn().getOriinr()))
			  {
			    this.getTrnmod().sdbRead(this.getTrnmod().getSptchk(),this.getTrnmod().getTrn().getOriinr());
			    ctx.getDaoSession().dbDelete(this.getTrnmod().getSptchk());
			  }
			  this.getSysmod().getSpt().setSta("B");
			  this.getSysmod().getSpt().setScrtxt(this.getTrnmod().getTrn().getInr());
			  this.getTrnmod().getTrn().setSta("B");
			  ctx.getDaoSession().dbUpdate(this.getSysmod().getSpt());
			  ctx.getDaoSession().dbUpdate(this.getTrnmod().getTrn());
			}
			//将ers的报文状态改为B
			String hnglbh = this.getMadgrp().getMadlst().getElement(index).getHnglbh();
			ctx.getDaoSession().dbRead(this.getMadgrp().getErs(),new Argument<String>("hnglbh",hnglbh));
			int errcode = ctx.getErrorCode();
			this.getMadgrp().getErs().setRecsta("B");
			ctx.getDaoSession().dbUpdate(this.getMadgrp().getErs());
			MdaUtils.clear(this.getSysmod().getSpt());
			MdaUtils.clear(this.getTrnmod().getTrn());
			MdaUtils.clear(this.getTrnmod().getSptchk());
			MdaUtils.clear(this.getTrnmod().getWfmmod().getWfs());
			MdaUtils.clear(this.getTrnmod().getWfmmod().getWfe());
			MdaUtils.clear(this.getTrnmod().getOrdmod().getOrd());
			MdaUtils.clear(this.getTrnmod().getOrdmod().getOre());
			//如果退回成功，删除界面列表及对账结果表中的记录
			log.info("{}","退回成功" );
			ctx.setMessage(MdaUtils.getI18NString("matchk","CT000109"),MdaUtils.getI18NString("matchk","CT000110"));
			this.getMadgrp().getMadlst().delete(index);
			ctx.getDaoSession().dbDelete(this.getMadgrp().getRec(),new Argument("hnglbh",hnglbh));
			
			ctx.getDaoSession().dbCommit();
			log.info("{}","out repchk...");

			return true;
        }

        /**
        *   source:matchk.@0015.script
        */
        @Rule(target="matp.download",order=100)
        public boolean ruleMatpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","in download...");
			int index = 0;
			log.info("{}","current line selected is =" +index );
			int length = this.getMadgrp().getMadlst().fullSize();
			log.info("{}","size of tmplst is =" +length);
			String sigchk = "Q";
			if(index < 0 || index >= this.getMadgrp().getMadlst().fullSize())
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000086"),MdaUtils.getI18NString("matchk","CT000087"));
			  return true;
			}
			else if (!sigchk.equals(this.getMadgrp().getMadlst().getElement(index).getSigchk()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000088"),MdaUtils.getI18NString("matchk","CT000089"));
			  return true;
			}
			//判断是否待手工清分，如果待处理，则不允许重新下载
			ctx.getDaoSession().dbRead(this.getMadgrp().getErs(),new Argument<String>("hnglbh",this.getMadgrp().getMadlst().getElement(index).getHnglbh()));
			int errcode = ctx.getErrorCode();
			ctx.getDaoSession().dbRead(this.getMadgrp().getRpd(),new Argument<String>("ownref",this.getMadgrp().getErs().getOwnref()));
			int errcode1 = ctx.getErrorCode();
			String ptyinr = this.getMadgrp().getRpd().getPtyinr();
			String bchcod = this.getMadgrp().getRpd().getBchcod();
			log.info("{}","ptyinr =" +ptyinr);
			log.info("{}","bchcod =" +bchcod);
			if(MdaUtils.isEmpty(ptyinr) && Platform.headBchcod().equals(bchcod))
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000094"),MdaUtils.getI18NString("matchk","CT000095"));
			  return true;
			}
			ctx.getDaoSession().dbRead(this.getMadgrp().getRec(),new Argument<String>("hnglbh",this.getMadgrp().getMadlst().getElement(index).getHnglbh()));
			int errcode2 = ctx.getErrorCode();
			String sigapl = this.getMadgrp().getRec().getSigapl();
			if("0".equals(sigapl))
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000101"),MdaUtils.getI18NString("matchk","CT000102"));
			  return true;
			}
			String dir = "0";
			String hnglbh = this.getMadgrp().getMadlst().getElement(index).getHnglbh();
			String msgref = this.getMadgrp().getMadlst().getElement(index).getMsgref();
			log.info("{}","dir =" + dir);
			log.info("{}","hnglbh =" + hnglbh);
			log.info("{}","msgref =" + msgref);
			log.info("{}","业务处理开始");
			String cls="com.brilliance.eibs.main.Client";
			Object resMsg = MdaUtils.invoke(cls,"scall","yyptquery","yyptquery",new Object[]{dir,hnglbh,msgref});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","(content:" + content + ",isSuc:" + isSuc +")");
			  if("true ".equals(isSuc))
			  {
			    log.debug("{}","  in  if ...... ") ;
			    // 报文发送成功，标记该笔业务已经申请重新下载，不能重复申请
			    ctx.getDaoSession().dbBegin();
			    ctx.getDaoSession().dbRead(this.getMadgrp().getRec(),new Argument<String>("hnglbh",hnglbh));
			    int errcode3 = ctx.getErrorCode();
			    this.getMadgrp().getRec().setSigapl("0");
			    //如果已经下载成功，将界面上的处理状态更改为已下载，收报交易收报对账后再更新其处理状态及mad表
			    ctx.getDaoSession().dbUpdate(this.getMadgrp().getRec());
			    ctx.getDaoSession().dbCommit();
			    this.getMadgrp().getMadlst().getElement(index).setHadsta("3");
			    
			    ctx.setMessage(MdaUtils.getI18NString("matchk","CT000187"),MdaUtils.getI18NString("matchk","CT000188"));
			    return true;
			  }
			  else
			  {
			    ctx.setMessage(MdaUtils.getI18NString("matchk","CT000203"),MdaUtils.getI18NString("matchk","CT000204"));
			    return true;
			  }
			}
			log.info("{}","out download...");

			return true;
        }

        /**
        *   source:matchk.@0022.script
        */
        @Rule(target="matp.search",order=100)
        public boolean ruleMatpSearchN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}",".in  matp.search order 100 ");
			if(!ctx.checkAll(this.getMatp()))
			  return false;
			Date chkdat = this.getMatp().getChkdat();
			String bic = this.getSysmod().getPty().getBic();
			String ptyinr = this.getSysmod().getPty().getInr();
			String sql = "";
			log.info("{}","bic:" + bic );
			MdaUtils.clear(this.getMadgrp().getMadlst());
			//查询机构隔离
			if(MdaUtils.isEmpty(ctx.absGet(Sysmod.class).getPty().getBic()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000179"),MdaUtils.getI18NString("matchk","CT000180"));
			  return false;
			}
			//判断是否有当天的对账记录，如果有直接从mad表读取对账结果，否则再开始对账
			sql = "SELECT count(*) cnt FROM mat where agtextkey = '"+ bic +"' AND outdat >= ? AND outdat <= ?";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getMatp().getChkdat(),GT),MdaUtils.sqlDate(this.getMatp().getChkdat(),LT));
			Argument<Integer> cntArg = new Argument<Integer>("cnt");
			ctx.getDaoSession().dbFetchFields(cntArg) ;
			int errcode = ctx.getErrorCode();
			ctx.getDaoSession().dbCloseCursor();
			if( cntArg.value > 0  )
			{
			  log.info("{}","cntArg:" + cntArg.value );
			  sql="SELECT hnglbh,ownref,outdat,rptcur,rptamt,agtextkey,agtact,sigchk,hadsta,trninr FROM mad where agtextkey = '"+ bic +"' AND outdat >= ? AND outdat <= ?";
			  Argument<String> hnglbh = new Argument<String>("hnglbh");
			  Argument<String> ownref = new Argument<String>("ownref");
			  Argument<Date> outdat = new Argument<Date>("outdat");
			  Argument<String> rptcur = new Argument<String>("rptcur");
			  Argument<BigDecimal> rptamt = new Argument<BigDecimal>("rptamt");
			  Argument<String> agtextkey = new Argument<String>("agtextkey");
			  Argument<String> agtact = new Argument<String>("agtact");
			  Argument<String> sigchk = new Argument<String>("sigchk");
			  Argument<String> hadsta = new Argument<String>("hadsta");
			  Argument<String> trninr = new Argument<String>("trninr");
			  ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getMatp().getChkdat(),GT),MdaUtils.sqlDate(this.getMatp().getChkdat(),LT));
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(hnglbh,ownref,outdat,rptcur,rptamt,agtextkey,agtact,sigchk,hadsta,trninr);
			    if(ctx.getErrorCode()==NO_ERROR)
			      this.getMadgrp().getMadlst().add(hnglbh,ownref,outdat,rptcur,rptamt,agtextkey,agtact,sigchk,hadsta,trninr);
			    else
			      break;
			  }
			  ctx.getDaoSession().dbCloseCursor();
			  
			  return false;
			}
			//判断是否收到当天对账文件，如果没有则不允许对账
			String dat = MdaUtils.format(this.getMatp().getChkdat(),"yyyyMMdd");
			String sql0 = "SELECT count(*) cnt FROM kjzf_yydldz where cjrq = ?";
			ctx.getDaoSession().dbExecuteSQL(sql0,dat);
			Argument<Integer> cntArg1 = new Argument<Integer>("cnt");
			ctx.getDaoSession().dbFetchFields(cntArg1);
			int errcode1 = ctx.getErrorCode();
			ctx.getDaoSession().dbCloseCursor();
			if( cntArg1.value <= 0  )
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000195"),MdaUtils.getI18NString("matchk","CT000196"));
			  return false;
			}
			//如果是初次对账，则查询对账文件表及ERS记录，且生成新的mad结果
			//单证通终态和非终态报文笔数存表
			MdaUtils.clear(this.getMatp().getChklst());
			String sql1="SELECT a.hnglbh,a.ownref,a.outdat,b.rptcur,b.rptamt,b.agtextkey,b.agtact,a.recsta,a.dir,b.bchcod,b.inr objinr,a.trninr,a.msgref FROM ers a,rpd b WHERE a.objtyp='rpd' AND a.objinr=b.inr  AND (a.recsta='A' OR a.recsta='N' OR a.recsta='S' OR a.recsta='F') AND a.outdat >= ? AND a.outdat <= ?";
			sql1 = sql1 + " AND b.agtextkey= '"+ bic +"' AND b.ptyinr= '"+ ptyinr +"' " ;
			Argument<String> hnglbh1 = new Argument<String>("hnglbh");
			Argument<String> ownref1 = new Argument<String>("ownref");
			Argument<Date> outdat1 = new Argument<Date>("outdat");
			Argument<String> rptcur1 = new Argument<String>("rptcur");
			Argument<BigDecimal> rptamt1 = new Argument<BigDecimal>("rptamt");
			Argument<String> agtextkey1 = new Argument<String>("agtextkey");
			Argument<String> agtact1 = new Argument<String>("agtact");
			Argument<String> recsta1 = new Argument<String>("recsta");
			Argument<String> dir1 = new Argument<String>("dir");
			Argument<String> bchcod1 = new Argument<String>("bchcod");
			Argument<String> objinr1 = new Argument<String>("objinr");
			Argument<String> trninr1 = new Argument<String>("trninr");
			Argument<String> msgref1 = new Argument<String>("msgref");
			ctx.getDaoSession().dbExecuteSQL(sql1,MdaUtils.sqlDate(this.getMatp().getChkdat(),GT),MdaUtils.sqlDate(this.getMatp().getChkdat(),LT));
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(hnglbh1,ownref1,outdat1,rptcur1,rptamt1,agtextkey1,agtact1,recsta1,dir1,bchcod1,objinr1,trninr1,msgref1);
			  if(ctx.getErrorCode()==NO_ERROR)
			    this.getMatp().getChklst().add(hnglbh1,ownref1,outdat1,rptcur1,rptamt1,agtextkey1,agtact1,recsta1,dir1,bchcod1,objinr1,trninr1,msgref1);
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			log.info("{}","chklst current line is ="+this.getMatp().getChklst().fullSize() );
			//清算系统终态及处理中报文存列表，kjzf_yydldz为对账文件所对应表
			MdaUtils.clear(this.getMatp().getReclst());
			//根据代理行行号进行机构隔离
			String sql2="SELECT a.hnglbh,to_timestamp(a.cjrq,'yyyy-mm-dd hh24:mi:ss.ff') outdat,a.jyhbfh rptcur,a.jyje rptamt, a.dlhdm agtextkey, a.dlhzhdh agtact,a.qsywzt recsta,a.sfbz dir,substr(a.dlhzhdh,1,5) bchcod FROM kjzf_yydldz a WHERE a.cjrq = ? AND a.dlhdm = '"+ bic +"' ";
			Argument<String> hnglbh2 = new Argument<String>("hnglbh");
			Argument<String> rptcur2 = new Argument<String>("rptcur");
			Argument<Date> outdat2 = new Argument<Date>("outdat");
			Argument<BigDecimal> rptamt2 = new Argument<BigDecimal>("rptamt");
			Argument<String> agtextkey2 = new Argument<String>("agtextkey");
			Argument<String> agtact2 = new Argument<String>("agtact");
			Argument<String> recsta2 = new Argument<String>("recsta");
			Argument<String> dir2 = new Argument<String>("dir");
			Argument<String> bchcod2 = new Argument<String>("bchcod");
			String datStr1 = MdaUtils.format(this.getMatp().getChkdat(),"yyyyMMdd");
			ctx.getDaoSession().dbExecuteSQL(sql2,datStr1);
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(hnglbh2,rptcur2,outdat2,rptamt2,agtextkey2,agtact2,recsta2,dir2,bchcod2);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    if(!MdaUtils.isEmpty(dir2.value))
			    {
			      if( "1".equals(dir2.value))
			      {
			        dir2.value = ">";
			      }
			      else
			      {
			        dir2.value = "<";
			      }
			    }
			    this.getMatp().getReclst().add(hnglbh2,rptcur2,outdat2,rptamt2,agtextkey2,agtact2,recsta2,dir2,bchcod2);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
			log.info("{}","reclst current line is ="+this.getMatp().getReclst().fullSize() );
			log.debug("{}",".out  matp.search order 100 ");

			return true;
        }

        /**
        *   source:matchk.@0023.script
        */
        @Rule(target="matp.search",order=200)
        public boolean ruleMatpSearchN200(){
            IContext ctx = MdaEnv.getContext();
            
			//1.清算系统终态报文与单证通终态报文自动核对
			log.debug("{}",".in  matp.search order 200 ");
			MdaUtils.clear(this.getMadgrp().getMadlst());
			String sigchk = "";
			String hadsta = "";
			String sql = "";
			String recsta1 = "";
			int chkSize = this.getMatp().getChklst().fullSize();
			int recSize = this.getMatp().getReclst().fullSize();
			log.debug("{}","chkSize kaishi =" + chkSize);
			for(int i = 0;i < recSize; i++)
			{
			  String id2 = this.getMatp().getReclst().getElement(i).getHnglbh();
			  String dir2 = this.getMatp().getReclst().getElement(i).getDir();
			  String rptcur2 = this.getMatp().getReclst().getElement(i).getRptcur();
			  BigDecimal rptamt2 = this.getMatp().getReclst().getElement(i).getRptamt();
			  String agtextkey2 = this.getMatp().getReclst().getElement(i).getAgtextkey();
			  String agtact2 = this.getMatp().getReclst().getElement(i).getAgtact().trim();
			  Argument<String> objtyp = new Argument<String>("objtyp","rpd");
			  Argument<String> objinr = new Argument<String>("objinr");
			  Argument<String> trninr = new Argument<String>("trninr");
			  Argument<String> msgref = new Argument<String>("msgref");
			  Argument<String> ownref = new Argument<String>("ownref");
			  if(chkSize > 0)
			  {
			    for(int j=0;j<chkSize;j++)
			    {
			      String id1 = this.getMatp().getChklst().getElement(j).getHnglbh();
			      String dir1 = this.getMatp().getChklst().getElement(j).getDir();
			      String rptcur1 = this.getMatp().getChklst().getElement(j).getRptcur();
			      BigDecimal rptamt1 = this.getMatp().getChklst().getElement(j).getRptamt();
			      String agtextkey1 = this.getMatp().getChklst().getElement(j).getAgtextkey();
			      String agtact1 = this.getMatp().getChklst().getElement(j).getAgtact();
			      if(id2.equals(id1))
			      {
			        objinr.setValue(this.getMatp().getChklst().getElement(j).getObjinr());
			        trninr.setValue(this.getMatp().getChklst().getElement(j).getTrninr());
			        msgref.setValue(this.getMatp().getChklst().getElement(j).getMsgref());
			        ownref.setValue(this.getMatp().getChklst().getElement(j).getOwnref());
			        if(dir2.equals(dir1) && rptamt2.equals(rptamt1) && rptcur2.equals(rptcur1) && agtextkey2.equals(agtextkey1) &&  agtact2.equals(agtact1)  )
			        {
			          sigchk="C";
			          hadsta="1";
			        }
			        else
			        {
			          sigchk="Y";
			          hadsta="0";
			        }
			        recsta1 = this.getMatp().getChklst().getElement(j).getRecsta();
			        this.getMatp().getChklst().delete(j);
			        chkSize = chkSize - 1 ;
			        break;
			      }
			      else if((j+1)==chkSize && !id2.equals(id1))
			      {
			        sigchk = "Q";
			        hadsta = "0";
			        recsta1 = "A";
			      }
			    }
			  }
			  else
			  {
			    sigchk = "Q";
			    hadsta = "0";
			    recsta1 = "A";
			  }
			  // 2. 将对账成功结果加入到展示列表中
			  Argument<String> hnglbh = new Argument<String>("hnglbh",this.getMatp().getReclst().getElement(i).getHnglbh());
			  Argument<Date> outdat = new Argument<Date>("outdat",this.getMatp().getReclst().getElement(i).getOutdat());
			  Argument<String> rptcur = new Argument<String>("rptcur",this.getMatp().getReclst().getElement(i).getRptcur());
			  Argument<BigDecimal> rptamt = new Argument<BigDecimal>("rptamt",this.getMatp().getReclst().getElement(i).getRptamt());
			  Argument<String> agtextkey = new Argument<String>("agtextkey",this.getMatp().getReclst().getElement(i).getAgtextkey());
			  Argument<String> agtact = new Argument<String>("agtact",this.getMatp().getReclst().getElement(i).getAgtact().trim());
			  Argument<String> recsta = new Argument<String>("recsta",recsta1);
			  Argument<String> dir = new Argument<String>("dir",this.getMatp().getReclst().getElement(i).getDir());
			  Argument<String> bchcod = new Argument<String>("bchcod",this.getMatp().getReclst().getElement(i).getBchcod());
			  Argument<String> sigchk1 = new Argument<String>("sigchk" , sigchk );
			  Argument<String> hadsta1 = new Argument<String>("hadsta", hadsta );
			  this.getMadgrp().getMadlst().add(hnglbh,outdat,rptcur,rptamt,agtextkey,agtact,recsta,dir,bchcod,sigchk1,hadsta1,objtyp,objinr,trninr,msgref,ownref);

			}
			//单证通多余报文加入到展示列表中
			log.debug("{}","chkSize jieshu =" +this.getMatp().getChklst().fullSize() );
			for(int i=0 ;i< this.getMatp().getChklst().fullSize(); i++)
			{
			  if("F".equals(this.getMatp().getChklst().getElement(i).getRecsta()))
			  {
			    sigchk="C";
			    hadsta="1";
			  }
			  else
			  {
			    sigchk="D";
			    hadsta="0";
			  }
			  Argument<String> hnglbh = new Argument<String>("hnglbh",this.getMatp().getChklst().getElement(i).getHnglbh());
			  Argument<Date> outdat = new Argument<Date>("outdat",this.getMatp().getChklst().getElement(i).getOutdat());
			  Argument<String> rptcur = new Argument<String>("rptcur",this.getMatp().getChklst().getElement(i).getRptcur());
			  Argument<BigDecimal> rptamt = new Argument<BigDecimal>("rptamt",this.getMatp().getChklst().getElement(i).getRptamt());
			  Argument<String> agtextkey = new Argument<String>("agtextkey",this.getMatp().getChklst().getElement(i).getAgtextkey());
			  Argument<String> agtact = new Argument<String>("agtact",this.getMatp().getChklst().getElement(i).getAgtact());
			  Argument<String> recsta = new Argument<String>("recsta",this.getMatp().getChklst().getElement(i).getRecsta());
			  Argument<String> dir = new Argument<String>("dir",this.getMatp().getChklst().getElement(i).getDir());
			  Argument<String> bchcod = new Argument<String>("bchcod",this.getMatp().getChklst().getElement(i).getBchcod());
			  Argument<String> sigchk1 = new Argument<String>("sigchk" , sigchk);
			  Argument<String> hadsta1 = new Argument<String>("hadsta" , hadsta);
			  Argument<String> objinr = new Argument<String>("objinr",this.getMatp().getChklst().getElement(i).getObjinr());
			  Argument<String> objtyp = new Argument<String>("objtyp","rpd");
			  Argument<String> trninr = new Argument<String>("trninr",this.getMatp().getChklst().getElement(i).getTrninr());
			  Argument<String> msgref = new Argument<String>("msgref",this.getMatp().getChklst().getElement(i).getMsgref());
			  Argument<String> ownref = new Argument<String>("ownref",this.getMatp().getChklst().getElement(i).getOwnref());
			  this.getMadgrp().getMadlst().add(hnglbh,outdat,rptcur,rptamt,agtextkey,agtact,recsta,dir,bchcod,sigchk1,hadsta1,objinr,objtyp,trninr,msgref,ownref);
			}
			
			ctx.getDaoSession().dbBegin();
			log.info("{}","---madlst size ---:" + this.getMadgrp().getMadlst().fullSize());
			if(this.getMadgrp().getMadlst().fullSize()>0)
			{
			  for(int i=0 ; i<this.getMadgrp().getMadlst().fullSize(); i++ )
			  {
			    this.getMadgrp().getMadlst().getElement(i).setInr( Platform.sdbCounter("mad"));
			    ctx.getDaoSession().dbInsert(this.getMadgrp().getMadlst().getElement(i)) ;
			  }
			  // 将对账结果存入mad表；且在mat表标记 outdat已经对账
			  MdaUtils.clear(this.getMadgrp().getMat());
			  this.getMadgrp().getMat().setOutdat( this.getMatp().getChkdat());
			  this.getMadgrp().getMat().setAgtextkey( this.getSysmod().getPty().getBic());
			  this.getMadgrp().getMat().setInr( Platform.sdbCounter("mat"));
			  ctx.getDaoSession().dbInsert(this.getMadgrp().getMat()) ;
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("matchk","CT000185"),MdaUtils.getI18NString("matchk","CT000186"));
			}
			ctx.getDaoSession().dbCommit();
			log.debug("{}",".out  matp.search order 200 ");

			return true;
        }


        /**
        *   source:matchk.@0011.script
        */
        @Check(target="matp.chkdat",order=100)
        public boolean checkMatpChkdatN100(){
            IContext ctx = MdaEnv.getContext();
            
			String dat1 = MdaUtils.format(this.getMatp().getChkdat(),"yyyyMMdd");
			String dat2 = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			if(MdaUtils.isEmpty(this.getMatp().getChkdat()))
			  ctx.setFieldError(this,"matp.chkdat",MdaUtils.getI18NString("matchk","CT000030"));
			else if(MdaUtils.diff(MdaUtils.today(),this.getMatp().getChkdat()) < 0 || dat1.equals(dat2))
			{
			  MdaUtils.clear(this.getMatp().getMadgrp().getMadlst());
			  ctx.setFieldError(this,"matp.chkdat",MdaUtils.getI18NString("matchk","CT000190"));
			}

			return true;
        }


        /**
        *   source:matchk.@0019.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getMatp().setChkdat(MdaUtils.add(MdaUtils.today(),-1));
			

			return true;
        }


        /**
        *   source:matchk.@0013.script
        */
        public void createSpt()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//#CT000034
			if(!MdaUtils.isEmpty(this.getSysmod().getSpt().getInr()))
			  return;
			this.getSysmod().getSpt().setSta("B");
			this.getSysmod().getSpt().setSmhinr("");
			this.getSysmod().getSpt().setOrdinr(this.getTrnmod().getTrn().getOrdinr());
			this.getSysmod().getSpt().setObjtyp(this.getTrnmod().getTrn().getObjtyp());
			this.getSysmod().getSpt().setObjinr(this.getTrnmod().getTrn().getObjinr());
			this.getSysmod().getSpt().setObjnam(this.getTrnmod().getTrn().getObjnam());
			this.getSysmod().getSpt().setOprusrinr("");
			this.getSysmod().getSpt().setOprogninr(this.getTrnmod().getTrn().getOptptyinr());
			this.getSysmod().getSpt().setPtyinr(this.getTrnmod().getTrn().getPtyinr());
			this.getSysmod().getSpt().setOwnref(this.getTrnmod().getTrn().getOwnref());
			this.getSysmod().getSpt().setFrm(this.getTrnmod().getTrn().getInifrm());
			this.getSysmod().getSpt().setDattim(new Date());
			this.getSysmod().getSpt().setScr("I");
			this.getSysmod().getSpt().setScrtxt(this.getTrnmod().getTrn().getInr());
			String subptyinr = this.getTrnmod().getTrn().getPtyinr();
			if(!MdaUtils.isEmpty(subptyinr))
			{
			  this.getSysmod().getSpt().setScrpty(this.getTrnmod().getTrn().getPtyinr());
			}
			this.getSysmod().getSpt().setInr(Platform.sdbCounter("spt"));
			ctx.getDaoSession().dbInsert(this.getSysmod().getSpt());
			//String sptinr=$sysmod\\spt\\inr.getValue();
			//String tarfile=sptinr+".bak";
			//String path=Platform.catPath(Platform.catPath(Platform.getRootPath(),"data"),"delete");
			//tarfile=Platform.catPath(path,tarfile);
			log.info("{}","sptinr =" +this.getSysmod().getSpt().getInr());
			String tarfile = this.getSysmod().createFilename(this.getSysmod().getSpt().getInr(),"bak");
			if(MdaUtils.fileExists(tarfile))
			  MdaUtils.fileDelete(tarfile);
			//String inr=$trnmod\\trn\\inr.getValue();
			//String filename=inr+".dat";
			//String path=Platform.catPath(Platform.catPath(Platform.getRootPath(),"data"),"trndata");
			//filename=Platform.catPath(path,filename);
			String filename = this.getSysmod().createFilename(this.getTrnmod().getTrn().getInr(),"dat");
			log.info("{}","message"+filename);
			if(MdaUtils.fileExists(filename))
			  MdaUtils.fileCopy(filename,tarfile);
			else
			  ctx.setMessage("",MdaUtils.getI18NString("matchk","CT000035"));
		}








}