package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.QueusrVO;

import com.ceb.gjjs.mda.manager.module.Qsrgrp;
import com.ceb.gjjs.mda.manager.module.Qsrmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Qsrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 单证通开户情况查询
*/
@Transaction(vo= QueusrVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Queusr extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Queusr.class);

		@BDGetter
		private Qsrgrp qsrgrp;

		@BDGetter
		private Qsrmod qsrmod;

		@BDGetter
		private Qsrp qsrp;

		@BDGetter
		private Sysmod sysmod;


		public Queusr()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getQsrmod().setQsrgrpHolder(()->this.getQsrgrp());
           this.getQsrp().setQsrgrpHolder(()->this.getQsrgrp());
        }

        /**
        *   source:queusr.@0002.script
        */
        @Rule(target="qsrp.query",order=100)
        public boolean ruleQsrpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			refresh();

			return true;
        }

        /**
        *   source:queusr.@0016.script
        */
        @Rule(target="qsrgrp.qsrlst",order=100)
        public boolean ruleQsrgrpQsrlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getQsrgrp().getQsrlst().fullSize();
			log.debug("{}","index = "+index);
			if(index < 0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("queusr","CT000097"),MdaUtils.getI18NString("queusr","CT000098"));
			  return true;
			}
			MdaUtils.clear(this.getQsrgrp().getPtylst());
			String ptyinr = this.getQsrgrp().getQsrlst().getElement(index).getPtyinr();
			log.debug("{}","now view "+ptyinr);
			if(MdaUtils.isEmpty(ptyinr))
			  return true;
			String sql="SELECT nam,begdat FROM pty  WHERE  begdat>=? AND begdat<=? AND  (ptytyp='1' OR ptytyp='2') AND inr "+
			  "IN  (SELECT preptyinr FROM ptr WHERE  nxtptyinr ='"+ptyinr+"' AND (ptrtyp='0' OR ptrtyp='1'))";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT));
			Argument<String> nam = new Argument<String>("nam");
			Argument<Date> begdat= new Argument<Date>("begdat");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(nam,begdat);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    this.getQsrgrp().getPtylst().add(nam,begdat);
			  }
			  else
			  {
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			

			return true;
        }

        /**
        *   source:queusr.@0018.script
        */
        @Rule(target="qsrp.download",order=100)
        public boolean ruleQsrpDownloadN100(){
            IContext ctx = MdaEnv.getContext();
            

			IStream is=this.getQsrp().getDownload();
			is.setType("xls");
			//is.setName("开户情况.xls");
			List<Object[]> lst = new ArrayList<Object[]>();
			String tit[] = new String[8];
			tit[0] = "客户号";
			tit[1] = "客户名称";
			tit[2] = "所属分行";
			tit[3] = "所属机构";
			tit[4] = "签约版本";
			tit[5] = "签约时间";

			lst.add(tit);
			for(int i=0;i<this.getQsrgrp().getQsrlst().fullSize();i++)
			{
			  String[] line = new String[8];
			  line[0] = this.getQsrgrp().getQsrlst().getElement(i).getCid();
			  line[1] = this.getQsrgrp().getQsrlst().getElement(i).getCnam();
			  line[2] = this.getQsrgrp().getQsrlst().getElement(i).getNnam();
			  line[3] = this.getQsrgrp().getQsrlst().getElement(i).getBcod();
			  line[4] = this.getQsrgrp().getQsrlst().getElement(i).getVer();
			  if(MdaUtils.isEmpty(this.getQsrgrp().getQsrlst().getElement(i).getBegdat()))
			    line[5] ="";
			  else
			    line[5] = MdaUtils.format(this.getQsrgrp().getQsrlst().getElement(i).getBegdat(),"yyyy/MM/dd HH:mm:ss");
			  lst.add(line);
			}
			//String today = Platform.format(Platform.today(),"yyyyMMdd");
			String startdate=MdaUtils.format(this.getQsrp().getBegdat(),"yyyyMMdd");
			String enddate=MdaUtils.format(this.getQsrp().getEnddat(),"yyyyMMdd");
			if(MdaUtils.isEmpty(startdate))
			{
			  String fileName="企业手机银行阳光e智汇签约情况统计表"+enddate+".xls";
			  is.setName(fileName);
			}
			else
			{
			  String fileName = "企业手机银行阳光e智汇签约情况统计表"+startdate+"-"+enddate+".xls";
			  is.setName(fileName);
			}

			MdaUtils.unloadExcel(lst,is,false);

			return true;
        }

        /**
        *   source:queusr.@0005.script
        */
        @Rule(target="qsrp.orgnam",order=100)
        public boolean ruleQsrpOrgnamN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!MdaUtils.isEmpty(this.getQsrp().getOrgnam()))
			{
			  String ptyr=this.getQsrp().getOrgnam();
			  String cid=this.getSysmod().getCidByInr(ptyr);
			  String lvl=this.getSysmod().getTransLevel(cid);
			  if("0".equals(lvl)||"1".equals(lvl))
			  {
			    //获取下属机构
			    
			    MdaUtils.setValues(this.getQsrp(),"suborg",getXList(cid));
			    if(!MdaUtils.isEmpty(getXList(cid)))
			      this.getQsrp().setSuborg(getXList(cid).get(0).getValue());
			  }
			  else
			  {
			    
			    this.getQsrp().setSuborg(NULLSTR);
			  }
			  
			}
			/*
			  if("3".equals($sysmod\\pty\\brhlvl.getValue()))
			  return;
			  else
			  {
			  String pntcid=$qsrp\\orgnam.getValue();
			  log.info("---current selected pntbchcod is --- "+pntcid);
			  if(!Platform.isEmpty(pntcid))
			  {
			  Platform.clear($qsrp\\suborg);
			  List<CodetableItem> bch=new ArrayList<CodetableItem>();
			  if( "08101".equals(pntcid))
			  bch=$bchmod.getBchcodByDZTLevel("2");
			  if("2".equals($bchmod.getBchlvl(pntcid)))
			  bch=$bchmod.getSubBchcod(pntcid);
			  Platform.setValues($qsrp\\suborg,bch);
			  Platform.setModified($qsrp\\suborg);
			  }
			  }*/

			return true;
        }


        /**
        *   source:queusr.@0007.script
        */
        @Check(target="qsrp.begdat",order=100)
        public boolean checkQsrpBegdatN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*if(Platform.isEmpty($qsrp\\begdat))
			  Platform.error($qsrp\\begdat,#CT000000);
			  Date cntDate = Platform.add($qsrp\\enddat.getValue(),-366);
			  if(Platform.diff($qsrp\\begdat.getValue(),cntDate)<0)
			  Platform.error($qsrp\\begdat,#CT000103);*/
			if (!MdaUtils.isEmpty(this.getQsrp().getBegdat()))
			{
			  if(MdaUtils.diff(this.getQsrp().getBegdat(),MdaUtils.today())>0)
			  {
			    ctx.setFieldError(this,"qsrp.begdat","开始时间不能超过今天");
			  }
			  if(MdaUtils.diff(this.getQsrp().getEnddat(),this.getQsrp().getBegdat())<0)
			    ctx.setFieldError(this,"qsrp.begdat","结束日期不得早与开始日期");
			}

			return true;
        }

        /**
        *   source:queusr.@0008.script
        */
        @Check(target="qsrp.enddat",order=100)
        public boolean checkQsrpEnddatN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getQsrp().getEnddat()))
			  ctx.setFieldError(this,"qsrp.enddat",MdaUtils.getI18NString("queusr","CT000006"));
			else if (!MdaUtils.isEmpty(this.getQsrp().getBegdat()))
			{
			  if(MdaUtils.diff(this.getQsrp().getEnddat(),MdaUtils.today())>0)
			  {
			    ctx.setFieldError(this,"qsrp.enddat","结束日期不能超过今天");
			  }
			  if(MdaUtils.diff(this.getQsrp().getEnddat(),this.getQsrp().getBegdat())<0)
			    ctx.setFieldError(this,"qsrp.enddat",MdaUtils.getI18NString("queusr","CT000007"));
			}

			/* Date cntDate = Platform.add($qsrp\\enddat.getValue(),-366);
			  if(Platform.diff($qsrp\\begdat.getValue(),cntDate)<0)
			  Platform.error($qsrp\\enddat,"起止日期跨度不能超过一年");*/

			return true;
        }


        /**
        *   source:queusr.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			//银行机构
			if("0".equals(this.getSysmod().getPty().getPtytyp()))
			{
			  List<CodetableItem> bchtyp = new ArrayList<CodetableItem>();
			  //String lvl = $sysmod\\pty\\brhlvl.getValue();
			  String lvl = this.getSysmod().getPty().getLvl();
			  String ptyinr=this.getSysmod().getPty().getLvl();
			  if("0".equals(lvl))
			  {
			    bchtyp.add(new CodetableItem("全行","0"));
			    bchtyp.add(new CodetableItem("分行","1"));
			    this.getQsrp().setBrhtyp("0");
			  }
			  else if("1".equals(lvl))
			  {
			    bchtyp.add(new CodetableItem("分行","1"));
			    this.getQsrp().setBrhtyp("1");
			  }
			  else
			  {
			    this.getQsrp().setBrhtyp("2");
			  }
			  bchtyp.add(new CodetableItem("支行","2"));
			  

			  MdaUtils.setValues(this.getQsrp(),"brhtyp",bchtyp);
			  //载入机构
			  List<CodetableItem> bchcod=getBranchLst(this.getSysmod().getPty().getCid());
			  MdaUtils.setValues(this.getQsrp(),"orgnam",bchcod);
			  if(!MdaUtils.isEmpty(bchcod))
			    this.getQsrp().setOrgnam(bchcod.get(0).getValue());

			  
			  //总行
			  if("0".equals(lvl) || "1".equals(lvl))
			  {
			    //获取下属机构
			    MdaUtils.setValues(this.getQsrp(),"suborg",getXList(this.getSysmod().getCidByInr(this.getQsrp().getOrgnam())));
			  }
			  //分行
			  else if("1".equals(lvl))
			  {
			    MdaUtils.setValues(this.getQsrp(),"orgnam",this.getSysmod().getBchmod().getBrhBchcod(ptyinr));
			    MdaUtils.setValues(this.getQsrp(),"suborg",this.getSysmod().getBchmod().getSubBchcod(this.getSysmod().getPty().getCid()));
			  }
			  else if("2".equals(lvl))
			  {
			    MdaUtils.setValues(this.getQsrp(),"suborg",null);
			    
			    
			  }
			}
			else
			{

			  

			}

			this.getQsrp().setBegdat(null);
			this.getQsrp().setEnddat(MdaUtils.today());

			
			
			
			

			//默认查询所有记录
			MdaUtils.clear(this.getQsrgrp().getQsrlst());
			String orgnam=this.getQsrp().getOrgnam();
			log.debug("{}","开始时间："+this.getQsrp().getBegdat());
			log.debug("{}","开始时间："+this.getQsrp().getEnddat());
			String sql="select pp.cid ppcid,pp.nam bcod,p.begdat begdat,p.ver ver,p.cid cid,p.nam cnam,ps.nam nnam from pty p,ptr pr,pty pp  left join pty ps on pp.pntinr= ps.cid"
			  +" where p.ptytyp='2'and pr.preptyinr=p.inr and pr.nxtptyinr=pp.inr and pr.ptrtyp='0'";
			//sql=sql+getBankSql();
			
			sql=sql+"and p.begdat < ?";

			Argument<String> cid= new Argument<String>("cid");
			Argument<String> cnam= new Argument<String>("cnam");
			Argument<Date> begdat= new Argument<Date>("begdat");
			Argument<String> ver= new Argument<String>("ver");
			Argument<String> bcod= new Argument<String>("bcod");
			Argument<String> nnam= new Argument<String>("nnam");

			//String ptyinr=$sysmod\\pty\\inr.getValue();
			//String lvl=$sysmod\\pty\\lvl.getValue();
			//String ccid=$sysmod\\pty\\cid.getValue();
			String ptyinr="";
			if(!MdaUtils.isEmpty(this.getQsrp().getOrgnam())) //获取机构主键和机构等级
			  //ptyinr=orgnam;
			//lvl=$sysmod\\bchmod.getBranchLvlByInr(ptyinr);
			//ccid=$sysmod.getCidByInr(ptyinr);
			ptyinr=this.getQsrp().getOrgnam();
			else
			  ptyinr=this.getSysmod().getPty().getInr();
			String ccid=this.getSysmod().getCidByInr(ptyinr);
			String lvl=this.getSysmod().getTransLevel(ccid);
			if("0".equals(lvl))
			{
			  sql=sql+"AND EXISTS (SELECT  inr FROM pty WHERE pr.nxtptyinr=inr or pr.nxtptyinr='"+ptyinr+"')";
			}
			else if("1".equals(lvl))
			{
			  sql=sql+"AND EXISTS (SELECT inr FROM pty WHERE pr.nxtptyinr=inr and (inr='"+ptyinr+"' or pntinr='"+ccid+"'))";
			}
			else
			{
			  sql=sql+" AND pr.nxtptyinr='"+ptyinr+"'";
			}
			sql=sql+"order by pp.cid";

			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT));
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(cid,cnam,begdat,ver,bcod,nnam);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    if("总行单证中心".equals(nnam.value))
			    {
			      nnam.value=bcod.value;
			      this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			    }
			    else
			    {
			      this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			    }

			  }
			  else
			    break;

			}
			ctx.getDaoSession().dbCloseCursor();
			
			//初始时间
			/*
			  $qsrp\\begdat.setValue(Platform.add(Platform.today(),-7));
			  $qsrp\\enddat.setValue(Platform.today());*/


			return true;
        }


        /**
        *   source:queusr.@0010.script
        */
        public void queryAllClient()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//查询兴业银行的所有客户
			List<CodetableItem> bchpty=this.getSysmod().getBchmod().getBchcodByDZTLevel("2");
			int sumbch=bchpty.size();
			for(int idx=0;idx<sumbch;idx++)
			{
			  String cid=bchpty.get(idx).getValue();
			  //    log.info("--sub lvl, the***"+idx+" ***ptyinr is:"+cid);
			  queryBranchClient(cid);
			}
			log.info("{}","---query for 08101, total bch is:"+sumbch);
			log.info("{}","---Exit the branch search--");
		}
        /**
        *   source:queusr.@0011.script
        */
        public BigDecimal queryDirectClient(String bchptyinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//查询某一机构下的所属一级企业客户(含商行)
			BigDecimal sum=new BigDecimal(0);
			String sql="SELECT COUNT(inr) num FROM pty "
			  +" WHERE begdat>=? AND begdat<=? AND (ptytyp='1' OR ptytyp='2') AND inr IN "
			  +" (SELECT preptyinr FROM ptr WHERE nxtptyinr=? AND (ptrtyp='0' OR ptrtyp='1'))";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT),bchptyinr);
			int errcod=ctx.getErrorCode();
			if(NO_ERROR==errcod)
			{
			  Argument<BigDecimal> num = new Argument<BigDecimal>("num");
			  ctx.getDaoSession().dbFetchFields(num);
			  if(ctx.getErrorCode()==NO_ERROR)
			    sum=num.value;
			  log.info("{}","---the 1st dirct client be found is :"+sum);
			}
			ctx.getDaoSession().dbCloseCursor();
			return sum;
		}
        /**
        *   source:queusr.@0012.script
        */
        public BigDecimal queryCommericalBank(String bchptyinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//查询某一机构下的所属商行
			BigDecimal sum=new BigDecimal(0);
			String sql="SELECT COUNT(inr) num FROM pty "
			  +" WHERE begdat>=? AND begdat<=? AND ptytyp='1' AND inr IN "
			  +" (SELECT preptyinr FROM ptr WHERE nxtptyinr=? AND ptrtyp='1')";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT),bchptyinr);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  Argument<BigDecimal> num = new Argument<BigDecimal>("num");
			  ctx.getDaoSession().dbFetchFields(num);
			  if(ctx.getErrorCode()==NO_ERROR)
			    sum=num.value;
			  log.info("{}","--the 1st comlbank  be found is ="+sum);
			}
			ctx.getDaoSession().dbCloseCursor();
			return sum;
		}
        /**
        *   source:queusr.@0013.script
        */
        public BigDecimal queryClientofComlBank(String bchptyinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//查询某一机构下的所属商行的客户
			BigDecimal sum=new BigDecimal(0);
			String sql="SELECT COUNT(inr) num FROM pty "
			  +" WHERE begdat>=? AND begdat<=? AND ptytyp='3' AND inr IN "
			  +" (SELECT a.preptyinr FROM ptr a LEFT OUTER JOIN ptr b ON a.nxtptyinr=b.preptyinr "
			  +" WHERE a.ptrtyp='2' AND b.nxtptyinr=? AND b.ptrtyp='1')";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT),bchptyinr);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  Argument<BigDecimal> num = new Argument<BigDecimal>("num");
			  ctx.getDaoSession().dbFetchFields(num);
			  if(ctx.getErrorCode()==NO_ERROR)
			    sum=num.value;
			  log.info("{}","---the 2th client be found is ="+sum);
			}
			ctx.getDaoSession().dbCloseCursor();
			return sum;
		}
        /**
        *   source:queusr.@0014.script
        */
        public void queryBranchClient(String cid)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","--enter branch searching,--- input cid is :"+cid);
			//1.查询分行机构下的 所有客户
			querySubBchClient(cid);
			//2.查询分行下所属支行的所有客户
			String sqlsub="SELECT inr subptyinr ,nam ptynam FROM pty "
			  +" WHERE lvl='3' AND SUBSTR(cid,1,2)=SUBSTR("+cid+",1,2)";
			//
			List<CodetableItem> subpty=new ArrayList<CodetableItem>();
			ctx.getDaoSession().dbExecuteSQL(sqlsub);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  Argument<String> subptyinr = new Argument<String>("subptyinr");
			  Argument<String> ptynam = new Argument<String>("ptynam");
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(subptyinr,ptynam);
			    int er2=ctx.getErrorCode();
			    if(er2==NO_ERROR)
			    {
			      subpty.add(new CodetableItem(ptynam.value,subptyinr.value));
			    }
			    else if (er2==NO_MORE_ROW)
			      break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			int sumsub=subpty.size();
			for(int idx=0;idx<sumsub;idx++)
			{
			  String inr=subpty.get(idx).getValue();
			  //    log.info("--sub lvl, the***"+idx+" ***ptyinr is:"+inr);
			  BigDecimal sum=queryDirectClient(inr);
			  log.info("{}","====current sub ,total client num is:"+sum);
			  if(sum.compareTo(new BigDecimal(0))>0)
			  {
			    String nam=subpty.get(idx).getLabel();
			    log.debug("{}","inr="+inr+" nam="+nam);
			    this.getQsrgrp().getQsrlst().add(new Argument<String>("ptyinr",inr),new Argument<String>("ptynam",nam),new Argument<BigDecimal>("cltnum",sum));
			  }
			}
			log.info("{}","---*rhlvl-2, after query, total subbch is:"+sumsub);
			log.info("{}","the BRANCH row found is ="+this.getQsrgrp().getQsrlst().fullSize());
			log.info("{}","---Exit the branch search--");
		}
        /**
        *   source:queusr.@0015.script
        */
        public void querySubBchClient(String cid)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","--enter bch search,-- argument cid is :"+cid);
			String sql="SELECT inr ptyinr,nam ptynam FROM pty WHERE cid='"+cid+"'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  Argument<String> ptyinr = new Argument<String>("ptyinr");
			  Argument<String> ptynam= new Argument<String>("ptynam");
			  ctx.getDaoSession().dbFetchFields(ptyinr,ptynam);
			  if(ctx.getErrorCode()==NO_ERROR)
			  {
			    String inr=ptyinr.value;
			    log.info("{}","current bch pty inr is :"+inr);
			    BigDecimal sum=queryDirectClient(inr);
			    log.info("{}","current sub bch ,total row is:"+sum);
			    if(sum.compareTo(new BigDecimal(0))>0)
			    {
			      log.debug("{}","inr="+inr+" nam="+ptynam.value);
			      this.getQsrgrp().getQsrlst().add(ptyinr,ptynam,new Argument<BigDecimal>("cltnum",sum));
			    }
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			log.info("{}","--the Bch row found is :"+this.getQsrgrp().getQsrlst().fullSize());
			log.info("{}","--Exit the bch search---");
		}
        /**
        *   source:queusr.@0017.script
        */
        public void query()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getQsrgrp().getQsrlst());
			// String sql="SELECT nvl(n.nam,substr(p.cid,0,2) ) nnam,n.cid ncid,p.cid bcod ,p.nam ptynam,b.ncid cid,b.inr,b.nam cnam,b.begdat FROM pty p LEFT JOIN pty n ON substr(n.cid,0,2) = substr(p.cid,0,2)  AND n.nam LIKE '%分行' ";
			String sql="SELECT nvl(n.nam,substr(p.cid,0,2) ) nnam,n.cid ncid,b.heqinr opnbchcod,p.cid bcod ,p.nam ptynam,b.ncid cid,b.inr,b.nam cnam,b.begdat,b.enddat enddat FROM pty p LEFT JOIN pty n ON substr(n.cid,0,2) = substr(p.cid,0,2) AND n.brhflg ='1' AND n.brhlvl='2' ";
			sql=sql+",pty b,ptr WHERE (ptrtyp='0' OR ptrtyp='1') AND nxtptyinr=p.inr AND preptyinr=b.inr AND (b.ptytyp='1' OR b.ptytyp='2') ";
			if(!MdaUtils.isEmpty(this.getQsrp().getOrgnam()))
			{

			  String orgnam= this.getQsrp().getOrgnam();
			  log.info("{}","orgnam :"+orgnam);
			  if(orgnam.contains("'"))
			  {
			    ctx.setFieldError(this,"qsrp.orgnam",MdaUtils.getI18NString("queusr","CT000100"));
			    return;
			  }

			  sql=sql+" AND (p.cid like'%"+this.getQsrp().getOrgnam()+"%' OR p.nam like '%"+this.getQsrp().getOrgnam()+"%' )";
			}
			log.debug("{}","message"+MdaUtils.diff(this.getQsrp().getBegdat(),this.getQsrp().getEnddat()));
			sql = sql+" AND b.begdat>=? AND b.begdat<=?";
			String brhlvlcon = "";
			// 2 分行
			if("2".equals(this.getQsrp().getBrhtyp()))
			{
			  brhlvlcon = " AND p.brhlvl IN ('2','3','4')";
			}
			// 3 支行
			else if("3".equals(this.getQsrp().getBrhtyp()))
			{
			  brhlvlcon = " AND p.brhlvl IN ('3','4')";
			}
			log.debug("{}","NOMORROW=="+NO_MORE_ROW);
			sql=sql+brhlvlcon;
			sql=sql+" ORDER BY n.cid,p.cid,b.inr";
			ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT));
			Argument<String> nnam = new Argument<String>("nnam");   // 上级机构名称
			Argument<String> cid = new Argument<String>("cid");     // 核心客户号
			Argument<String> opnbchcod  = new Argument<String>("opnbchcod"); // 开户机构
			Argument<String> bcod  = new Argument<String>("bcod"); // 归属机构
			Argument<String> ptynam = new Argument<String>("ptynam"); // 开户机构名称
			Argument<String> cnam = new Argument<String>("cnam");  // 客户名称
			Argument<Date> begdat = new Argument<Date>("begdat");		// 开通日期
			Argument<Date> enddat = new Argument<Date>("enddat");   // 关户日期
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(nnam,cid,opnbchcod,bcod,ptynam,cnam,begdat,enddat);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    this.getQsrgrp().getQsrlst().add(nnam,cid,opnbchcod,bcod,ptynam,cnam,begdat);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:queusr.@0019.script
        */
        public void refresh()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getQsrgrp().getQsrlst());
			String orgnam=this.getQsrp().getOrgnam();
			log.debug("{}","开始时间："+this.getQsrp().getBegdat());
			log.debug("{}","开始时间："+this.getQsrp().getEnddat());
			String sql="select pp.cid ppcid,pp.nam bcod,p.begdat begdat,p.ver ver,p.cid cid,p.nam cnam,ps.nam nnam from pty p,ptr pr,pty pp  left join pty ps on pp.pntinr= ps.cid"
			  +" where p.ptytyp='2'and pr.preptyinr=p.inr and pr.nxtptyinr=pp.inr and pr.ptrtyp='0'";
			//sql=sql+getBankSql();
			
			if(MdaUtils.isEmpty(this.getQsrp().getBegdat()))
			{
			  sql=sql+"and p.begdat <= ?";
			}
			else
			{
			  sql=sql+"and p.begdat >= ? and p.begdat <= ?";
			}

			Argument<String> cid= new Argument<String>("cid");
			Argument<String> cnam= new Argument<String>("cnam");
			Argument<Date> begdat= new Argument<Date>("begdat");
			Argument<String> ver= new Argument<String>("ver");
			Argument<String> bcod= new Argument<String>("bcod");
			Argument<String> nnam= new Argument<String>("nnam");

			//String ptyinr=$sysmod\\pty\\inr.getValue();
			//String lvl=$sysmod\\pty\\lvl.getValue();
			//String ccid=$sysmod\\pty\\cid.getValue();
			String ptyinr="";
			if(!MdaUtils.isEmpty(this.getQsrp().getSuborg())) //获取机构主键和机构等级
			  //ptyinr=orgnam;
			//lvl=$sysmod\\bchmod.getBranchLvlByInr(ptyinr);
			//ccid=$sysmod.getCidByInr(ptyinr);
			//根据下属机构查询
			ptyinr=this.getQsrp().getSuborg();
			else
			  ptyinr=this.getQsrp().getOrgnam();
			String ccid=this.getSysmod().getCidByInr(ptyinr);
			String lvl=this.getSysmod().getTransLevel(ccid);
			if("0".equals(lvl))
			{
			  sql=sql+"AND EXISTS (SELECT  inr FROM pty WHERE pr.nxtptyinr=inr or pr.nxtptyinr='"+ptyinr+"')";
			}
			else if("1".equals(lvl))
			{
			  sql=sql+"AND EXISTS (SELECT inr FROM pty WHERE pr.nxtptyinr=inr and (inr='"+ptyinr+"' or pntinr='"+ccid+"'))";
			}
			else
			{
			  sql=sql+" AND pr.nxtptyinr='"+ptyinr+"'";
			}
			sql=sql+"order by pp.cid";

			//开始日期为空，只根据开始结束日期
			if(MdaUtils.isEmpty(this.getQsrp().getBegdat()))
			{
			  ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT));
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(cid,cnam,begdat,ver,bcod,nnam);
			    if(ctx.getErrorCode()==NO_ERROR)
			    {
			      log.debug("{}","nnam值:"+nnam.value);
			      log.debug("{}","总行单证中心".equals(nnam.value));
			      if("总行单证中心".equals(nnam.value))
			      {
			        log.debug("{}","*****");
			        nnam.value=bcod.value;
			        log.debug("{}","nnam值："+nnam);
			        this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			      }
			      else
			      {
			        this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			      }
			    }
			    else
			      break;

			  }
			}
			else
			  ctx.getDaoSession().dbExecuteSQL(sql,MdaUtils.sqlDate(this.getQsrp().getBegdat(),GT),MdaUtils.sqlDate(this.getQsrp().getEnddat(),LT));
			while(true)
			{
			ctx.getDaoSession().dbFetchFields(cid,cnam,begdat,ver,bcod,nnam);
			if(ctx.getErrorCode()==NO_ERROR)
			{
			  log.debug("{}","nnam值:"+nnam.value);
			  log.debug("{}","总行单证中心".equals(nnam.value));
			  if("总行单证中心".equals(nnam.value))
			  {
			    log.debug("{}","*****");
			    nnam.value=bcod.value;
			    log.debug("{}","nnam值："+nnam);
			    this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			  }
			  else
			  {
			    this.getQsrgrp().getQsrlst().add(cid,cnam,begdat,ver,bcod,nnam);
			  }
			}
			else
			  break;

			}
			ctx.getDaoSession().dbCloseCursor();
			
		}
        /**
        *   source:queusr.@0021.script
        */
        public List<CodetableItem> getXList(String bchcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<CodetableItem> bch=new ArrayList<CodetableItem>();
			log.debug("{}","[getBranchList()]bchcod="+bchcod);
			String trnlvl = this.getSysmod().getTransLevel(bchcod);
			String sql="";
			log.debug("{}","[getBranchList()]trnlvl="+trnlvl);
			/*
			  if("1".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='2' OR lvl='1') ORDER BY p.inr";
			  }
			  else if("2".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='2' OR lvl='3') ";
			  sql = sql+"AND substr(p.cid, 1, 2) = '"+bchcod.substring(0,2)+"' ORDER BY p.inr";
			  }
			  else if("3".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND cid='"+bchcod+"' ";
			  }
			  */
			if("0".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='1' or lvl='0') ORDER BY lvl";
			}
			else if("1".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND lvl='2' ";
			  sql = sql+"AND pntinr = '"+bchcod+"' or cid = '" + bchcod + "' ORDER BY lvl";
			  //sql = sql+"AND substr(p.cid, 1, 2) = '"+bchcod.substring(0,2)+"' ORDER BY p.inr";
			}
			else if("2".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND cid='"+bchcod+"' ";
			}

			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> inr = new Argument<String>("inr");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,nam);
			  if(ctx.getErrorCode()== NO_ERROR)
			  {
			    bch.add(new CodetableItem(nam.value,inr.value));
			  }
			  else
			  {
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			return bch;
		}
        /**
        *   source:queusr.@0023.script
        */
        public List<CodetableItem> getBranchLst(String bchcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<CodetableItem> bch=new ArrayList<CodetableItem>();
			log.debug("{}","[getBranchList()]bchcod="+bchcod);
			String trnlvl = this.getSysmod().getTransLevel(bchcod);
			String sql="";
			log.debug("{}","[getBranchList()]trnlvl="+trnlvl);
			/*
			  if("1".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='2' OR lvl='1') ORDER BY p.inr";
			  }
			  else if("2".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='2' OR lvl='3') ";
			  sql = sql+"AND substr(p.cid, 1, 2) = '"+bchcod.substring(0,2)+"' ORDER BY p.inr";
			  }
			  else if("3".equals(trnlvl))
			  {
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND cid='"+bchcod+"' ";
			  }
			  */
			if("0".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='0' OR lvl='1') ORDER BY lvl";
			}
			else if("1".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND (lvl='2' OR lvl='1') ";
			  sql = sql+"AND pntinr = '"+bchcod+"' or cid = '" + bchcod + "' ORDER BY lvl";
			  //sql = sql+"AND substr(p.cid, 1, 2) = '"+bchcod.substring(0,2)+"' ORDER BY p.inr";
			}
			else if("2".equals(trnlvl))
			{
			  sql = "SELECT p.inr inr,p.nam nam FROM pty p WHERE p.ptytyp='0' AND cid='"+bchcod+"' ";
			}

			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> nam = new Argument<String>("nam");
			Argument<String> inr = new Argument<String>("inr");
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,nam);
			  if(ctx.getErrorCode()== NO_ERROR)
			  {
			    bch.add(new CodetableItem(nam.value,inr.value));
			  }
			  else
			  {
			    break;
			  }
			}
			ctx.getDaoSession().dbCloseCursor();
			return bch;
		}





}