package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.SysautVO;

import com.ceb.gjjs.mda.manager.module.Grant;
import com.ceb.gjjs.mda.manager.module.Authp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Authgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 主管授权
*/
@Transaction(vo= SysautVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Sysaut extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Sysaut.class);

		@BDGetter
		private Authgrp authgrp;

		@BDGetter
		private Authp authp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Grant grant;


		public Sysaut()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAuthp().setAuthgrpHolder(()->this.getAuthgrp());
        }

        /**
        *   source:sysaut.@0001.script
        */
        @Rule(target="authp.sel",order=100)
        public boolean ruleAuthpSelN100(){
            IContext ctx = MdaEnv.getContext();
            
			//goSelectedItem();
			showSelectedItem();

			return true;
        }

        /**
        *   source:sysaut.@0005.script
        */
        @Rule(target="authgrp.authlst",order=100)
        public boolean ruleAuthgrpAuthlstN100(){
            IContext ctx = MdaEnv.getContext();
            
			showSelectedItem();

			return true;
        }

        /**
        *   source:sysaut.@0007.script
        */
        @Rule(target="authgrp.authlst",order=200)
        public boolean ruleAuthgrpAuthlstN200(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.prompt(MdaUtils.getI18NString("sysaut","CT000008"),MdaUtils.getI18NString("sysaut","CT000009")))
			  return true;
			int index=0;
			log.info("{}","remove..."+index);
			this.getAuthgrp().getAuth().copyValue(this.getAuthgrp().getAuthlst().getElement(index));
			ctx.getDaoSession().dbBegin();
			this.getAuthgrp().getAuth().setSta("L");
			ctx.getDaoSession().dbUpdate(this.getAuthgrp().getAuth());
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!=NO_ERROR)
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000010"),MdaUtils.getI18NString("sysaut","CT000011"));
			else
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000012"),MdaUtils.getI18NString("sysaut","CT000013"));
			updateList();

			return true;
        }

        /**
        *   source:sysaut.@0011.script
        */
        @Rule(target="authp.grant",order=100)
        public boolean ruleAuthpGrantN100(){
            IContext ctx = MdaEnv.getContext();
            
			boolean result = true;
			if("dbmaut".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmaut();
			else if("dbmopr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmopr0();
			else if("dbmbpr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmbpr0();
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000038"),MdaUtils.getI18NString("sysaut","CT000039"));
			  return false;
			}
			if(result)
			{
			  //重置授权记录的标志位
			  log.debug("{}","将要删除inr["+this.getAuthgrp().getAuth().getInr()+"]的授权记录!");
			  ctx.getDaoSession().dbBegin();
			  this.getAuthgrp().getAuth().setSta("D");
			  //Platform.dbDelete($authgrp\\auth,new Argument<String>("inr",$authgrp\\auth\\inr.getValue()));
			  ctx.getDaoSession().dbUpdate(this.getAuthgrp().getAuth());
			  ctx.getDaoSession().dbCommit();
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000040"),MdaUtils.getI18NString("sysaut","CT000041"));
			}
			else
			{
			  log.info("{}","error when delete auth record!");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000042"),MdaUtils.getI18NString("sysaut","CT000043"));
			}

			
			updateList();

			return true;
        }

        /**
        *   source:sysaut.@0012.script
        */
        @Rule(target="authp.reject",order=100)
        public boolean ruleAuthpRejectN100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbBegin();
			this.getAuthgrp().getAuth().setSta("R");
			ctx.getDaoSession().dbUpdate(this.getAuthgrp().getAuth());
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!=NO_ERROR)
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000044"),MdaUtils.getI18NString("sysaut","CT000045"));
			else
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000046"),MdaUtils.getI18NString("sysaut","CT000047"));
			
			updateList();

			return true;
        }



        /**
        *   source:sysaut.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//log.info("ptyinr:"+$sysmod\\usr\\ptyinr.getValue());
			//读取待授权列表
			//Platform.dbReadset($authgrp\\authlst,new Argument<String>("ptyinr",$sysmod\\usr\\ptyinr.getValue()));
			
			return true;
        }

        /**
        *   source:sysaut.@0002.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.info("{}","ptyinr:"+this.getSysmod().getUsr().getPtyinr());
			ctx.getDaoSession().dbReadset(this.getAuthgrp().getAuthlst(),new Argument<String>("ptyinr",this.getSysmod().getUsr().getPtyinr()),new Argument<Object>("inr",DESC),new Argument<String>("usrinr",NE,this.getSysmod().getUsr().getInr()),new Argument<String>("sta","W"));
			int errorCode = ctx.getErrorCode();
			if(errorCode!=NO_ERROR)
			  log.error("{}","load authlst wrong!errorCode="+errorCode);
			log.info("{}","authlist loaded!");
			

			return true;
        }


        /**
        *   source:sysaut.@0004.script
        */
        public void goSelectedItem()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int index = 0;
			if(index<0   ||  index>=this.getAuthgrp().getAuthlst().fullSize())
			{
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000002"),MdaUtils.getI18NString("sysaut","CT000003"));
			  return;
			}
			//准备数据
			log.info("{}","auth inr:"+this.getAuthgrp().getAuthlst().getElement(index).getInr());
			MdaUtils.clear(this.getAuthgrp().getAuth());
			this.getAuthgrp().getAuth().copyValue(this.getAuthgrp().getAuthlst().get(index));
			ctx.storeData("com.brilliance.sysaut.auth",this.getAuthgrp().getAuth());
			
		}
        /**
        *   source:sysaut.@0008.script
        */
        public void updateList()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","ptyinr:"+this.getSysmod().getUsr().getPtyinr());
			ctx.getDaoSession().dbReadset(this.getAuthgrp().getAuthlst(),new Argument<String>("ptyinr",this.getSysmod().getUsr().getPtyinr()),new Argument<Object>("inr",DESC),new Argument<String>("sta","W"));
			int errorCode = ctx.getErrorCode();
			if(errorCode!=NO_ERROR)
			  log.error("{}","load authlst wrong!errorCode="+errorCode);
			log.info("{}","authlist loaded!");
			
		}
        /**
        *   source:sysaut.@0010.script
        */
        public void showSelectedItem()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int index = 0;
			if(index<0)
			{
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000016"),MdaUtils.getI18NString("sysaut","CT000017"));
			  return;
			}
			//准备数据
			log.info("{}","auth inr:"+this.getAuthgrp().getAuthlst().getElement(index).getInr());
			MdaUtils.clear(this.getAuthgrp().getAuth());
			this.getAuthgrp().getAuth().copyValue(this.getAuthgrp().getAuthlst().get(index));
			//
			String inr=this.getAuthgrp().getAuth().getInr();
			Platform.writeToSession("dspfile",inr);//token，用来判断请求唯一性
			log.info("{}","session dspfile :"+Platform.readFromSession("dspfile"));
			String frm=this.getAuthgrp().getAuth().getFrm().trim();
			String filenameUrl="";
			if("dbmaut".equals(frm))
			  filenameUrl="/data/grant/dbmaut/dsp/"+inr+".zul";
			else if("dbmopr0".equals(frm))
			  filenameUrl="/data/grant/dbmopr0/dsp/"+inr+".zul";
			else if("dbmbpr0".equals(frm))
			  filenameUrl="/data/grant/dbmbpr0/dsp/"+inr+".zul";
			else
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000036"),MdaUtils.getI18NString("sysaut","CT000037"));
			this.getAuthp().setDisplay("/dsp"+filenameUrl);
			
		}
        /**
        *   source:sysaut.@0013.script
        */
        public boolean grantDbmaut()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//autp数据恢复
			String filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmaut/dat/" +this.getAuthgrp().getAuth().getInr()+"autp.dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000048"),MdaUtils.getI18NString("sysaut","CT000049"));
			  return false;
			}
			IStream is=this.getAuthp().getStream();
			log.debug("{}","streamLoad...");
			MdaUtils.streamLoad(is,filename);
			log.debug("{}","loadData autp...");
			MdaUtils.loadData(this.getGrant().getAutp(),is);
			log.debug("{}","loadData autp OK...");
			log.debug("{}","amt1:"+this.getGrant().getAutp().getAmt1());
			//autgrp数据恢复
			filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmaut/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000050"),MdaUtils.getI18NString("sysaut","CT000051"));
			  return false;
			}
			is=this.getAuthp().getStream();
			log.debug("{}","streamLoad...");
			MdaUtils.streamLoad(is,filename);
			log.debug("{}","loadData...");
			MdaUtils.loadData(this.getGrant().getAutgrp(),is);
			log.debug("{}","loadData OK...");
			log.debug("{}","chkflg:"+this.getGrant().getAutgrp().getPtyaut().getChkflg());
			log.debug("{}","lvl:"+this.getGrant().getAutgrp().getPtyaut().getLvl());
			//如果frm是空的，那说明是所有交易都要更新，否则只更新指定交易
			boolean result=true;
			if(!MdaUtils.isEmpty(this.getGrant().getAutgrp().getModlst().getFrm()))
			{
			  result=updatePtyaut(this.getGrant().getAutgrp().getModlst().getFrm());
			  if(!result)
			    return false;
			}
			else
			{
			  for(int i=1;i<this.getGrant().getAutgrp().getModlstlst().fullSize();i++)
			  {
			    result=updatePtyaut(this.getGrant().getAutgrp().getModlstlst().getElement(i).getFrm());
			    if(!result)
			      return false;
			  }
			}
			return result;
		}
        /**
        *   source:sysaut.@0014.script
        */
        public boolean grantDbmopr0()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean result=true;
			//恢复数据
			String filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmopr0/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000052"),MdaUtils.getI18NString("sysaut","CT000053"));
			  return false;
			}
			IStream is=this.getAuthp().getStream();
			MdaUtils.streamLoad(is,filename);
			MdaUtils.loadData(this.getGrant().getOprgrp(),is);
			//End of load data
			MdaUtils.clear(this.getGrant().getOprgrp().getUsraut());
			String frm ="";
			if(!MdaUtils.isEmpty(this.getGrant().getOprgrp().getOpraut().getTrsinr()))
			  frm = this.getGrant().getOprgrp().getOpraut().getTrsinr().trim();
			if(!MdaUtils.isEmpty(frm))
			  result = saveUsrautByFrm(frm);
			else
			{
			  for(int i=1;i<this.getGrant().getOprgrp().getOprautlst().fullSize();i++)
			  {
			    result = saveUsrautByFrm(this.getGrant().getOprgrp().getOprautlst().getElement(i).getTrsinr());
			    if(!result)
			      return result;
			  }
			}
			return result;
		}
        /**
        *   source:sysaut.@0015.script
        */
        public boolean grantDbmbpr0()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmbpr0/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			if(!MdaUtils.fileExists(fileName))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut","CT000054"),MdaUtils.getI18NString("sysaut","CT000055"));
			  return false;
			}
			IStream is=this.getAuthp().getStream();
			MdaUtils.streamLoad(is,fileName);
			MdaUtils.loadData(this.getGrant().getBprgrp(),is);
			ctx.getDaoSession().dbBegin();
			log.debug("{}","to make sure stream is load or not?ptyinr"+this.getGrant().getBprgrp().getAuth().getInr());
			//如果是新增用户，只要修改状态即可
			log.debug("{}","主管授权用户密码 psw = "+this.getGrant().getBprgrp().getUsr().getPwd());
			if("I".equals(this.getGrant().getBprgrp().getUsr().getStat()))
			{
			  //新增用户
			  this.getGrant().getBprgrp().getUsr().setInr(Platform.sdbCounter("usr"));
			  this.getGrant().getBprgrp().getUsr().setPwd("pkKner19T1G/kibOr4kfy7Wymbg=");
			  this.getGrant().getBprgrp().getUsr().setStat(null);
			  //Platform.dbUpdate($grant\\bprgrp\\usr);
			  ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsr());
			  log.debug("{}","Insert Usr inr = "+this.getGrant().getBprgrp().getUsr().getInr());
			}
			else if("U".equals(this.getGrant().getBprgrp().getUsr().getStat()))
			{
			  //修改用户
			  this.getGrant().getBprgrp().getUsr().setStat(null);
			  ctx.getDaoSession().dbUpdate(this.getGrant().getBprgrp().getUsr());
			  log.debug("{}","Update Usr inr = "+this.getGrant().getBprgrp().getUsr().getInr());
			}
			log.info("{}","size1="+this.getGrant().getBprgrp().getSelrol().fullSize());
			for(int i = 0; i < this.getGrant().getBprgrp().getSelrol().fullSize(); i++)
			{
			  if(!existUsrRol(this.getGrant().getBprgrp().getSelrol().getElement(i).getInr()))
			  {
			    //保存右侧选中角色
			    MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			    this.getGrant().getBprgrp().getUsrrol().setInr(Platform.sdbCounter("usrrol"));
			    this.getGrant().getBprgrp().getUsrrol().setUsrinr(this.getGrant().getBprgrp().getUsr().getInr());
			    this.getGrant().getBprgrp().getUsrrol().setRolinr(this.getGrant().getBprgrp().getSelrol().getElement(i).getInr());
			    this.getGrant().getBprgrp().getUsrrol().setRolnam(this.getGrant().getBprgrp().getSelrol().getElement(i).getRolnam());
			    this.getGrant().getBprgrp().getUsrrol().setPtyinr(this.getGrant().getBprgrp().getPty().getInr());
			    ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsrrol());
			    log.debug("{}","Insert Usr inr = "+this.getGrant().getBprgrp().getUsrrol().getUsrinr()+", rolinr = "+this.getGrant().getBprgrp().getUsrrol().getRolinr());
			    if("管理员".equals(this.getGrant().getBprgrp().getUsrrol().getRolnam()))
			    {
			      ctx.getDaoSession().dbRead(this.getAuthgrp().getAdmin(),new Argument<String>("workid",this.getGrant().getBprgrp().getUsr().getLgnnam()));
			      if(MdaUtils.isEmpty(this.getAuthgrp().getAdmin().getInr()))
			      {
			        this.getAuthgrp().getAdmin().setInr(Platform.sdbCounter("admin"));
			        this.getAuthgrp().getAdmin().setWorkid(this.getGrant().getBprgrp().getUsr().getLgnnam());
			        this.getAuthgrp().getAdmin().setNam(this.getGrant().getBprgrp().getUsr().getOprnam());
			        ctx.getDaoSession().dbInsert(this.getAuthgrp().getAdmin());
			        log.debug("{}","添加admin管理员记录！----" + this.getGrant().getBprgrp().getUsr().getOprnam());
			      }

			      /*$authgrp\\admin\\workid.setValue($sysmod\\usr\\lgnnam.getValue());
			        $authgrp\\admin\\nam.setValue($sysmod\\usr\\oprnam.getValue());
			        String sql = "select inr ,workid ,nam from admin where workid = '" + $sysmod\\usr\\lgnnam.getValue() + "' and nam = '" + $sysmod\\usr\\oprnam.getValue() + "'";
			        Argument<String> inr = new Argument<String>("inr");
			        Platform.dbExecuteSQL(sql);
			        Platform.dbFetchFields(inr);
			        int errorCode = Platform.errorCode();
			        if(errorCode == NO_ERROR)
			        {
			        log.debug("插入管理员记录！");
			        $authgrp\\admin\\inr.setValue(Platform.sdbCounter("admin"));
			        Platform.dbInsert($authgrp\\admin);*/
			    }
			  }
			}
			log.info("{}","size2="+this.getGrant().getBprgrp().getRollst().fullSize());
			for(int i = 0; i < this.getGrant().getBprgrp().getRollst().fullSize(); i++)
			{
			  if(existUsrRol(this.getGrant().getBprgrp().getRollst().getElement(i).getInr()))
			  {
			    //删除左侧未选中角色
			    MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			    ctx.getDaoSession().dbRead(this.getGrant().getBprgrp().getUsrrol(),new Argument<String>("rolinr",this.getGrant().getBprgrp().getRollst().getElement(i).getInr()),new Argument<String>("usrinr",this.getGrant().getBprgrp().getUsr().getInr()));

			    //插入管理员记录
			    if("管理员".equals(this.getGrant().getBprgrp().getRollst().getElement(i).getRolnam()))
			    {
			      ctx.getDaoSession().dbRead(this.getGrant().getBprgrp().getUsr(),new Argument<String>("inr",this.getGrant().getBprgrp().getUsrrol().getUsrinr()));
			      ctx.getDaoSession().dbRead(this.getAuthgrp().getAdmin(),new Argument<String>("workid",this.getGrant().getBprgrp().getUsr().getLgnnam()));
			      if(!MdaUtils.isEmpty(this.getAuthgrp().getAdmin().getInr()))
			      {
			        log.debug("{}","删除admin管理员记录！----" + this.getAuthgrp().getAdmin().getNam());
			        ctx.getDaoSession().dbDelete(this.getAuthgrp().getAdmin());
			      }

			    }
			    log.debug("{}","Delete Usr inr = "+this.getGrant().getBprgrp().getUsrrol().getUsrinr()+", rolinr = "+this.getGrant().getBprgrp().getUsrrol().getRolinr());
			    ctx.getDaoSession().dbDelete(this.getGrant().getBprgrp().getUsrrol());
			  }
			  log.debug("{}","Not Deal With rol inr = "+this.getGrant().getBprgrp().getRollst().getElement(i).getInr());
			}
			existDbipsw();
			//删除授权任务
			IModule auth = (IModule)ctx.restoreData("com.brilliance.sysaut.auth");
			if(!MdaUtils.isEmpty(auth))
			{
			  MdaUtils.clear(this.getGrant().getBprgrp().getAuth());
			  this.getGrant().getBprgrp().getAuth().copyValue(auth);
			}
			this.getGrant().getBprgrp().getAuth().setSta("D");
			ctx.getDaoSession().dbUpdate(this.getGrant().getBprgrp().getAuth());
			ctx.getDaoSession().dbCommit();
			log.debug("{}","Commit Update auth inr = "+this.getGrant().getBprgrp().getAuth().getInr());
			return true;
		}
        /**
        *   source:sysaut.@0016.script
        */
        public boolean updatePtyaut(String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbBegin();
			String objinr = this.getSysmod().getPty().getInr();
			String objtyp = "pty";
			/*
			  if("1".equals($sysmod\\pty\\ptytyp.getValue()))
			  {
			  //商行维护的是其及下属企业的业务授权模式
			  objinr = $sysmod\\pty\\etyinr.getValue();
			  objtyp = "ety";
			  }
			  else if("2".equals($sysmod\\pty\\ptytyp.getValue()))
			  {
			  //本行企业维护的是自身的业务授权模式
			  objinr = $sysmod\\pty\\inr.getValue();
			  objtyp = "pty";
			  }
			  */
			ctx.getDaoSession().dbDelete(this.getGrant().getAutgrp().getPtyaut(),new Argument<String>("objinr",objinr),new Argument<String>("frm",frm),new Argument<String>("objtyp",objtyp));
			this.getGrant().getAutgrp().getPtyaut().setObjtyp(objtyp);
			this.getGrant().getAutgrp().getPtyaut().setObjinr(objinr);
			this.getGrant().getAutgrp().getPtyaut().setFrm(frm);
			this.getGrant().getAutgrp().getPtyaut().setCur("USD");
			String chkflg = this.getGrant().getAutgrp().getPtyaut().getChkflg();
			log.info("{}","lvl:"+this.getGrant().getAutgrp().getPtyaut().getLvl());
			int lvl = Integer.valueOf(this.getGrant().getAutgrp().getPtyaut().getLvl());
			String flg = "O";
			//是否复核
			if("0".equals(chkflg))
			  flg = flg + "B";
			//没有授权
			if(lvl==0)
			{
			  this.getGrant().getAutgrp().getPtyaut().setInr(Platform.sdbCounter("ptyaut"));
			  this.getGrant().getAutgrp().getPtyaut().setFlg(flg);
			  ctx.getDaoSession().dbInsert(this.getGrant().getAutgrp().getPtyaut());
			}
			//有授权
			else
			{
			  String auttyp = this.getGrant().getAutp().getAuttyp();
			  //不可跨级完全授权
			  this.getGrant().getAutgrp().getPtyaut().setFlg1("1");
			  this.getGrant().getAutgrp().getPtyaut().setFlg2("0");
			  for(int i = 0;i < lvl*2 ;i = i + 2 )
			  {
			    flg = flg + "A";
			    this.getGrant().getAutgrp().getPtyaut().setFlg(flg);
			    //$grant\\autgrp\\ptyaut\\lvl.setValue((i+1)+"");
			    this.getGrant().getAutgrp().getPtyaut().setInr(Platform.sdbCounter("ptyaut"));
			    IDatafield lowamt = MdaDriver.getDatafield(this.getGrant().getAutp(),"amt"+String.valueOf(i));
			    this.getGrant().getAutgrp().getPtyaut().setLowamt(new BigDecimal(String.valueOf(lowamt.getValue())));
			    IDatafield uppamt = MdaDriver.getDatafield(this.getGrant().getAutp(),"amt"+String.valueOf(i+1));
			    this.getGrant().getAutgrp().getPtyaut().setUppamt(new BigDecimal(String.valueOf(uppamt.getValue())));
			    ctx.getDaoSession().dbInsert(this.getGrant().getAutgrp().getPtyaut());
			    log.debug("{}","Insert ptyaut inr = "+this.getGrant().getAutgrp().getPtyaut().getInr()+", typ = "+objtyp);
			  }
			}
			ctx.getDaoSession().dbCommit();
			int errorCode=ctx.getErrorCode();
			if(errorCode==NO_ERROR)
			{
			  //Platform.message(#CT000056,#CT000057);
			  return true;
			}
			else
			{
			  //Platform.message(#CT000058,#CT000059);
			  return false;
			}
		}
        /**
        *   source:sysaut.@0017.script
        */
        public boolean saveUsrautByFrm(String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean result = true;
			if("brtfre".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("brtfre"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("brtfrc"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("brtfrd"))
			    return false;
			}
			else if("letfre".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("letfre"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("letfrc"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("letfrd"))
			    return false;
			}
			else if ("bdtfre".equals(frm))
			{
			  if (!this.getGrant().getOprp().savUsraut("bdtfre"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("bdtfrc"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("bdtfrd"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("bdtdfr"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("bdtdfd"))
			    return false;
			}
			else if ("detfre".equals(frm))
			{
			  if (!this.getGrant().getOprp().savUsraut("detfre"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("detfrc"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("detfrd"))
			    return false;
			}
			else if("bptopn".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("bptopn"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptopl"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptopc"))
			    return false;
			}
			else if("bptapn0".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("bptapn0"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptapl"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptapn"))
			    return false;
			}
			else
			  return this.getGrant().getOprp().savUsraut(frm);
			return result;
		}
        /**
        *   source:sysaut.@0018.script
        */
        public boolean existUsrRol(String rolinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean flg = false;
			String sql = "SELECT inr FROM usrrol WHERE usrinr = '"
			  + this.getGrant().getBprgrp().getUsr().getInr() + "' AND ptyinr = '"
			  + this.getGrant().getBprgrp().getUsr().getPtyinr() + "' AND rolinr = '" + rolinr + "'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbFetchFields(inr);
			//if(inr.value != null)
			if(!MdaUtils.isEmpty(inr.value))
			{
			  //已存在
			  log.debug("{}","Rolinr = " +rolinr+", inr.value = "+inr.value+" Has Exsited for rol = "+this.getGrant().getBprgrp().getUsr().getInr());
			  flg = true;
			}
			ctx.getDaoSession().dbCloseCursor();
			return flg;
		}
        /**
        *   source:sysaut.@0019.script
        */
        public void existDbipsw()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String sql = "SELECT inr FROM usrrol WHERE rolinr = '00000006'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbFetchFields(inr);
			//if(inr.value != null)
			ctx.getDaoSession().dbCloseCursor();
			if(!MdaUtils.isEmpty(inr.value))
			{
			  //已存在
			  log.debug("{}","Trans dbipsw Has Exsited for usr = "+this.getGrant().getBprgrp().getUsr().getInr());
			  return;
			}
			MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			this.getGrant().getBprgrp().getUsrrol().setInr(Platform.sdbCounter("usrrol"));
			this.getGrant().getBprgrp().getUsrrol().setUsrinr(this.getGrant().getBprgrp().getUsr().getInr());
			this.getGrant().getBprgrp().getUsrrol().setRolinr("00000006");
			this.getGrant().getBprgrp().getUsrrol().setRolnam("银行端登录人修改密码");
			this.getGrant().getBprgrp().getUsrrol().setPtyinr(this.getGrant().getBprgrp().getPty().getInr());
			ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsrrol());
			log.debug("{}","Insert trans dbipsw usrrol inr = "+this.getGrant().getBprgrp().getUsrrol().getInr());
		}





}