package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.Sysaut0VO;

import com.ceb.gjjs.mda.manager.module.Grant;
import com.ceb.gjjs.mda.manager.module.Authp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Authgrp;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 主管授权
*/
@Transaction(vo= Sysaut0VO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Sysaut0 extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Sysaut0.class);

		@BDGetter
		private Authgrp authgrp;

		@BDGetter
		private Authp authp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Grant grant;


		public Sysaut0()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getAuthp().setAuthgrpHolder(()->this.getAuthgrp());
        }

        /**
        *   source:sysaut0.@0001.script
        */
        @Rule(target="authp.grant",order=100)
        public boolean ruleAuthpGrantN100(){
            IContext ctx = MdaEnv.getContext();
            
			//根据交易的不同进行不同的处理
			boolean result = true;
			log.debug("{}","开始授权"+result+", frm = "+this.getAuthgrp().getAuth().getFrm().trim());
			if("dbmaut".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmaut();
			else if("dbmopr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmopr0();
			else if("dbmbpr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			  result = grantDbmbpr0();
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000130"),MdaUtils.getI18NString("sysaut0","CT000131"));
			  return false;
			}
			log.debug("{}","授权后result = "+result);
			if(result)
			{
			  //重置授权记录的标志位
			  log.debug("{}","将要删除inr["+this.getAuthgrp().getAuth().getInr()+"]的授权记录!");
			  ctx.getDaoSession().dbBegin();
			  this.getAuthgrp().getAuth().setSta("D");
			  //Platform.dbDelete($authgrp\\auth,new Argument<String>("inr",$authgrp\\auth\\inr.getValue()));
			  ctx.getDaoSession().dbUpdate(this.getAuthgrp().getAuth());
			  ctx.getDaoSession().dbCommit();
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000184"),MdaUtils.getI18NString("sysaut0","CT000185"));
			}
			else
			{
			  log.info("{}","error when delete auth record!");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000194"),MdaUtils.getI18NString("sysaut0","CT000195"));
			}
			

			return true;
        }

        /**
        *   source:sysaut0.@0003.script
        */
        @Rule(target="authp.reject",order=100)
        public boolean ruleAuthpRejectN100(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.getDaoSession().dbBegin();
			this.getAuthgrp().getAuth().setSta("R");
			ctx.getDaoSession().dbUpdate(this.getAuthgrp().getAuth());
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!=NO_ERROR)
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000180"),MdaUtils.getI18NString("sysaut0","CT000181"));
			else
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000182"),MdaUtils.getI18NString("sysaut0","CT000183"));
			//Platform.closePanel($authp\\aut);
			

			return true;
        }



        /**
        *   source:sysaut0.@0000.script
        */
        @Init(order=500)
        public boolean	init500(){
            IContext ctx = MdaEnv.getContext();
            
			//根据授权信息读取数据
			log.debug("{}","begin restore auth..");
			IModule auth = (IModule)ctx.restoreData("com.brilliance.sysaut.auth");
			if(!MdaUtils.isEmpty(auth))
			  this.getAuthgrp().getAuth().copyValue(auth);
			else
			{
			  log.debug("{}","failed restore auth..");
			  return false;
			}
			log.debug("{}","the restored auth inr="+this.getAuthgrp().getAuth().getInr());
			Platform.writeToSession("dspfile",this.getAuthgrp().getAuth().getInr());//token，用来判断请求唯一性
			log.info("{}","session dspfile :"+Platform.readFromSession("dspfile"));
			//读取display文件
			if("dbmaut".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			{
			  String filename="/data/grant/dbmaut/dsp/"+this.getAuthgrp().getAuth().getInr()+".zul";
			  this.getAuthp().setDisplay("/dsp"+filename);
			}
			else if("dbmopr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			{
			  String filename="/data/grant/dbmopr0/dsp/"+this.getAuthgrp().getAuth().getInr()+".zul";
			  this.getAuthp().setDisplay("/dsp"+filename);
			}
			else if("dbmbpr0".equals(this.getAuthgrp().getAuth().getFrm().trim()))
			{
			  String filename="/data/grant/dbmbpr0/dsp/"+this.getAuthgrp().getAuth().getInr()+".zul";
			  this.getAuthp().setDisplay("/dsp"+filename);
			}
			else
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000038"),MdaUtils.getI18NString("sysaut0","CT000039"));

			return true;
        }


        /**
        *   source:sysaut0.@0002.script
        */
        public boolean grantDbmaut()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//autp数据恢复
			String filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmaut/dat/" +this.getAuthgrp().getAuth().getInr()+"autp.dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000170"),MdaUtils.getI18NString("sysaut0","CT000171"));
			  return false;
			}
			IStream is=this.getAuthp().getStream();
			log.debug("{}","streamLoad...");
			MdaUtils.streamLoad(is,filename);
			log.debug("{}","loadData autp...");
			MdaUtils.loadData(this.getGrant().getAutp(),is);
			log.debug("{}","loadData autp OK...");
			log.debug("{}","amt1:"+this.getGrant().getAutp().getAmt1());
			//autgrp数据恢复
			filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmaut/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000172"),MdaUtils.getI18NString("sysaut0","CT000173"));
			  return false;
			}
			is=this.getAuthp().getStream();
			log.debug("{}","streamLoad...");
			MdaUtils.streamLoad(is,filename);
			log.debug("{}","loadData...");
			MdaUtils.loadData(this.getGrant().getAutgrp(),is);
			log.debug("{}","loadData OK...");
			log.debug("{}","chkflg:"+this.getGrant().getAutgrp().getPtyaut().getChkflg());
			log.debug("{}","lvl:"+this.getGrant().getAutgrp().getPtyaut().getLvl());
			//如果frm是空的，那说明是所有交易都要更新，否则只更新指定交易
			boolean result=true;
			if(!MdaUtils.isEmpty(this.getGrant().getAutgrp().getModlst().getFrm()))
			{
			  result=updatePtyaut(this.getGrant().getAutgrp().getModlst().getFrm());
			  if(!result)
			    return false;
			}
			else
			{
			  for(int i=1;i<this.getGrant().getAutgrp().getModlstlst().fullSize();i++)
			  {
			    result=updatePtyaut(this.getGrant().getAutgrp().getModlstlst().getElement(i).getFrm());
			    if(!result)
			      return false;
			  }
			}
			return result;
		}
        /**
        *   source:sysaut0.@0004.script
        */
        public boolean grantDbmopr0()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean result=true;
			//恢复数据
			String filename=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmopr0/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			if(!MdaUtils.fileExists(filename))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000206"),MdaUtils.getI18NString("sysaut0","CT000207"));
			  return false;
			}
			IStream is=this.getAuthp().getStream();
			MdaUtils.streamLoad(is,filename);
			MdaUtils.loadData(this.getGrant().getOprgrp(),is);
			//End of load data
			MdaUtils.clear(this.getGrant().getOprgrp().getUsraut());
			String frm ="";
			if(!MdaUtils.isEmpty(this.getGrant().getOprgrp().getOpraut().getTrsinr()))
			  frm = this.getGrant().getOprgrp().getOpraut().getTrsinr().trim();
			if(!MdaUtils.isEmpty(frm))
			  result = saveUsrautByFrm(frm);
			else
			{
			  for(int i=1;i<this.getGrant().getOprgrp().getOprautlst().fullSize();i++)
			  {
			    result = saveUsrautByFrm(this.getGrant().getOprgrp().getOprautlst().getElement(i).getTrsinr());
			    if(!result)
			      return result;
			  }
			}
			return result;
		}
        /**
        *   source:sysaut0.@0005.script
        */
        public boolean updatePtyaut(String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbBegin();
			String objinr = this.getSysmod().getPty().getInr();
			String objtyp = "pty";
			/*
			  if("1".equals($sysmod\\pty\\ptytyp.getValue()))
			  {
			  //商行维护的是其及下属企业的业务授权模式
			  objinr = $sysmod\\pty\\etyinr.getValue();
			  objtyp = "ety";
			  }
			  else if("2".equals($sysmod\\pty\\ptytyp.getValue()))
			  {
			  //本行企业维护的是自身的业务授权模式
			  objinr = $sysmod\\pty\\inr.getValue();
			  objtyp = "pty";
			  }
			  */
			ctx.getDaoSession().dbDelete(this.getGrant().getAutgrp().getPtyaut(),new Argument<String>("objinr",objinr),new Argument<String>("frm",frm),new Argument<String>("objtyp",objtyp));
			this.getGrant().getAutgrp().getPtyaut().setObjtyp(objtyp);
			this.getGrant().getAutgrp().getPtyaut().setObjinr(objinr);
			this.getGrant().getAutgrp().getPtyaut().setFrm(frm);
			this.getGrant().getAutgrp().getPtyaut().setCur("USD");
			String chkflg = this.getGrant().getAutgrp().getPtyaut().getChkflg();
			log.info("{}","lvl:"+this.getGrant().getAutgrp().getPtyaut().getLvl());
			int lvl = Integer.valueOf(this.getGrant().getAutgrp().getPtyaut().getLvl());
			String flg = "O";
			//是否复核
			if("0".equals(chkflg))
			  flg = flg + "B";
			//没有授权
			if(lvl==0)
			{
			  this.getGrant().getAutgrp().getPtyaut().setInr(Platform.sdbCounter("ptyaut"));
			  this.getGrant().getAutgrp().getPtyaut().setFlg(flg);
			  ctx.getDaoSession().dbInsert(this.getGrant().getAutgrp().getPtyaut());
			}
			//有授权
			else
			{
			  String auttyp = this.getGrant().getAutp().getAuttyp();
			  //不可跨级完全授权
			  this.getGrant().getAutgrp().getPtyaut().setFlg1("1");
			  this.getGrant().getAutgrp().getPtyaut().setFlg2("0");
			  for(int i = 0;i < lvl*2 ;i = i + 2 )
			  {
			    flg = flg + "A";
			    this.getGrant().getAutgrp().getPtyaut().setFlg(flg);
			    //$grant\\autgrp\\ptyaut\\lvl.setValue((i+1)+"");
			    this.getGrant().getAutgrp().getPtyaut().setInr(Platform.sdbCounter("ptyaut"));
			    IDatafield lowamt = MdaDriver.getDatafield(this.getGrant().getAutp(),"amt"+String.valueOf(i));
			    this.getGrant().getAutgrp().getPtyaut().setLowamt(new BigDecimal(String.valueOf(lowamt.getValue())));
			    IDatafield uppamt = MdaDriver.getDatafield(this.getGrant().getAutp(),"amt"+String.valueOf(i+1));
			    this.getGrant().getAutgrp().getPtyaut().setUppamt(new BigDecimal(String.valueOf(uppamt.getValue())));
			    ctx.getDaoSession().dbInsert(this.getGrant().getAutgrp().getPtyaut());
			    log.debug("{}","Insert ptyaut inr = "+this.getGrant().getAutgrp().getPtyaut().getInr()+", typ = "+objtyp);
			  }
			}
			ctx.getDaoSession().dbCommit();
			int errorCode=ctx.getErrorCode();
			if(errorCode==NO_ERROR)
			{
			  //Platform.message(#CT000210,#CT000211);
			  return true;
			}
			else
			{
			  //Platform.message(#CT000212,#CT000213);
			  return false;
			}
		}
        /**
        *   source:sysaut0.@0006.script
        */
        public boolean saveUsrautByFrm(String frm)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in saveUsrautByFrm ... frm =  " + frm );
			boolean result = true;
			if("brtfre".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("brtfre"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("brtfrc"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("brtfrd"))
			    return false;
			}
			else if("letfre".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("letfre"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("letfrc"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("letfrd"))
			    return false;
			}
			else if("bdtfre".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("bdtfre"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bdtfrc"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bdtfrd"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bdtdfr"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bdtdfd"))
			    return false;
			}
			else if ("detfre".equals(frm))
			{
			  if (!this.getGrant().getOprp().savUsraut("detfre"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("detfrc"))
			    return false;
			  if (!this.getGrant().getOprp().savUsraut("detfrd"))
			    return false;
			}
			else if("bptopn".equals(frm))
			{
			  if(!this.getGrant().getOprp().savUsraut("bptopn"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptopl"))
			    return false;
			  if(!this.getGrant().getOprp().savUsraut("bptopc"))
			    return false;
			}
			else
			  return this.getGrant().getOprp().savUsraut(frm);
			return result;
		}
        /**
        *   source:sysaut0.@0007.script
        */
        public boolean grantDbmbpr0()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/grant/dbmbpr0/dat/" +this.getAuthgrp().getAuth().getInr()+".dat");
			log.debug("{}","grantDbmbpr0 fileName = "+fileName);
			if(!MdaUtils.fileExists(fileName))
			{
			  log.error("{}","dbmaut:未找到序列化文件！");
			  ctx.setMessage(MdaUtils.getI18NString("sysaut0","CT000236"),MdaUtils.getI18NString("sysaut0","CT000237"));
			  return false;
			}
			log.debug("{}","grantDbmbpr0授权文件存在！");
			IStream is = this.getAuthp().getStream();
			MdaUtils.streamClear(is);
			MdaUtils.streamLoad(is,fileName);
			MdaUtils.loadData(this.getGrant().getBprgrp(),is);
			/*
			  log.info("授权操作员为" + $grant\\bprgrp\\auth\\usrinr.getValue());
			  log.info("当前操作员为" + $sysmod\\usr\\inr.getValue());
			  if($sysmod\\usr\\inr.getValue().equals($grant\\bprgrp\\auth\\usrinr.getValue()))
			  {
			  Platform.message(#CT000242,#CT000243);
			  return false;
			  }*/
			ctx.getDaoSession().dbBegin();
			//如果是新增用户，只要修改状态即可
			if("I".equals(this.getGrant().getBprgrp().getUsr().getStat()))
			{
			  //新增用户
			  this.getGrant().getBprgrp().getUsr().setInr(Platform.sdbCounter("usr"));
			  this.getGrant().getBprgrp().getUsr().setPwd("pkKner19T1G/kibOr4kfy7Wymbg=");
			  this.getGrant().getBprgrp().getUsr().setStat(null);
			  //Platform.dbUpdate($grant\\bprgrp\\usr);
			  ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsr());
			  log.debug("{}","Insert Usr inr = "+this.getGrant().getBprgrp().getUsr().getInr()+", pwd = "+this.getGrant().getBprgrp().getUsr().getPwd());
			}
			else if("U".equals(this.getGrant().getBprgrp().getUsr().getStat()))
			{
			  //修改用户
			  log.debug("{}","Update Usr inr = "+this.getGrant().getBprgrp().getUsr().getInr());
			  this.getGrant().getBprgrp().getUsr().setStat(null);
			  ctx.getDaoSession().dbUpdate(this.getGrant().getBprgrp().getUsr());
			}
			ctx.getDaoSession().dbCommit();
			ctx.getDaoSession().dbBegin();
			log.debug("{}","Selected rol size = "+this.getGrant().getBprgrp().getSelrol().fullSize());
			for(int i = 0; i < this.getGrant().getBprgrp().getSelrol().fullSize(); i++)
			{
			  if(!existUsrRol(this.getGrant().getBprgrp().getSelrol().getElement(i).getInr()))
			  {
			    //保存右侧选中角色
			    MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			    this.getGrant().getBprgrp().getUsrrol().setInr(Platform.sdbCounter("usrrol"));
			    this.getGrant().getBprgrp().getUsrrol().setUsrinr(this.getGrant().getBprgrp().getUsr().getInr());
			    this.getGrant().getBprgrp().getUsrrol().setRolinr(this.getGrant().getBprgrp().getSelrol().getElement(i).getInr());
			    this.getGrant().getBprgrp().getUsrrol().setRolnam(this.getGrant().getBprgrp().getSelrol().getElement(i).getRolnam());
			    this.getGrant().getBprgrp().getUsrrol().setPtyinr(this.getGrant().getBprgrp().getPty().getInr());
			    ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsrrol());
			    log.debug("{}","Insert Usr inr = "+this.getGrant().getBprgrp().getUsrrol().getUsrinr()+", rolinr = "+this.getGrant().getBprgrp().getUsrrol().getRolinr());
			  }
			}
			ctx.getDaoSession().dbCommit();
			ctx.getDaoSession().dbBegin();
			log.debug("{}","Not selected Rol size = "+this.getGrant().getBprgrp().getRollst().fullSize());
			for(int i = 0; i < this.getGrant().getBprgrp().getRollst().fullSize(); i++)
			{
			  if(existUsrRol(this.getGrant().getBprgrp().getRollst().getElement(i).getInr()))
			  {
			    //删除左侧未选中角色
			    MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			    ctx.getDaoSession().dbRead(this.getGrant().getBprgrp().getUsrrol(),new Argument<String>("rolinr",this.getGrant().getBprgrp().getRollst().getElement(i).getInr()),new Argument<String>("usrinr",this.getGrant().getBprgrp().getUsr().getInr()));
			    ctx.getDaoSession().dbDelete(this.getGrant().getBprgrp().getUsrrol());
			    log.debug("{}","Delete Usr inr = "+this.getGrant().getBprgrp().getUsrrol().getUsrinr()+", rolinr = "+this.getGrant().getBprgrp().getUsrrol().getRolinr());
			  }
			  log.debug("{}","Not Deal With rol inr = "+this.getGrant().getBprgrp().getRollst().getElement(i).getInr());
			}
			ctx.getDaoSession().dbCommit();
			existDbipsw();
			/*
			  //删除授权任务
			  IModule auth = (IModule)Platform.restoreData("com.brilliance.sysaut.auth");
			  if(!Platform.isEmpty(auth))
			  {
			  //Platform.clear($grant\\bprgrp\\auth);
			  //$grant\\bprgrp\\auth.copyValue(auth);
			  Platform.clear($authgrp\\auth);
			  $authgrp\\auth.copyValue(auth);
			  }
			  $authgrp\\auth\\sta.setValue("D");
			  Platform.dbBegin();
			  log.debug("Auth dbmopr Begin! auth inr = "+$authgrp\\auth\\inr);
			  Platform.dbUpdate($authgrp\\auth);
			  log.debug("Auth dbmopr done! auth inr = "+$authgrp\\auth\\inr);
			  Platform.dbCommit();
			  log.debug("Commit Update auth inr = "+$authgrp\\auth\\inr);
			  */
			return true;
		}
        /**
        *   source:sysaut0.@0008.script
        */
        public boolean existUsrRol(String rolinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean flg = false;
			String sql = "SELECT inr FROM usrrol WHERE usrinr = '"
			  + this.getGrant().getBprgrp().getUsr().getInr() + "' AND ptyinr = '"
			  + this.getGrant().getBprgrp().getUsr().getPtyinr() + "' AND rolinr = '" + rolinr + "'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbFetchFields(inr);
			//if(inr.value != null)
			if(!MdaUtils.isEmpty(inr.value))
			{
			  //已存在
			  log.debug("{}","Rolinr = " +rolinr+", inr.value = "+inr.value+" Has Exsited for usr = "+this.getGrant().getBprgrp().getUsr().getInr());
			  flg = true;
			}
			ctx.getDaoSession().dbCloseCursor();
			return flg;
		}
        /**
        *   source:sysaut0.@0009.script
        */
        public void existDbipsw()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","existDbipsw开始！");
			String sql = "SELECT inr FROM usrrol WHERE rolinr = '00000006' AND usrinr = '"+this.getGrant().getBprgrp().getUsr().getInr()+"'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<String> inr = new Argument<String>("inr");
			ctx.getDaoSession().dbFetchFields(inr);
			//if(inr.value != null)
			ctx.getDaoSession().dbCloseCursor();
			if(!MdaUtils.isEmpty(inr.value))
			{
			  //已存在
			  log.debug("{}","Trans dbipsw Has Exsited for usr = "+this.getGrant().getBprgrp().getUsr().getInr());
			  return;
			}
			MdaUtils.clear(this.getGrant().getBprgrp().getUsrrol());
			this.getGrant().getBprgrp().getUsrrol().setInr(Platform.sdbCounter("usrrol"));
			this.getGrant().getBprgrp().getUsrrol().setUsrinr(this.getGrant().getBprgrp().getUsr().getInr());
			this.getGrant().getBprgrp().getUsrrol().setRolinr("00000006");
			this.getGrant().getBprgrp().getUsrrol().setRolnam("银行端登录人修改密码");
			this.getGrant().getBprgrp().getUsrrol().setPtyinr(this.getGrant().getBprgrp().getPty().getInr());
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbInsert(this.getGrant().getBprgrp().getUsrrol());
			log.debug("{}","existDbipsw开始Commit！");
			ctx.getDaoSession().dbCommit();
			log.debug("{}","Insert trans dbipsw usrrol inr = "+this.getGrant().getBprgrp().getUsrrol().getInr());
		}





}