package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.TatopnVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Tatp;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Swmmod;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Tasgrp;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 三方协议签约申请
*/
@Transaction(vo= TatopnVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Tatopn extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Tatopn.class);

		@BDGetter
		private Tatp tatp;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Tasgrp tasgrp;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Rmkmod rmkmod;

		@BDGetter
		private Swmmod swmmod;


		public Tatopn()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getTatp().setTasgrpHolder(()->this.getTasgrp());
           this.getTrnmod().setCurHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setAmtHolder(new FieldConstantHolder<>(new BigDecimal("0")));
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Tatopn.this.getFieldPath("tasgrp.rec.ownref");}
 				public void setValue(String arg){Tatopn.this.getTasgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Tatopn.this.getTasgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Tatopn.this.getFieldPath("tasgrp.rec.inr");}
 				public void setValue(String arg){Tatopn.this.getTasgrp().getRec().setInr(arg);}
 				public String getValue(){return Tatopn.this.getTasgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setStlrefHolder(new FieldConstantHolder<>(""));
        }

        /**
        *   source:tatopn.@0002.script
        */
        @Rule(target="tatp.save",order=100)
        public boolean ruleTatpSaveN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(!ctx.checkAll(this.getTasgrp()))
			{
			  return false;
			}
			if(!MdaUtils.isEmpty(this.getTasgrp().getRec().getReason()))
			{
			  this.getTasgrp().getRec().setReason(NULLSTR);
			  
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("tatopn","CT000011"),MdaUtils.getI18NString("tatopn","CT000012")))
			{
			  return false;
			}
			String cifno = this.getTasgrp().getRec().getCifno();
			if(MdaUtils.isEmpty(cifno))
			{
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000013"),MdaUtils.getI18NString("tatopn","CT000014"));
			  return false;
			}
			if(MdaUtils.isEmpty(this.getTasgrp().getRec().getBchcod()))
			{
			  ctx.setFieldError(this,"tasgrp.rec.bchcod",MdaUtils.getI18NString("tatopn","CT000015"));
			  return false;
			}
			//报文发送成功处理业务逻辑
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			//更新业务表
			this.getTasgrp().getRec().setSta("D");
			this.getTasgrp().getRec().setHandletyp("M");
			this.getTasgrp().getRec().setTatdate(MdaUtils.today());
			if(MdaUtils.isEmpty(this.getTasgrp().getRec().getInr()))
			{
			  this.getTasgrp().getRec().setInr(Platform.sdbCounter("tas"));
			  ctx.getDaoSession().dbInsert(this.getTasgrp().getRec());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getTasgrp().getRec());
			}
			//处理swinfo表
			ctx.getDaoSession().dbRead(this.getTasgrp().getSwinfo(),new Argument<String>("cifno",cifno));
			if(MdaUtils.isEmpty(this.getTasgrp().getSwinfo().getInr()))
			{
			  this.getTasgrp().getSwinfo().setInr(Platform.sdbCounter("swinfo"));
			  this.getTasgrp().getSwinfo().setCifno(cifno);
			  this.getTasgrp().getSwinfo().setQysta("1");//签约状态
			  this.getTasgrp().getSwinfo().setQydate(MdaUtils.today());
			  this.getTasgrp().getSwinfo().setQyfunctions(this.getTasgrp().getRec().getFunctionts());
			  ctx.getDaoSession().dbInsert(this.getTasgrp().getSwinfo());
			}
			else
			{
			  this.getTasgrp().getSwinfo().setQysta("1");//
			  this.getTasgrp().getSwinfo().setQydate(MdaUtils.today());
			  String srfunctions = this.getTasgrp().getSwinfo().getQyfunctions();
			  if(MdaUtils.isEmpty(srfunctions))srfunctions="";
			  String newFuncions = this.getTasgrp().getRec().getFunctionts();
			  StringBuffer sb = new StringBuffer(srfunctions);
			  if(!MdaUtils.isEmpty(newFuncions))
			  {
			    String[] funarr =newFuncions.split("#");
			    for(int i=0;i<funarr.length;i++)
			    {
			      if(srfunctions.contains(funarr[i]))
			        continue;
			      if(srfunctions.endsWith("#"))
			      {
			        sb.append(funarr[i]);
			      }
			      else
			      {
			        sb.append("#"+funarr[i]);
			      }
			    }
			  }
			  this.getTasgrp().getSwinfo().setQyfunctions(sb.toString());
			  ctx.getDaoSession().dbUpdate(this.getTasgrp().getSwinfo());
			}
			//转历史
			if(!MdaUtils.isEmpty(this.getTasgrp().getRec().getBchcod()))
			{
			  String bchcod =this.getTasgrp().getRec().getBchcod();
			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}
			String objinr = this.getTatp().getTasgrp().getRec().getInr();
			String objtyp = "tas";

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"经办,";

			ctx.absGet(Trnmod.class).goHistory(objinr,objtyp,ctx.getTransName(),this.getTatp().getTatopn(),txt);
			//上传影像
			/* String cibBranchID = $sysmod\\pty\\cid.getValue().substring(0,2);
			  String cibOrgID = $sysmod\\pty\\cid.getValue().substring(2);
			  Platform.dbRead($\\trnmod\\itfmod\\imgmod\\img,new Argument("trninr",$trnmod\\bnktrn\\inr.getValue()));
			  Boolean result=$\\trnmod\\itfmod\\imgmod.uploadImages($\\trnmod\\itfmod\\imgmod\\img\\ownref.getValue(),$\\trnmod\\itfmod\\imgmod\\img\\imgref.getValue(),$\\trnmod\\itfmod\\imgmod\\img\\guid.getValue(),cibBranchID,cibOrgID);
			  log.info("upload result=" +result);
			  if(!result)
			  {
			  log.debug("#######");
			  Platform.dbRollback();
			  Platform.message(#CT000016,#CT000117);
			  return false;
			  }
			  */
			//发报文
			//发送业务报文给单一窗口
			Map map = new HashMap();
			map.put("code","SFS122");
			this.getSysmod().setSwHeaderMap("SFS122","",map,this.getTatp().getTasgrp().getRec().getMsgref());
			map.put("FileName",this.getTrnmod().getApldoc().getPdfdoc().getPdffilnam());
			map.put("FileType",this.getTasgrp().getRec().getDoctyp());
			map.put("EntName",this.getTasgrp().getRec().getEntname());
			map.put("CifNo",this.getTasgrp().getRec().getCifno());
			map.put("ProtocolNo",this.getTasgrp().getRec().getProtocolno());
			map.put("Functions",this.getTasgrp().getRec().getFunctionts());
			this.getSwmmod().storeSWM("SFS122",this.getTasgrp().getRec().getInr(),"tas",map);
			/* Map rst = $sysmod.retSW("SFS122",map,null);
			  //判断处理结果，给出提示
			  String code = (String) rst.get("code");
			  if(Platform.isEmpty(code))
			  {
			  log.error("接口调用失败，请重试！");
			  Platform.dbRollback();
			  return false;
			  }
			  else
			  {
			  if(!"000000".equals(code))
			  {
			  String des = (String) rst.get("des");
			  log.error("接口调用失败:"+des+",请重试!");
			  Platform.dbRollback();
			  return false;
			  }
			  }
			  */
			//插入地址信息
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000118"),MdaUtils.getI18NString("tatopn","CT000119"));
			  return false;
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000120"),MdaUtils.getI18NString("tatopn","CT000242"));
			  //更新国结数据库状态。TODO
			}
			//
			

			return true;
        }

        /**
        *   source:tatopn.@0004.script
        */
        @Rule(target="tatp.exit",order=100)
        public boolean ruleTatpExitN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:tatopn.@0007.script
        */
        @Rule(target="tatp.history",order=100)
        public boolean ruleTatpHistoryN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*if(Platform.isEmpty($tasgrp\\rec\\bchcod.getValue()))
			  {
			  Platform.error($tasgrp\\rec\\bchcod,#CT000220);
			  return false;
			  }*/
			//转为历史
			if(MdaUtils.isEmpty(this.getTasgrp().getRec().getReason()))
			{
			  ctx.setFieldError(this,"tasgrp.rec.reason",MdaUtils.getI18NString("tatopn","CT000221"));
			  return false;
			}
			if(MdaUtils.prompt(MdaUtils.getI18NString("tatopn","CT000222"),MdaUtils.getI18NString("tatopn","CT000223")))
			{
			  return false;
			}

			//处理业务逻辑
			ctx.getErrorCode();
			ctx.getDaoSession().dbBegin();
			//更新业务表
			this.getTasgrp().getRec().setSta("B");
			this.getTasgrp().getRec().setHandletyp("M");
			this.getTasgrp().getRec().setTatdate(MdaUtils.today());
			if(MdaUtils.isEmpty(this.getTasgrp().getRec().getInr()))
			{
			  this.getTasgrp().getRec().setInr(Platform.sdbCounter("tas"));
			  ctx.getDaoSession().dbInsert(this.getTasgrp().getRec());
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getTasgrp().getRec());
			}
			log.info("{}","before go history "+ctx.getErrorCode());
			log.info("{}","begin go history !");
			//转历史
			if(!MdaUtils.isEmpty(this.getTasgrp().getRec().getBchcod()))
			{
			  String bchcod =this.getTasgrp().getRec().getBchcod();
			  MdaUtils.clear(ctx.absGet(Sysmod.class).getBch());
			  ctx.getDaoSession().dbRead(ctx.absGet(Sysmod.class).getBch(),new Argument<String>("cid",bchcod),new Argument<String>("ptytyp","0"));
			}
			String objinr = this.getTatp().getTasgrp().getRec().getInr();
			String objtyp = "tas";

			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String userName = this.getSysmod().getLoginUserName();
			String txt=time+",银行柜员:"+userName+"退回,退回原因："+this.getTasgrp().getRec().getReason();

			ctx.absGet(Trnmod.class).goHistory(objinr,objtyp,ctx.getTransName(),this.getTatp().getTatopn(),txt);

			//发送业务报文给单一窗口
			Map map = new HashMap();
			map.put("code","SFS201");
			this.getSysmod().setSwHeaderMap("SFS201","",map,this.getTatp().getTasgrp().getRec().getMsgref());
			map.put("BusiNo","SFS121");
			map.put("Result","90001");
			map.put("AddWord","银行退回!");
			this.getSwmmod().storeSWM("SFS201",this.getTasgrp().getRec().getInr(),"tas",map);
			//插入地址信息
			ctx.getDaoSession().dbCommit();
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000224"),MdaUtils.getI18NString("tatopn","CT000225"));
			  return false;
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000226"),MdaUtils.getI18NString("tatopn","CT000245"));
			  //更新国结数据库状态。TODO
			}
			//
			

			return true;
        }

        /**
        *   source:tatopn.@0008.script
        */
        @Rule(target="tatp.carmer",order=100)
        public boolean ruleTatpCarmerN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}"," in imgviw....");
			ctx.absGet(Trnmod.class).getItfmod().getImgmod().imgScans(this.getTrnmod().getBnktrn().getInr());

			return true;
        }

        /**
        *   source:tatopn.@0009.script
        */
        @Rule(target="tatp.rebook",order=100)
        public boolean ruleTatpRebookN100(){
            IContext ctx = MdaEnv.getContext();
            
			String pdfpath = ctx.absGet(Trnmod.class).getApldoc().getPdfdoc().getPdffilnam();
			if(MdaUtils.isEmpty(pdfpath))
			{
			  ctx.setMessage(MdaUtils.getI18NString("tatopn","CT000234"),MdaUtils.getI18NString("tatopn","CT000235"));
			  return false;
			}
			pdfpath = "pdf/"+pdfpath;
			log.info("{}","pdfpath : "+pdfpath);
			this.getTatp().getPdfviw().showPDF(pdfpath,"三方协议文本",1);

			return true;
        }


        /**
        *   source:tatopn.@0005.script
        */
        @Check(target="tasgrp.rec.cifno",order=100)
        public boolean checkTasgrpRecCifnoN100(){
            IContext ctx = MdaEnv.getContext();
            
			String cifno = this.getTasgrp().getRec().getCifno();
			if(MdaUtils.isEmpty(cifno))
			{
			  ctx.setFieldError(this,"tasgrp.rec.cifno",MdaUtils.getI18NString("tatopn","CT000010"));
			  return false;
			}
			else
			{
			  if (cifno.length() != 18)
			  {
			    ctx.setFieldError(this,"tasgrp.rec.cifno",MdaUtils.getI18NString("tatopn","CT000019"));
			    return false;
			  }
			}

			return true;
        }


        /**
        *   source:tatopn.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			IModule mdl = (IModule)ctx.restoreData("com.brilliance.tatopn.ref");
			if(!MdaUtils.isEmpty(mdl))
			  this.getTasgrp().getRec().copyValue(mdl);

			this.getTasgrp().getRec().setTatdate(MdaUtils.today());

			

			
			
			
			
			
			
			
			
			
			
			

			ctx.getDaoSession().dbRead(this.getTasgrp().getPty(),new Argument<String>("cifno",EQ,this.getTasgrp().getRec().getCifno()));
			List<CodetableItem> bchcod =this.getSysmod().getAndSetBchcodFlg(this.getTasgrp().getPty().getInr(),this.getTasgrp().getRec().getBchcod());
			MdaUtils.setValues(this.getTasgrp().getRec(),"bchcod",bchcod);

			if (!MdaUtils.isEmpty(this.getTasgrp().getRec().getInr()))
			{
			  String fun=this.getTasgrp().getRec().getFunctionts();
			  if(!MdaUtils.isEmpty(fun))
			  {
			    String[] funarr =fun.split("#");
			    for(int i=0;i<funarr.length;i++)
			    {
			      if("user_binding".equals(funarr[i]))
			        this.getTasgrp().setUserbinding(TRUE);
			      if("open_account".equals(funarr[i]))
			        this.getTasgrp().setOpenaccount(TRUE);
			      if("inward_remit".equals(funarr[i]))
			        this.getTasgrp().setInwardremit(TRUE);
			      if("outward_remit".equals(funarr[i]))
			        this.getTasgrp().setOutwardremit(TRUE);
			      if("finance_application".equals(funarr[i]))
			        this.getTasgrp().setFinanceapplication(TRUE);
			      if("open_guara_letter".equals(funarr[i]))
			        this.getTasgrp().setOpenguaraletter(TRUE);
			    }
			    // if(!TRUE.equals($tasgrp\\userbinding.getValue())&&TRUE.equals($tasgrp\\userbinding.getValue()))
			    //   fun+="user_binding";
			  }
			}
			String objinr = this.getTasgrp().getRec().getInr();
			String objtyp = "tas";
			MdaUtils.clear(this.getTrnmod().getBnktrn());
			MdaUtils.clear(this.getTrnmod().getApldoc().getPdfdoc());
			ctx.getDaoSession().dbRead(this.getTrnmod().getBnktrn(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp",objtyp));
			ctx.getDaoSession().dbRead(this.getTrnmod().getApldoc().getPdfdoc(),new Argument<String>("objinr",objinr),new Argument<String>("objtyp",objtyp));
			/*
			  String aaa=$tasgrp\\rec\\functionts;
			  String[] items =aaa.split("#");
			  for(int i=0;i<items.length;i++){
			  switch(items[i])
			  {
			  case "user_binding":
			  $tasgrp\\userbinding.setValue("X");
			  break;
			  case "open_account":
			  $tasgrp\\openaccount.setValue("X");
			  break;
			  case "inward_remit":
			  $tasgrp\\inwardremit.setValue("X");
			  break;
			  case "outward_remit":
			  $tasgrp\\outwardremit.setValue("X");
			  break;
			  case "finance_application":
			  $tasgrp\\financeapplication.setValue("X");
			  break;
			  case "open_guara_letter":
			  $tasgrp\\openguaraletter.setValue("X");
			  break;
			  // default:
			  // break;
			  }
			  }
			  */

			return true;
        }









}