package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.WitdavVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Witp;
import com.ceb.gjjs.mda.manager.module.Widgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 期权签约证实
*/
@Transaction(vo= WitdavVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Witdav extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Witdav.class);

		@BDGetter
		private Widgrp widgrp;

		@BDGetter
		private Witp witp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Witdav()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getWitp().setWidgrpHolder(()->this.getWidgrp());
           this.getMtabut().setRecHolder(()->this.getWidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.cur");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setCur(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getCur();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.ownref");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.bchcod");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.inr");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setInr(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.ptyinr");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.stlref");}
 				public void setValue(String arg){Witdav.this.getWidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Witdav.this.getWidgrp().getRec().getStlref();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Witdav.this.getFieldPath("widgrp.rec.qqfamt");}
 				public void setValue(BigDecimal arg){Witdav.this.getWidgrp().getRec().setQqfamt(arg);}
 				public BigDecimal getValue(){return Witdav.this.getWidgrp().getRec().getQqfamt();}}
			 );
        }



        /**
        *   source:witdav.@0000.script
        */
        @Init(order=50)
        public boolean	init50(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.absGet(Mtabut.class).getImgtp().getImgRef();

			return true;
        }

        /**
        *   source:witdav.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			setValuePdf();
			ctx.getDaoSession().dbRead(this.getWidgrp().getRec(),new Argument<String>("ownref",this.getSysmod().getSpt().getOwnref()));
			this.dealPdf();
			String labels = "";
			String tempfiles="";

			if(this.getWidgrp().getWiclst().size() == 1)
			{
			  labels = "期权签约证实";
			  tempfiles = "A:witdav1";
			}
			else if(this.getWidgrp().getWiclst().size() == 2)
			{
			  labels = "期权签约证实";
			  tempfiles = "A:witdav2";
			}
			else if(this.getWidgrp().getWiclst().size() == 3)
			{
			  labels = "期权签约证实";
			  tempfiles = "A:witdav3";
			}
			else
			{
			  labels = "";
			  tempfiles = "";
			}

			//获取需要存表的pdf或草稿名
			Map<String,String> cntLabel = ctx.absGet(Trnmod.class).getPDFInfo1();
			labels = cntLabel.get("label") + labels;
			tempfiles = cntLabel.get("tempfile") + tempfiles;
			if(MdaUtils.isEmpty(labels)&&MdaUtils.isEmpty(tempfiles))
			{
			  labels = ",";
			  tempfiles = ",";
			}
			String[] strs = labels.split(",");
			int cnt = strs.length;
			log.debug("{}","labels=====" + labels);
			log.debug("{}","tempfiles====" + tempfiles);
			log.debug("{}","cnt ======"+ cnt);
			ctx.absGet(Trnmod.class).getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().noticeAck(this.getWitp().getWitdav());

			ctx.getDaoSession().dbReadset(this.getWidgrp().getWiclst(),new Argument<String>("objinr",this.getWidgrp().getRec().getInr()),new Argument<String>("modflg","0"));
			for(int i = 0; i < this.getWidgrp().getWiclst().size(); i++)
			{
			  this.getWidgrp().getWiclst().getElement(i).setNo(""+ (i + 1));
			}
			

			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			


			return true;
        }


        /**
        *   source:witdav.@0003.script
        */
        public void dealPdf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			this.loadValues();
			this.dealPdfWiclst();
			//交割方式
			if("0".equals(this.getWidgrp().getRec().getSfcejg()))
			{
			  this.getWidgrp().setSfcejg("1");
			}
			else if("1".equals(this.getWidgrp().getRec().getSfcejg()))
			{
			  this.getWidgrp().setSfcejg("2");
			}
			else
			{
			  this.getWidgrp().setSfcejg("");
			}
			

			//结售汇方向（综合）
			if("0".equals(this.getWidgrp().getRec().getJshfx()))
			{
			  this.getWidgrp().setJshfx("1");
			}
			else if("1".equals(this.getWidgrp().getRec().getJshfx()))
			{
			  this.getWidgrp().setJshfx("2");
			}
			else
			{
			  this.getWidgrp().setJshfx("");
			}
			

			//普通欧式期权期权类型
			if(this.getWidgrp().getWiclst().size()==1)
			{
			  if("0".equals(this.getWidgrp().getWiclst().getElement(0).getJyfx()))
			  {
			    if("0".equals(this.getWidgrp().getWiclst().getElement(0).getQqfx()))
			    {
			      this.getWidgrp().setQqlx("1");
			    }
			    else if("1".equals(this.getWidgrp().getWiclst().getElement(0).getQqfx()))
			    {
			      this.getWidgrp().setQqlx("2");
			    }
			  }
			  else if("1".equals(this.getWidgrp().getWiclst().getElement(0).getJyfx()))
			  {
			    if("0".equals(this.getWidgrp().getWiclst().getElement(0).getQqfx()))
			    {
			      this.getWidgrp().setQqlx("3");
			    }
			    else if("1".equals(this.getWidgrp().getWiclst().getElement(0).getQqfx()))
			    {
			      this.getWidgrp().setQqlx("4");
			    }
			  }
			}
			else
			{
			  this.getWidgrp().setQqlx(NULLSTR);
			}

			//期权费
			BigDecimal qqfamt = this.getWidgrp().getRec().getQqfamt();
			qqfamt = MdaUtils.parseDecimal(MdaUtils.format(qqfamt,"#0.00"));
			this.getWidgrp().getRec().setQqfamt(qqfamt);

			//交易背景金额
			BigDecimal amt = this.getWidgrp().getRec().getAmt();
			amt = MdaUtils.parseDecimal(MdaUtils.format(amt,"#0.000"));
			this.getWidgrp().getRec().setAmt(amt);

		}
        /**
        *   source:witdav.@0004.script
        */
        public void dealPdfWiclst()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			this.getWidgrp().setJyfx1(NULLSTR);
			this.getWidgrp().setJyfx2(NULLSTR);
			this.getWidgrp().setQqfx1(NULLSTR);
			this.getWidgrp().setQqfx2(NULLSTR);
			this.getWidgrp().setAmt(NULLSTR);
			this.getWidgrp().setZxamt(NULLSTR);
			this.getWidgrp().setDxjej(NULLSTR);

			int len = this.getWidgrp().getWiclst().fullSize();
			StringBuffer jyfx1=new StringBuffer();
			StringBuffer jyfx2=new StringBuffer();
			StringBuffer qqfx1=new StringBuffer();
			StringBuffer qqfx2=new StringBuffer();
			StringBuffer cur=new StringBuffer();
			StringBuffer amt=new StringBuffer();
			StringBuffer zxamt=new StringBuffer();
			StringBuffer dxjej=new StringBuffer();
			String conn="";
			String cc = null;
			BigDecimal bd = null;
			for(int i=0;i<len;i++)
			{
			  //交易方向
			  if("0".equals(this.getWidgrp().getWiclst().getElement(i).getJyfx()))
			  {
			    cc="√";
			    jyfx1.append(conn).append(cc);
			    cc="";
			    jyfx2.append(conn).append(cc);
			  }
			  else if("1".equals(this.getWidgrp().getWiclst().getElement(i).getJyfx()))
			  {
			    cc="";
			    jyfx1.append(conn).append(cc);
			    cc="√";
			    jyfx2.append(conn).append(cc);
			  }
			  else
			  {
			    cc="";
			    jyfx1.append(conn).append(cc);
			    jyfx2.append(conn).append(cc);
			  }

			  //期权方向
			  if("0".equals(this.getWidgrp().getWiclst().getElement(i).getQqfx()))
			  {
			    cc="√";
			    qqfx1.append(conn).append(cc);
			    cc="";
			    qqfx2.append(conn).append(cc);
			  }
			  else if("1".equals(this.getWidgrp().getWiclst().getElement(i).getQqfx()))
			  {
			    cc="";
			    qqfx1.append(conn).append(cc);
			    cc="√";
			    qqfx2.append(conn).append(cc);
			  }
			  else
			  {
			    cc="";
			    qqfx1.append(conn).append(cc);
			    qqfx2.append(conn).append(cc);
			  }
			  //币种
			  cur.append(conn).append(this.getWidgrp().getRec().getCur().toString());

			  //交易金额
			  bd = this.getWidgrp().getWiclst().getElement(i).getAmt();
			  log.debug("{}",""+bd+(bd.compareTo(new BigDecimal(0))!=0));
			  if(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)
			    amt.append(conn).append("");
			  else
			    amt.append(conn).append(bd.setScale(2));

			  //执行价格
			  bd = this.getWidgrp().getWiclst().getElement(i).getZxamt();
			  if(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)
			  {
			    zxamt.append(conn).append("");
			  }
			  else
			  {
			    zxamt.append(conn).append(bd.setScale(3));
			  }

			  //大写金额
			  bd = this.getWidgrp().getWiclst().getElement(i).getAmt();
			  if(!(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)&&!MdaUtils.isEmpty(this.getWidgrp().getRec().getCur()))
			  {
			    cc = this.deslCovEnAmt(this.getWidgrp().getWiclst().getElement(i).getAmt(),this.getWidgrp().getRec().getCur());
			    dxjej.append(conn).append(cc);
			  }
			  else
			  {
			    cc = "";
			    dxjej.append(conn).append(cc);
			  }
			  conn = ",";
			}
			// log.info("atcnum:"+atcnum);
			// log.info("atccur:"+atccur);
			// log.info("atcamt:"+atcamt);
			// log.info("chkcur:"+chkcur);
			// log.info("chkamt:"+chkamt);
			this.getWidgrp().setJyfx1(jyfx1.toString());
			this.getWidgrp().setJyfx2(jyfx2.toString());
			this.getWidgrp().setQqfx1(qqfx1.toString());
			this.getWidgrp().setQqfx2(qqfx2.toString());
			this.getWidgrp().setCur(cur.toString());
			this.getWidgrp().setAmt(amt.toString());
			this.getWidgrp().setZxamt(zxamt.toString());
			this.getWidgrp().setDxjej(dxjej.toString());

		}
        /**
        *   source:witdav.@0005.script
        */
        public String deslCovEnAmt(BigDecimal amt ,String cur)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String maramt = this.getSysmod().covCnAmt(amt,cur);
			return  maramt;
		}
        /**
        *   source:witdav.@0006.script
        */
        public void loadValues()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbReadset(this.getWidgrp().getWiclst(),new Argument<String>("objinr",this.getWidgrp().getRec().getInr()),new Argument<String>("modflg","0"));
		}
        /**
        *   source:witdav.@0007.script
        */
        public void setValuePdf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String jsbzjzyxy="";
			if(!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelbzjacc())||!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelzyxybh()))
			{
			  if(!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelbzjacc())&&MdaUtils.isEmpty(this.getWidgrp().getRec().getRelzyxybh()))
			  {
			    jsbzjzyxy=this.getWidgrp().getRec().getRelbzjacc()+"/";
			  }
			  if(MdaUtils.isEmpty(this.getWidgrp().getRec().getRelbzjacc())&&!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelzyxybh()))
			  {
			    jsbzjzyxy="/"+this.getWidgrp().getRec().getRelzyxybh();
			  }
			  if(!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelbzjacc())&&!MdaUtils.isEmpty(this.getWidgrp().getRec().getRelzyxybh()))
			  {
			    jsbzjzyxy=this.getWidgrp().getRec().getRelbzjacc()+"/"+this.getWidgrp().getRec().getRelzyxybh();
			  }
			  this.getWidgrp().setJsbzjzyxy(jsbzjzyxy);
			}
			else
			{
			  this.getWidgrp().setJsbzjzyxy(jsbzjzyxy);
			}
		}







}