package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.WitmavVO;

import com.ceb.gjjs.mda.manager.module.Trnmod;
import com.ceb.gjjs.mda.manager.module.Mtabut;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Witp;
import com.ceb.gjjs.mda.manager.module.Widgrp;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Rmkmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 期权交易后处理证实
*/
@Transaction(vo= WitmavVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Witmav extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Witmav.class);

		@BDGetter
		private Widgrp widgrp;

		@BDGetter
		private Witp witp;

		@BDGetter
		private Mtabut mtabut;

		@BDGetter
		private Trnmod trnmod;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Rmkmod rmkmod;


		public Witmav()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getWitp().setWidgrpHolder(()->this.getWidgrp());
           this.getMtabut().setRecHolder(()->this.getWidgrp().getRec());
           this.getMtabut().setPrefixHolder(new FieldConstantHolder<>(""));
           this.getTrnmod().setCurHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.cur");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setCur(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getCur();}}
			 );
           this.getTrnmod().setOwnrefHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.ownref");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setOwnref(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getOwnref();}}
			 );
           this.getTrnmod().setBchcodHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.bchcod");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setBchcod(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getBchcod();}}
			 );
           this.getTrnmod().setObjinrHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.inr");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setInr(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getInr();}}
			 );
           this.getTrnmod().setPtyinrHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.ptyinr");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setPtyinr(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getPtyinr();}}
			 );
           this.getTrnmod().setStlrefHolder( new FieldHolder<String>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.stlref");}
 				public void setValue(String arg){Witmav.this.getWidgrp().getRec().setStlref(arg);}
 				public String getValue(){return Witmav.this.getWidgrp().getRec().getStlref();}}
			 );
           this.getTrnmod().setAmtHolder( new FieldHolder<BigDecimal>(){
				public String getPath(){return Witmav.this.getFieldPath("widgrp.rec.qqfamt");}
 				public void setValue(BigDecimal arg){Witmav.this.getWidgrp().getRec().setQqfamt(arg);}
 				public BigDecimal getValue(){return Witmav.this.getWidgrp().getRec().getQqfamt();}}
			 );
        }



        /**
        *   source:witmav.@0000.script
        */
        @Init(order=50)
        public boolean	init50(){
            IContext ctx = MdaEnv.getContext();
            
			ctx.absGet(Mtabut.class).getImgtp().getImgRef();

			return true;
        }

        /**
        *   source:witmav.@0001.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			String labels = "";
			String tempfiles =  "";
			if("0".equals(this.getWidgrp().getRec().getQqywlx()))
			{
			  labels = "人民币外汇期权业务行权通知书";
			  tempfiles = "A:witmav1";
			}
			else if("1".equals(this.getWidgrp().getRec().getQqywlx()))
			{
			  labels = "人民币与外汇衍生产品业务平仓证实书";
			  tempfiles = "A:witmav2";
			}
			else if("4".equals(this.getWidgrp().getRec().getQqywlx()))
			{
			  labels = "人民币与外汇期权交割方式修改证实书";
			  tempfiles = "A:witmav3";
			}
			else
			{
			  labels = "";
			  tempfiles = "";
			}

			this.dealPdf();

			//获取需要存表的pdf或草稿名
			Map<String,String> cntLabel = ctx.absGet(Trnmod.class).getPDFInfo1();
			labels = cntLabel.get("label") + labels;
			tempfiles = cntLabel.get("tempfile") + tempfiles;
			if(MdaUtils.isEmpty(labels)&&MdaUtils.isEmpty(tempfiles))
			{
			  labels=",";
			  tempfiles = ",";
			  //tempfiles = cntLabel.put("tempfile",",");
			  //tempfiles = cntLabel.get("tempfile");
			}
			String[] strs = labels.split(",");
			int cnt = strs.length;
			log.debug("{}","labels=====" + labels);
			log.debug("{}","tempfiles====" + tempfiles);
			log.debug("{}","cnt ======"+ cnt);
			ctx.absGet(Trnmod.class).getApldoc().setPDFInfo(cnt,labels,tempfiles);
			this.getTrnmod().noticeAck(this.getWitp().getWitmav());

			
			
			
			
			
			
			
			
			
			
			
			
			
			
			
			

			return true;
        }


        /**
        *   source:witmav.@0002.script
        */
        public void dealPdf()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean bool = false;
			this.getWidgrp().setAmt(NULLSTR);
			StringBuffer amt=new StringBuffer();
			String conn="";
			BigDecimal bd = null;

			log.info("{}","期权e结算参号："+this.getSysmod().getSpt().getOwnref());
			ctx.getDaoSession().dbRead(this.getWidgrp().getRec(),new Argument<String>("ownref",this.getSysmod().getSpt().getOwnref()));
			log.info("{}","期权e结算业务序号："+this.getWidgrp().getRec().getInr());
			ctx.getDaoSession().dbReadset(this.getWidgrp().getWiclst(),new Argument<String>("objinr",this.getWidgrp().getRec().getInr()),new Argument<String>("modflg","0"));
			log.info("{}","期权记录数："+this.getWidgrp().getWiclst().size());

			//是否行权 (正常一条业务记录行权)
			for(int i = 0; i < this.getWidgrp().getWiclst().size(); i++ )
			{
			  //取行权记录
			  if("0".equals(this.getWidgrp().getWiclst().getElement(i).getSfxq()))
			  {
			    bool = true;
			    //行权金额
			    BigDecimal xqamt = this.getWidgrp().getWiclst().getElement(i).getAmt();
			    xqamt = MdaUtils.parseDecimal(MdaUtils.format(xqamt,"#0.00"));
			    this.getWidgrp().setXqamt(xqamt);

			    if(!MdaUtils.isEmpty(this.getWidgrp().getWiclst().getElement(i).getAmt())&&!MdaUtils.isEmpty(this.getWidgrp().getRec().getCur()))
			      this.getWidgrp().setDxjej(this.deslCovEnAmt(this.getWidgrp().getWiclst().getElement(i).getAmt(),this.getWidgrp().getRec().getCur()));
			    //执行价格
			    BigDecimal zxamt = this.getWidgrp().getWiclst().getElement(i).getZxamt();
			    zxamt = MdaUtils.parseDecimal(MdaUtils.format(zxamt,"#0.00"));
			    this.getWidgrp().setZxamt1(zxamt);

			    //期权方向（看涨看跌）
			    if("0".equals(this.getWidgrp().getWiclst().getElement(i).getQqfx()))
			      this.getWidgrp().setQqlx("1");
			    else
			      this.getWidgrp().setQqlx("2");
			  }

			  //取期权每笔金额记录
			  bd = this.getWidgrp().getWiclst().getElement(i).getAmt();
			  log.debug("{}",""+bd+(bd.compareTo(new BigDecimal(0))!=0));
			  if(MdaUtils.isEmpty(bd)||bd.compareTo(new BigDecimal(0))==0)
			    amt.append(conn).append("");
			  else
			    amt.append(conn).append(bd.setScale(2));

			  conn = ",";
			}
			if(bool)
			{
			  this.getWidgrp().setSfxqpdf("1");
			}
			else
			{
			  this.getWidgrp().setSfxqpdf("2");
			}
			this.getWidgrp().setAmt(amt.toString());

			//交割方式（差额全额）
			if("0".equals(this.getWidgrp().getRec().getSfcejg()))
			{
			  this.getWidgrp().setSfcejg("1");
			}
			else if("1".equals(this.getWidgrp().getRec().getSfcejg()))
			{
			  this.getWidgrp().setSfcejg("2");
			}
			else
			{
			  this.getWidgrp().setSfcejg("");
			}

			//盈亏及盈亏金额
			BigDecimal ykje = this.getWidgrp().getRec().getYkje();
			ykje = MdaUtils.parseDecimal(MdaUtils.format(ykje,"#0.00"));
			if("1".equals(this.getWidgrp().getRec().getYktyp()))
			{
			  this.getWidgrp().setYlje(ykje);
			  this.getWidgrp().setKsje(new BigDecimal(0));
			  this.getWidgrp().setCnyacc(this.getWidgrp().getRec().getCnybacc());
			  this.getWidgrp().setDate1(this.getWidgrp().getRec().getZxdate());
			  this.getWidgrp().setDate2(null);
			}
			else if("2".equals(this.getWidgrp().getRec().getYktyp()))
			{
			  this.getWidgrp().setKsje(ykje);
			  this.getWidgrp().setYlje(new BigDecimal(0));
			  this.getWidgrp().setCnyacc(NULLSTR);
			  this.getWidgrp().setDate2(this.getWidgrp().getRec().getZxdate());
			  this.getWidgrp().setDate1(null);
			}
			else
			{
			  this.getWidgrp().setYlje(new BigDecimal(0));
			  this.getWidgrp().setKsje(new BigDecimal(0));
			  this.getWidgrp().setCnyacc(NULLSTR);
			  this.getWidgrp().setDate1(null);
			  this.getWidgrp().setDate2(null);
			}
		}
        /**
        *   source:witmav.@0003.script
        */
        public String deslCovEnAmt(BigDecimal amt ,String cur)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String maramt = this.getSysmod().covCnAmt(amt,cur);
			return  maramt;
		}







}