package com.ceb.gjjs.mda.manager;

import java.util.*;
import java.math.BigDecimal;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.fasterxml.jackson.annotation.*;
import com.brilliance.mda.runtime.mda.util.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.vo.XptansVO;

import com.ceb.gjjs.mda.manager.module.Btnmod;
import com.ceb.gjjs.mda.manager.module.Sysmod;
import com.ceb.gjjs.mda.manager.module.Xptp;
import com.ceb.gjjs.mda.manager.module.Xptbtn;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.manager.module.Xptgrp;
import com.ceb.gjjs.mda.manager.module.Xptmod;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
/**
* 专家回复
*/
@Transaction(vo= XptansVO.class)
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Xptans extends AbstractTransaction{
		private static Logger log = LoggerFactory.getLogger(Xptans.class);

		@BDGetter
		private Xptgrp xptgrp;

		@BDGetter
		private Xptmod xptmod;

		@BDGetter
		private Xptp xptp;

		@BDGetter
		private Xptbtn xptbtn;

		@BDGetter
		private Sysmod sysmod;

		@BDGetter
		private Btnmod btnmod;


		public Xptans()
        {
            super();
            setArgument();
        }

        public void setArgument()
        {
           this.getXptmod().setXptgrpHolder(()->this.getXptgrp());
           this.getXptp().setXptgrpHolder(()->this.getXptgrp());
        }

        /**
        *   source:xptans.@0001.script
        */
        @Rule(target="xptp.query",order=100)
        public boolean ruleXptpQueryN100(){
            IContext ctx = MdaEnv.getContext();
            
			refreshQus();

			return true;
        }

        /**
        *   source:xptans.@0002.script
        */
        @Rule(target="xptp.delete",order=100)
        public boolean ruleXptpDeleteN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getXptgrp().getXptqnalst().fullSize();
			if( index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000052"),MdaUtils.getI18NString("xptans","CT000053"));
			  return true;
			}
			String sta = this.getXptgrp().getXptqnalst().getElement(index).getSta();
			if("B".equals(sta)  ||  "C".equals(sta))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000054"),MdaUtils.getI18NString("xptans","CT000055"));
			  return true;
			}
			MdaUtils.clear(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbRead(this.getXptgrp().getXptqna(),new Argument("inr",this.getXptgrp().getXptqnalst().getElement(index).getInr()));
			this.getXptgrp().getXptqna().setXptinr("");
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbUpdate(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbCommit();
			refreshQus();

			return true;
        }

        /**
        *   source:xptans.@0003.script
        */
        @Rule(target="xptp.sure",order=100)
        public boolean ruleXptpSureN100(){
            IContext ctx = MdaEnv.getContext();
            
			int index = 0;
			int length = this.getXptgrp().getXptqnalst().fullSize();
			if( index<0   ||   index >= length)
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000010"),MdaUtils.getI18NString("xptans","CT000011"));
			  return true;
			}
			String sta =this.getXptgrp().getXptqnalst().getElement(index).getSta();
			log.info("{}","qst sta="+sta);
			MdaUtils.clear(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbRead(this.getXptgrp().getXptqna(),new Argument("inr",this.getXptgrp().getXptqnalst().getElement(index).getInr()));
			

			return true;
        }

        /**
        *   source:xptans.@0006.script
        */
        @Rule(target="xptbtn.ped",order=100)
        public boolean ruleXptbtnPedN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getXptgrp().getXptqna().setSta("C");//答复中
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbUpdate(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbCommit();
			
			refreshQus();

			return true;
        }

        /**
        *   source:xptans.@0007.script
        */
        @Rule(target="xptbtn.reset",order=100)
        public boolean ruleXptbtnResetN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getXptgrp().getXptqna().setAns(NULLSTR);
			

			return true;
        }

        /**
        *   source:xptans.@0008.script
        */
        @Rule(target="xptbtn.submit",order=100)
        public boolean ruleXptbtnSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getXptgrp().getXptqna().getAns()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000014"),MdaUtils.getI18NString("xptans","CT000015"));
			  return true;
			}
			this.getXptgrp().getXptqna().setSta("G");//已答复
			this.getXptgrp().getXptqna().setAnsxpt(this.getSysmod().getUsr().getInr());
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbUpdate(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbCommit();
			
			refreshQus();

			return true;
        }

        /**
        *   source:xptans.@0010.script
        */
        @Rule(target="xptp.quedoc",order=100)
        public boolean ruleXptpQuedocN100(){
            IContext ctx = MdaEnv.getContext();
            

			if(MdaUtils.isEmpty(this.getXptgrp().getXptqna().getRef()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000016"),MdaUtils.getI18NString("xptans","CT000017"));
			  return true;
			}
			this.getXptp().loadDisplay(this.getXptgrp().getXptqna().getRef());

			return true;
        }

        /**
        *   source:xptans.@0011.script
        */
        @Rule(target="xptbtn.sav2faq",order=100)
        public boolean ruleXptbtnSav2faqN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getXptp().setSamtyp(NULLSTR);
			List<CodetableItem> faqtyp = this.getXptp().loadFaqTyp();
			MdaUtils.setValues(this.getXptp(),"samtyp",faqtyp);
			if(!MdaUtils.isEmpty(faqtyp))
			{
			  this.getXptp().setSamtyp((faqtyp.get(0)).getValue());
			}
			this.getXptgrp().getXptfaq().setSub(NULLSTR);
			this.getXptgrp().getXptfaq().setQue(NULLSTR);
			this.getXptgrp().getXptfaq().setAns(NULLSTR);
			this.getXptgrp().getXptfaq().setQue(this.getXptgrp().getXptqna().getQue());
			this.getXptgrp().getXptfaq().setAns(this.getXptgrp().getXptqna().getAns());
			
			
			
			
			

			return true;
        }

        /**
        *   source:xptans.@0012.script
        */
        @Rule(target="xptbtn.sav2sam",order=100)
        public boolean ruleXptbtnSav2samN100(){
            IContext ctx = MdaEnv.getContext();
            
			this.getXptp().setSamtyp(NULLSTR);
			List<CodetableItem> samtyp = this.getXptp().loadSamTyp();
			MdaUtils.setValues(this.getXptp(),"samtyp",samtyp);
			if(!MdaUtils.isEmpty(samtyp))
			{
			  this.getXptp().setSamtyp((samtyp.get(0)).getValue());
			}
			this.getXptgrp().getXptsam().setCasque(NULLSTR);
			this.getXptgrp().getXptsam().setCasans(NULLSTR);
			this.getXptgrp().getXptsam().setCasbgr(NULLSTR);
			this.getXptgrp().getXptsam().setCasque(this.getXptgrp().getXptqna().getQue());
			this.getXptgrp().getXptsam().setCasans(this.getXptgrp().getXptqna().getAns());
			
			
			
			
			

			return true;
        }

        /**
        *   source:xptans.@0013.script
        */
        @Rule(target="xptp.back",order=100)
        public boolean ruleXptpBackN100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:xptans.@0014.script
        */
        @Rule(target="xptp.submit",order=100)
        public boolean ruleXptpSubmitN100(){
            IContext ctx = MdaEnv.getContext();
            

			if(MdaUtils.isEmpty(this.getXptgrp().getXptfaq().getQue()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000030"),MdaUtils.getI18NString("xptans","CT000031"));
			  return true;
			}
			if(MdaUtils.isEmpty(this.getXptgrp().getXptfaq().getAns()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000032"),MdaUtils.getI18NString("xptans","CT000033"));
			  return true;
			}
			this.getXptgrp().getXptfaq().setInr(Platform.sdbCounter("xptfaq"));
			this.getXptgrp().getXptfaq().setQuetyp(this.getXptp().getSamtyp());
			this.getXptgrp().getXptfaq().setOprinr(this.getXptgrp().getXptqna().getOprinr());
			this.getXptgrp().getXptfaq().setEtyinr(this.getSysmod().getEty().getInr());
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbInsert(this.getXptgrp().getXptfaq());
			ctx.getDaoSession().dbCommit();
			

			return true;
        }

        /**
        *   source:xptans.@0015.script
        */
        @Rule(target="xptp.submit1",order=100)
        public boolean ruleXptpSubmit1N100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.isEmpty(this.getXptgrp().getXptsam().getCasque()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000040"),MdaUtils.getI18NString("xptans","CT000041"));
			  return true;
			}
			if(MdaUtils.isEmpty(this.getXptgrp().getXptsam().getCasans()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000042"),MdaUtils.getI18NString("xptans","CT000043"));
			  return true;
			}
			if(MdaUtils.isEmpty(this.getXptgrp().getXptsam().getCasbgr()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("xptans","CT000044"),MdaUtils.getI18NString("xptans","CT000045"));
			  return true;
			}
			this.getXptgrp().getXptsam().setCastyp(this.getXptp().getSamtyp());
			this.getXptgrp().getXptsam().setInr(Platform.sdbCounter("xptsam"));
			this.getXptgrp().getXptsam().setCredat(new Date());
			this.getXptgrp().getXptsam().setEtyinr(this.getSysmod().getEty().getInr());
			this.getXptgrp().getXptsam().setOprinr(this.getXptgrp().getXptqna().getOprinr());
			ctx.getDaoSession().dbBegin();
			ctx.getDaoSession().dbInsert(this.getXptgrp().getXptsam());
			ctx.getDaoSession().dbCommit();
			

			return true;
        }

        /**
        *   source:xptans.@0016.script
        */
        @Rule(target="xptp.back1",order=100)
        public boolean ruleXptpBack1N100(){
            IContext ctx = MdaEnv.getContext();
            
			

			return true;
        }

        /**
        *   source:xptans.@0017.script
        */
        @Rule(target="xptgrp.xptqnalst",order=10)
        public boolean ruleXptgrpXptqnalstN10(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in onclick ...  xptgrp.xptqnalst  ... ");
			int index = 0;
			int length = this.getXptgrp().getXptqnalst().fullSize();
			String sta =this.getXptgrp().getXptqnalst().getElement(index).getSta();
			log.info("{}","qst sta="+sta);
			MdaUtils.clear(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbRead(this.getXptgrp().getXptqna(),new Argument("inr",this.getXptgrp().getXptqnalst().getElement(index).getInr()));
			


			return true;
        }

        /**
        *   source:xptans.@0018.script
        */
        @Rule(target="xptgrp.xptqnalst",order=10)
        public boolean ruleXptgrpXptqnalstN10R1(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","in onclick ...  xptgrp.xptqnalst  ... ");
			int index = 0;
			int length = this.getXptgrp().getXptqnalst().fullSize();
			String sta =this.getXptgrp().getXptqnalst().getElement(index).getSta();
			log.info("{}","qst sta="+sta);
			MdaUtils.clear(this.getXptgrp().getXptqna());
			ctx.getDaoSession().dbRead(this.getXptgrp().getXptqna(),new Argument("inr",this.getXptgrp().getXptqnalst().getElement(index).getInr()));
			


			return true;
        }



        /**
        *   source:xptans.@0000.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            

			MdaUtils.setValues(this.getXptp(),"questa",MdaUtils.getCodetable("qnastabnk"));
			if(MdaUtils.isEmpty(this.getXptp().getQuesta()))
			  this.getXptp().setQuesta("B");
			
			refreshQus();

			return true;
        }

        /**
        *   source:xptans.@0004.script
        */
        @Init(order=100)
        public boolean	init100R1(){
            IContext ctx = MdaEnv.getContext();
            
			;

			return true;
        }

        /**
        *   source:xptans.@0005.script
        */
        @Init(order=100)
        public boolean	init100R2(){
            IContext ctx = MdaEnv.getContext();
            
			
			

			return true;
        }


        /**
        *   source:xptans.@0009.script
        */
        public void refreshQus()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			if(MdaUtils.isEmpty(this.getXptp().getXptinf()))
			  this.getXptp().loadXptNam();
			Map<String,String> xptinf = (Map<String,String>)this.getXptp().getXptinf();
			String sql = "SELECT x.inr,x.dat,x.que,x.sta,x.etnnam,x.xptinr,x.ansxpt FROM XPTQNA x "
			  +"WHERE  XPTINR='"+this.getSysmod().getUsr().getInr()+"'";
			if(!MdaUtils.isEmpty(this.getXptp().getEtnnam()))
			{
			  sql = sql + " AND etnnam LIKE '%" + this.getXptp().getEtnnam() + "%'";
			}
			if(!MdaUtils.isEmpty(this.getXptp().getQuesta()))
			{
			  sql = sql + " AND sta = '" + this.getXptp().getQuesta() + "'";
			}
			sql = sql + " ORDER BY dat DESC";
			ctx.getDaoSession().dbExecuteSQL(sql);
			Argument<Date> dat = new Argument<Date>("dat");
			Argument<String> etnnam = new Argument<String>("etnnam");
			Argument<String> que = new Argument<String>("que");
			Argument<String> sta = new Argument<String>("sta");
			Argument<String> inr = new Argument<String>("inr");
			Argument<String> xptinr = new Argument<String>("xptinr");
			Argument<String> ansxpt = new Argument<String>("ansxpt");
			MdaUtils.clear(this.getXptgrp().getXptqnalst());
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(dat,etnnam,que,sta,inr,xptinr,ansxpt);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == NO_ERROR)
			  {
			    if(xptinr.value==null)xptinr.value="";
			    if(ansxpt.value==null)ansxpt.value="";
			    if(!MdaUtils.isEmpty(xptinf.get(xptinr.value.trim())))
			      xptinr.value = xptinf.get(xptinr.value.trim());
			    if(!MdaUtils.isEmpty(xptinf.get(ansxpt.value.trim())))
			      ansxpt.value=xptinf.get(ansxpt.value.trim());
			    this.getXptgrp().getXptqnalst().add(dat,etnnam,que,sta,inr,xptinr,ansxpt);
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			
		}







}