package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Pty;
import com.ceb.gjjs.mda.bo.Ptr;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Ghtp extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Ghtp.class);

        //接收数据
        private transient IControl receptd = new ControlImpl("receptd", "接收数据", this);

        //加解锁
        private transient IControl addunlock = new ControlImpl("addunlock", "加解锁", this);

        //客户号
        private String ecifno;

        //业务参考号
        private String businessno;

        //加解锁标记
        private String eduflag;

        //交易类型
        private String jylx;

        //付汇金额
        private BigDecimal fuhje = new BigDecimal("0.00");

        //结汇金额
        private BigDecimal jiehje = new BigDecimal("0.00");

        //客户号
        private String cusno;

        //柜员号
        private String operno;

        //结汇业务编号
        private String jhbusno;

        //付汇业务编号
        private String fjbusno;

        //加解锁名称
        private String nam;

        //异常解锁标识
        private String errulock;


        @JsonIgnore
        @BDGetter
        private transient IPanel ghtp01;


	    @BDGetter
		private Fqdgrp fqdgrp;

		@BDGetter
		private ModuleList<Ptr> ptrlst;

		@BDGetter
		private ModuleList<Pty> ptylst;


		public Ghtp()
        {
            super();
            setArgument();
        }

        public Ghtp(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:ghtp.@0000.script
        */
        @Rule(target="receptd",order=100)
        public boolean ruleReceptdN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，ORDER编号:100");
			//1、数据落地
			//2、获取自助售汇额度申请参考号的值
			String edbusno = this.getFqdgrp().getRec().getEdbusno();
			//3、根据ghxx表的自助购汇额度申请参考号查询shs表
			MdaUtils.clear(this.getFqdgrp().getShs());
			ctx.getDaoSession().dbRead(this.getFqdgrp().getShs(),new Argument<String>("businessno", edbusno));
			ctx.getErrorCode(); //清空errorCode,防止影响后边errorCode的取值
			if(MdaUtils.isEmpty(this.getFqdgrp().getShs().getInr()))
			{
			  ctx.setMessage("E9999","未查询到相关购汇额度申请数据！");
			  return false;
			}
			//(0)、判断是不是在同一额度币种下购汇
			String curren = this.getFqdgrp().getRec().getCurrency();
			String bizhong = MdaUtils.getCodetableLabel("feqcur",curren);
			if(MdaUtils.isEmpty(bizhong))
			{
			  ctx.setMessage("E9999","币种有误，请修改后重试！");
			  return false;
			}
			if(!curren.equals(this.getFqdgrp().getShs().getCurrency()))
			{
			  ctx.setMessage("E9999","该额度项下只允许做" + bizhong + "的购汇申请！");
			  return false;
			}
			//(1)、判断购汇状态(有效继续交易，无效/作废交易报错)
			String applystatus = this.getFqdgrp().getShs().getApplystatus();
			if(!"3".equals(applystatus))
			{
			  ctx.setMessage("E9999","购汇额度为无效/作废状态，请重新生效后再试！");
			  return false;
			}
			String jiehsign = this.getFqdgrp().getShs().getJiehsign(); //结汇标志
			//购汇时，判断结汇标志，为“1“时不能发起购汇
			if("1".equals(jiehsign))
			{
			  ctx.setMessage("E9999","当前为结汇状态不支持购汇操作！");
			  return false;
			}
			//(2)、判断可购汇额度是否大于0(大于0继续交易，反之报错)
			BigDecimal cansaleed = this.getFqdgrp().getShs().getCansaleed(); //可购汇额度
			BigDecimal ling = MdaUtils.parseDecimal(0.00);
			if(cansaleed.compareTo(ling) <= 0)
			{
			  ctx.setMessage("E9999","当前可购汇额度为0.00，请申请新的额度后再试！");
			  return false;
			}
			//判断这笔购汇成功后累计购汇金额是否会超出购汇额度
			BigDecimal bankmcje = this.getFqdgrp().getRec().getBankmcje();//银行卖出金额
			BigDecimal paysum = this.getFqdgrp().getShs().getPaysum();//金额
			BigDecimal havesale = this.getFqdgrp().getShs().getHavesale();//累计购汇金额
			BigDecimal havegwfed = this.getFqdgrp().getShs().getHavegwfed();//已购未付金额
			BigDecimal havesaleNew = havesale.add(bankmcje);//累计购汇金额新
			if(ling.compareTo(paysum.subtract(havesaleNew)) > 0)
			{
			  ctx.setMessage("E9999","累计购汇金额不能超过总额度，数据异常！");
			  return false;
			}
			//(3)、判断购汇交易日期是否小于等于最迟购汇日期(小于等于继续交易，反之报错)
			Date shjyrq = MdaUtils.parseDate(MdaUtils.format(MdaUtils.today(),"yyyy/MM/dd"),"yyyy/MM/dd");//购汇交易日期
			int difft = MdaUtils.diff(shjyrq,this.getFqdgrp().getShs().getZcghnewdat());
			if(difft > 0)
			{
			  ctx.setMessage("E9999","购汇日期不能大于最迟购汇日期，请修改后再试！");
			  return false;
			}
			//(4)、判断购汇金额（外币）是否小于等于可购汇额度(小于等于继续交易，反之报错)
			BigDecimal jioyje = this.getFqdgrp().getRec().getJioyje();
			if(cansaleed.compareTo(bankmcje) < 0)
			{
			  ctx.setMessage("E9999","购汇金额不能大于可购汇额度，请修改后再试！");
			  return false;
			}
			MdaUtils.clear(this.getFqdgrp().getPty());
			ctx.getDaoSession().dbRead(this.getFqdgrp().getPty(),new Argument<String>("ptytyp", "0"),new Argument<String>("idc", this.getFqdgrp().getRec().getOrgcode()));
			ctx.getErrorCode();
			if(MdaUtils.isEmpty(this.getFqdgrp().getPty().getInr()))
			{
			  ctx.setMessage("E9999","请联系银行工作人员维护机构信息！");
			  return false;
			}
			if(MdaUtils.diff(MdaUtils.parseDate(MdaUtils.format(MdaUtils.today(),"yyyyMMdd"),"yyyyMMdd"),MdaUtils.parseDate(this.getFqdgrp().getRec().getJoy1rq(),"yyyyMMdd")) < 0)
			{
			  ctx.setMessage("E9999","申报业务交易日期不能大于当前日期！");
			  return false;
			}
			log.debug("{}","业务处理结束，ORDER编号:100");

			return true;
        }

        /**
        *   source:ghtp.@0001.script
        */
        @Rule(target="addunlock",order=100)
        public boolean ruleAddunlockN100(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","加解锁业务处理开始，ORDER编号:100");
			//1、获取国结传的参数
			String ecifno = this.getEcifno(); //客户号
			String businessno = this.getBusinessno(); //业务参考号
			String eduflag = this.getEduflag(); //加解锁标记  0-加锁  1-解锁
			String jylx = this.getJylx(); //交易类型 2-付汇  4-结汇 5-信用证付款  6-托收付款 7-线下汇出汇款8-线下信用证付款9-线下托收付款 1-购汇 3-人工
			String reason = "";
			BigDecimal fuhje = this.getFuhje(); //付汇金额
			BigDecimal jiehje = this.getJiehje(); //结汇金额
			String cusno = this.getCusno(); //客户号
			String operno = this.getOperno(); //柜员号
			String jhbusno = this.getJhbusno(); //结汇业务编号
			String fjbusno = this.getFjbusno(); //付汇业务编号
			String nam = this.getNam(); //加解锁名称
			String errulock = this.getErrulock(); //异常解锁标识
			BigDecimal ling = MdaUtils.parseDecimal(0.00);
			MdaUtils.clear(this.getFqdgrp().getShs()); //查询之前清空一下
			ctx.getDaoSession().dbRead(this.getFqdgrp().getShs(),new Argument<String>("ecifno", ecifno),new Argument<String>("businessno", businessno));
			ctx.getErrorCode(); //清空errorCode,防止影响后边errorCode的取值
			if(MdaUtils.isEmpty(this.getFqdgrp().getShs().getInr()))
			{
			  ctx.setMessage("E9999","未查询到相关购汇额度申请的数据！");
			  return false;
			}
			if(!"0".equals(eduflag) && !"1".equals(eduflag))
			{
			  ctx.setMessage("E9999","加解锁标记不合法，请修改后重试！");
			  return false;
			}
			if("4".equals(jylx))
			{
			  MdaUtils.clear(ctx.absGet(Trnmod.class).getTrn()); //查询之前清空一下
			  ctx.getDaoSession().dbRead(ctx.absGet(Trnmod.class).getTrn(),new Argument<String>("ownref", businessno));
			  ctx.getErrorCode(); //清空errorCode,防止影响后边errorCode的取值
			  if(MdaUtils.isEmpty(ctx.absGet(Trnmod.class).getTrn().getInr()))
			  {
			    ctx.setMessage("E9999","未查询到相关业务数据！");
			    return false;
			  }
			  if(!"d".equals(ctx.absGet(Trnmod.class).getTrn().getSta()))
			  {
			    ctx.setMessage("E9999","当前状态不支持结汇操作！");
			    return false;
			  }
			}
			if("4".equals(jylx) && !"4".equals(this.getFqdgrp().getShs().getApplystatus()))
			{
			  ctx.setMessage("E9999","只有购汇额度状态度为失效状态时才可以做结汇！");
			  return false;
			}
			if("2".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","付汇金额不能小于0！");
			  return false;
			}
			if("5".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","信用证付款金额不能小于0！");
			  return false;
			}
			if("6".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","托收付款金额不能小于0！");
			  return false;
			}
			if("7".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","线下汇出汇款金额不能小于0！");
			  return false;
			}
			if("8".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","线下信用证付款金额不能小于0！");
			  return false;
			}
			if("9".equals(jylx) && fuhje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","线下托收付款金额不能小于0！");
			  return false;
			}
			if("4".equals(jylx) && jiehje.compareTo(ling) < 0)
			{
			  ctx.setMessage("E9999","结汇金额不能小于0！");
			  return false;
			}
			String jiehsign = this.getFqdgrp().getShs().getJiehsign(); //结汇标志
			//已购未付金额是否大于0
			BigDecimal havegwfed = this.getFqdgrp().getShs().getHavegwfed();
			if(havegwfed.compareTo(ling) <= 0)
			{
			  ctx.setMessage("E9999","已购未付金额为0，不能结/付汇！");
			  return false;
			}
			if("2".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","付汇金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("5".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","信用证付款金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("6".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","托收付款金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("7".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","线下汇出汇款金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("8".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","线下信用证付款金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("9".equals(jylx) && havegwfed.compareTo(fuhje) < 0)
			{
			  ctx.setMessage("E9999","线下托收付款金额不能大于已购未付金额，请修改后再试！");
			  return false;
			}
			if("4".equals(jylx) && havegwfed.compareTo(jiehje) != 0)
			{
			  ctx.setMessage("E9999","结汇金额必须等于已购未付金额，请修改后再试！");
			  return false;
			}
			if("1".equals(eduflag))
			{
			  if(!"0".equals(errulock) && !"1".equals(errulock))
			  {
			    ctx.setMessage("E9999","异常解锁标识不合法，请修改后重试！");
			    return false;
			  }
			}
			if("2".equals(jylx))
			{
			  reason = "付汇";
			}
			else if("4".equals(jylx))
			{
			  reason = "结汇";
			}
			else if("5".equals(jylx))
			{
			  reason = "信用证付款";
			}
			else if("6".equals(jylx))
			{
			  reason = "托收付款";
			}
			else if("7".equals(jylx))
			{
			  reason = "线下汇出汇款";
			}
			else if("8".equals(jylx))
			{
			  reason = "线下信用证付款";
			}
			else if("9".equals(jylx))
			{
			  reason = "线下托收付款";
			}
			boolean queryResult = false;
			String lockName = "";
			String lockKey = "shs" + this.getFqdgrp().getShs().getInr();
			if("0".equals(eduflag))
			{
			  if("2".equals(jylx) || "5".equals(jylx) || "6".equals(jylx) || "7".equals(jylx) || "8".equals(jylx) || "9".equals(jylx))
			  {
			    lockName = "fh" + this.getFqdgrp().getShs().getInr() + MdaUtils.format(ctx.getDaoSession().dbCounter("DGGH"),"00000000");
			  }
			  else
			  {
			    lockName = "jh" + this.getFqdgrp().getShs().getInr() + MdaUtils.format(ctx.getDaoSession().dbCounter("DGGH"),"00000000");
			  }
			  log.debug("{}","结付汇给额度表加锁的lockName=" + lockName + "----lockKey=" + lockKey);
			  log.debug("{}","--" + reason + "加锁--");
			  queryResult = queryLck(lockKey, "0");
			  if(!queryResult)
			  {
			    return false;
			  }
			  LockInfo lockinf = ctx.getLocker().lock(lockName,lockKey);
			  int errorCode = ctx.getErrorCode();
			  if(errorCode == ERROR_LOCKED  || errorCode == ERROR_LOCK)
			  {
			    ctx.setMessage("E9999","该笔业务已经被其他用户锁定,无法配置！");
			    return false;
			  }
			  ctx.getDaoSession().dbBegin();
			  this.setNam(lockName);
			  this.getFqdgrp().getShs().setLockflag("0"); //加锁标识
			  ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			  if(ctx.getErrorCode()!= NO_ERROR)
			  {
			    ctx.getDaoSession().dbRollback();
			    log.error("{}","addunlock:购汇额度申请表更新数据失败");
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    return false;
			  }
			  ctx.getDaoSession().dbCommit();
			  log.debug("{}","-------加锁dbCommit-------");
			  if(ctx.getErrorCode()!= NO_ERROR)
			  {
			    log.error("{}","addunlock:提交事务时数据库异常");
			    ctx.setMessage("E9999","数据库异常，请联系管理员！");
			    ctx.getDaoSession().dbRollback();
			    return false;
			  }
			  
			  ctx.setMessage("00000","加锁成功");
			}
			else
			{
			  BigDecimal havesale = this.getFqdgrp().getShs().getHavesale(); //累计购汇金额
			  BigDecimal yifhje = this.getFqdgrp().getShs().getYifhje(); //已付汇金额
			  BigDecimal yijhje = this.getFqdgrp().getShs().getYijhje(); //已结汇金额
			  try
			  {
			    lockName = this.getNam();
			    //判断LCK表存不存在要解锁的记录
			    queryResult = queryLck(lockKey, "1");
			    if(!queryResult)
			    {
			      return false;
			    }
			    ctx.getDaoSession().dbBegin();
			    if("0".equals(errulock))
			    {
			      //异常解锁
			      this.getFqdgrp().getShs().setLockflag("1"); //解锁标识
			      ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","addunlock:购汇额度申请表更新数据失败");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbCommit();
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        log.error("{}","addunlock:提交事务时数据库异常");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        ctx.getDaoSession().dbRollback();
			        return false;
			      }
			      log.debug("{}","--异常解锁--lockName=" + lockName);
			      ctx.setMessage("00000","异常解锁成功");
			    }
			    else
			    {
			      //正常解锁
			      this.getFqdgrp().getShm().setInr(Platform.sdbCounter("shm")); //主键
			      this.getFqdgrp().getShm().setEdbusno(businessno); //自助购汇额度申请参考号
			      this.getFqdgrp().getShm().setPaysum(this.getFqdgrp().getShs().getPaysum()); //金额
			      this.getFqdgrp().getShm().setCansaleed(this.getFqdgrp().getShs().getCansaleed()); //可购汇额度(原金额)
			      this.getFqdgrp().getShm().setHavesale(this.getFqdgrp().getShs().getHavesale()); //已购金额(原金额)
			      this.getFqdgrp().getShm().setHavegwfed(this.getFqdgrp().getShs().getHavegwfed()); //已购未付金额(原金额)
			      this.getFqdgrp().getShm().setYifhje(this.getFqdgrp().getShs().getYifhje()); //已付汇金额(原金额)
			      this.getFqdgrp().getShm().setYijhje(this.getFqdgrp().getShs().getYijhje()); //已结汇金额(原金额)
			      this.getFqdgrp().getShm().setOperno(operno); //柜员号
			      this.getFqdgrp().getShm().setCredat(MdaUtils.today()); //创建日期
			      if("2".equals(jylx) || "5".equals(jylx) || "6".equals(jylx) || "7".equals(jylx) || "8".equals(jylx) || "9".equals(jylx))
			      {
			        log.debug("{}","--" + reason + "解锁--");
			        yifhje = yifhje.add(fuhje); //已付汇金额+付汇金额
			        this.getFqdgrp().getShs().setHavegwfed(havesale.subtract(yifhje)); //新已购未付金额=累计购汇金额-已付汇金额
			        this.getFqdgrp().getShs().setYifhje(yifhje); //新已付汇金额
			        this.getFqdgrp().getShm().setFjbusno(fjbusno); //付汇业务编号
			        this.getFqdgrp().getShm().setOpertype(jylx); //操作类型  2-付汇
			        this.getFqdgrp().getShm().setReason(reason); //修改原因
			        this.getFqdgrp().getShm().setYifhjenew(fuhje);//新已付汇金额
			        //判断可购汇金额=0 && 已购未付金额=0，这个时候要把额度业务状态改为5-已完成
			        if(ling.compareTo(this.getFqdgrp().getShs().getCansaleed()) == 0 && ling.compareTo(this.getFqdgrp().getShs().getHavegwfed()) == 0)
			          this.getFqdgrp().getShs().setApplystatus("5");
			      }
			      else
			      {
			        log.debug("{}","--结汇解锁--");
			        yijhje = yijhje.add(jiehje);
			        this.getFqdgrp().getShs().setHavegwfed(MdaUtils.parseDecimal(0.00)); //已购未付金额置成0.00
			        this.getFqdgrp().getShs().setYijhje(yijhje); //已结汇金额
			        this.getFqdgrp().getShm().setJhbusno(jhbusno); //结汇业务编号
			        this.getFqdgrp().getShm().setOpertype(jylx); //操作类型  4-结汇
			        this.getFqdgrp().getShm().setReason(reason); //修改原因
			        this.getFqdgrp().getShm().setYijhjenew(jiehje);
			        this.getFqdgrp().getShs().setApplystatus("5");
			        this.getFqdgrp().getShs().setJiehsign("1");
			        //20230420
			        this.getFqdgrp().getShs().setApplytyp("3");
			      }
			      ctx.getDaoSession().dbInsert(this.getFqdgrp().getShm());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","addunlock:登记簿明细表插入数据库异常");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        return false;
			      }
			      this.getFqdgrp().getShs().setLockflag("1"); //解锁标识
			      ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","addunlock:更新购汇额度申请表失败");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        return false;
			      }
			      ctx.getDaoSession().dbCommit();
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","addunlock:提交事务数据库异常");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        return false;
			      }
			      
			      log.debug("{}","正常解锁lockName=" + lockName);
			      ctx.setMessage("00000","正常解锁成功");
			    }
			  }
			  finally
			  {
			    //释放未解开的锁
			    log.info("{}","加解锁交易结束，释放未解开的锁lockName=" + lockName);
			    ctx.getLocker().unlock(lockName);
			  }
			}

			return true;
        }

        /**
        *   source:ghtp.@0005.script
        */
        @Rule(target="receptd",order=300)
        public boolean ruleReceptdN300(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，ORDER编号:300");
			//5、给额度表的数据加锁
			String lockName = this.getFqdgrp().getRec().getAppid() + this.getFqdgrp().getShs().getInr() + MdaUtils.format(ctx.getDaoSession().dbCounter("DGGH"),"00000000"); //渠道号3位+主键8位+计数器8位
			ctx.getErrorCode();
			this.setNam(lockName);
			String lockKey = "shs" + this.getFqdgrp().getShs().getInr();
			boolean queryResult = false;
			queryResult = queryLck(lockKey, "0");
			if(!queryResult)
			{
			  return false;
			}
			log.debug("{}","购汇给额度表的数据加锁lockKey=" +lockKey + "----lockName=" + lockName);
			LockInfo lockinf = ctx.getLocker().lock(lockName,lockKey);
			int errorCode = ctx.getErrorCode();
			if(errorCode == ERROR_LOCKED  || errorCode == ERROR_LOCK)
			{
			  ctx.setMessage("E9999","该笔业务已经被其他用户锁定,无法配置！");
			  return false;
			}

			return true;
        }

        /**
        *   source:ghtp.@0006.script
        */
        @Rule(target="receptd",order=400)
        public boolean ruleReceptdN400(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，ORDER编号:400");
			//6、业务表、trn、ord、ore数据存入模型
			String lockName = this.getNam();
			String lockKey = "shs" + this.getFqdgrp().getShs().getInr();
			Date shjyrq = MdaUtils.parseDate(MdaUtils.format(MdaUtils.today(),"yyyy/MM/dd"),"yyyy/MM/dd");//购汇交易日期
			//(1)、业务表入库
			String bchcod = this.getFqdgrp().getShs().getEcifno();
			String ptyinr = this.getFqdgrp().getShs().getPtyinr();
			String ptynam = this.getFqdgrp().getShs().getEcifname();
			this.getFqdgrp().getRec().setInr(Platform.sdbCounter("fqd"));//主键
			this.getFqdgrp().getRec().setRmbjz(this.getFqdgrp().getRec().getJioyje());//人民币金额
			this.getFqdgrp().getRec().setAmount(this.getFqdgrp().getRec().getBankmcje());//外币金额
			this.getFqdgrp().getRec().setWbskno(this.getFqdgrp().getShs().getCuswbzh());//外币收款账号
			this.getFqdgrp().getRec().setSalejyrq(shjyrq);//购汇交易日期
			this.getFqdgrp().getRec().setGjszsbno(this.getFqdgrp().getShs().getGjszsbnewno());//国际收支申报交易编码
			this.getFqdgrp().getRec().setBchcod(bchcod);//归属机构
			this.getFqdgrp().getRec().setPtyinr(ptyinr);//客户机构主键
			this.getFqdgrp().getRec().setEtyinr("00000000");//实体inr
			this.getFqdgrp().getRec().setCredat(shjyrq);//创建日期
			this.getFqdgrp().getRec().setProjecttype(this.getFqdgrp().getShs().getJieshtjno());//外管局统计码
			
			//(2)、业务流水表trn
			//参考号生成规则
			String prefix = ctx.absGet(Mtabut.class).getPrefix() + MdaUtils.format(MdaUtils.today(),"yyMMdd");
			// 默认同类交易当天不会有10000条
			prefix = prefix + MdaUtils.format(ctx.getDaoSession().dbCounter(ctx.absGet(Mtabut.class).getPrefix() + MdaUtils.format(MdaUtils.today(),"yy")),"0000");
			ctx.getErrorCode();
			this.getFqdgrp().getRec().setBusinessno(prefix);//业务参考号
			String trninr = Platform.sdbCounter("trn");
			String ordinr  = Platform.sdbCounter("ord");
			ctx.absGet(Trnmod.class).getTrn().setInr(trninr);//主键
			ctx.absGet(Trnmod.class).getTrn().setBchcod(bchcod);//业务归属机构号
			ctx.absGet(Trnmod.class).getTrn().setInidattim(shjyrq);//交易创建时间
			ctx.absGet(Trnmod.class).getTrn().setInifrm("fqtopn");//交易编码
			ctx.absGet(Trnmod.class).getTrn().setNam(ptynam);//企业名称
			ctx.absGet(Trnmod.class).getTrn().setObjinr(this.getFqdgrp().getRec().getInr());//对象编号
			ctx.absGet(Trnmod.class).getTrn().setObjtyp("fqd");//对象类型
			ctx.absGet(Trnmod.class).getTrn().setOptptyinr(ptyinr);//业务归属机构主键
			ctx.absGet(Trnmod.class).getTrn().setOrdinr(Platform.sdbCounter(ordinr));//申请订单编号
			ctx.absGet(Trnmod.class).getTrn().setOwnref(prefix);//参考号
			ctx.absGet(Trnmod.class).getTrn().setPtyinr(ptyinr);//企业客户主键
			ctx.absGet(Trnmod.class).getTrn().setReloricur(this.getFqdgrp().getRec().getCurrency());//原始币种
			ctx.absGet(Trnmod.class).getTrn().setReloriamt(this.getFqdgrp().getRec().getBankmcje());//原始金额
			ctx.absGet(Trnmod.class).getTrn().setRelreq("O");//业务授权流程定义   只经办 不授权
			ctx.absGet(Trnmod.class).getTrn().setRelres("O");//业务已授权状态
			ctx.absGet(Trnmod.class).getTrn().setSta("f");//业务状态
			ctx.absGet(Trnmod.class).getTrn().setRelstp(0);//操作流程计数器
			ctx.absGet(Trnmod.class).getTrn().setPtytyp("0");//业务流水类型   （0银行端  2企业端）
			
			//(3)、订单信息表ord
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setInr(ordinr);//唯一编号
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setBchcod(bchcod);//订单所属机构号
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setFrm("fqtopn");//当前交易名称
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setInidattim(shjyrq);//订单创建时间
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setInifrm("fqtopn");//订单创建交易名称
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setNam("购汇申请");//订单名称
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setObjinr(this.getFqdgrp().getRec().getInr());//对象编号
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setObjtyp("fqd");//对象类型
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setOptptyinr(ptyinr);//订单当前处理机构
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setSta("C");//订单创建
			ctx.absGet(Trnmod.class).getOrdmod().getOrd().setStadattim(shjyrq);//订单更新状时间
			
			//(4)、订单状态事件表ore
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setInr(Platform.sdbCounter("ore"));
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setBegdattim(shjyrq);//操作开始时间
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setEnddattim(shjyrq);//操作结束时间
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setFrm("fqtopn");//交易代码
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setObjinr(this.getFqdgrp().getRec().getInr());//业务编号
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setObjtyp("fqd");//业务类型
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setOrdinr(ordinr);//ord编号
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setPtyinr(ptyinr);//操作机构
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setTxt("订单创建");//批注信息
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setTyp("C");//ORD.Sta状态
			ctx.absGet(Trnmod.class).getOrdmod().getOre().setAction("11");//操作类型
			log.debug("{}","业务处理结束，ORDER编号:400");

			return true;
        }

        /**
        *   source:ghtp.@0007.script
        */
        @Rule(target="receptd",order=500)
        public boolean ruleReceptdN500(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，ORDER编号:500");
			String lockName = this.getNam();
			log.debug("{}","order 500 lockName=" + lockName);
			String lockKey = "shs" + this.getFqdgrp().getShs().getInr();
			log.debug("{}","购汇申请的lockKey=" + lockKey);
			boolean isNotLock = false; //true-需要一直锁着 false-需要解锁
			try
			{
			  //7、起事务,组装核心接口报文
			  ctx.getDaoSession().dbBegin();
			  ctx.getErrorCode();
			  BigDecimal bankmcje = this.getFqdgrp().getRec().getBankmcje();//银行卖出金额
			  BigDecimal paysum = this.getFqdgrp().getShs().getPaysum();//金额
			  BigDecimal cansaleed = this.getFqdgrp().getShs().getCansaleed();//可购汇额度
			  BigDecimal havesale = this.getFqdgrp().getShs().getHavesale();//累计购汇金额
			  BigDecimal havegwfed = this.getFqdgrp().getShs().getHavegwfed();//已购未付金额
			  BigDecimal havesaleNew = havesale.add(bankmcje);//累计购汇金额新
			  BigDecimal havegwfedNew = havegwfed.add(bankmcje);//已购未付金额新
			  BigDecimal cansaleedNew = paysum.subtract(havesaleNew);//可购汇额度新
			  //7.1 组装组合接口参数
			  //7.1.1 4309账户控制
			  Map zhkz4309 = new HashMap();
			  zhkz4309.put("CAOZBZ", "6"); //操作标志
			  zhkz4309.put("RMZHLX", this.getFqdgrp().getRec().getRmzhlx()); //人民币客户帐号类型
			  zhkz4309.put("KHZHLX", "0"); //客户帐号类型
			  zhkz4309.put("KEHUZH", this.getFqdgrp().getShs().getCuswbzh()); //客户帐号
			  zhkz4309.put("JIO1JE", this.getFqdgrp().getRec().getBankmcje()); //交易金额
			  zhkz4309.put("HUOBDH", this.getFqdgrp().getRec().getMcbiz()); //货币代号
			  zhkz4309.put("YNJYRQ", this.getFqdgrp().getRec().getYnjyrq()); //前台交易日期
			  zhkz4309.put("QANTLS", this.getFqdgrp().getRec().getQantls()); //前台流水号
			  zhkz4309.put("JIO1GY", this.getFqdgrp().getRec().getJio1gy()); //交易柜员
			  zhkz4309.put("APPIDN", this.getFqdgrp().getRec().getAppid()); //渠道来源
			
			  //7.1.2 5006小额结售汇
			  Map xesh5006 = new HashMap();
			  xesh5006.put("WHGMLX", "5"); //外汇买卖类型  5-代客售汇
			  xesh5006.put("PNGCFX", "1"); //银行买卖方向  1-卖出
			  xesh5006.put("JIEHZL", "4"); //结汇种类  4-其它结售汇
			  xesh5006.put("XNZHBZ", "1"); //买入方现转标志  1-转帐
			  xesh5006.put("MAIRZH", this.getFqdgrp().getRec().getDuifzh()); //买入帐号
			  xesh5006.put("CHUIBZ", "1"); //买入钞汇标志  1-汇
			  xesh5006.put("MCXZBZ", "1"); //卖出方现转标志  1-转帐
			  xesh5006.put("MAICZH", this.getFqdgrp().getShs().getCuswbzh()); //卖出帐号
			  xesh5006.put("MCCHBZ", "1"); //卖出方钞汇标志   1-汇
			  xesh5006.put("KEHULB", "0"); //客户类别  0-对公客户
			  xesh5006.put("MAIRHM", this.getFqdgrp().getShs().getEcifname()); //客户名
			  xesh5006.put("HUO1DH", this.getFqdgrp().getRec().getMcbiz()); //银行卖出货币
			  xesh5006.put("MAIRUJ", this.getFqdgrp().getRec().getMairj()); //买入价
			  xesh5006.put("MAICHJ", this.getFqdgrp().getRec().getMaicj()); //卖出价
			  xesh5006.put("PPMRJA", this.getFqdgrp().getRec().getPpanmrj()); //平盘买入价
			  xesh5006.put("PPMCJA", this.getFqdgrp().getRec().getPpanmcj()); //平盘卖出价
			  xesh5006.put("MAICJE", this.getFqdgrp().getRec().getBankmcje()); //银行卖出金额
			  xesh5006.put("ZHYODM", this.getFqdgrp().getRec().getZhyomd()); //摘要代码
			  xesh5006.put("WAIGTJ", this.getFqdgrp().getShs().getJieshtjno()); //外管局统计码
			  xesh5006.put("KEHHAO", this.getFqdgrp().getRec().getEcifno()); //客户号
			  xesh5006.put("HUOBDH", "01"); //银行买入货币
			  xesh5006.put("MAIRJE", this.getFqdgrp().getRec().getJioyje()); //银行买入金额
			  xesh5006.put("RUZHJG", this.getFqdgrp().getRec().getWhzhkhjgh()); //入账机构
			
			  //7.1.3 8593售汇申报信息录入
			  Map shsb8593 = new HashMap();
			  shsb8593.put("CAOZZL", "A"); //操作种类（交易内容）  A-新建申报信息
			  shsb8593.put("JOY1RQ", this.getFqdgrp().getRec().getJoy1rq()); //申报业务交易日期
			  shsb8593.put("YNGYJG", this.getFqdgrp().getRec().getOrgcode()); //申报业务营业机构
			  shsb8593.put("CHULLX", "E"); //结售汇标志  E-售汇
			  shsb8593.put("CAOZBZ", "A"); //操作类型（申报内容）  A－新建
			  shsb8593.put("LEIXIN", "C"); //购汇申请人主体类型  C－对公用户
			  String dihdig = this.getFqdgrp().getRec().getDihdig(); //申请人统一社会信用代码
			  dihdig = dihdig.substring(8, 17); //统一社会信用代码中的第9至17位
			  shsb8593.put("DIHDIG", dihdig); //购汇申请人组织机构代码
			  shsb8593.put("SJJY01", this.getFqdgrp().getRec().getSjjy01()); //购汇申请人名称1
			  shsb8593.put("SJJY02", this.getFqdgrp().getRec().getSjjy02()); //购汇申请人名称2
			  shsb8593.put("DUIFZH", this.getFqdgrp().getRec().getDuifzh()); //人民币账号
			  shsb8593.put("SJZGZH", this.getFqdgrp().getShs().getCuswbzh()); //外币账号
			  shsb8593.put("SJJY03", this.getFqdgrp().getRec().getSjjy03()); //人民币收款人名称1
			  shsb8593.put("SJJY04", this.getFqdgrp().getRec().getSjjy04()); //人民币收款人名称2
			  shsb8593.put("DAYXX1", this.getFqdgrp().getPty().getNam()); //外汇账户开户行名称
			  shsb8593.put("JIOYJE", this.getFqdgrp().getRec().getJioyje()); //购汇金额
			  shsb8593.put("HBZMSX", this.getFqdgrp().getRec().getCurrency()); //币别
			  shsb8593.put("CJIOHL", this.getFqdgrp().getRec().getCjiohl()); //汇率
			  String bangdh = this.getFqdgrp().getShs().getWhjno();
			  shsb8593.put("BANGDH", bangdh);//外汇局批件号/备案表号/业务编号
			  this.getFqdgrp().getRec().setBangdh(bangdh);
			  shsb8593.put("CHJHTH", this.getFqdgrp().getShs().getGjszsbnewno()); //交易编码
			  shsb8593.put("ZHJNMC", this.getFqdgrp().getRec().getZhjnmc()); //填报人
			  shsb8593.put("YYEDZH", this.getFqdgrp().getRec().getYyedzh()); //填报人电话
			  shsb8593.put("RIQIII", MdaUtils.format(MdaUtils.today(),"yyyyMMdd")); //申报日期
			
			  //shm表登记簿操作记录
			  this.getFqdgrp().getShm().setInr(Platform.sdbCounter("shm")); //主键
			  this.getFqdgrp().getShm().setEdbusno(this.getFqdgrp().getRec().getEdbusno()); //自助购汇额度申请参考号
			  this.getFqdgrp().getShm().setGhbusno(this.getFqdgrp().getRec().getBusinessno()); //购汇业务编号
			  this.getFqdgrp().getShm().setOpertype("1"); //操作类型
			  this.getFqdgrp().getShm().setPaysum(this.getFqdgrp().getShs().getPaysum()); //金额
			  this.getFqdgrp().getShm().setHavesalenew(bankmcje); //已购金额
			  this.getFqdgrp().getShm().setCansaleed(this.getFqdgrp().getShs().getCansaleed()); //可购汇额度(原金额)
			  this.getFqdgrp().getShm().setHavesale(this.getFqdgrp().getShs().getHavesale()); //已购金额(原金额)
			  this.getFqdgrp().getShm().setHavegwfed(this.getFqdgrp().getShs().getHavegwfed()); //已购未付金额(原金额)
			  this.getFqdgrp().getShm().setYifhje(this.getFqdgrp().getShs().getYifhje()); //已付汇金额(原金额)
			  this.getFqdgrp().getShm().setYijhje(this.getFqdgrp().getShs().getYijhje()); //已结汇金额(原金额)
			  this.getFqdgrp().getShm().setCusno(this.getFqdgrp().getRec().getEcifno()); //客户号
			  this.getFqdgrp().getShm().setOperno(this.getFqdgrp().getRec().getJio1gy()); //柜员号
			  this.getFqdgrp().getShm().setZhjnmc(this.getFqdgrp().getRec().getZhjnmc()); //填报人
			  this.getFqdgrp().getShm().setReason("网银/手机银行对公购汇申请"); //修改原因
			  this.getFqdgrp().getShm().setCredat(MdaUtils.today()); //创建日期
			
			  //计算金额
			  this.getFqdgrp().getShs().setCansaleed(cansaleedNew); //可购汇额度
			  this.getFqdgrp().getShs().setHavesale(havesaleNew); //累计购汇金额新
			  this.getFqdgrp().getShs().setHavegwfed(havegwfedNew); //已购未付金额
			  this.getFqdgrp().getShs().setDuifzh(this.getFqdgrp().getRec().getDuifzh());

			  //8、调用核心组合接口
			  log.debug("{}","-----调用组合接口开始-----");
			  String cls="com.brilliance.eibs.main.Client";
			  Object zhRtnVal = MdaUtils.invoke(cls,"scall","account_500685934309","account_500685934309",new Object[]{zhkz4309,xesh5006,shsb8593});
			  Map zhRtnMsg = (Map)MdaUtils.invoke(zhRtnVal,"getContent");
			  String errcod = (String)zhRtnMsg.get("errorCode");
			  boolean putStor = false;
			  //9、判断交易结果
			  if("000000".equals(errcod))
			  {
			    log.debug("{}","调用组合接口成功");
			    //交易成功，修改额度表加锁的那条数据对应的额度、购汇结果改为“成功”，并解锁数据，提交/回滚事务
			    this.getFqdgrp().getRec().setShjiayjg("0");//购汇申请交易结果
			    ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			    if(ctx.getErrorCode()!= NO_ERROR)
			    {
			      ctx.getDaoSession().dbRollback();
			      log.error("{}","order 500购汇额度申请表更新数据失败");
			      ctx.setMessage("E9999","数据库异常，请联系管理员！");
			      return false;
			    }
			    ctx.getDaoSession().dbInsert(this.getFqdgrp().getShm());
			    log.debug("{}","shm表入库");
			    if(ctx.getErrorCode()!= NO_ERROR)
			    {
			      ctx.getDaoSession().dbRollback();
			      log.error("{}","order 500登记簿明细表插入时数据库异常");
			      ctx.setMessage("E9999","数据库异常，请联系管理员！");
			      return false;
			    }
			    putStor = putStorage();
			    if(putStor)
			    {
			      
			      ctx.setMessage("00000","购汇成功");
			    }
			    else
			    {
			      return false;
			    }
			  }
			  else if("PPB1091".equals(errcod))
			  {
			    //组合接口交易超时，调用查证接口，最多发起5次
			    Map<String,String> czMap = new HashMap<String,String>();
			    String retcod = "";
			    String zhangt ="";
			    //查证交易超时，再尝试
			    for(int i = 0; i < 5; i++)
			    {
			      czMap = chaZheng9970();
			      retcod = czMap.get("retcod");
			      if("PPB1091".equals(retcod))
			      {
			        continue;
			      }
			      zhangt = czMap.get("zhangt");
			      break;
			    }
			    if("0000000".equals(retcod))
			    {
			      if("0".equals(zhangt))
			      {
			        //普通交易成功
			        ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			        if(ctx.getErrorCode()!= NO_ERROR)
			        {
			          ctx.getDaoSession().dbRollback();
			          log.error("{}","order 500购汇额度申请表更新数据失败");
			          ctx.setMessage("E9999","数据库异常，请联系管理员！");
			          return false;
			        }
			        ctx.getDaoSession().dbInsert(this.getFqdgrp().getShm());
			        if(ctx.getErrorCode()!= NO_ERROR)
			        {
			          ctx.getDaoSession().dbRollback();
			          log.error("{}","order 500登记簿明细表插入时数据库异常");
			          ctx.setMessage("E9999","数据库异常，请联系管理员！");
			          return false;
			        }
			        //存表
			        putStor = putStorage();
			        if(putStor)
			        {
			          
			          ctx.setMessage("00000","购汇成功");
			        }
			        else
			        {
			          return false;
			        }
			      }
			      else
			      {
			        log.debug("{}","购汇申请交易失败-查证接口返回结果");
			        //交易失败
			        this.getFqdgrp().getRec().setShjiayjg("1");//购汇申请交易结果
			        //存表
			        putStor = putStorage();
			        if(putStor)
			        {
			          ctx.setMessage("E9999","购汇失败，请重试！");
			          return false;
			        }
			        else
			        {
			          return false;
			        }
			      }
			    }
			    else
			    {
			      log.debug("{}","购汇申请交易失败-查证接口调用失败");
			      //交易失败
			      this.getFqdgrp().getRec().setShjiayjg("3");//购汇申请交易结果为交易未明
			      this.getFqdgrp().getShs().setCansaleed(cansaleed); //可购汇额度
			      this.getFqdgrp().getShs().setHavesale(havesale); //累计购汇金额
			      this.getFqdgrp().getShs().setHavegwfed(havegwfed); //已购未付金额
			      this.getFqdgrp().getShs().setLockflag("0");
			      ctx.getDaoSession().dbUpdate(this.getFqdgrp().getShs());
			      if(ctx.getErrorCode()!= NO_ERROR)
			      {
			        ctx.getDaoSession().dbRollback();
			        log.error("{}","order 500购汇额度申请表更新数据失败,交易未明");
			        ctx.setMessage("E9999","数据库异常，请联系管理员！");
			        return false;
			      }
			      //存表
			      putStor = putStorage();
			      isNotLock = true; //交易未明不解锁额度
			      if(putStor)
			      {
			        ctx.setMessage("E9999","购汇申请交易状态未明，请人工干预处理");
			        return false;
			      }
			      else
			      {
			        return false;
			      }
			    }
			  }
			  else
			  {
			    log.debug("{}","购汇申请交易失败-组合接口调用失败");
			    //(3)、交易失败，修改购汇结果改为“失败”，并解锁数据，提交/回滚事务
			    //交易失败
			    this.getFqdgrp().getRec().setShjiayjg("1");//购汇申请交易结果
			    //存表
			    putStor = putStorage();
			    if(putStor)
			    {
			      log.error("{}",zhRtnMsg.get("errorDesp"));
			      ctx.setMessage("E9999",zhRtnMsg.get("errorDesp"));
			      return false;
			    }
			    else
			    {
			      return false;
			    }
			  }
			}
			finally
			{
			  //释放未解开的锁
			  log.info("{}","====isNotLock====" + isNotLock);
			  if(!isNotLock)
			  {
			    log.info("{}","交易结束，释放未解开的锁");
			    ctx.getLocker().unlock(lockName);
			  }
			}

			return true;
        }

        /**
        *   source:ghtp.@0008.script
        */
        @Rule(target="receptd",order=200)
        public boolean ruleReceptdN200(){
            IContext ctx = MdaEnv.getContext();
            
			log.debug("{}","业务处理开始，ORDER编号:200");
			//4、调用国结eg02参数查询接口 ，根据客户号获取自助购汇申请时限 ，判断申请时间是否在时限之内
			String cls="com.brilliance.eibs.main.Client";
			String ecifno = this.getFqdgrp().getRec().getEcifno();
			String currency = this.getFqdgrp().getRec().getCurrency();
			Object rtnVal = MdaUtils.invoke(cls,"scall","eg02","eg02",new Object[]{ecifno,currency});
			Map retMsg = (Map)MdaUtils.invoke(rtnVal,"getContent");
			String reqCod = (String)retMsg.get("JIAYJG");
			if("AAAAAAA".equals(reqCod))
			{
			  String shqssjkh = MdaUtils.format(MdaUtils.today(),"yyyyMMdd") + (String)retMsg.get("SHQSSJKH");
			  shqssjkh = shqssjkh.replaceAll("[[\\s-:punct:]]", "");
			  String shjzsjkh = MdaUtils.format(MdaUtils.today(),"yyyyMMdd") + (String)retMsg.get("SHJZSJKH");
			  shjzsjkh = shjzsjkh.replaceAll("[[\\s-:punct:]]", "");
			  String shjysjd = MdaUtils.format(MdaUtils.today(),"yyyyMMddHHmmss");
			  log.debug("{}","自助购汇提前申请时限为：" + shqssjkh + "-" + shjzsjkh);
			  if(!MdaUtils.isEmpty(shqssjkh) && !MdaUtils.isEmpty(shjzsjkh))
			  {
			    //自助购汇提前申请开始时间（9:30:00）,截止时间最大值为23:30:00（默认18:00:00)
			    int diff1 = MdaUtils.diff(MdaUtils.parseDate(shjysjd,"yyyyMMddHHmmss"),MdaUtils.parseDate(shqssjkh,"yyyyMMddHHmmss"));
			    int diff2 = MdaUtils.diff(MdaUtils.parseDate(shjzsjkh,"yyyyMMddHHmmss"),MdaUtils.parseDate(shjysjd,"yyyyMMddHHmmss"));
			    if(diff1 < 0 || diff2 < 0)
			    {
			      ctx.setMessage("E9999","不在自助购汇申请时限内，当前申请时限：" + (String)retMsg.get("SHQSSJKH") + "-" + (String)retMsg.get("SHJZSJKH"));
			      return false;
			    }
			  }
			  else
			  {
			    ctx.setMessage("E9999","未查到自助购汇申请时限！");
			    return false;
			  }
			}
			else
			{
			  log.error("{}",retMsg.get("ERRORMESSAGE"));
			  ctx.setMessage("E9999",retMsg.get("ERRORMESSAGE"));
			  return false;
			}
			log.debug("{}","业务处理结束，ORDER编号:200");

			return true;
        }




        /**
        *   source:ghtp.@0009.script
        */
        public Map<String,String> chaZheng9970()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String cls="com.brilliance.eibs.main.Client";
			Map<String,String> map = new HashMap<String,String>();
			log.debug("{}","交易超时，调用查证接口ynjyrq=" + this.getFqdgrp().getRec().getYnjyrq() + "qantls=" + this.getFqdgrp().getRec().getQantls());
			//(2)、交易超时，调用查证接口再判断交易是否成功
			Object czRtnVal = MdaUtils.invoke(cls,"scall","9970","9970",new Object[]{this.getFqdgrp().getRec().getYnjyrq(),this.getFqdgrp().getRec().getQantls()});
			Map czRtnMsg = (Map)MdaUtils.invoke(czRtnVal,"getContent");
			String errcod = (String)czRtnMsg.get("ERRCOD");
			String zhangt = (String)czRtnMsg.get("RESULT");
			String errmsg = (String)czRtnMsg.get("ERRMSG");
			log.debug("{}","errcod=" + errcod + "zhangt=" + zhangt);
			if("0000000".equals(errcod))
			{
			  if("0".equals(zhangt))
			  {
			    map.put("retcod", "0000000"); //响应码
			    map.put("zhangt", "0"); //原交易结果
			    map.put("errmsg", "");
			    return map;
			  }
			  else
			  {
			    map.put("retcod", "0000000");
			    map.put("zhangt", "2");
			    map.put("errmsg", "");
			    return map;
			  }
			}
			else
			{
			  log.error("{}",czRtnMsg.get("ERRMSG"));
			  map.put("retcod", errcod);
			  map.put("zhangt", "");
			  map.put("errmsg", errmsg);
			  return map;
			}
		}
        /**
        *   source:ghtp.@0010.script
        */
        public boolean putStorage()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			ctx.getDaoSession().dbInsert(this.getFqdgrp().getRec());
			log.debug("{}","业务表入库");
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  log.error("{}","putStorage:购汇信息表插入时数据库异常");
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return false;
			}
			ctx.getDaoSession().dbInsert(ctx.absGet(com.ceb.gjjs.mda.manager.module.Trnmod.class).getTrn());
			log.debug("{}","trn表入库");
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  log.error("{}","putStorage:业务流水表插入时数据库异常");
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return false;
			}
			ctx.getDaoSession().dbInsert(ctx.absGet(com.ceb.gjjs.mda.manager.module.Trnmod.class).getOrdmod().getOrd());
			log.debug("{}","ord表入库");
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  log.error("{}","putStorage:订单信息表插入时数据库异常");
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return false;
			}
			ctx.getDaoSession().dbInsert(ctx.absGet(com.ceb.gjjs.mda.manager.module.Trnmod.class).getOrdmod().getOre());
			log.debug("{}","ore表入库");
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  ctx.getDaoSession().dbRollback();
			  log.error("{}","putStorage:订单状态事件表插入时数据库异常");
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  return false;
			}
			ctx.getDaoSession().dbCommit();
			log.debug("{}","-------dbCommit---------");
			if(ctx.getErrorCode()!= NO_ERROR)
			{
			  log.error("{}","putStorage:提交事务时数据库异常");
			  ctx.setMessage("E9999","数据库异常，请联系管理员！");
			  ctx.getDaoSession().dbRollback();
			  return false;
			}
			return true;
		}
        /**
        *   source:ghtp.@0011.script
        */
        public boolean queryLck(String lockKey, String lockflag)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","queryLck开始lockKey=" + lockKey + "--lockflag=" + lockflag);
			//判断LCK表存不存在要解锁的记录
			//lockflag  0-加锁  1-解锁
			String sql = "SELECT txt FROM lck where txt='" + lockKey + "'";
			ctx.getDaoSession().dbExecuteSQL(sql);
			int err1 = ctx.getErrorCode();
			log.debug("{}","err1=" + err1);
			Argument<String> txt = new Argument<String>("txt");
			ctx.getDaoSession().dbFetchFields(txt);
			int err2 = ctx.getErrorCode();
			log.debug("{}","err2=" + err2);
			ctx.getDaoSession().dbCloseCursor();
			if(err2 == NO_ERROR)
			{
			  if(!MdaUtils.isEmpty(txt.value))
			  {
			    log.debug("{}","txtvalue=" + txt.value);
			    if("0".equals(lockflag))
			    {
			      ctx.setMessage("E9999","该笔业务已锁定，不要重复加锁！");
			      return false;
			    }
			  }
			  if(MdaUtils.isEmpty(txt.value) && "1".equals(lockflag))
			  {
			    ctx.setMessage("E9999","该笔业务未锁定，无法解锁！");
			    return false;
			  }
			}
			else if(err2 == NO_MORE_ROW)
			{
			  if("1".equals(lockflag))
			  {
			    ctx.setMessage("E9999","该笔业务未锁定，无法解锁！");
			    return false;
			  }
			}
			else
			{
			  ctx.setMessage("E9999","获取加锁记录异常，请联系管理员！");
			  return false;
			}
			return true;
		}



































}