package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Img;
import com.ceb.gjjs.mda.bo.Tblcnt;
import com.ceb.gjjs.mda.bo.Tblbil;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Imgmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Imgmod.class);

        //业务编号
        private String ownref;

        //影像批次号
        private String imgref;

        //影像批次编号
        private String guid;



	    @BDGetter
		private Img img;

	    @BDGetter
		private Tblcnt tblcnt;

	    @BDGetter
		private Tblbil tblbil;


		public Imgmod()
        {
            super();
            setArgument();
        }

        public Imgmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }




        /**
        *   source:imgmod.@0005.script
        */
        public boolean callImageComponent(String actiontype,String ownref,String imgref,String trncod, String logname,String objtyp )
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 影像控件调用入口
			  * 调用参数
			  -actiontype: 操作类型   ImageUpload.影像上传 ,  ImageScan.影像查阅
			  -ownref ：业务参考号
			  -imgref ： 影像参考号. 如果未传入特定的影像参考号，则控件认为影像参考号与业务参考一致。
			  -trncod : 交易代码. eg. 申请类交易传入申请的交易码;通知类交易传入通知原STL接口传入的交易码; 备注：复核夹/历史夹需要传入产生该影像信息的交易代码
			  -logname：经办人员名称
			  -objtyp: 业务表名称
			  */

			log.debug("{}","in imgmod.callImageComponent...  ");
			if(MdaUtils.isEmpty(actiontype))
			{
			  log.error("{}","未指定调用影像控件的具体操作");
			  return false;
			}
			if(MdaUtils.isEmpty(imgref) && MdaUtils.isEmpty(ownref))
			{
			  log.error("{}","未传入调用影像控件的必要参数");
			  return false;
			}
			if(MdaUtils.isEmpty(imgref) && !MdaUtils.isEmpty(ownref))
			{
			  imgref = ownref ;
			}
			Object msg = null;
			/*session只为影像控件使用
			  *1、每次调用影像前 	必须 	设置
			  *2、请确定知道什么意思，然后再修改*/
			Platform.writeToSession("djcod",imgref);//影像批次号
			Platform.writeToSession("buscod",ownref);//业务参号
			String uuidtoken = UUID.randomUUID().toString().replace("-", "");
			Platform.writeToSession("uuidtoken",uuidtoken);//token，用来判断请求唯一性
			log.info("{}","djcod|buscod|uuidtoken from session :"+Platform.readFromSession("djcod")+"	"+Platform.readFromSession("buscod")+"	"+Platform.readFromSession("uuidtoken"));
			//session设置结束。
			if("ImageUpload".equals(actiontype))
			{
			  log.debug("{}","in ImageUpload...  ");
			  this.setImgref(imgref);
			  this.setOwnref(ownref);
			  saveOrUpdateImg(ownref,imgref,trncod,logname,objtyp );
			  msg = MdaUtils.invoke("client:",actiontype,trncod,ownref,imgref,logname,uuidtoken);
			}
			else
			  if("ImageScan".equals(actiontype))
			{
			  log.debug("{}","in ImageScan...  ");
			  msg = MdaUtils.invoke("client:",actiontype,"",ownref,imgref,"",uuidtoken);
			}
			// TODO 返回值处理
			return true ;
		}
        /**
        *   source:imgmod.@0007.script
        */
        public String saveOrUpdateImg(String ownref,String imgref,String trncod, String logname,String objtyp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 保存影像上传控件调用信息
			  *
			  */
			log.debug("{}","in imgmod.saveOrUpdateImg ");
			MdaUtils.clear(this.getImg());
			ctx.getDaoSession().dbBegin();
			Argument<Integer> cnt = new Argument<Integer>("cnt");
			ctx.getDaoSession().dbExecuteSQL("SELECT Count(INR) AS CNT FROM IMG WHERE IMGREF = ? AND OWNREF = ?",imgref,ownref);
			ctx.getDaoSession().dbFetchFields(cnt);
			ctx.getDaoSession().dbCloseCursor();
			if(ctx.getErrorCode()== NO_ERROR && cnt.value>0)
			{
			  ctx.getDaoSession().dbRead(this.getImg(),new Argument("imgref",imgref ),new Argument("ownref",ownref));
			  log.debug("{}","该影像批次号下已经保存了对应的IMG操作记录：img.inr=" +this.getImg().getInr()+",img.ownref="+ ownref+",img.imgref="+imgref);
			  this.getImg().setInifrm( trncod );
			  this.getImg().setLgnnam( logname);
			  this.getImg().setObjtyp( objtyp );
			  this.getImg().setOptdattim( MdaUtils.today());
			  this.getImg().setCnt(this.getImg().getCnt() + 1);
			  ctx.getDaoSession().dbUpdate(this.getImg());
			}
			else
			{
			  this.getImg().setImgref( imgref);
			  this.getImg().setOwnref( ownref);
			  this.getImg().setCredat( MdaUtils.today());
			  this.getImg().setInifrm( trncod);
			  this.getImg().setLgnnam( logname);
			  this.getImg().setCnt(1);
			  this.getImg().setOptdattim( MdaUtils.today());
			  this.getImg().setObjtyp( objtyp);
			  this.getImg().setFtysuc("Z00238");
			  this.getImg().setInr(MdaUtils.format(ctx.getDaoSession().dbCounter("img"),"00000000"));
			  ctx.getDaoSession().dbInsert(this.getImg());
			  log.debug("{}","保存影像操作记录成功，img.inr="+this.getImg().getInr() +",img.ownref="+ ownref+",img.imgref="+imgref);
			}
			ctx.getDaoSession().dbCommit();
			return this.getImg().getInr();
		}
        /**
        *   source:imgmod.@0008.script
        */
        public void updateImageByIDs(String imgref , String objinr ,String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 业务保存时根据imgref值更新IMG表的 objinr 、trninr. 在 sav 1000中调用
			  */

			log.debug("{}","in imgmod.updateImageByID ... ");
			MdaUtils.clear(this.getImg());
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("imgref",imgref),new Argument("ftysuc","Z00238"));
			log.debug("{}","errorCode:" + ctx.getErrorCode());
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  this.getImg().setTrninr( trninr);
			  this.getImg().setObjinr( objinr);
			  if(MdaUtils.isEmpty(this.getImg().getGuid()))
			    this.getImg().setGuid( getDocID());
			  this.setGuid( this.getImg().getGuid());
			  this.getImg().setCredat( MdaUtils.today());
			  //  Platform.dbUpdate($img);
			  ctx.getDaoSession().dbUpdate(this.getImg());
			}
		}
        /**
        *   source:imgmod.@0011.script
        */
        public boolean uploadImage(String ownref,String imgRef,String cibBranchID,String cibOrgID )
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in uploadImage ... ");
			String sql = "select djcod,inr,filnam,edtfilpth,alsnam,doctyp from tblbil where buscod = '"+ownref+"' and djcod = '"+imgRef+"' and itmcod = 'KZSQS' and tratyp is null order by inr asc";
			Argument<String> imgref = new Argument<String>("djcod");
			Argument<Integer> inr = new Argument<Integer>("inr");
			Argument<String> fileName = new Argument<String>("filnam");
			Argument<String> filePath = new Argument<String>("edtfilpth");
			Argument<String> displayName = new Argument<String>("alsnam");
			Argument<String> doctyp = new Argument<String>("doctyp");
			ctx.getDaoSession().dbExecuteSQL(sql);
			List <Map<String,Object> > datalist = new  ArrayList<Map<String,Object> >();
			List <Map<String,Object> > list = new  ArrayList<Map<String,Object> >();
			int cnt = 0;
			//根据规则同一批次文件存放路径一致
			String path="";
			while(true)
			{

			  ctx.getDaoSession().dbFetchFields(imgref,inr,fileName,filePath,displayName,doctyp);
			  if( ctx.getErrorCode() == NO_ERROR)
			  {
			    log.debug("{}","imgref=" +imgref.value);
			    log.debug("{}","displayName=" +displayName.value);
			    path = filePath.value.substring(0,filePath.value.length() - fileName.value.toString().length());
			    log.debug("{}","path=" +path);

			    Map<String,Object> data1 = new HashMap<String,Object>();
			    data1.put("PFileName",fileName.value.toString());
			    data1.put("DisplayName",displayName.value);
			    data1.put("MD5","");
			    data1.put("SideTag","1");
			    data1.put("FileForm","other");
			    data1.put("CibBranchID",cibBranchID);
			    data1.put("CibOrgID",cibOrgID);
			    data1.put("Doctyp",doctyp.value.trim());
			    data1.put("CibOperID",ctx.absGet(Sysmod.class).getUsr().getNotesid());
			    data1.put("ReceivedDate",MdaUtils.format(MdaUtils.today(),"yyyyMMdd"));
			    data1.put("opertype","A");
			    data1.put("imagepath",path);
			    list.add(data1);
			    cnt = cnt +1;
			  }

			  else
			    break;
			}

			ctx.getDaoSession().dbCloseCursor();

			if( cnt!=0)
			{
			  //增加排序文件上传
			  Map<String,Object> sortMap = new HashMap<String,Object>();
			  sortMap.put("PFileName","sort_"+imgRef+".xml");
			  sortMap.put("DisplayName","sort_"+imgRef+".xml");
			  sortMap.put("MD5","");
			  sortMap.put("SideTag","1");
			  sortMap.put("FileForm","SORT_");
			  sortMap.put("CibBranchID",cibBranchID);
			  sortMap.put("CibOrgID",cibOrgID);
			  sortMap.put("Doctyp","xml");
			  sortMap.put("CibOperID",ctx.absGet(Sysmod.class).getUsr().getNotesid());
			  sortMap.put("ReceivedDate",MdaUtils.format(MdaUtils.today(),"yyyyMMdd"));
			  sortMap.put("opertype","A");
			  sortMap.put("imagepath",path);
			  list.add(sortMap);

			  log.debug("{}","本批次"+imgRef+"开始上传： "+cnt+"张影像！");

			  Map<String,Object> data = new HashMap<String,Object>();
			  data.put("ImageRegID",imgRef);
			  data.put("OwnRef",ownref);
			  data.put("imageList",list);

			  datalist.add(data);
			  String cls="com.brilliance.eibs.main.Client";
			  Object resMsg = MdaUtils.invoke(cls,"scall","dzticmsend","dzticmsend",new Object[]{datalist});
			  if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    if("true".equals(isSuc.substring(0,5).trim()))
			    {
			      log.debug("{}","影像上传成功 ... ");
			      this.updateImageByID(imgref.value);
			      this.updateImageUplodState(ownref,imgRef);
			      return true;
			    }
			    else
			    {
			      log.debug("{}","影像上传失败 ... ");
			      String errorcod=isSuc.substring(5,24).trim();
			      log.debug("{}","errorcod=" +errorcod);
			      String errorcodname=MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"cfg/icmapi.properties");
			      String errorvalue=MdaUtils.getPropertyValue(errorcodname,errorcod.substring(errorcod.indexOf("-")+1,errorcod.indexOf("-")+8).trim());
			      log.debug("{}","errorvalue=" +errorvalue);
			      if("D".equals(errorcod.substring(0,1)))
			      {
			        ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000084"),MdaUtils.getI18NString("imgmod","CT000085"));
			        return false;
			      }
			      else
			      {
			        ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000086"),errorvalue);
			        return false;
			      }
			    }
			  }
			}
			else
			{
			  log.debug("{}","该笔业务没有影像信息需要提交");
			}
			log.debug("{}","out uploadImage ... ");
			return true;
		}
        /**
        *   source:imgmod.@0012.script
        */
        public boolean imgScan(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//影像查询
			log.debug("{}","in imgScan ... ");
			log.debug("{}","trninr=" +trninr);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			String ownref = this.getImg().getOwnref();
			String imgref = this.getImg().getImgref();
			String objtyp = this.getImg().getObjtyp();
			Date date = this.getImg().getCredat();
			String nam = this.getImg().getLgnnam();
			if(MdaUtils.isEmpty(this.getImg().getImgref()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000088"),MdaUtils.getI18NString("imgmod","CT000089"));
			  return false;
			}
			log.debug("{}","ownref=" +ownref);
			log.debug("{}","imgref=" +imgref);
			//String appId = "1001";
			//String netId = "KJ01";
			String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			if(ownref.startsWith("YK"))
			  fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/imgdyck.properties");
			String appId = MdaUtils.getPropertyValue(fileName,"appId");
			String netId = MdaUtils.getPropertyValue(fileName,"netId");
			String gdate = MdaUtils.format(date,"yyyyMMdd");
			String guid = this.getImg().getGuid();
			if(MdaUtils.isEmpty(guid))
			{
			  log.debug("{}","guid为空，影像未上传ecm ... ");
			  //查询影像成功则调用影像控件
			  boolean result= this.callImageComponent("ImageScan",ownref,imgref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			  return true;
			}
			String operId = nam;
			String cls="com.brilliance.eibs.main.Client";
			Object resMsg = MdaUtils.invoke(cls,"scall","dztdownload","dztdownload",new Object[]{appId,netId,guid,gdate,operId});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","isSuc= "+isSuc);
			  if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			  {
			    log.debug("{}","查询影像成功 ... ");
			    //查询影像成功则调用影像控件
			    boolean result= this.callImageComponent("ImageScan",ownref,imgref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			    if(result)
			    {
			      return true;
			    }
			    else
			      return false;
			  }
			  else
			  {
			    log.debug("{}","查询影像失败 ... ");
			    String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000090"),errorcod);
			  }
			}
			else
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","isSuc= "+isSuc);
			  log.debug("{}","isSuc的长度为：" + isSuc.length());
			  String errorcod="调用接口异常！";
			  log.debug("{}","errorcod=" +errorcod);
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000091"),errorcod);
			  return false;

			}
			return true;
		}
        /**
        *   source:imgmod.@0013.script
        */
        public String saveSTLImage(String stlref,String imgref,String objtyp,String objinr,String trninr,String trncod,String logname,String bchcod )
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 保存STL端新增的影像信息 - 在收报交易中调动
			  */
			MdaUtils.clear(this.getImg());
			this.getImg().setImgref(imgref);
			this.getImg().setOwnref(stlref);
			this.getImg().setCredat(MdaUtils.today());
			this.getImg().setInifrm( trncod );
			this.getImg().setLgnnam( logname);
			this.getImg().setTrninr( trninr);
			this.getImg().setReldattim(MdaUtils.today());
			this.getImg().setCnt( 0);
			this.getImg().setObjinr( objinr);
			this.getImg().setObjtyp( objtyp);
			this.getImg().setOptdattim(MdaUtils.today());
			this.getImg().setBchcod( bchcod);
			this.getImg().setFtysuc("Z00001");
			this.getImg().setInr(MdaUtils.format(ctx.getDaoSession().dbCounter("img"),"00000000"));
			ctx.getDaoSession().dbInsert(this.getImg());
			return this.getImg().getInr();

		}
        /**
        *   source:imgmod.@0014.script
        */
        public void updateImageByID(String imgref)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 业务提交时根据imgref值更新IMG表的  reldattim , 在银行端复核时调用
			  */
			log.debug("{}","in imgmod.updateImgByOwnref ... ");
			MdaUtils.clear(this.getImg());
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("imgref",imgref),new Argument("ftysuc","Z00238"));
			log.debug("{}","error:"+ ctx.getErrorCode());
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  this.getImg().setGuid( getDocID());
			  // $guid = $img\\guid.getValue();
			  this.getImg().setReldattim( MdaUtils.today());
			  ctx.getDaoSession().dbUpdate(this.getImg());
			}
		}
        /**
        *   source:imgmod.@0017.script
        */
        public void updateSTLImage(String stlref,String imgref ,String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 收报时根据stlref,imgref 值更新IMG表的  trninr. 在 stlbod中调用
			  */
			log.debug("{}","in imgmod.updateImgByOwnref ... ");
			if(!MdaUtils.isEmpty(stlref) && !MdaUtils.isEmpty(imgref))
			{
			  MdaUtils.clear(this.getImg());
			  ctx.getDaoSession().dbRead(this.getImg(),new Argument("ownref",stlref),new Argument("imgref",imgref),new Argument("ftysuc","Z00001"));
			  if(ctx.getErrorCode() == NO_ERROR)
			  {
			    this.getImg().setTrninr( trninr);
			    ctx.getDaoSession().dbUpdate(this.getImg());
			  }
			}
		}
        /**
        *   source:imgmod.@0018.script
        */
        public boolean judgingImageOpen(String cid,String frm,String bch)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String sql="select trnopnflg from epc where cid='"+cid+"' and trncod='"+frm+"' and ptybch='"+bch+"'";
			Argument<String> flg = new Argument<String>("trnopnflg");
			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getDaoSession().dbFetchFields(flg);
			ctx.getDaoSession().dbCloseCursor();
			if(!"X".equals(flg.value))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000097"),MdaUtils.getI18NString("imgmod","CT000098"));
			  return false;
			}
			return true;
		}
        /**
        *   source:imgmod.@0019.script
        */
        public String getImageReference()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * IMG记录产生以后，在保存或更新前获取当前业务的影像批次号
			  */
			//用于组报文时获取guid放入imageID中
			String imageID = "";
			if(MdaUtils.isEmpty(this.getImgref()))
			{
			  log.debug("{}","当前业务未生成新的影像信息");
			  return null;
			}
			if( imageUploaded(this.getImgref(),this.getOwnref()))
			{
			  this.setGuid(NULLSTR);
			  this.setGuid( this.getDocID());
			  imageID = this.getGuid();
			}
			return imageID;
		}
        /**
        *   source:imgmod.@0020.script
        */
        public boolean imageUploaded(String imgref,String ownref)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 判断当前业务影像控件是否实际上传相关的影像
			  */
			log.debug("{}","in imgmod.imageUploaded ...  imgref=" +imgref +", ownref="+ ownref );
			Argument<Integer> cnt = new Argument<Integer>("CNT");
			ctx.getDaoSession().dbExecuteSQL("SELECT COUNT(INR) AS CNT FROM TBLBIL WHERE DJCOD = ? AND BUSCOD = ? AND BILFLG = '0' ",imgref,ownref);
			ctx.getDaoSession().dbFetchFields(cnt);
			ctx.getDaoSession().dbCloseCursor();
			if(ctx.getErrorCode()== NO_ERROR && cnt.value>0)
			{
			  return true;
			}
			else
			{
			  return false;
			}

		}
        /**
        *   source:imgmod.@0021.script
        */
        public boolean stlImgScan(String imginr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//影像查询
			log.debug("{}","in imgScan ... ");
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("inr",imginr));
			//String ownref = $\\sysmod\\itfmod\\imgmod\\img\\ownref.getValue();
			String imgref = this.getImg().getImgref();
			String objtyp = this.getImg().getObjtyp();
			String ownref = this.getImg().getOwnref();
			Date date = this.getImg().getCredat();
			String trncod = this.getImg().getInifrm();
			String yngyjg = this.getImg().getBchcod();
			String nam = this.getImg().getLgnnam();
			if(MdaUtils.isEmpty(this.getImg().getImgref()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000104"),MdaUtils.getI18NString("imgmod","CT000105"));
			  return false;
			}
			//log.debug("ownref=" +ownref);
			log.debug("{}","imgref=" +imgref);

			String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			String appId = MdaUtils.getPropertyValue(fileName,"appId");
			String netId = MdaUtils.getPropertyValue(fileName,"netId");
			String gdate = MdaUtils.format(date,"yyyyMMdd");
			//String guid = $img\\guid.getValue();
			String operId = nam;
			log.debug("{}","netID:" + netId);
			log.debug("{}","appId:" + appId);
			log.debug("{}","gdate:" + gdate);
			log.debug("{}","operId:" + operId);
			log.debug("{}","imgref:" + imgref);
			log.debug("{}","trncod:" + trncod);
			log.debug("{}","ownref:" + ownref);
			log.debug("{}","yngyjg:" + yngyjg);

			String cls="com.brilliance.eibs.main.Client";
			Object resMsg = MdaUtils.invoke(cls,"scall","download","download",new Object[]{netId,appId,gdate,operId,imgref,trncod,ownref,yngyjg});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","isSuc= "+isSuc);
			  log.debug("{}","isSuc的长度为：" + isSuc.length());
			  if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			  {
			    log.debug("{}","查询影像成功 ... ");
			    //查询影像成功则调用影像控件
			    boolean result= this.callImageComponent("ImageScan",ownref,ownref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			    if(result)
			    {
			      return true;
			    }
			    else
			      return false;
			  }
			  else
			  {
			    log.debug("{}","查询影像失败 ... ");
			    String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000106"),errorcod);
			  }
			}
			else
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","isSuc= "+isSuc);
			  log.debug("{}","isSuc的长度为：" + isSuc.length());
			  if(isSuc.contains("登陆失败"))
			  {
			    String errorcod="登录影像平台失败！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000107"),errorcod);
			    return false;
			  }
			  else
			  {
			    String errorcod="调用接口失败！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000108"),errorcod);
			    return false;
			  }
			}
			return true;
		}
        /**
        *   source:imgmod.@0022.script
        */
        public boolean updateImageUplodState(String buscod , String djcod )
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 上传影像管理平台成功后，更新上传成功标志 tratyp 为UPLOAD
			  */
			ctx.getErrorCode();
			String sql="update tblbil set tratyp='UPLOAD'  where buscod = '"+buscod+"' and djcod = '"+djcod+"' and itmcod = 'KZSQS' and tratyp is null ";
			ctx.getDaoSession().dbExecuteSQL(sql);
			ctx.getDaoSession().dbCloseCursor();
			if(ctx.getErrorCode() == NO_ERROR)
			  return true;
			else
			  return false;
		}
        /**
        *   source:imgmod.@0023.script
        */
        public boolean uploadImageToCMS(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImageToCMS ... ");
			boolean uploaded = false ;
			String cibBranchID = ctx.absGet(Sysmod.class).getPty().getCid().substring(0,2);
			String cibOrgID = ctx.absGet(Sysmod.class).getPty().getCid().substring(2);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			uploaded=this.uploadImage(this.getImg().getOwnref(),this.getImg().getImgref(),cibBranchID,cibOrgID);
			log.debug("{}","in uploadImageToCMS ... " + uploaded );
			return uploaded;
		}
        /**
        *   source:imgmod.@0024.script
        */
        public boolean viewImage(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 查阅影像
			log.debug("{}"," in imgviw....trninr="+ trninr);
			MdaUtils.clear(this.getImg());
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			String ownref= this.getImg().getOwnref();
			String imgref = this.getImg().getImgref();
			String objtyp = this.getImg().getObjtyp();
			if(MdaUtils.isEmpty(this.getImg().getImgref()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000123"),MdaUtils.getI18NString("imgmod","CT000124"));
			  return false ;
			}
			boolean result= this.callImageComponent("ImageScan",ownref,imgref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			return result ;
		}
        /**
        *   source:imgmod.@0025.script
        */
        public boolean uploadImages(String ownref,String imgRef,String docid,String cibBranchID,String cibOrgID)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImage ... ");
			List <Integer>  list = new  ArrayList<Integer>();
			boolean isRight = false;
			String sql = "select inr,djcod from tblbil where buscod = '"+ownref+"' and djcod = '"+imgRef+"' and itmcod = 'KZSQS' and tratyp is null  order by inr asc";
			Argument<Integer> inr = new Argument<Integer>("inr");
			Argument<String> imgref = new Argument<String>("djcod");
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt = 0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,imgref);
			  if( ctx.getErrorCode() == NO_ERROR)
			  {
			    list.add(inr.value);
			    cnt = cnt +1;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			log.info("{}","cnt为+++" + cnt);
			if( cnt!=0)
			{
			  log.debug("{}","本批次"+imgRef+"开始上传： "+cnt+"张影像！");
			  String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			  String netId = MdaUtils.getPropertyValue(fileName,"netId");
			  String appId = MdaUtils.getPropertyValue(fileName,"appId");
			  String guid = docid;
			  String cls="com.brilliance.eibs.main.Client";
			  Object resMsg = MdaUtils.invoke(cls,"scall","upload","upload",new Object[]{netId,appId,list,guid});
			  if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为："+isSuc.length());
			    if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			    {
			      log.debug("{}","影像上传成功 ... ");
			      //$this.updateImageByID(imgref.value);
			      //$this.updateImageUplodState(ownref,imgRef);
			      isRight = true;
			    }
			    else
			    {
			      log.debug("{}","影像上传失败 ... ");
			      String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			      log.debug("{}","errorcod=" +errorcod);
			      ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000146"),errorcod);
			      isRight =  false;
			    }
			  }
			  else
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为：" + isSuc.length());
			    String errorcod="调用接口异常！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000147"),errorcod);
			    return false;
			  }
			}
			else
			{
			  isRight = true;
			  log.debug("{}","该笔业务没有影像信息需要提交");
			}
			log.debug("{}","out uploadImage ... ");
			return isRight;
		}
        /**
        *   source:imgmod.@0027.script
        */
        public boolean uploadImageToCMSS(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImageToCMS ... ");
			boolean uploaded = false ;
			String cibBranchID = ctx.absGet(Sysmod.class).getPty().getCid().substring(0,2);
			String cibOrgID = ctx.absGet(Sysmod.class).getPty().getCid().substring(2);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			log.info("{}","img模块中是否获取到数据：    " + !MdaUtils.isEmpty(this.getImg()));
			uploaded=this.uploadImages(this.getImg().getOwnref(),this.getImg().getImgref(),this.getImg().getGuid(),cibBranchID,cibOrgID);
			log.debug("{}","in uploadImageToCMS ... " + uploaded );
			return uploaded;
		}
        /**
        *   source:imgmod.@0028.script
        */
        public String  getWords()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//用当前日期和时间加上A-F组成的一个32位的字符串
			//Date date = new Date();
			String sdf = MdaUtils.format(MdaUtils.today(),"yyMMddHHmmssSSS");
			log.debug("{}","sdf:" + sdf);
			StringBuffer sb = new StringBuffer();
			sb.append(sdf);
			Random random = new Random();
			for(int i = 0;i < 17; i++){
			  switch (random.nextInt(5))
			{
			  case 0:
			  sb.append("A");
			  break;
			  case 1:
			  sb.append("B");
			  break;
			  case 2:
			  sb.append("C");
			  break;
			  case 3:
			  sb.append("D");
			  break;
			  case 4:
			  sb.append("E");
			  break;
			  case 5:
			  sb.append("F");
			  break;
			}
			}
			log.debug("{}","word:" + sb.toString());
			return sb.toString();
		}
        /**
        *   source:imgmod.@0029.script
        */
        public String getDocID()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//获取影像批次编号
			String sb = getWords();
			StringBuffer ssb = new StringBuffer();
			Random random = new Random();
			//从这个32位的字符串中随机获取一位拼成新的字符串，直到32位
			for (int j = 0; j < 32; j++)
			{
			  ssb.append(sb.charAt(random.nextInt(32)));
			}
			log.debug("{}","docID-->" + ssb.toString());
			return ssb.toString();
		}
        /**
        *   source:imgmod.@0030.script
        */
        public String getImageReferences()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * IMG记录产生以后，在保存或更新前获取当前业务的影像批次号
			  */
			//用于获取imageID放在变量imgref中
			String imageID = "";
			if(MdaUtils.isEmpty(this.getImgref()))
			{
			  log.debug("{}","当前业务未生成新的影像信息");
			  return null;
			}
			if( imageUploaded(this.getImgref(),this.getOwnref()))
			{
			  imageID= this.getImgref();
			}
			return imageID;
		}
        /**
        *   source:imgmod.@0031.script
        */
        public boolean imgScans(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//直接调用影像控件
			log.debug("{}","in imgScan ... ");
			log.debug("{}","trninr=" +trninr);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			String ownref = this.getImg().getOwnref();
			String imgref = this.getImg().getImgref();
			String objtyp = this.getImg().getObjtyp();
			Date date = this.getImg().getCredat();
			String nam = this.getImg().getLgnnam();
			if(MdaUtils.isEmpty(this.getImg().getImgref()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000192"),MdaUtils.getI18NString("imgmod","CT000193"));
			  return false;
			}
			log.debug("{}","ownref=" +ownref);
			log.debug("{}","imgref=" +imgref);
			boolean result= this.callImageComponent("ImageScan",ownref,imgref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			return result;
		}
        /**
        *   source:imgmod.@0032.script
        */
        public boolean imgSscan(String imgref)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//用于公告信息维护的影像查询 ，公告信息维护中的影像导入功能没有在img表中插入trninr字段
			log.debug("{}","in imgScan ... ");
			//log.debug("trninr=" +trninr);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("imgref",imgref));
			String ownref = this.getImg().getOwnref();
			String objtyp = this.getImg().getObjtyp();
			Date date = this.getImg().getCredat();
			String nam = this.getImg().getLgnnam();
			if(MdaUtils.isEmpty(this.getImg().getImgref()))
			{
			  ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000206"),MdaUtils.getI18NString("imgmod","CT000207"));
			  return false;
			}
			log.debug("{}","ownref=" +ownref);
			log.debug("{}","imgref=" +imgref);
			//String appId = "1001";
			//String netId = "KJ01";
			String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			String appId = MdaUtils.getPropertyValue(fileName,"appId");
			String netId = MdaUtils.getPropertyValue(fileName,"netId");
			String gdate = MdaUtils.format(date,"yyyyMMdd");
			String guid = this.getImg().getGuid();
			String operId = nam;
			String cls="com.brilliance.eibs.main.Client";
			Object resMsg = MdaUtils.invoke(cls,"scall","dztdownload","dztdownload",new Object[]{appId,netId,guid,gdate,operId});
			if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			{
			  Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			  String isSuc = content.toString();
			  log.debug("{}","isSuc= "+isSuc);
			  if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			  {
			    log.debug("{}","查询影像成功 ... ");
			    //查询影像成功则调用影像控件
			    boolean result= this.callImageComponent("ImageScan",ownref,imgref,ctx.getTransName(),ctx.absGet(Sysmod.class).getUsr().getLgnnam(),objtyp);
			    if(result)
			    {
			      return true;
			    }
			    else
			      return false;
			  }
			  else
			  {
			    log.debug("{}","查询影像失败 ... ");
			    String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000208"),errorcod);
			  }
			}
			return true;
		}
        /**
        *   source:imgmod.@0033.script
        */
        public boolean uploadImagesDyck(String ownref,String imgRef,String docid,String cibBranchID,String cibOrgID)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImage ... ");
			List <Integer>  list = new  ArrayList<Integer>();
			boolean isRight = false;
			String sql = "select inr,djcod from tblbil where buscod = '"+ownref+"' and djcod = '"+imgRef+"' and itmcod = 'KZSQS' and tratyp is null  order by inr asc";
			Argument<Integer> inr = new Argument<Integer>("inr");
			Argument<String> imgref = new Argument<String>("djcod");
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt = 0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,imgref);
			  if( ctx.getErrorCode() == NO_ERROR)
			  {
			    list.add(inr.value);
			    cnt = cnt +1;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			log.info("{}","cnt为+++" + cnt);
			if( cnt!=0)
			{
			  log.debug("{}","本批次"+imgRef+"开始上传： "+cnt+"张影像！");
			  String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/imgdyck.properties");
			  String netId = MdaUtils.getPropertyValue(fileName,"netId");
			  String appId = MdaUtils.getPropertyValue(fileName,"appId");
			  String guid = docid;
			  String cls="com.brilliance.eibs.main.Client";
			  Object resMsg = MdaUtils.invoke(cls,"scall","upload","upload",new Object[]{netId,appId,list,guid});
			  if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为："+isSuc.length());
			    if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			    {
			      log.debug("{}","影像上传成功 ... ");
			      //$this.updateImageByID(imgref.value);
			      //$this.updateImageUplodState(ownref,imgRef);
			      isRight = true;
			    }
			    else
			    {
			      log.debug("{}","影像上传失败 ... ");
			      String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			      log.debug("{}","errorcod=" +errorcod);
			      ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000233"),errorcod);
			      isRight =  false;
			    }
			  }
			  else
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为：" + isSuc.length());
			    String errorcod="调用接口异常！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000234"),errorcod);
			    return false;
			  }
			}
			else
			{
			  isRight = true;
			  log.debug("{}","该笔业务没有影像信息需要提交");
			}
			log.debug("{}","out uploadImage ... ");
			return isRight;
		}
        /**
        *   source:imgmod.@0034.script
        */
        public boolean reuploadImageToCMSS(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台(影像补录)
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImageToCMS ... ");
			boolean uploaded = false ;
			String cibBranchID = ctx.absGet(Sysmod.class).getPty().getCid().substring(0,2);
			String cibOrgID = ctx.absGet(Sysmod.class).getPty().getCid().substring(2);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			log.info("{}","img模块中是否获取到数据：    " + !MdaUtils.isEmpty(this.getImg()));
			uploaded=this.reuploadImages(this.getImg().getOwnref(),this.getImg().getImgref(),this.getImg().getGuid(),cibBranchID,cibOrgID);
			log.debug("{}","in uploadImageToCMS ... " + uploaded );
			return uploaded;
		}
        /**
        *   source:imgmod.@0035.script
        */
        public boolean reuploadImages(String ownref,String imgRef,String docid,String cibBranchID,String cibOrgID)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台(影像补录)
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in reuploadImage ... ");
			List <Integer>  list = new  ArrayList<Integer>();
			boolean isRight = false;
			String sql = "select inr,djcod from tblbil where buscod = '"+ownref+"' and djcod = '"+imgRef+"' and itmcod = 'KZSQS' and tratyp is null  order by inr asc";
			Argument<Integer> inr = new Argument<Integer>("inr");
			Argument<String> imgref = new Argument<String>("djcod");
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt = 0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,imgref);
			  if( ctx.getErrorCode() == NO_ERROR)
			  {
			    list.add(inr.value);
			    cnt = cnt +1;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			log.info("{}","cnt为+++" + cnt);
			if( cnt!=0)
			{
			  log.debug("{}","本批次"+imgRef+"开始补充： "+cnt+"张影像！");
			  String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			  String netId = MdaUtils.getPropertyValue(fileName,"netId");
			  String appId = MdaUtils.getPropertyValue(fileName,"appId");
			  String guid = docid;
			  String cls="com.brilliance.eibs.main.Client";
			  Object resMsg = MdaUtils.invoke(cls,"scall","addimg","addimg",new Object[]{netId,appId,list,guid});
			  if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为："+isSuc.length());
			    if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			    {
			      log.debug("{}","影像补充成功 ... ");
			      //$this.updateImageByID(imgref.value);
			      //$this.updateImageUplodState(ownref,imgRef);
			      isRight = true;
			    }
			    else
			    {
			      log.debug("{}","影像补充失败 ... ");
			      String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			      log.debug("{}","errorcod=" +errorcod);
			      ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000237"),errorcod);
			      isRight =  false;
			    }
			  }
			  else
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为：" + isSuc.length());
			    String errorcod="调用接口异常！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000238"),errorcod);
			    return false;
			  }
			}
			else
			{
			  isRight = true;
			  log.debug("{}","该笔业务没有影像信息需要提交");
			}
			log.debug("{}","out reuploadImage ... ");
			return isRight;
		}
        /**
        *   source:imgmod.@0036.script
        */
        public void pdfdocToImg()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.info("{}","ownref--imgcod = " + this.getOwnref());
		}
        /**
        *   source:imgmod.@0037.script
        */
        public int getTblcntVal(String tblbills,int stp)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//String tblcnt = "";
			ctx.getDaoSession().dbRead(this.getTblcnt(),new Argument("typ",tblbills));
			int val = MdaUtils.parseInt(this.getTblcnt().getVal());
			//int stp = Platform.parseInt($tblcnt\\stp.getValue());
			int vals = val + stp;
			log.info("{}","tblcnt val ：" + this.getTblcnt().getVal() + ", val+ :" + val);
			this.getTblcnt().setVal(""+vals);
			ctx.getDaoSession().dbUpdate(this.getTblcnt());
			return val;
		}
        /**
        *   source:imgmod.@0038.script
        */
        public void insertTblbil(String filnam,String alsnam,String ownref,String imgref,String trncod,String logname,String objtyp,int tblcnt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String date = MdaUtils.format(MdaUtils.today(),"yyyyMMdd");
			String filpth = MdaUtils.catPath(MdaUtils.catPath(MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"img"),date),filnam);
			String[] typ = filnam.split("\\.");
			Long fileSize = MdaUtils.fileSize(filpth);
			String tblcnts = "" + tblcnt;
			alsnam = alsnam + "." + typ[1];
			MdaUtils.clear(this.getTblbil());
			this.getTblbil().setInr(tblcnts);
			this.getTblbil().setReldat(MdaUtils.format(MdaUtils.today(),"yyyy/MM/dd HH:mm:ss"));
			this.getTblbil().setFilnam(filnam);
			this.getTblbil().setAlsnam(alsnam);
			this.getTblbil().setBilflg("0");
			this.getTblbil().setOrdnum("0");//
			this.getTblbil().setDoctyp(typ[1]);
			this.getTblbil().setCurbat("0");
			this.getTblbil().setSavway("F");
			this.getTblbil().setFilpth(filpth);
			this.getTblbil().setFilsiz(fileSize.toString());
			this.getTblbil().setOffset("0");
			this.getTblbil().setEdtfilpth(filpth);
			this.getTblbil().setEdtfilsiz(fileSize.toString());//
			this.getTblbil().setEdtoffset("0");
			this.getTblbil().setVer("E");
			this.getTblbil().setBuscod(ownref);
			this.getTblbil().setTrncod(trncod);
			this.getTblbil().setItmcod("KZSQS");//
			this.getTblbil().setUsr(logname);
			this.getTblbil().setDjcod(imgref);
			ctx.getDaoSession().dbInsert(this.getTblbil());
		}
        /**
        *   source:imgmod.@0039.script
        */
        public boolean uploadHtiImageToCMSS(String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImageToCMS ... ");
			boolean uploaded = false ;
			String cibBranchID = ctx.absGet(Sysmod.class).getPty().getCid().substring(0,2);
			String cibOrgID = ctx.absGet(Sysmod.class).getPty().getCid().substring(2);
			ctx.getDaoSession().dbRead(this.getImg(),new Argument("trninr",trninr));
			log.info("{}","img模块中是否获取到数据：    " + !MdaUtils.isEmpty(this.getImg()));
			uploaded=this.uploadAllImages(this.getImg().getOwnref(),this.getImg().getImgref(),this.getImg().getGuid(),cibBranchID,cibOrgID);
			log.debug("{}","in uploadImageToCMS ... " + uploaded );
			return uploaded;
		}
        /**
        *   source:imgmod.@0040.script
        */
        public boolean uploadAllImages(String ownref,String imgRef,String docid,String cibBranchID,String cibOrgID)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 功能：上传影像信息到影像管理平台
			  * 返回值：false - 上传失败 ； true - 上传成功或无影像上传
			  */
			log.debug("{}","in uploadImage ... ");
			List <Integer>  list = new  ArrayList<Integer>();
			boolean isRight = false;
			String sql = "select inr,djcod from tblbil where buscod = '"+ownref+"' and djcod = '"+imgRef+"' and itmcod = 'KZSQS'  order by inr asc";
			Argument<Integer> inr = new Argument<Integer>("inr");
			Argument<String> imgref = new Argument<String>("djcod");
			ctx.getDaoSession().dbExecuteSQL(sql);
			int cnt = 0;
			while(true)
			{
			  ctx.getDaoSession().dbFetchFields(inr,imgref);
			  if( ctx.getErrorCode() == NO_ERROR)
			  {
			    list.add(inr.value);
			    cnt = cnt +1;
			  }
			  else
			    break;
			}
			ctx.getDaoSession().dbCloseCursor();
			log.info("{}","cnt为+++" + cnt);
			if( cnt!=0)
			{
			  log.debug("{}","本批次"+imgRef+"开始上传： "+cnt+"张影像！");
			  String fileName = MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"/cfg/img.properties");
			  String netId = MdaUtils.getPropertyValue(fileName,"netId");
			  String appId = MdaUtils.getPropertyValue(fileName,"appId");
			  String guid = docid;
			  String cls="com.brilliance.eibs.main.Client";
			  Object resMsg = MdaUtils.invoke(cls,"scall","upload","upload",new Object[]{netId,appId,list,guid});
			  if((Boolean)MdaUtils.invoke(resMsg,"isSuccess"))
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为："+isSuc.length());
			    if("true".equals(isSuc.substring(isSuc.length()-(int)5,isSuc.length()-(int)1).trim()))
			    {
			      log.debug("{}","影像上传成功 ... ");
			      //$this.updateImageByID(imgref.value);
			      //$this.updateImageUplodState(ownref,imgRef);
			      isRight = true;
			    }
			    else
			    {
			      log.debug("{}","影像上传失败 ... ");
			      String errorcod=isSuc.substring(5,isSuc.length()-(int)17).trim();
			      log.debug("{}","errorcod=" +errorcod);
			      ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000243"),errorcod);
			      isRight =  false;
			    }
			  }
			  else
			  {
			    Object content = (Object)MdaUtils.invoke(resMsg,"getContent") ;
			    String isSuc = content.toString();
			    log.debug("{}","isSuc= "+isSuc);
			    log.debug("{}","isSuc的长度为：" + isSuc.length());
			    String errorcod="调用接口异常！";
			    log.debug("{}","errorcod=" +errorcod);
			    ctx.setMessage(MdaUtils.getI18NString("imgmod","CT000244"),errorcod);
			    return false;
			  }
			}
			else
			{
			  isRight = true;
			  log.debug("{}","该笔业务没有影像信息需要提交");
			}
			log.debug("{}","out uploadImage ... ");
			return isRight;
		}













}