package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Trn;
import com.ceb.gjjs.mda.bo.Smh;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Spt;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Kjsbod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Kjsbod.class);

        //返回信息
        private Map response;

        //行内关联编号
        private String hnglbh;

        //代理行账户代号
        private String dlhzhdh;

        //落地交易代码
        private String frmcod;

        //业务数据流
        private IStream grpdata = new StreamImpl();



		@Module(getter = false, setter = false)
        private transient ModuleHolder<Busgrp> busgrp;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Ptyset> ptyset;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Trn> trn;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Smh> smh;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Spt> spt;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Trn> apltrn;


		public Kjsbod()
        {
            super();
            setArgument();
        }

        public Kjsbod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }




        /**
        *   source:kjsbod.@0000.script
        */
        public void parseMessage(String msgTyp, Map<String,Object> data, Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.invoke(this,"parseCPSS"+msgTyp,data,resMsg) ;
		}
        /**
        *   source:kjsbod.@0002.script
        */
        public void setPartiesByAct(String argAct)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}"," in kjsbod.setPartyByAct...  代理行账号：" + argAct +"。"  );
			if(MdaUtils.isEmpty(argAct))
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到对应的代理行账号信息。");
			  return ;
			}
			if(this.getPtyset().setAccByAgentAccount(argAct))
			{
			  log.debug("{}","我行机构 bnkptyinr = " + this.getPtyset().getBnkptyinr());
			  this.getPtyset().setBnkByPtyinr(this.getPtyset().getBnkptyinr());
			  log.debug("{}","代理商行 cliptyinr =" + this.getPtyset().getCliptyinr());
			  this.getPtyset().setCliByPtyinr( this.getPtyset().getCliptyinr());
			}
			else
			{
			  log.warn("{}","交易将落地到总行 08101 机构，代理商行需要在银行端分配 。");
			  this.getPtyset().setBnkByBchcod("08101");
			}
		}
        /**
        *   source:kjsbod.@0003.script
        */
        public void  parseCPSS0401 (Map<String,Object> data,Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 解析 0401-XML报文信息
			  */
			log.debug("{}"," in kjsbod.parseCPSS0401 .... ") ;
			String hnglbh =(String)data.get("VROOT.MsgBody.HNGLBH");  // 行内关联编号
			String clientAct =(String)data.get("CROOT.MsgBody.DLHZHDH"); // 代理行账号
			String jyckh =(String)data.get("VROOT.MsgBody.JYCKH");       // 交易参考号
			String xmlfile =(String)data.get("XMLFIL");
			log.debug("{}"," 行内关联编号："+ hnglbh + ",代理行账号：" + clientAct  );
			// 1.设置公共参数
			this.setFrmcod( "rptshw");

			if(MdaUtils.isEmpty(clientAct) )
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到代理行账号信息");
			  resMsg.putAll(this.getResponse());
			  return ;
			}
			else
			{
			  setPartiesByAct(clientAct);
			}
			// 2.按照公共函数进行数据映射
			MdaUtils.clear(this.getBusgrp().getRpdgrp());

			setModuleContent(data,this.getFrmcod());
			// 3. 当前交易下 GRP字段赋值
			this.getBusgrp().getRpdgrp().getRec().setRpttyp("I" );
			if(!MdaUtils.isEmpty(this.getPtyset().getCliptyinr()))
			{
			  this.getBusgrp().getRpdgrp().getRec().setPtyinr( this.getPtyset().getCliptyinr());
			}
			if(!MdaUtils.isEmpty(this.getPtyset().getCli().getEtyinr()))
			{
			  this.getBusgrp().getRpdgrp().getRec().setEtyinr(this.getPtyset().getCli().getEtyinr());
			}
			this.getBusgrp().getRpdgrp().getRec().setBchcod( this.getPtyset().getBnk().getCid());
			this.getBusgrp().getRpdgrp().getRec().setCredat( MdaUtils.today());
			this.getBusgrp().getRpdgrp().getRec().setOwnref( Platform.getRef("LP") );
			this.getBusgrp().getRpdgrp().getRec().setInr(Platform.sdbCounter("rpd"));
			ctx.absGet(Sysmod.class).sdbInsert(this.getBusgrp().getRpdgrp().getRec()) ;
			log.debug("{}"," insert into RPD {INR = " + this.getBusgrp().getRpdgrp().getRec().getInr() +", ownref = " + this.getBusgrp().getRpdgrp().getRec().getOwnref() + " } ") ;
			Map<String,Object> busmap = getBusFactorsMap(this.getBusgrp().getRpdgrp().getRec().getInr(),"rpd", this.getBusgrp().getRpdgrp().getRec().getOwnref(),
			  jyckh,this.getBusgrp().getRpdgrp().getRec().getRptamt(),this.getBusgrp().getRpdgrp().getRec().getRptcur());
			setTransactionInfo(busmap);
			this.getBusgrp().getBusinf().setInifrm(this.getFrmcod());
			log.debug("{}","0401交易名：" +this.getBusgrp().getBusinf().getInifrm());
			// 4.存储TRN报文
			setTrnFromKjsbod("A");
			//  5.存储 ERS
			// 备注：来报业务需要处理一下对账中发起的来账文件重新下载的报文信息, MAD.hnglbh - 日期  ERS.outdat = MAD.outdat   更新  mad.sigchk= C
			Date outdat = updateMadByHnglbh( hnglbh);
			setErsFromKjsmod("0401",jyckh, outdat);
			// 6.存储界面文件 TODO saveDisplay 无法生成文件，逻辑暂时屏蔽
			// saveDisplayFromkjsbod($trn\\inr.getValue(), "rptp\\\\xxxx");
			// 7.存储 SMH
			setSmhFromKjsbod("0401", xmlfile);
			// 8.存储 SPT
			setSptFromKjsbod(this.getBusgrp().getRpdgrp(),this.getFrmcod());
			// 9.增加工作流
			addNoticeWorkflow(this.getSpt(),this.getFrmcod());

			log.debug("{}"," out kjsbod.parseCPSS0401 .... ") ;
			resMsg.putAll(this.getResponse());
		}
        /**
        *   source:kjsbod.@0004.script
        */
        public String getResonseMsgCode()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String msgCode =(String) this.getResponse().get("ERRORCODE");
			if(MdaUtils.isEmpty(msgCode))
			{
			  msgCode =  "00000";
			}
			return msgCode;
		}
        /**
        *   source:kjsbod.@0005.script
        */
        public void setModuleContent(Map<String,Object> data, String frmcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 将data中的值按照配置映射到对应的模块字段中
			  */
			log.debug("{}","in kjsbod.setModuleContent  ... ") ;
			Map<String,String>  tagdata =  Platform.loadPropertyPart(frmcod,"DATA");

			// 根据映射文件将 data的值映射,设置模型的字段值
			for(String key:data.keySet())
			{
			  if ( tagdata != null && tagdata.containsKey(key) )
			  {

			    IDatafield datafield = MdaDriver.getDatafield(this.getBusgrp(),tagdata.get(key));
			    log.debug("{}","fldpath:" + tagdata.get(key));
			    log.debug("{}","fldValue:"+ data.get(key));

			    if(ctx.getErrorCode()== NO_ERROR)
			    {
			      datafield.setValue(data.get(key));
			    }
			  }
			}
			log.debug("{}","out kjsbod.setModuleContent  ... ") ;
		}
        /**
        *   source:kjsbod.@0009.script
        */
        public void setTransactionInfo(Map<String,Object> basdata)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in kjsbod setTransactionInfo... ");
			MdaUtils.clear(this.getBusgrp().getBusinf());
			this.getBusgrp().getBusinf().setObjtyp((String)basdata.get("objtyp"));
			this.getBusgrp().getBusinf().setObjinr((String)basdata.get("objinr"));
			this.getBusgrp().getBusinf().setOwnref((String) basdata.get("ownref"));
			this.getBusgrp().getBusinf().setRef((String)basdata.get("ref"));
			this.getBusgrp().getBusinf().setCur((String)basdata.get("cur"));
			this.getBusgrp().getBusinf().setAmt((BigDecimal)basdata.get("amt"));
			if(!MdaUtils.isEmpty(basdata.get("credat")))
			{
			  this.getBusgrp().getBusinf().setCredat((Date)basdata.get("credat"));
			}
			else
			{
			  this.getBusgrp().getBusinf().setCredat(MdaUtils.today());
			}
			this.getBusgrp().getBusinf().setBnkinr( this.getPtyset().getBnk().getInr());
			this.getBusgrp().getBusinf().setBnknam( this.getPtyset().getBnk().getNam());
			this.getBusgrp().getBusinf().setBchcod( this.getPtyset().getBnk().getCid());
			this.getBusgrp().getBusinf().setBnketyinr( this.getPtyset().getBnk().getEtyinr());
			this.getBusgrp().getBusinf().setBnketginr(  this.getPtyset().getPtyEtginr(this.getBusgrp().getBusinf().getBnketyinr()));
			this.getBusgrp().getBusinf().setCliinr( this.getPtyset().getCli().getInr());
			this.getBusgrp().getBusinf().setClinam( this.getPtyset().getCli().getNam());
			this.getBusgrp().getBusinf().setClietyinr( this.getPtyset().getCli().getEtyinr());
			this.getBusgrp().getBusinf().setClietginr(  this.getPtyset().getPtyEtginr(this.getBusgrp().getBusinf().getClietyinr()));
			this.getBusgrp().getBusinf().setCl2inr( this.getPtyset().getBnk2cl().getInr());
			this.getBusgrp().getBusinf().setCl2nam( this.getPtyset().getBnk2cl().getNam());

		}
        /**
        *   source:kjsbod.@0010.script
        */
        public Map<String,Object> getBusFactorsMap(String objinr, String objtyp,String ownref,String ref, BigDecimal amt, String cur)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 返回业务要素的基本信息
			  */
			log.debug("{}","in kjsbod getBusFactorsMap... ");
			Map<String,Object> factors = new HashMap<String,Object>();
			factors.put("objinr",objinr);
			factors.put("objtyp",objtyp) ;
			factors.put("ownref",ownref);
			factors.put("ref", ref);
			factors.put("amt",amt);
			factors.put("cur",cur);
			return factors;
		}
        /**
        *   source:kjsbod.@0011.script
        */
        public void setTrnFromKjsbod(String relsta)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 设置并存储TRN
			  */
			log.debug("{}","in kjsbod.setTrnFromKjsbod ... ");
			MdaUtils.clear(this.getTrn());
			this.getTrn().setEtginr(this.getBusgrp().getBusinf().getClietyinr());
			this.getTrn().setObjtyp(this.getBusgrp().getBusinf().getObjtyp());
			this.getTrn().setObjinr(this.getBusgrp().getBusinf().getObjinr());
			this.getTrn().setOwnref(this.getBusgrp().getBusinf().getOwnref());
			this.getTrn().setBchcod(this.getBusgrp().getBusinf().getBchcod());
			this.getTrn().setReloricur(this.getBusgrp().getBusinf().getCur());
			this.getTrn().setReloriamt(this.getBusgrp().getBusinf().getAmt());
			this.getTrn().setRelcur("USD");
			if(MdaUtils.isEmpty(this.getBusgrp().getBusinf().getClinam()))
			{
			  this.getTrn().setNam(this.getTrn().getReloricur()+"/" +this.getTrn().getReloriamt());
			}
			else
			{
			  this.getTrn().setNam(this.getTrn().getReloricur()+"/"+this.getTrn().getReloriamt()+this.getBusgrp().getBusinf().getClinam());
			}
			this.getTrn().setInifrm(this.getBusgrp().getBusinf().getInifrm());
			this.getTrn().setInidattim(MdaUtils.today());
			this.getTrn().setCpldattim(MdaUtils.today());
			this.getTrn().setCfmdattim(MdaUtils.today());
			if(ctx.absGet(Trnmod.class).setReleaseAmout())
			{
			  this.getTrn().setSta(relsta);
			  this.getTrn().setPtyinr(this.getBusgrp().getBusinf().getCliinr());
			  this.getTrn().setEtyinr(this.getBusgrp().getBusinf().getClietyinr());
			  this.getTrn().setEtginr(this.getBusgrp().getBusinf().getClietginr());
			  this.getTrn().setOptptyinr(this.getBusgrp().getBusinf().getCliinr());
			  this.getTrn().setOptetyinr(this.getBusgrp().getBusinf().getClietyinr());
			  this.getTrn().setOptetginr(this.getBusgrp().getBusinf().getClietginr());
			  this.getTrn().setInr(Platform.sdbCounter("trn"));
			  ctx.absGet(Sysmod.class).sdbInsert(this.getTrn());
			  log.debug("{}"," SAVE TRN { INR:"+this.getTrn().getInr()+",OWNREF:"+this.getTrn().getOwnref()+"}");
			}
		}
        /**
        *   source:kjsbod.@0012.script
        */
        public void setErsFromKjsmod(String msgtyp, String ref, Date outdat )
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 保存ERS表：此逻辑按照收报交易进行处理
			  */
			log.debug("{}","in setErsFromKjsmod ...  ");

			this.getBusgrp().getErsgrp().getRec().setDeldat( MdaUtils.today());
			this.getBusgrp().getErsgrp().getRec().setOutdat(outdat);
			this.getBusgrp().getErsgrp().getRec().setMsgref( ref );
			this.getBusgrp().getErsgrp().getRec().setBchcod(this.getBusgrp().getBusinf().getBchcod());
			this.getBusgrp().getErsgrp().getRec().setCredat(this.getBusgrp().getBusinf().getCredat());
			this.getBusgrp().getErsgrp().getRec().setOwnref(this.getBusgrp().getBusinf().getOwnref());
			this.getBusgrp().getErsgrp().getRec().setObjtyp(this.getBusgrp().getBusinf().getObjtyp());
			this.getBusgrp().getErsgrp().getRec().setObjinr(this.getBusgrp().getBusinf().getObjinr());
			this.getBusgrp().getErsgrp().getRec().setMsgtyp(msgtyp);
			this.getBusgrp().getErsgrp().getRec().setCur(this.getBusgrp().getBusinf().getCur());
			this.getBusgrp().getErsgrp().getRec().setAmt(this.getBusgrp().getBusinf().getAmt());
			this.getBusgrp().getErsgrp().getRec().setHnglbh(ref);
			this.getBusgrp().getErsgrp().getRec().setRecsta("A");
			this.getBusgrp().getErsgrp().getRec().setInftxt(this.getBusgrp().getRpdgrp().getRec().getBeizhu());
			this.getBusgrp().getErsgrp().getRec().setMsgatt(this.getBusgrp().getRpdgrp().getRec().getMsgatr());
			this.getBusgrp().getErsgrp().getRec().setTrninr(this.getTrn().getInr());
			this.getBusgrp().getErsgrp().getRec().setDir("<");
			this.getBusgrp().getErsgrp().getRec().setPtyinr(this.getBusgrp().getBusinf().getCliinr());
			this.getBusgrp().getErsgrp().getRec().setAgtact(this.getBusgrp().getRpdgrp().getRec().getAgtact());
			this.getBusgrp().getErsgrp().getRec().setAgtextkey(this.getBusgrp().getRpdgrp().getRec().getAgtextkey());
			this.getBusgrp().getErsgrp().getRec().setEtyinr(this.getPtyset().getCli().getEtyinr());
			this.getBusgrp().getErsgrp().getRec().setInr(Platform.sdbCounter("ers"));
			ctx.getDaoSession().dbInsert(this.getBusgrp().getErsgrp().getRec());
			log.info("{}","out setErsFromKjsmod");
		}
        /**
        *   source:kjsbod.@0014.script
        */
        public Date updateMadByHnglbh(String ref)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

			Date outdat = MdaUtils.today();
			MdaUtils.clear(this.getBusgrp().getMadgrp().getRec());
			ctx.getDaoSession().dbRead(this.getBusgrp().getMadgrp().getRec(),new Argument("hnglbh",ref));
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  // 此表业务为对账后发起的下载业务
			  log.debug("{}"," 对账后收到原业务报文 hnglbh = " + ref ) ;
			  outdat = this.getBusgrp().getMadgrp().getRec().getOutdat();
			  BigDecimal amt = this.getBusgrp().getRpdgrp().getRec().getRptamt();
			  BigDecimal madamt= this.getBusgrp().getMadgrp().getRec().getRptamt();
			  String cur = this.getBusgrp().getRpdgrp().getRec().getRptcur();
			  String madcur = this.getBusgrp().getMadgrp().getRec().getRptcur();
			  if(!MdaUtils.isEmpty(amt) && !MdaUtils.isEmpty(cur))
			  {
			    if( amt.compareTo(madamt) == 0 && cur.equals(madcur))
			    {
			      this.getBusgrp().getMadgrp().getRec().setOwnref( this.getBusgrp().getRpdgrp().getRec().getOwnref());
			      this.getBusgrp().getMadgrp().getRec().setSigchk( "C" );
			      this.getBusgrp().getMadgrp().getRec().setHadsta( "1" );
			    }
			    else
			    {
			      this.getBusgrp().getMadgrp().getRec().setOwnref( this.getBusgrp().getRpdgrp().getRec().getOwnref());
			      this.getBusgrp().getMadgrp().getRec().setSigchk( "Y" );
			      this.getBusgrp().getMadgrp().getRec().setHadsta( "0" );
			    }
			    ctx.getDaoSession().dbUpdate(this.getBusgrp().getMadgrp().getRec());
			  }
			  else
			  {
			    log.error("{}"," 找到对账信息，但是原业务报文中金额或币种为空  ");
			  }
			}
			return outdat;
		}
        /**
        *   source:kjsbod.@0015.script
        */
        public void  parseCPSS0402 (Map<String,Object> data,Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 解析 0402-XML报文信息
			  @ 返回解析是否成功
			  */
			log.debug("{}"," in kjsbod.parseCPSS0402 .... ") ;
			// 1.设置公共参数
			String clibic =(String)data.get("VROOT.MsgBody.DLHDM");  // 代理行行号
			String clientAct =(String)data.get("CROOT.MsgBody.DLHZHDH"); // 代理行账号
			String yhnglbh =(String)data.get("VROOT.MsgBody.YHNGLBH"); // 原行内关联编号
			String xmlfile =(String)data.get("XMLFIL");
			this.setFrmcod("ersshw");

			log.debug("{}"," clibic ="+ clibic + ",cliacc=" + clientAct +",yhnglbh=" +yhnglbh );
			if(MdaUtils.isEmpty(clientAct) )
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到代理行账号信息");
			  resMsg.putAll(this.getResponse());
			  return ;
			}
			else
			{
			  setPartiesByAct(clientAct);
			  if(MdaUtils.isEmpty(this.getPtyset().getCli().getInr()))
			  {
			    Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到代理行账号信息");
			    resMsg.putAll(this.getResponse());
			    return ;
			  }
			}
			// 2.按照公共函数进行数据映射
			MdaUtils.clear(this.getBusgrp().getErsgrp().getRec());
			setModuleContent(data,"ersshw");

			// 3. 当前交易下 ERS表字段赋值
			if(!MdaUtils.isEmpty(yhnglbh) && loadErsbyHnglbh(yhnglbh))
			{
			  log.debug("{}","匹配原报文成功，olders.hnglbh:" +yhnglbh +",olders.inr=" + this.getBusgrp().getOldersgrp().getRec().getInr() +"... ") ;
			  this.getBusgrp().getErsgrp().getRec().setAgtextkey(this.getBusgrp().getOldersgrp().getRec().getAgtextkey());
			  this.getBusgrp().getErsgrp().getRec().setBusref(this.getBusgrp().getOldersgrp().getRec().getOwnref());
			  this.getBusgrp().getErsgrp().getRec().setObjtyp( "ers");
			  this.getBusgrp().getErsgrp().getRec().setObjinr( this.getBusgrp().getOldersgrp().getRec().getInr());
			  this.getBusgrp().getErsgrp().getRec().setPtyinr( this.getBusgrp().getOldersgrp().getRec().getPtyinr());
			  this.getBusgrp().getErsgrp().getRec().setEtyinr( this.getBusgrp().getOldersgrp().getRec().getEtyinr());
			  this.getBusgrp().getErsgrp().getRec().setBchcod( this.getBusgrp().getOldersgrp().getRec().getBchcod());
			}
			this.getBusgrp().getErsgrp().getRec().setCredat( MdaUtils.today());
			this.getBusgrp().getErsgrp().getRec().setOutdat( MdaUtils.today());
			this.getBusgrp().getErsgrp().getRec().setDeldat( MdaUtils.today());
			this.getBusgrp().getErsgrp().getRec().setBchcod(this.getPtyset().getBnk().getCid());
			this.getBusgrp().getErsgrp().getRec().setObjtyp("ers");
			this.getBusgrp().getErsgrp().getRec().setMsgtyp("0402");
			this.getBusgrp().getErsgrp().getRec().setDir( "<");
			this.getBusgrp().getErsgrp().getRec().setRecsta( "A");
			this.getBusgrp().getErsgrp().getRec().setOwnref(Platform.getRef("EQ"));
			this.getBusgrp().getErsgrp().getRec().setInr(Platform.sdbCounter("ers"));
			ctx.getDaoSession().dbInsert(this.getBusgrp().getErsgrp().getRec());
			log.debug("{}"," insert into ERS {INR = " + this.getBusgrp().getErsgrp().getRec().getInr() +", ownref = " + this.getBusgrp().getErsgrp().getRec().getOwnref() + " } ") ;
			// 5. 交易基础信息初始化
			Map<String,Object> busmap = getBusFactorsMap(this.getBusgrp().getErsgrp().getRec().getInr(),"ers", this.getBusgrp().getErsgrp().getRec().getOwnref(),
			  this.getBusgrp().getErsgrp().getRec().getRelref(),this.getBusgrp().getErsgrp().getRec().getAmt(),this.getBusgrp().getErsgrp().getRec().getCur());
			setTransactionInfo(busmap);
			this.getBusgrp().getBusinf().setInifrm(this.getFrmcod());
			log.debug("{}","0402交易名：" +this.getBusgrp().getBusinf().getInifrm());
			// 6.存储TRN报文
			setTrnFromKjsbod("A");

			// 6.存储界面文件 -TODO平台无法存储界面文件
			/**
			  String filename = $\\sysmod.createFilename($trn\\inr.getValue(),"zul");
			  log.info("filename is "+filename);
			  Platform.saveDisplay($ersp\\ersshw,filename);
			  **/

			// 7.存储 SMH
			setSmhFromKjsbod("0402", xmlfile);
			// 8.存储 SPT
			setSptFromKjsbod(this.getBusgrp().getErsgrp(),this.getFrmcod());
			// 9.增加工作流
			addNoticeWorkflow(this.getSpt(),this.getFrmcod());

			resMsg.putAll(this.getResponse());
			log.debug("{}"," out kjsbod.parseCPSS0402 .... ") ;

		}
        /**
        *   source:kjsbod.@0016.script
        */
        public boolean loadErsbyHnglbh(String ref)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			boolean ret = false;
			MdaUtils.clear(this.getBusgrp().getOldersgrp().getRec());
			ctx.getDaoSession().dbRead(this.getBusgrp().getOldersgrp().getRec(),new Argument<String>("hnglbh",EQ,ref));
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  ret = true;
			}
			return ret;
		}
        /**
        *   source:kjsbod.@0017.script
        */
        public void parseCPSS0403 (Map<String,Object> data,Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 解析 0403-XML报文信息-回执
			  @ 返回解析是否成功
			  */
			log.debug("{}"," in kjsbod.parseCPSS0403 .... ") ;

			// 1.设置公共参数
			String yhnglbh= (String)data.get("VROOT.MsgBody.YHNGLBH"); // 原行内关联编号
			String hzzt = (String)data.get("CROOT.MsgBody.HZZT"); // 回执状态
			String xmlfile =(String)data.get("XMLFIL");
			this.setFrmcod("rptdav");
			log.debug("{}","yhnglbh=" +yhnglbh +",hzzt=" + hzzt +"." );
			if(MdaUtils.isEmpty(yhnglbh))
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到原行内关联编号");
			  resMsg.putAll(this.getResponse());
			  return ;
			}

			if(!loadErsbyHnglbh(yhnglbh))
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","原行内关联编号:"+yhnglbh +"无法关联原始业务");
			  resMsg.putAll(this.getResponse());
			  return ;
			}
			// 2.按照公共函数进行数据映射
			setModuleContent(data,"rptdav");
			this.getBusgrp().getOldersgrp().getRec().setRecsta(convertErsHZZT(hzzt));
			this.getBusgrp().getOldersgrp().getRec().setDeldat(MdaUtils.today());
			ctx.absGet(Sysmod.class).sdbUpdate(this.getBusgrp().getOldersgrp().getRec()) ;
			log.debug("{}"," update  Ers { INR = " + this.getBusgrp().getOldersgrp().getRec().getInr() +",recsta : "+this.getBusgrp().getOldersgrp().getRec().getRecsta() + " } . ") ;

			// 3. 交易基础信息初始化
			Map<String,Object> busmap = getBusFactorsMap(this.getBusgrp().getOldersgrp().getRec().getInr(),"ers", this.getBusgrp().getOldersgrp().getRec().getOwnref(),
			  this.getBusgrp().getOldersgrp().getRec().getRelref(),this.getBusgrp().getOldersgrp().getRec().getAmt(),this.getBusgrp().getOldersgrp().getRec().getCur());
			setTransactionInfo(busmap);

			// 4.此笔业务为隔日收到往账业务回执报文
			MdaUtils.clear(this.getBusgrp().getMadgrp().getRec());
			ctx.getDaoSession().dbRead(this.getBusgrp().getMadgrp().getRec(),new Argument("hnglbh",yhnglbh));
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  log.debug("{}"," 隔日收到原业务报文回执 yhnglbh = " + yhnglbh ) ;
			  this.getBusgrp().getMadgrp().getRec().setSigchk( "C" );
			  this.getBusgrp().getMadgrp().getRec().setHadsta( "1" );
			  this.getBusgrp().getMadgrp().getRec().setRecsta(  this.getBusgrp().getOldersgrp().getRec().getRecsta());
			  ctx.getDaoSession().dbUpdate(this.getBusgrp().getMadgrp().getRec());
			  log.debug("{}","隔日回执 update MAD{ INR ="+this.getBusgrp().getMadgrp().getRec().getInr()+ ",hnglbh=" +yhnglbh + ", hadsta = 1 , recsta ="+this.getBusgrp().getMadgrp().getRec().getRecsta() + "}");
			}
			// 5.存储 SMH
			setSmhFromKjsbod("0403", xmlfile);
			// 6.存储 SPT
			setSptFromKjsbod(this.getBusgrp().getRpdgrp().getRec(),this.getFrmcod());
			// 7.增加短信通知工作流
			addNoticeWorkflow(this.getSpt(),this.getFrmcod());
			// 8.更新申请交易状态
			this.updateAplTrnFromKjsbod(this.getBusgrp().getOldersgrp().getRec(),new String[]{"rptopn"});

			resMsg.putAll(this.getResponse());
			log.debug("{}"," out kjsbod.parseCPSS0403 .... ") ;
		}
        /**
        *   source:kjsbod.@0018.script
        */
        public String convertErsHZZT(String state)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 对回执报文状态码表进行转换
			  */
			String sta ="";
			if("10".equals(state))
			{
			  sta ="A";
			}
			else
			  if("11".equals(state))
			{
			  sta ="N";
			}
			else
			  if("99".equals(state))
			{
			  sta ="F";
			}
			return sta ;
		}
        /**
        *   source:kjsbod.@0019.script
        */
        public void parseCPSS0404 (Map<String,Object> data,Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 解析 0404-XML报文信息-回执
			  @ 返回解析是否成功
			  */
			log.debug("{}"," in kjsbod.parseCPSS0404 .... ") ;
			// 1.设置公共参数
			this.setFrmcod( "ersdav" );
			String yhnglbh= (String)data.get("VROOT.MsgBody.YHNGLBH"); // 原行内关联编号
			String hzzt = (String)data.get("CROOT.MsgBody.HZZT"); // 回执状态
			String xmlfile =(String)data.get("XMLFIL");
			log.debug("{}","yhnglbh=" +yhnglbh +",hzzt=" + hzzt +"." );
			if(MdaUtils.isEmpty(yhnglbh))
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","报文中未获取到原行内关联编号");
			  resMsg.putAll(this.getResponse());
			  return ;
			}
			if(!loadErsbyHnglbh(yhnglbh))
			{
			  Platform.setErrorInfo(this.getResponse(),"11003","原行内关联编号:"+yhnglbh +"无法关联原始业务");
			  resMsg.putAll(this.getResponse());
			  return ;
			}

			log.debug("{}"," ers: { inr = " + this.getBusgrp().getOldersgrp().getRec().getInr() +" } ") ;

			// 2.按照公共函数进行数据映射
			setModuleContent(data,"ersdav");
			this.getBusgrp().getOldersgrp().getRec().setRecsta(convertErsHZZT(hzzt));
			this.getBusgrp().getOldersgrp().getRec().setDeldat(MdaUtils.today());
			ctx.absGet(Sysmod.class).sdbUpdate(this.getBusgrp().getOldersgrp().getRec()) ;
			log.debug("{}"," update  Ers { INR = " + this.getBusgrp().getOldersgrp().getRec().getInr() +",recsta : "+this.getBusgrp().getOldersgrp().getRec().getRecsta() + " } . ") ;

			// 5. 交易基础信息初始化
			Map<String,Object> busmap = getBusFactorsMap(this.getBusgrp().getOldersgrp().getRec().getInr(),"ers", this.getBusgrp().getOldersgrp().getRec().getOwnref(),
			  this.getBusgrp().getOldersgrp().getRec().getRelref(),this.getBusgrp().getOldersgrp().getRec().getAmt(),this.getBusgrp().getOldersgrp().getRec().getCur());
			setTransactionInfo(busmap);
			// 6.存储 SMH
			setSmhFromKjsbod("0404", xmlfile);
			// 7.存储 SPT
			setSptFromKjsbod(this.getBusgrp().getRpdgrp().getRec(),this.getFrmcod());
			// 8.增加短信通知工作流
			addNoticeWorkflow(this.getSpt(),this.getFrmcod());
			// 9.更新申请交易状态
			this.updateAplTrnFromKjsbod(this.getBusgrp().getOldersgrp().getRec(),new String[]{"ersfre"});

			resMsg.putAll(this.getResponse());
			log.debug("{}"," out kjsbod.parseCPSS0404 .... ") ;
		}
        /**
        *   source:kjsbod.@0020.script
        */
        public void setSmhFromKjsbod(String msgtyp,String xmlfil)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 存储SMH记录
			  */
			log.debug("{}","in kjsbod.setSmhFromKjsbod..." );
			log.debug("{}"," objtyp= " + this.getBusgrp().getBusinf().getObjtyp() +",objinr =" +  this.getBusgrp().getBusinf().getObjinr());
			this.getSmh().setObjtyp(this.getBusgrp().getBusinf().getObjtyp());
			this.getSmh().setObjinr(this.getBusgrp().getBusinf().getObjinr());
			this.getSmh().setXmlfil(xmlfil);
			if(!MdaUtils.isEmpty(msgtyp))
			{
			  this.getSmh().setMsgtyp(msgtyp.substring(1));
			}
			this.getSmh().setMsgsta("1");
			// $RootPath/data/xmlin/arc/yyyymmdd
			String docpath=MdaUtils.catPath(MdaUtils.catPath(ctx.getEnvConfig().getRootPath(),"data/xmlin/arc"),MdaUtils.format(MdaUtils.today(),"yyyyMMdd"));
			this.getSmh().setDocpth(docpath);
			this.getSmh().setDir("I");
			this.getSmh().setCreusr("");
			this.getSmh().setCredattim(MdaUtils.today());
			this.getSmh().setInr(Platform.sdbCounter("smh"));
			ctx.getDaoSession().dbInsert(this.getSmh());
			log.debug("{}","save SMH {inr:" + this.getSmh().getInr()+",objinr:"+ this.getSmh().getObjinr()+",objtyp:"+this.getSmh().getObjtyp()+"}");
			log.debug("{}","out  kjsbod.setSmhFromKjsbod...");
		}
        /**
        *   source:kjsbod.@0021.script
        */
        public void saveDisplayFromkjsbod(String filname,String panPath)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * TODO 在收报交易里存储界面文件
			  */
			filname =  ctx.absGet(Sysmod.class).createFilename(filname,"zul");
			IPanel pan = (IPanel) MdaDriver.getBaseObject(this,panPath);
			if(ctx.getErrorCode() == NO_ERROR)
			{
			  
			  ctx.saveDisplay(filname);
			}
		}
        /**
        *   source:kjsbod.@0022.script
        */
        public void setSptFromKjsbod(IModule mod, String frmcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * create record SPT, ORD, ORE
			  */
			log.debug("{}","in kjsbod.setSptFromKjsbod ... ");
			MdaUtils.clear(this.getSpt());
			this.getSpt().setPtyinr(this.getPtyset().getCli().getInr());  // 商行/企业客户
			this.getSpt().setOprogninr(this.getPtyset().getBnk().getInr()); // 银行端业务落地机构
			if(!MdaUtils.isEmpty(this.getSmh().getInr()))
			{
			  this.getSpt().setSmhinr(this.getSmh().getInr());
			}
			if(!MdaUtils.isEmpty(this.getBusgrp().getBusinf().getOwnref()))
			{
			  this.getSpt().setOwnref( this.getBusgrp().getBusinf().getOwnref());
			}
			else
			{
			  this.getSpt().setOwnref("NOREF");
			}
			this.getSpt().setObjtyp( this.getBusgrp().getBusinf().getObjtyp());
			this.getSpt().setObjinr( this.getBusgrp().getBusinf().getObjinr());
			this.getSpt().setTrnamt( this.getBusgrp().getBusinf().getAmt());
			this.getSpt().setTrncur( this.getBusgrp().getBusinf().getCur());
			this.getSpt().setNam( this.getBusgrp().getBusinf().getClinam());
			if(MdaUtils.isEmpty(this.getBusgrp().getBusinf().getClinam()))
			{
			  this.getTrn().setNam(this.getSpt().getTrncur()+"/" + this.getSpt().getTrnamt());
			}
			else
			{
			  String clinam = this.getBusgrp().getBusinf().getClinam();
			  if(clinam.length() > 35)
			  {
			    clinam = clinam.substring(0,35);
			  }
			  this.getSpt().setNam(this.getSpt().getTrncur()+"/"+ this.getSpt().getTrnamt() +clinam);
			}
			this.getSpt().setFrm(frmcod);
			this.getSpt().setSta("T");
			this.getSpt().setScr("A");
			this.getSpt().setDattim(MdaUtils.today());
			this.getSpt().setInr(Platform.sdbCounter("spt"));
			ctx.getDaoSession().dbInsert(this.getSpt());
			log.debug("{}","SAV SPT {inr:" + this.getSpt().getInr() +",objinr:" + this.getSpt().getObjinr() + ",objtyp:"+ this.getSpt().getObjtyp() + ",smhinr:"+ this.getSpt().getSmhinr() + "}") ;
			// 保存 数据文件
			MdaUtils.clear(this.getGrpdata());
			IStream os = this.getGrpdata();
			MdaUtils.saveData(mod,os);
			String fileName = ctx.absGet(Sysmod.class).createFilename(this.getSpt().getInr(),"bak");
			MdaUtils.streamSave(os,fileName);
			// 保存ORD和ORE记录
			this.setOreOrdFromKjsbod();
			log.debug("{}","out kjsbod.setSptFromKjsbod ... ");
		}
        /**
        *   source:kjsbod.@0023.script
        */
        public void addNoticeWorkflow(com.ceb.gjjs.mda.bo.Spt spt ,String frmcod)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 注册工作流接口：可调用共用函数或者客户化实现
			IModule mod= MdaDriver.getModule(this,ctx.getRoot(),"xmlbod");
			MdaUtils.invoke(mod,"setNoticeWorkflow",spt,frmcod,"1");
		}
        /**
        *   source:kjsbod.@0024.script
        */
        public void updateAplTrnFromKjsbod(IModule mod,String[] frmlist)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			// 更新原申请业务的交易流水记录状态:此处可调用共用函数或者客户化实现
			IModule bodmod= MdaDriver.getModule(this,ctx.getRoot(),"xmlbod");
			MdaUtils.invoke(bodmod,"updateAplTrn",mod,frmlist);
		}
        /**
        *   source:kjsbod.@0025.script
        */
        public void setOreOrdFromKjsbod()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 保存ORE和ORD记录
			  */
			log.debug("{}","in kjsbod.setOreOrdFromKjsbod ... ");
			MdaUtils.invoke(ctx.getRoot(),"createOrdAndOre");
		}
        /**
        *   source:kjsbod.@0026.script
        */
        public void setNoticeWorkflow()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

		}

        public void setBusgrpHolder(ModuleHolder<Busgrp> busgrp)
        {
           this.busgrp = busgrp;
        }

        public Busgrp getBusgrp()
        {
           return this.busgrp.get();
        }

        public void setPtysetHolder(ModuleHolder<Ptyset> ptyset)
        {
           this.ptyset = ptyset;
        }

        public Ptyset getPtyset()
        {
           return this.ptyset.get();
        }

        public void setTrnHolder(ModuleHolder<Trn> trn)
        {
           this.trn = trn;
        }

        public Trn getTrn()
        {
           return this.trn.get();
        }

        public void setSmhHolder(ModuleHolder<Smh> smh)
        {
           this.smh = smh;
        }

        public Smh getSmh()
        {
           return this.smh.get();
        }

        public void setSptHolder(ModuleHolder<Spt> spt)
        {
           this.spt = spt;
        }

        public Spt getSpt()
        {
           return this.spt.get();
        }

        public void setApltrnHolder(ModuleHolder<Trn> apltrn)
        {
           this.apltrn = apltrn;
        }

        public Trn getApltrn()
        {
           return this.apltrn.get();
        }











}