package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Rmk;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 备注信息模块
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Rmkmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Rmkmod.class);

        //flg
        private String flg;

        //otext
        private String otext;

        //ntext
        private String ntext;


        @JsonIgnore
        @BDGetter
        private transient IPanel rmkp;

        @JsonIgnore
        @BDGetter
        private transient IPanel markp;

        @JsonIgnore
        @BDGetter
        private transient IPanel marksp;

        @JsonIgnore
        @BDGetter
        private transient IPanel ntextp;

        @JsonIgnore
        @BDGetter
        private transient IPanel otextp;

        @JsonIgnore
        @BDGetter
        private transient IPanel gitnext;


	    @BDGetter
		private Rmk rmk;


		public Rmkmod()
        {
            super();
            setArgument();
        }

        public Rmkmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:rmkmod.@0006.script
        */
        @Rule(target="ntext",order=100)
        public boolean ruleNtextN100(){
            IContext ctx = MdaEnv.getContext();
            
			String ntext=this.getNtext();
			if(ntext.length() > 200)
			{
			  ctx.setFieldError(this,"ntext",MdaUtils.getI18NString("rmkmod","CT000016"));
			}
			

			return true;
        }



        /**
        *   source:rmkmod.@0002.script
        */
        @Init(order=300)
        public boolean	init300(){
            IContext ctx = MdaEnv.getContext();
            
			if(ctx.absGet(Sysmod.class).sptIsLoaded("B"))
			{
			  String ordinr=ctx.absGet(Sysmod.class).getSpt().getOrdinr();
			  log.debug("{}","业务被退回，加载订单ORD信息。  ordinr =" + ordinr);
			  if(!MdaUtils.isEmpty(ordinr))
			  {
			    this.loadRemarkByOrd(ordinr);
			  }
			}

			return true;
        }


        /**
        *   source:rmkmod.@0000.script
        */
        public void createRemark(String ordinr,String trninr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *新增交易备注信息
			  */
			log.debug("{}","新订单创建交易备注信息... ordinr="+ordinr +",trninr =" + trninr);
			String txt= "" ;
			this.getRmk().setOrdinr(ordinr);
			String userName = ctx.absGet(Sysmod.class).getLoginUserName();
			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			String roleName = "企业用户";
			String channel="网银端";
			if(Platform.isFromApp())
			{
			  channel="手机银行端";
			}
			if("0".equals(ctx.absGet(Sysmod.class).getPty().getPtytyp()))
			{
			  roleName = "银行柜员";
			  channel="";
			}
			txt =roleName + userName + " " + time +" "+channel+ " 经办";
			if(!MdaUtils.isEmpty(this.getNtext()))
			{
			  txt= txt+ CR + this.getNtext();
			}
			this.getRmk().setTxt(txt);
			this.getRmk().setFlg("");
			this.getRmk().setTrninr(trninr);
			this.getRmk().setDattim(new Date());
			this.getRmk().setInr(Platform.sdbCounter("rmk"));
			ctx.getDaoSession().dbInsert(this.getRmk());
			log.info("{}","新建交易备注：inr = " + this.getRmk().getInr()+",备注内容="+txt);
		}
        /**
        *   source:rmkmod.@0001.script
        */
        public void updateRmk(String lev)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 根据操作更新交易备注信息
			  */
			log.info("{}","updateRmk... lev = "+lev);
			String channel="网银端";
			if(Platform.isFromApp())
			{
			  channel="手机银行端";
			}
			if("7".equals(lev)||"12".equals(lev)||"13".equals(lev)||"14".equals(lev)||"15".equals(lev))
			{
			  channel="";
			}
			if(!MdaUtils.isEmpty(this.getRmk().getInr()))
			{
			  String txt="";
			  if(!MdaUtils.isEmpty(this.getOtext()))
			  {
			    txt=this.getOtext()+CR;
			  }
			  log.info("{}","历史备注： "+ txt);
			  if(!MdaUtils.isEmpty(lev))
			    lev=MdaUtils.getCodetableLabel("lev",lev);
			  String time=MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm");
			  String userName = ctx.absGet(Sysmod.class).getLoginUserName();
			  txt = txt +  userName + " " + time + " "+channel+" "+ lev;  // 用户  + 操作时间 + 操作类型
			  if(!MdaUtils.isEmpty(this.getNtext()))
			  {
			    txt = txt + CR + this.getNtext();
			  }
			  log.info("{}","更新操作备注信息为： "+txt);
			  this.getRmk().setTxt(txt);
			  this.getRmk().setDattim(new Date());
			  ctx.getDaoSession().dbUpdate(this.getRmk());
			  this.setOtext(NULLSTR);
			  this.setNtext(NULLSTR);
			}
		}
        /**
        *   source:rmkmod.@0003.script
        */
        public void loadRemarkByOrd(String ordinr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 根据订单号加载交易备注信息
			  */
			this.setNtext(NULLSTR);
			this.setOtext(NULLSTR);
			MdaUtils.clear(this.getRmk());
			ctx.getDaoSession().dbRead(this.getRmk(),new Argument<String>("ordinr",ordinr));
			if(!MdaUtils.isEmpty(this.getRmk().getInr()))
			{
			  this.setOtext( this.getRmk().getTxt());  // 处理历史备注信息
			  
			  
			}
		}
        /**
        *   source:rmkmod.@0007.script
        */
        public void createDRemark(String ordinr,String trninr,String txt)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *新增单一窗口交易备注信息
			  */
			log.debug("{}","新订单创建交易备注信息... ordinr="+ordinr +",trninr =" + trninr);
			//String txt= "" ;
			this.getRmk().setOrdinr(ordinr);
			/*String userName = $\\sysmod.getLoginUserName();
			  String time = Platform.format(Platform.today(),"yyyyMMdd HH:mm");
			  String roleName = "企业用户";
			  if("0".equals($\\sysmod\\pty\\ptytyp.getValue()))
			  {
			  roleName = "银行柜员";
			  }
			  txt =roleName + userName + " " + time + " 经办";
			  */
			if(!MdaUtils.isEmpty(this.getNtext()))
			{
			  txt= txt+ CR + this.getNtext();
			}
			this.getRmk().setTxt(txt);
			this.getRmk().setFlg("");
			this.getRmk().setTrninr(trninr);
			this.getRmk().setDattim(new Date());
			this.getRmk().setInr(Platform.sdbCounter("rmk"));
			ctx.getDaoSession().dbInsert(this.getRmk());
			log.info("{}","新建交易备注：inr = " + this.getRmk().getInr()+",备注内容="+txt);
		}
        /**
        *   source:rmkmod.@0008.script
        */
        public void setRmkMseeage(String ordinr,String trninr,String gidtxt,String rvl,String oldrmk)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			MdaUtils.clear(this.getRmk());
			if("OLD".equals(oldrmk))     //如果信息为空，读取
			{
			  ctx.getDaoSession().dbRead(this.getRmk(),new Argument<String>("ordinr",ordinr));
			}
			String txt= "" ;
			String roleType="";
			if(!MdaUtils.isEmpty(this.getRmk().getTxt()))
			{
			  txt=this.getRmk().getTxt()+CR;
			}

			String userName = ctx.absGet(Sysmod.class).getLoginUserName();     //获取操作员名称
			String time = MdaUtils.format(MdaUtils.today(),"yyyyMMdd HH:mm:ss");
			if(!MdaUtils.isEmpty(rvl))
			  roleType=MdaUtils.getCodetableLabel("rvl",rvl);  //何种操作记录！
			
			txt=txt+time+",该笔业务被"+roleType+",处理人："+userName;
			if(!MdaUtils.isEmpty(gidtxt))    //退回原因
			{
			  txt=txt+",退回原因："+gidtxt;
			}
			else
			{
			  if(!MdaUtils.isEmpty(this.getNtext()))     //复核通过意见
			  {
			    txt= txt+",处理意见："+ this.getNtext();
			  }
			}
			this.getRmk().setTxt(txt);
			this.getRmk().setDattim(new Date());
			if(MdaUtils.isEmpty(this.getRmk().getInr()))    //不存在新建
			{
			  this.getRmk().setOrdinr(ordinr);
			  this.getRmk().setTrninr(trninr);
			  this.getRmk().setFlg("");
			  this.getRmk().setInr(Platform.sdbCounter("rmk"));
			  ctx.getDaoSession().dbInsert(this.getRmk());
			  log.debug("{}","insert success");
			}
			else
			{
			  ctx.getDaoSession().dbUpdate(this.getRmk());
			}
			log.info("{}","Remark successful,inr is:" + this.getRmk().getInr()+",remarks is:"+txt);
		}









}