package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.bo.Sig;
import com.ceb.gjjs.mda.bo.Trn;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Sigmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Sigmod.class);

        //签名
        private transient IControl sign = new ControlImpl("sign", "签名", this);

        //取消
        private transient IControl cancel = new ControlImpl("cancel", "取消", this);

        //flg
        private String flg;

        //批量签名
        private transient IControl signall = new ControlImpl("signall", "批量签名", this);


        @JsonIgnore
        @BDGetter
        private transient IPanel sigp;


	    @BDGetter
		private Sig sig;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Trn> trn;


		public Sigmod()
        {
            super();
            setArgument();
        }

        public Sigmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:sigmod.@0000.script
        */
        @Rule(target="sign",order=200)
        public boolean ruleSignN200(){
            IContext ctx = MdaEnv.getContext();
            
			//String=MdaUtils.getEventData();
			String ownref = this.getTrn().getOwnref();
			BigDecimal amt = this.getTrn().getReloriamt();
			String cur = this.getTrn().getReloricur();
			String signdata = ownref+","+amt+","+cur;
			log.debug("{}","soure data=["+signdata+"]");
			//光大银行签名逻辑
			//lxy 20190315
			String trans = this.getTrn().getInifrm();
			String trannam = MdaUtils.getCodetableLabel("trans",trans);
			if(MdaUtils.isEmpty(amt))
			  amt = new BigDecimal(0);
			List<String> items = new ArrayList<String>();
			items.add("count|s|总笔数|1");
			items.add("Aamt|s|总金额|"+amt);
			items.add("ownref|s|业务参号|"+ownref+",CUR|s|币种|"+cur+",amt|s|金额|"+amt);
			String utilcls = "com.brilliance.etrade.signature.SigUtils";
			String plain = (String)MdaUtils.invoke(utilcls,"getSignXML",new Object[]{trannam,items,false});

			String CN = (String)Platform.getLoginData("CN");
			String signinput = CN+";"+plain;
			String algorithm = (String)Platform.getLoginData("algorithm");
			log.info("{}","signinput :"+signinput);
			String result = (String)MdaUtils.invoke("client:","sign",signinput);
			log.info("{}","sign algorithm :"+algorithm);
			log.info("{}","result :"+result);
			if("SHA1".equals(algorithm))
			{
			  if(MdaUtils.isEmpty(result))
			  {
			    ctx.setMessage(MdaUtils.getI18NString("sigmod","CT000057"),MdaUtils.getI18NString("sigmod","CT000058"));
			    return false;
			  }
			}
			java.security.cert.X509Certificate cert = (java.security.cert.X509Certificate)Platform.getLoginData("CERT");

			Map parmap = (Map)MdaUtils.invoke(utilcls,"parseSigndata",new Object[]{result});
			Boolean verifed = (Boolean)MdaUtils.invoke(utilcls,"verify",new Object[]{cert,algorithm,parmap});
			log.info("{}","verifed :"+verifed);
			if("SM3".equals(algorithm))
			{
			  verifed = true;
			}
			/*
			  String result = (String)Platform.invoke("client:","sign",signdata);
			  if(result == ""||result == null)
			  {
			  return false;
			  }
			
			  log.debug("certsign data:=["+result+"]");
			  */
			//String result ="";
			if(verifed)
			{
			  this.getSig().setFrm(this.getTrn().getInifrm());
			  this.getSig().setUsr(MdaEnv.getLoginUser());
			  this.getSig().setAct("1");
			  this.getSig().setObjinr(this.getTrn().getInr());
			  this.getSig().setSig(result);
			  this.getSig().setCur(this.getTrn().getRelcur());
			  this.getSig().setAmt(this.getTrn().getRelamt());
			  this.getSig().setOwnref(this.getTrn().getOwnref());
			  this.getSig().setSigdate(new Date());
			  this.getSig().setObjtyp("trn");
			  this.getSig().setOrdinr(this.getTrn().getOrdinr());
			  this.getSig().setHash("***??***");
			  this.getSig().setInr(Platform.sdbCounter(this.getSig()));
			  ctx.getDaoSession().dbInsert(this.getSig());
			}
			else
			{
			  log.info("{}","******签名验证失败!******");
			  ctx.storeData("sigresult","100104");
			}
			this.setFlg(NULLSTR);
			//to fixme
			

			return true;
        }

        /**
        *   source:sigmod.@0001.script
        */
        @Rule(target="cancel",order=100)
        public boolean ruleCancelN100(){
            IContext ctx = MdaEnv.getContext();
            
			if(MdaUtils.prompt("提示","确定要取消？"))
			  return false;
			else
			{  //yes
			  log.debug("{}","<------- flg="+this.getFlg());
			  
			}

			return true;
        }







        public void setTrnHolder(ModuleHolder<Trn> trn)
        {
           this.trn = trn;
        }

        public Trn getTrn()
        {
           return this.trn.get();
        }









}