package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.global.Platform;
import com.ceb.gjjs.mda.bo.Bch;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Sqlp extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Sqlp.class);

        //sql input
        private String sql;

        //Execute sql
        private transient IControl exe = new ControlImpl("exe", "Execute sql", this);

        //logs
        private String _log;

        //Results
        private StreamGrid res;

        //runsql
        private transient IControl run = new ControlImpl("run", "runsql", this);


        @JsonIgnore
        @BDGetter
        private transient IPanel subp;

        @JsonIgnore
        @BDGetter
        private transient IPanel exep;

        @JsonIgnore
        @BDGetter
        private transient IPanel mainp;


	    @BDGetter
		private Bch bch;


		public Sqlp()
        {
            super();
            setArgument();
        }

        public Sqlp(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:sqlp.@0001.script
        */
        @Rule(target="exe",order=100)
        public boolean ruleExeN100(){
            IContext ctx = MdaEnv.getContext();
            
			///系统预留执行sql交易方法
			if(MdaUtils.isEmpty(this.getSql()))
			  return false;
			String res = "";
			String sql = this.getSql();
			res += "Executed sql:" +sql + "\r\n\r\n";
			if(!this.warning(sql))
			  return true;

			ctx.getDaoSession().dbExecuteSQL(sql);
			int err = ctx.getErrorCode();
			res += "ErrorCode:" + err + "\r\n";
			if(err != NO_ERROR)
			{
			  log.error("{}","Execute sql failed.");
			  this.set_log( "Error:\n" + err);

			}
			else
			{
			  //生成顶级表头
			  List<String> columnLst = ctx.getDaoSession().dbColumnNames();
			  List<Argument> argLst = new ArrayList<Argument>();
			  for(String column : columnLst)
			  {
			    column = column.toLowerCase();
			    Argument argItem = new Argument(column);
			    log.debug("{}","Fetch..." + column);
			    argLst.add(argItem);
			    res += column + "\t";
			  }
			  res += "\r\n\r\n";
			  Argument[] argArray = new Argument[argLst.size()];
			  argLst.toArray(argArray);
			  while(true)
			  {
			    ctx.getDaoSession().dbFetchFields(argArray);
			    err = ctx.getErrorCode();
			    if(err != NO_ERROR)
			      break;
			    for(Argument argItem : argArray)
			    {
			      res += formatDatafield(argItem.getValue()) + "\t";
			    }
			    res += "\r\n";
			  }
			  this.set_log( res);
			  
			  log.debug("{}","Res:" + res);
			}
			ctx.getDaoSession().dbCloseCursor();
			

			return true;
        }

        /**
        *   source:sqlp.@0004.script
        */
        @Rule(target="run",order=100)
        public boolean ruleRunN100(){
            IContext ctx = MdaEnv.getContext();
            
			/*
			  #! 执行res中指令,获取执行结果及执行结果result是否成功标识flg
			  */
			String res = this.getSql();
			String line="";
			this.set_log(NULLSTR);
			//  if(Platform.execLocalScript(res))
			Map map = Platform.execLocalScriptwithLog(res);
			boolean flg = Boolean.parseBoolean(map.get("flg").toString());
			log.info("{}","flg ="+flg);
			List result = (ArrayList<String[]>)map.get("result");
			List err= (ArrayList<String[]>)map.get("error");

			for(int i=0;i<result.size();i++)
			{
			  line += "\n"+result.get(i);
			}
			line += "\n\n\nError:";
			for(int i=0;i<err.size();i++)
			{
			  line += "\n"+err.get(i);
			}

			if(flg)
			{
			  ctx.setMessage(MdaUtils.getI18NString("sqlp","CT000021"),MdaUtils.getI18NString("sqlp","CT000022"));
			}
			else
			{
			  ctx.setMessage(MdaUtils.getI18NString("sqlp","CT000023"),MdaUtils.getI18NString("sqlp","CT000024"));
			}

			this.set_log(line);
			

			return true;
        }




        /**
        *   source:sqlp.@0000.script
        */
        public String formatDatafield(Object obj)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//将字段转化为文本形式
			if(null == obj)
			  return "";
			boolean isZero = false;
			//转化金额
			if(obj instanceof BigDecimal)
			{
			  BigDecimal num = MdaUtils.parseDecimal(obj);
			  return num.toPlainString();
			}
			//转化日期
			if(obj instanceof Date)
			{
			  return MdaUtils.format(obj,"yyyyMMdd");
			}
			return obj.toString();
		}
        /**
        *   source:sqlp.@0002.script
        */
        public boolean warning(String sql)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String sqlCmd = sql.toUpperCase();
			if(sqlCmd.contains("INSERT")
			  ||sqlCmd.contains("UPDATE")
			||sqlCmd.contains("DELETE")
			||sqlCmd.contains("DROP")
			||sqlCmd.contains("ALTER"))
			{
			  if((!"etrade".equals(ctx.absGet(Sysmod.class).getUsr().getLgnnam()))||(!"ceb".equals(ctx.absGet(Sysmod.class).getUsr().getLgnnam())))
			  {
			    ctx.setMessage(MdaUtils.getI18NString("sqlp","CT000005"),MdaUtils.getI18NString("sqlp","CT000006"));
			    return false;
			  }
			  if(!MdaUtils.prompt(MdaUtils.getI18NString("sqlp","CT000007"),MdaUtils.getI18NString("sqlp","CT000008")))
			  {
			    return true;
			  }
			  return false;
			}
			return true;
		}













}