package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* STL系统公共报文头
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Stlhad extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Stlhad.class);

        //数据接收
        private String ftytoo;

        //数据来源
        private String ftysuc;

        //批次号
        private String ftynum;

        //报文类型
        private String msgtyp;

        //业务类型
        private String bustyp;

        //申请类型
        private String ftytyp;

        //业务创建日期
        private Date credat;

        //关联系统流水号
        private String resnum;

        //业务编号
        private String reference;

        //落地机构号
        private String ownextkey;

        //核心客户号
        private String client;

        //影像批次号
        private String imgid;



		@Module(getter = false, setter = false)
        private transient ModuleHolder<Ptyset> ptyset;

		@Module(getter = false, setter = false)
        private transient ModuleHolder<Busgrp> busgrp;


		public Stlhad()
        {
            super();
            setArgument();
        }

        public Stlhad(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }




        /**
        *   source:stlhad.@0001.script
        */
        public void parseHeader(Map<String,Object> data, Map<String,Object> resMsg)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 初始化报文头
			  */
			log.debug("{}","in stlhad.parseHeader ... ");
			// 1.解析报文头信息
			this.setFtytoo((String)data.get("ftytoo"));
			this.setFtysuc((String)data.get("ftysuc"));
			this.setFtynum((String)data.get("ftynum"));
			this.setMsgtyp((String)data.get("msgtyp"));
			this.setBustyp((String)data.get("bustyp"));
			this.setFtytyp((String)data.get("ftytyp"));
			this.setResnum((String)data.get("resnum"));
			this.setReference((String)data.get("reference"));
			this.setOwnextkey((String)data.get("ownextkey"));
			this.setClient((String)data.get("client"));
			this.setImgid((String)data.get("imgid"));
			this.setCredat((Date)data.get("credat"));
			// 设置客户编号和落地机构
			log.debug("{}","bchcod=" + this.getOwnextkey());
			this.getPtyset().setBnkByBchcod(this.getOwnextkey());
			this.getPtyset().setCliByClientID(this.getClient());
			setBusinfFromStlhad();

		}
        /**
        *   source:stlhad.@0002.script
        */
        public String  getMessageType()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 报文头模块接口，返回报文的报文类型/报文编号
			  */
			String msgTyp = "";
			if(!MdaUtils.isEmpty(this.getMsgtyp())&& !MdaUtils.isEmpty(this.getFtytyp()))
			{
			  msgTyp = this.getMsgtyp()+ "_" + this.getFtytyp();
			}
			return msgTyp;
		}
        /**
        *   source:stlhad.@0003.script
        */
        public void setBusinfFromStlhad()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","in stlhad.setBusinfFromStlhad... ");
			MdaUtils.clear(this.getBusgrp().getBusinf());
			this.getBusgrp().getBusinf().setRef(this.getReference());
			this.getBusgrp().getBusinf().setStlref(this.getReference());
			this.getBusgrp().getBusinf().setImgref( this.getImgid());
			if(!MdaUtils.isEmpty(this.getCredat()))
			{
			  this.getBusgrp().getBusinf().setCredat(this.getCredat());
			}
			else
			{
			  this.getBusgrp().getBusinf().setCredat(MdaUtils.today());
			}
			this.getBusgrp().getBusinf().setBnkinr( this.getPtyset().getBnk().getInr());
			this.getBusgrp().getBusinf().setBnknam( this.getPtyset().getBnk().getNam());
			this.getBusgrp().getBusinf().setBchcod( this.getPtyset().getBnk().getCid());
			this.getBusgrp().getBusinf().setBnketyinr( this.getPtyset().getBnk().getEtyinr());
			this.getBusgrp().getBusinf().setBnketginr(  this.getPtyset().getPtyEtginr(this.getBusgrp().getBusinf().getBnketyinr()));
			this.getBusgrp().getBusinf().setCliinr( this.getPtyset().getCli().getInr());
			this.getBusgrp().getBusinf().setClinam( this.getPtyset().getCli().getNam());
			this.getBusgrp().getBusinf().setClietyinr( this.getPtyset().getCli().getEtyinr());
			this.getBusgrp().getBusinf().setClientid(  this.getClient());
			this.getBusgrp().getBusinf().setClietginr(  this.getPtyset().getPtyEtginr(this.getBusgrp().getBusinf().getClietyinr()));
			this.getBusgrp().getBusinf().setCl2inr( this.getPtyset().getBnk2cl().getInr());
			this.getBusgrp().getBusinf().setCl2nam( this.getPtyset().getBnk2cl().getNam());
			this.getBusgrp().getBusinf().setResnum( this.getResnum());

		}

        public void setPtysetHolder(ModuleHolder<Ptyset> ptyset)
        {
           this.ptyset = ptyset;
        }

        public Ptyset getPtyset()
        {
           return this.ptyset.get();
        }

        public void setBusgrpHolder(ModuleHolder<Busgrp> busgrp)
        {
           this.busgrp = busgrp;
        }

        public Busgrp getBusgrp()
        {
           return this.busgrp.get();
        }

























}