package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Stpmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Stpmod.class);

        //面板列表
        private List panellst;

        //当前索引
        private int curidx;

        //下一步
        private transient IControl next = new ControlImpl("next", "下一步", this);

        //上一步
        private transient IControl last = new ControlImpl("last", "上一步", this);

        //步骤列表
        private List pages;

        //步骤提示
        private StreamGrid steps;

        //跳到制定位置
        private transient IControl gostep = new ControlImpl("gostep", "跳到制定位置", this);

        //事件状态显示URL
        private String evtlst;

        //事件状态显示列表JSP
        private String evtlst2;

        //步骤跳转引子
        private transient IControl sgostep = new ControlImpl("sgostep", "步骤跳转引子", this);

        //面板索引
        private int panelidx;

        //保存
        private transient IControl save = new ControlImpl("save", "保存", this);


        @JsonIgnore
        @BDGetter
        private transient IPanel nextp;

        @JsonIgnore
        @BDGetter
        private transient IPanel lastp;

        @JsonIgnore
        @BDGetter
        private transient IPanel allstp;

        @JsonIgnore
        @BDGetter
        private transient IPanel stepsp;

        @JsonIgnore
        @BDGetter
        private transient IPanel evtlstp;

        @JsonIgnore
        @BDGetter
        private transient IPanel ztbstp;



		public Stpmod()
        {
            super();
            setArgument();
        }

        public Stpmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }

        /**
        *   source:stpmod.@0004.script
        */
        @Rule(target="next",order=100)
        public boolean ruleNextN100(){
            IContext ctx = MdaEnv.getContext();
            
			nextStep();
			setStepBtnSta();

			return true;
        }

        /**
        *   source:stpmod.@0005.script
        */
        @Rule(target="last",order=100)
        public boolean ruleLastN100(){
            IContext ctx = MdaEnv.getContext();
            
			lastStep();
			setStepBtnSta();

			return true;
        }

        /**
        *   source:stpmod.@0012.script
        */
        @Rule(target="gostep",order=100)
        public boolean ruleGostepN100(){
            IContext ctx = MdaEnv.getContext();
            

			String stepIndex = (String)MdaUtils.getEventData(); //此所以是面板索引
			int stepIdx = MdaUtils.parseInt(stepIndex);
			goTo(stepIdx);
			setStepBtnSta();

			return true;
        }

        /**
        *   source:stpmod.@0015.script
        */
        @Rule(target="sgostep",order=100)
        public boolean ruleSgostepN100(){
            IContext ctx = MdaEnv.getContext();
            
			IAttribute att =  MdaUtils.getEventTarget();
			String stepIndex = (String)att.getAttribute("stepIndex");

			ctx.postRule(this,"gostep");

			return true;
        }



        /**
        *   source:stpmod.@0011.script
        */
        @Init(order=100)
        public boolean	init100(){
            IContext ctx = MdaEnv.getContext();
            
			//初始化stopmod后，初始化上下步状态
			//Platform.disable($last);
			setStepBtnSta();
			this.setEvtlst("evtlst.jsp");
			this.setEvtlst2(this.getEvtlst()+"?rtime="+new Date().getTime());


			return true;
        }


        /**
        *   source:stpmod.@0000.script
        */
        public void storePanel(IPanel... panels)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  接收Panel函数
			  */
			List pnlst = this.getPanellst();
			for(IPanel panel : panels)
			{
			  pnlst.add(panel);
			}
		}
        /**
        *   source:stpmod.@0001.script
        */
        public boolean goTo(int idx)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			log.debug("{}","goto "+idx);
			List<IPanel> list = this.getPanellst();
			List<String[]> pagelist = this.getPages();
			if(idx < 0  || idx >= pagelist.size() )
			  return false;
			int pIdx = MdaUtils.parseInt(pagelist.get(idx)[0]);
			IPanel mp = list.get(pIdx);
			
			this.setCuridx( idx);
			this.setPanelidx( pIdx);
			calcSteps();
			return true;  //切换成功
					}
        /**
        *   source:stpmod.@0002.script
        */
        public boolean nextStep()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int curIdx = this.getCuridx();
			curIdx++;
			if(!goTo(curIdx))
			  return false;
			List<String[]> pagelist = this.getPages();

			return curIdx < pagelist.size() - 1 ;
					}
        /**
        *   source:stpmod.@0003.script
        */
        public boolean lastStep()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int curIdx = this.getCuridx();
			curIdx--;
			if(!goTo(curIdx))
			  return false;
			return curIdx!=0;
		}
        /**
        *   source:stpmod.@0006.script
        */
        public void resetPanel(IPanel...  panels)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<IPanel> pnlst = this.getPanellst();
			pnlst.clear();
			storePanel(panels);
		}
        /**
        *   source:stpmod.@0007.script
        */
        public void addPanel(IPanel p)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<IPanel> pnlst = this.getPanellst();
			pnlst.add(p);
		}
        /**
        *   source:stpmod.@0008.script
        */
        public void removePanel(int idx)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<IPanel> pnlst = this.getPanellst();
			pnlst.remove(idx);
		}
        /**
        *   source:stpmod.@0009.script
        */
        public void setPages(String stepstr)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *页码步骤控制数
			  *例如：1:签约声明;2:开证申请;3:打印
			  */
			List<String[]> steps = this.getPages();
			steps.clear();
			String[] items =  stepstr.split(";");
			for(String item:items)
			{
			  steps.add(item.split(":"));
			}
		}
        /**
        *   source:stpmod.@0010.script
        */
        public void calcSteps()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			List<String[]> pages = this.getPages();
			StreamGrid grid = this.getSteps();
			grid.clear();
			/*
			  int width= 150;
			  AttributeValue head = new AttributeValue("");
			  Platform.setViewType(head,VIEW_LABEL,width);
			  Platform.setViewStyle(head,null,"stepsHeader");
			  grid.setHeaders(new AttributeValue[]{head});
			  int curIdx = $curidx;
			  for(int i=0;i<pages.size();i++)
			  {
			  String item[] = pages.get(i);
			  AttributeValue att = new AttributeValue(item[1]);
			  att.setAttribute("stepIndex",item[0]);
			  IValue[] arr = new IValue[]{att};
			  Platform.setViewType(att,VIEW_BUTTON,width);
			
			  if(curIdx == i)
			  Platform.setViewStyle(att,null,"stepBtn  stepBtnSelected");
			  else if(curIdx < i)
			  {
			  Platform.setViewStyle(att,null,"stepBtn stepBtnOver");
			  Platform.addEventRule(att,onClick,$gostep,100);
			  }
			  else
			  {
			  Platform.addEventRule(att,onClick,$gostep,100);
			  Platform.setViewStyle(att,null,"stepBtn");
			  }
			  grid.add(arr);
			  }*/
			int curIdx = this.getCuridx();
			int width= 130;
			IValue[] arr = new IValue[pages.size()];
			AttributeValue[] arrHeader =  new AttributeValue[pages.size()];
			for(int i=0;i<pages.size();i++)
			{
			  String item[] = pages.get(i);
			  AttributeValue att = new AttributeValue(item[1]);
			  att.setAttribute("stepIndex",String.valueOf(i)); //存入page Index
			  arr[i]=att;

			  

			  //
			  AttributeValue att2 = new AttributeValue("");
			  
			  arrHeader[i]=att2;
			  String cssClazz = "stepBtn ";
			  if(curIdx == i)   //当前步骤
			  cssClazz += " stepBtnSelected";
			  else if(curIdx < i)  //未前进的步骤
			  {

			    Platform.addEventRule(att,onClick,this.getSgostep(),100);
			  }
			  else  //已过步骤
			  {
			    Platform.addEventRule(att,onClick,this.getSgostep(),100);
			    cssClazz+=" stepBtnOver";

			  }
			  if(i == pages.size() - 1 )
			    cssClazz+=" stepLstBtn";
			  
			}

			grid.add(arr);
			grid.setHeaders(arrHeader);
			
		}
        /**
        *   source:stpmod.@0013.script
        */
        public void setStepBtnSta()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			int curIdx = this.getCuridx();
			if(curIdx > 0)
			{
			  
			  
			}
			else
			{
			  
			  
			}
			int endIdx = this.getPages().size() - 1;
			if(curIdx < endIdx)
			{
			  
			  
			}
			else
			{
			  
			  
			}
		}
        /**
        *   source:stpmod.@0014.script
        */
        public void refreshEvtLst(List data,int limit)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *  data:List<Map>
			  数据键值示例：[
			  {time:"16:52:10",date:"2018-6-12",stpnam:"经办",opusr:"富凯",rmk:"提交一笔信用证开立"}
			  ]
			  * limit 表示默认显示多少条，界面上可以点击“加载更多”，展开数据
			  */
			Platform.writeToSession("evtlst",data);
			this.setEvtlst2(this.getEvtlst()+"?rtime="+new Date().getTime()+"&limit="+limit);
			
		}
        /**
        *   source:stpmod.@0016.script
        */
        public void refreshEvtLst(List data)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			refreshEvtLst( data,3);//默认显示3条
					}
        /**
        *   source:stpmod.@0017.script
        */
        public int getPanelIndex(int idx)
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			//通过Page Index 计算对应的 PanelIndex
			List<IPanel> list = this.getPanellst();
			List<String[]> pagelist = this.getPages();
			if(idx < 0  || idx >= pagelist.size() )
			  return -1;
			int pIdx = MdaUtils.parseInt(pagelist.get(idx)[0]);
			return pIdx;
		}
        /**
        *   source:stpmod.@0018.script
        */
        public IPanel[] getAllPanelsName()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  *获得当前显示步骤条所对应的所有面板
			  */
			log.debug("{}","执行stpmod模块下getAllPanelsName函数");
			List<String[]> steps = this.getPages();
			List<IPanel> pnlst = this.getPanellst();
			IPanel[] panels=new IPanel[steps.size()];
			//保存这几个界面的快照
			for(int i=0;i < steps.size();i++)
			{
			  int index=MdaUtils.parseInt(steps.get(i)[0]);
			  panels[i]=pnlst.get(index);
			}
			log.debug("{}","steps.size()="+steps.size());
			return panels;
		}

























}