package com.ceb.gjjs.mda.manager.module;

import java.util.*;
import java.math.BigDecimal;
import com.brilliance.mda.runtime.mda.*;
import com.brilliance.mda.runtime.mda.impl.*;
import com.brilliance.mda.runtime.annotation.*;
import com.brilliance.mda.runtime.mda.driver.*;
import static com.brilliance.mda.runtime.mda.Constants.*;
import com.brilliance.mda.runtime.mda.util.*;
import com.fasterxml.jackson.annotation.*;
import java.util.regex.*;
import lombok.Getter;
import lombok.Setter;
import com.ceb.gjjs.mda.global.Platform;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
* 
*/
@JsonIgnoreProperties(ignoreUnknown = true)
@Getter
@Setter
public class Xmlmod extends AbstractModule{
		private static Logger log = LoggerFactory.getLogger(Xmlmod.class);

        //目标系统编号
        private String destsys;




		public Xmlmod()
        {
            super();
            setArgument();
        }

        public Xmlmod(String name,IModule parent)
        {
            super(name,parent);
            setArgument();
        }

        public void setArgument()
        {
        }




        /**
        *   source:xmlmod.@0001.script
        */
        public Map getXmlHeader()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/**
			  * 组装生成XML文件
			  */
			log.debug("{}"," in xmlmod.getXmlHeaderMap ...") ;
			Map<String,Object> header = null ;
			String destSys = getDestSystemNumber();
			if(MdaUtils.isEmpty(destSys))
			{
			  log.error("{}","未指定目标系统编号");
			  return  header ;
			}
			if("z00001".equalsIgnoreCase(destSys))
			{
			  header =  this.getSTLXmlHeader();
			}
			else if("z00074".equalsIgnoreCase(destSys))
			{
			  header=  this.getCPSSXmlHeader();
			}
			else
			{
			  log.error("{}","传入的目标系统不确定");
			  header = null;
			}
			return header;
		}
        /**
        *   source:xmlmod.@0002.script
        */
        public Map getSTLXmlHeader()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 生成STL系统XML报文头
			  */
			Map<String,Object> head= new HashMap<String,Object>();
			String objtyp =  this.getSTLBustyp();
			String trninr = (String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\trn\\inr")).getValue();
			String ownextkey = (String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\trn\\bchcod")).getValue();
			String clientID = (String) (MdaDriver.getDatafield(ctx.getRoot(),"sysmod\\pty\\cid")).getValue();
			String imgID =   (String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\itfmod\\imgmod\\img\\guid")).getValue();
			String ownref = (String) (MdaDriver.getDatafield(ctx.getRoot(),"mtabut\\rec\\ownref")).getValue();

			//String bakref = (String) (Platform.getDatafield($\\,"trnmod\\\\trn\\\\bakref")).getValue();//国结退回参号
			
			String trnnam = ctx.getTransName();
			if(MdaUtils.isEmpty(objtyp))
			{
			  objtyp =(String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\trn\\objtyp")).getValue();
			}
			if(MdaUtils.isEmpty(objtyp))
			{
			  log.error("{}","业务类型字段为空");
			}
			head.put("FTYTOO","Z00001");               //数据接收
			head.put("FTYSUC","Z00238");				       //数据来源
			head.put("FTYNUM", trninr);                //系统唯一编号
			head.put("MSGTYP", this.getSTLMsgtyp());  //报文类型
			head.put("BUSTYP",objtyp.substring(0,2).toUpperCase());  //业务类型
			head.put("FTYTYP",this.getSTLFtytyp());   //申请类型
			head.put("CREDAT", MdaUtils.format(MdaUtils.today(),"yyyy-MM-dd"));      //业务创建日期
			head.put("RESNUM","");                  //操作员
			head.put("REFERENCE",ownref);              //业务编号
			head.put("OWNEXTKEY",ownextkey);           //落地机构号
			head.put("CLIENT",clientID);               //核心客户号
			head.put("IMGID", imgID);                  //影像批次号
			
			//head.put("STLOWNREF",bakref);              //国结退回传入参号
			
			return head;
		}
        /**
        *   source:xmlmod.@0003.script
        */
        public Map getCPSSXmlHeader()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			/*
			  * 生成跨境支付清算系统XML报文头
			  */
			log.debug("{}","in xmlmod.getCpssXmlHeader ... ");
			Map<String,Object> header = new HashMap<String,Object>();
			String jkbh = "";          // 接口编号
			String bchcod = "08101" ;  // 机构信息  - 默认在 08101
			String trninr = "" ;       // 业务流水
			String dqdh =""; 					 // 地区代号
			String jgdh = "" ;         // 机构代号
			String bwbz = "STD" ;      // 报文标准
			String qtjylsbh = "" ;     // 前台交易流水号： 前台系统编号 (Z00238)+前台日期(8位)+LSH +机构代号+ 交易流水序号qtjylsxh（16位）
			bchcod =(String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\bchcod")).getValue();
			trninr =(String) (MdaDriver.getDatafield(ctx.getRoot(),"trnmod\\trn\\inr")).getValue();
			jkbh = MdaUtils.getCodetableLabel("xmljkbh",ctx.getTransName());
			if(MdaUtils.isEmpty(jkbh))
			{
			  log.error("{}","获取接口编号失败") ;
			  return header ;
			}
			if(MdaUtils.isEmpty(trninr))
			{
			  // 非业务交易报文头中的流水号临时产生
			  trninr =  MdaUtils.format(ctx.getDaoSession().dbCounter("LSH"+MdaUtils.format(MdaUtils.today(),"yyMMdd")),"00000000");
			}
			qtjylsbh = "Z00238" + MdaUtils.format(MdaUtils.today(),"yyyyMMdd") + "LSH" + bchcod + trninr ;
			header.put("CROOT.MsgHead.DQDH",bchcod.substring(0,2));
			header.put("CROOT.MsgHead.JGDH",bchcod.substring(2));
			header.put("CROOT.MsgHead.BWBZ",bwbz);
			header.put("CROOT.MsgHead.JKBH",jkbh);
			header.put("CROOT.MsgHead.QTJYLSBH",qtjylsbh);
			header.put("DROOT.MsgHead.FBRQ",MdaUtils.today());
			log.debug("{}","out  xmlmod.getCpssXmlHeader ....  ");
			return header;
		}
        /**
        *   source:xmlmod.@0005.script
        */
        public String getSTLBustyp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

			String frm =ctx.getTransName();
			String bustyp = "" ;
			/*
			  if(frm.equals("brtsnd") || frm.equals("litame") )
			  {
			  String stlref =(String) (Platform.getDatafield($\\,"mtabut\\\\rec\\\\stlref")).getValue();
			  if(!Platform.isEmpty(stlref) )
			  {
			  frm =  frm + stlref.substring(5,7);
			  }
			  }
			  */
			bustyp = MdaUtils.getCodetableLabel("stlbustyp",frm);
			return bustyp;
		}
        /**
        *   source:xmlmod.@0006.script
        */
        public String getSTLFtytyp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String frm =ctx.getTransName();
			String ftytyp="";
			String oprtyp="";
			if(!frm.equals("brtsnd")&&!frm.equals("bctacp")&&!frm.equals("bdtsnd")&& !frm.equals("bdtdsn"))
			{
			  ftytyp = MdaUtils.getCodetableLabel("ftytyp",frm);
			}
			else
			{
			  oprtyp = (MdaDriver.getDatafield(ctx.getRoot(),"afdgrp\\rec\\oprtyp")).getValue().toString();
			  ftytyp = MdaUtils.getCodetableLabel("ftytyp",frm+oprtyp);
			}
			return ftytyp;
		}
        /**
        *   source:xmlmod.@0007.script
        */
        public String getDestSystemNumber()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);
			String destSys = "" ;
			if(MdaUtils.isEmpty(this.getDestsys()))
			{
			  String bustyp = ctx.getTransName().substring(0,2);
			  if("-rp-er-".indexOf(bustyp)>0)
			  {
			    this.setDestsys( "Z00074" );
			  }
			  else
			  {
			    // todo 此处暂时按照该方式取值，可优化
			    this.setDestsys( "Z00001");
			  }
			}
			return this.getDestsys();

		}
        /**
        *   source:xmlmod.@0011.script
        */
        public String getSTLMsgtyp()
		{
			//取得上下文
			IContext ctx = MdaEnv.getContext();
			ctx.setErrorCode(NO_ERROR);

			return "";
		}



}