package com.ceb.gjjs.mda.web;

import com.brilliance.mda.runtime.mda.IAuthInfo;
import com.brilliance.mda.runtime.mda.IContext;
import com.brilliance.mda.runtime.mda.driver.MdaEnv;
import com.brilliance.mda.runtime.mda.util.Systems;
import com.brilliance.mda.support.cache.ICache;
import com.brilliance.mda.support.td.BDAuthInfo;
import com.ceb.gjjs.mda.bo.Usr;
import com.ceb.gjjs.mda.dao.PtyMapper;
import com.ceb.gjjs.mda.dao.UsrMapper;
import com.ceb.gjjs.mda.util.LoginConstants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;

import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.ext.Provider;
import java.text.SimpleDateFormat;
import java.util.*;

import static com.brilliance.mda.runtime.mda.Constants.tdContextLASTUSERACTIONTIME;

/**
 * @Description
 * @Author s_guodong
 * @Date 2023/6/21
 */
@Provider
public class AuthorizationRequestFilter implements ContainerRequestFilter {

    @Qualifier(ICache.CTX_CACHE)
    @Autowired
    private ICache<String, IContext> contextICache;

    @Qualifier(ICache.AUTH_CACHE)
    @Autowired
    private ICache<String, IAuthInfo> authInfoICache;

    @Autowired
    private UsrMapper usrMapper;

    @Autowired
    private PtyMapper ptyMapper;

    /****
     *
     * @param request
     * 这里可以获取网银传递的uid、cid、ocid等各种信息
     */
    @Override
    public void filter(ContainerRequestContext request) {
        //String logName = request.getHeaderString("userId");

        //客户核心编号
        String cid = request.getHeaderString(LoginConstants.cid);
        //逻辑修改补充在这里.....
        Map<String,Object> argsMap = new HashMap<>();
        argsMap.put("sql","select * from usr where cid='"+cid+"'");
        List<Usr> usrList = usrMapper.dyncRead(argsMap);
        if(usrList.size()==0)
        {
            return ;
        }
        String userId=usrList.get(0).getInr();
        //网银编号
        String ncid = request.getHeaderString(LoginConstants.ncid);
        String CN = request.getHeaderString(LoginConstants.CN);
        String needSign = request.getHeaderString(LoginConstants.needSign);
        String __terminalType = request.getHeaderString(LoginConstants.__terminalType);
        String algorithm = request.getHeaderString(LoginConstants.algorithm);
        String CERT = request.getHeaderString(LoginConstants.CERT);

        //errorText
        String errorText=request.getHeaderString(LoginConstants.errorText);
        Map<String,Object> headMap=new HashMap<>();
        headMap.put(LoginConstants.usrinr,userId);
        headMap.put(LoginConstants.ncid,ncid);
        headMap.put(LoginConstants.errorText,errorText);
        headMap.put(LoginConstants.CN,CN);
        headMap.put(LoginConstants.needSign,needSign);
        headMap.put(LoginConstants.__terminalType,__terminalType);
        headMap.put(LoginConstants.algorithm,algorithm);
        headMap.put(LoginConstants.CERT,CERT);

        String token = getTokenKey(request);
        //目前采用自动登录模式认证
        getOrCreateAuthInfo(token, headMap);
        //设置一些系统参数
        String actionTime = new SimpleDateFormat("yyyyMMddHHmmssSSS").format(new Date());
        Systems.setContext(tdContextLASTUSERACTIONTIME, actionTime);

    }


    private String getTokenKey(ContainerRequestContext request) {
        /*String token = request.getHeaderString(LoginConstants.token);
        if (token == null || "undefined".equals(token))
            token = "test";
        return token;*/
        return UUID.randomUUID().toString();
    }


    private IAuthInfo getOrCreateAuthInfo(String tokenKey, Map<String,Object> headMap) {
        IAuthInfo authInfo = authInfoICache.get(tokenKey);
        if (authInfo == null) {
            synchronized (authInfoICache) {
                authInfo = authInfoICache.get(tokenKey);
                if (authInfo == null) {
                    String usrinr=headMap.get(LoginConstants.usrinr)==null?"":headMap.get(LoginConstants.usrinr).toString();
                    String ptyinr=headMap.get(LoginConstants.ptyinr)==null?"":headMap.get(LoginConstants.ncid).toString();
                    String errorText=headMap.get(LoginConstants.errorText)==null?"":headMap.get(LoginConstants.errorText).toString();
                    String CN=headMap.get(LoginConstants.CN)==null?"":headMap.get(LoginConstants.CN).toString();
                    String needSign=headMap.get(LoginConstants.needSign)==null?"":headMap.get(LoginConstants.needSign).toString();
                    String __terminalType=headMap.get(LoginConstants.__terminalType)==null?"":headMap.get(LoginConstants.__terminalType).toString();
                    String algorithm=headMap.get(LoginConstants.algorithm)==null?"":headMap.get(LoginConstants.algorithm).toString();
                    String CERT=headMap.get(LoginConstants.CERT)==null?"":headMap.get(LoginConstants.CERT).toString();
                    BDAuthInfo tdAuthInfo = new BDAuthInfo(usrinr,ptyinr,errorText,__terminalType,needSign,CN,algorithm,CERT);
                    authInfo = tdAuthInfo;
                    authInfoICache.store(tokenKey, authInfo);
                    //构造authInfo，本该在登录里面做
                    //  initAuthInfo(userId,authInfo);
                }
            }
        }
        MdaEnv.setAuthInfo(authInfo);
        return authInfo;
    }

}
